(* ::Package:: *)

(* This file contains the Pade approximants for the form factor for gg -> H *)
(* at two and three loops as determined in                                  *)
(* J. Davies, R. Groeber, A. Maier, T. Rauh and M. Steinhauser              *)
(* Top quark mass dependence of the Higgs-gluon form factor at three loops  *)

(* ------------------------------------------------------------ *)
(* ***
The following functions, which are defined in this file,
can be used to reproduce the plots in the paper.

Notation for Pade results:
41: information up to z^4 from z->0 and up to (1-z)^1 from threshold is used
61: information up to z^6 from z->0 and up to (1-z)^1 from threshold is used
43: information up to z^4 from z->0 and up to (1-z)^3 from threshold is used
63: information up to z^6 from z->0 and up to (1-z)^3 from threshold is used

z>0:

F_\triangle^{(1),fin}(z):   Ftri2Loop41[z_], Ftri2Loop43[z_], Ftri2Loop61[z_], Ftri2Loop63[z_]
                            Ftri2Loop (exact result from hep-ph/0509189)

F_\triangle^{(2),fin}(z):   Ftri3Loop41[z_], Ftri3Loop61[z_]
F_\triangle^{(2,0),fin}(z): Ftri3LoopNl041[z_], Ftri3LoopNl061[z_]
F_\triangle^{(2,1),fin}(z): Ftri3LoopNl141[z_], Ftri3LoopNl161[z_]

z<0:

F_\triangle^{(2),fin}(z): Ftri3Loop41Spacelike[z_], Ftri3Loop61Spacelike[z_]
*** *)
(* ------------------------------------------------------------ *)


(* For convenience we provide the two-loop form factor from hep-ph/0509189 *)
HPLNum[{1,0,-1,0},t_?NumericQ] := NIntegrate[(2PolyLog[3,-x]-PolyLog[2,-x]Log[x])/(1-x),{x,0,t}];
Ftri2Loop[z_?NumericQ] := 2/3 ((t (1+t)^2)/(1-t)^4 (72HPLNum[{1,0,-1,0},t]+6Log[1-t]Log[t]^3-36Zeta[2]PolyLog[2,t]-36Zeta[2]Log[1-t]Log[t]-108Zeta[3]Log[1-t]-64PolyLog[3,-t]+32PolyLog[2,-t]Log[t]-8Zeta[2]Log[t])-(36t(5+5t+11t^2+11t^3))/(1-t)^5 PolyLog[4,-t]-(36t(5+5t+7t^2+7t^3))/(1-t)^5 PolyLog[4,t]+(4t(1+t)(23+41t^2))/(1-t)^5 (PolyLog[3,t]+PolyLog[3,-t])Log[t]-(16t(1+t+t^2+t^3))/(1-t)^5 PolyLog[2,-t]Log[t]^2-(2t(5+5t+23t^2+23t^3))/(1-t)^5 PolyLog[2,t]Log[t]^2+(t(5+5t-13t^2-13t^3))/(24(1-t)^5) Log[t]^4+(t(1+t-17t^2-17t^3))/(1-t)^5 Zeta[2]Log[t]^2+(2t(11+11t-43t^2-43t^3))/(1-t)^5 Zeta[3]Log[t]+(36t(1+t-3t^2-3t^3))/(1-t)^5 Zeta[4]-(2t(55+82t+55t^2))/(1-t)^4 PolyLog[3,t]+(2t(51+74t+51t^2))/(1-t)^4 PolyLog[2,t]Log[t]+(t(47+66t+47t^2))/(1-t)^4 Log[1-t]Log[t]^2+(t(6+59t+58t^2+33t^3))/(3(1-t)^5) Log[t]^3+(2t(31+34t+31t^2))/(1-t)^4 Zeta[3]+(3t(3+22t+3t^2))/(2(1-t)^4) Log[t]^2-(24t(1+t))/(1-t)^3 Log[t]-(94t)/(1-t)^2)/.{t->(Sqrt[1-1/z]-1)/(Sqrt[1-1/z]+1)};


(* Auxiliary functions *)
(* Conformal transformation *)
w[z_] = (1-Sqrt[1-z])/(1+Sqrt[1-z]);
(* Threshold subtraction functions *)
pi1full[z_]=3/(16Pi^2)*(5/6+13/(6z)-(1-z)(3+2z)/z g[z]+(1-z)(1-16z)/(6z) g[z]^2 - (1+2z)/(6z) (iii[z]/z+2z*(1-z)D[iii[z]/z,z]));
g[z_]= 1/(2z)*Log[u]/Sqrt[1-1/z]/.u ->((1-1/z)^(1/2)-1)/((1-1/z)^(1/2)+1);
iii[z_]=6(Zeta[3]+4 PolyLog[3,-u]+2 PolyLog[3,u])-8(2 PolyLog[2,-u]+PolyLog[2,u])Log[u]-2(2 Log[1+u]+Log[1-u])Log[u]^2 /.u ->((1-1/z)^(1/2)-1)/((1-1/z)^(1/2)+1);
THRSub[2,1] = -((16 pi1 (1-z))/(3 z));
THRSub[2,2] = (256 pi1^2 (1-z))/(9 z);
THRSub[3,1] = -((32 g[z] pi1 (1-z)^2)/(3 \[Pi] z));
THRSub[4,1] = -((16 pi1 (1-z)^2)/(3 z^2))+328/(81 \[Pi]^2 z);
THRSub[5,1] = -((32 g[z] pi1 (1-z)^3)/(3 \[Pi] z^2))+656/(81 \[Pi]^3 z);
THRSub[6,1] = -((16 pi1 (1-z)^3)/(3 z^3))-(-(328/(81 \[Pi]^2))+(6404 z)/(675 \[Pi]^2))/z^2;


(* Pade approximants for the timelike region at two loops *)
(* In the construction Pade approximants with poles w0 in the region *)
(* Re[z[w0]]\[GreaterEqual]-2 && Abs[w0]\[LessEqual]1.2 were excluded. *)

(* Sample Pades for the 2-loop triangle form factor with LME to z^4 and THR to (1-z) *)
(* Mean and weighted standard deviation *)
Ftri2Loop41[z_] := Module[{const},
const = Ftri2LoopPade41[z];
{Mean[const],(StandardDeviation[Re[const]] + I*StandardDeviation[Im[const]])*80/Length[const]}
];
(* from 20 each of [4/1], [3/2], [2/3] and [1/4] Pades *)
Ftri2LoopPade41[z_] = {((9.68009727715079073184052312680349465352726369069965954186415528078913422833832`50.+ 3.84599644139344919713972479331289825141057458463266214309615918062568313650967`48.910540948828256 w+1.60996339914766673389883749557833941248119805698653019060902006263551084302824`48.910540948828256 w^2-0.72419370105703121855457241346139458933178467741286026780494313761536850705016`48.910540948828256 w^3-0.12138989896708363485482749251957604459287536810126026129730816084150763473849`48.910540948828256 w^4)/(1+0.44601035799858251759357884492466317853882084715006789259387078748497043615733`49.52287874528033 w)+14.65659963027209127108068624590456616150492941586166265854205795676747600656725`50.99077455409383 THRSub[2,1])/(1+0.11376801703326383219302371936985457378591850368903755234221779725515151309691`50. z),((13.20613245896117063795537127401720879371736351126765623165023914955043666538596`50.- 2.17324381349598310019345906567539400941040062370196584559023202758632111009788`49.15927795370501 w-2.78647367958557356235091896155760158310466611476816945779101202719309160343981`49.15927795370501 w^2-1.14845911262479705460808217277892909199542221120620474479997515028950431863645`49.15927795370501 w^3+0.89416511570824570506574740846144293031718635097127590178463819413106379706702`49.15927795370501 w^4)/(1-0.48791528737302977272348385531512880936459847416178885793233391343456866767877`49.52287874528033 w)+23.25064341152856391290141536384883243645156456057593676012547305590797232570112`50.36249341528635 THRSub[2,1])/(1+0.76683703317649730565789269785532144578759095521192108558765863483098137286749`50. z),((9.98715315084281065661187235059011522556749363071772967790799171949589210827892`50.+ 3.5309628156041042272138703160195886942178384371413370690249`48.28338776466921 w+1.57946963003582038990468184571164866299412466681890839601804154763744545382347`48.28338776466921 w^2-0.9569158524417583121828318621870680044360169564230736157981069442940900341287`48.28338776466921 w^3-0.02156400846680707475057833993830291448566578139052015586088267168134112285259`48.28338776466921 w^4)/(1+0.3594092043648707438920349374429188100805462529320969501932640860304850946382`49.52287874528033 w)+15.40499024061373438878608824942661825399561134295117151538540696076398313582764`50.83634494370941 THRSub[2,1])/(1+0.17063888388323398594259526005594359741836962825031121321009296552396481392312`50. z),((11.39150627001701983075805411399557373468825114681095148595703098031578578642247`50.+ 1.59942196915392171073913332875116203014673689583224463931001334606938132155088`49.69897000433602 w+0.55851980381836431127184166531661866798644727092165111733749619840824417623344`49.69897000433602 w^2-1.52644671110972366331595365286589189590717567580788033608223984179118358248791`49.69897000433602 w^3+0.40154858350757425824843753626487165523755054109316757210366803255225469552623`49.69897000433602 w^4)/(1-0.02024126514162948762248738773441063902838744004872578431316809121462701488682`49.52287874528033 w)+18.82783532531041980305613964366068046747945176610505161104714806229132886818808`50.52134275267853 THRSub[2,1])/(1+0.43074392043760352048338959580863141579972944258769909381673666997417754487906`50. z),((10.38337560187429040280680650320748802006514963004896545349064637679176347377755`50.+ 3.06730313357600728593197414108501491609767097378074046239776253063094150106956`49.075833745517464 w+1.43541479161547292012721785670236196070117719315064183275016105445369756141469`49.075833745517464 w^2-1.19825956614488375918299979604230606753003532952457257866481797680171003741455`49.075833745517464 w^3+0.10310223281289679913965648672355381076379609126570003387421220098781967525565`49.075833745517464 w^4)/(1+0.24972539068154620195572032242014677274825939257154635189517526112480664308152`49.52287874528033 w)+16.37070751673375614509287259739218596241572653920550360696951483403689390539027`50.70739536315057 THRSub[2,1])/(1+0.24402459699348518893449236301785029639926170739473979054742917714625816775377`50. z),((10.98378100147557913733696168146738648697268643676172847222049756488113423186837`50.+ 2.24303447280251459318930517589458775138289097191461144703740374102796362819604`49.69897000433602 w+0.99950265048648828991129786397307085707525753359077513032309192684522638690955`49.69897000433602 w^2-1.44188691550132883452040235346252356262392139707926461870354427200118952860341`49.69897000433602 w^3+0.28383406662786308763047374847148622456926415424912956159041694263689342264848`49.69897000433602 w^4)/(1+0.08752223353199469765435602354870996863683860420289197548972200367852233407646`49.52287874528033 w)+17.83408210734887273437340383020001113149437333242152400583328850019147236221026`50.58150541771136 THRSub[2,1])/(1+0.35522773121841900180859884801568210086460579583315550209571714306901486439073`50. z),((9.71964178195927448311569691179167749419529566394025351526710862556640077849553`50.+ 3.8076106468284568652149936990871801511498993641603144691596732344423291842894`48.875464220749436 w+1.61008270159570882192778181237968612996734802504757813337144285548766259147995`48.875464220749436 w^2-0.75644707469494117023050889510613517294404803133310985833206276649937465524809`48.875464220749436 w^3-0.10837001267676445921440307714402125444214347634897777763731147731789855688367`48.875464220749436 w^4)/(1+0.4347752971056566762407383118918793670235076393754334044516994373831773699049`49.52287874528033 w)+14.75298188062097405589905389303527695465178385706549555923289251902961240140405`50.96652519409247 THRSub[2,1])/(1+0.12109218979885952697950788838824514564745186458649512515999039660581895961392`50. z),((10.77251602347201719480704353594510061937828692053902220973812842879604793407142`50.+ 2.54976967398243344813247916888733886044802105063222242989369896838860429779575`49.52546402321527 w+1.18224400293825217490887545370129853409098028625118342774429975064616815849663`49.52546402321527 w^2-1.37258607767542415142338974290046716685530664542869046833251433882427329490548`49.52546402321527 w^3+0.22129939484434733046081606606327909076269262435104947095254555164044957758236`49.52546402321527 w^4)/(1+0.14408519894932215756532859859542401879602298309677063907136366652540002921213`49.52287874528033 w)+17.31916368572478700097930987825756533862918806273091051566592213873486664528986`50.61946583051827 THRSub[2,1])/(1+0.31609862324977147739185333783129531288789917811812682695607103198102263055008`50. z),((10.44898328267762027949401215577486255186151184995111317622812847228507822973591`50.+ 2.98435793915562873769132567422999518897009596390023160442691705818566226808095`49.17149932761444 w+1.40040175434776287230480252633860725711012574690537038291664540095465837059838`49.17149932761444 w^2-1.23195045186671802134316956281653848049599806801202248974988343485988984996025`49.17149932761444 w^3+0.12331498955910410979605687603492986489356334837607300217367615760076174655523`49.17149932761444 w^4)/(1+0.23177575655219098734654396492408653649632783735410883542057028761748376486312`49.52287874528033 w)+16.53061382853664224457463023511153471412473694996574641633540785717536469398846`50.69051202508384 THRSub[2,1])/(1+0.25617601958129704871725987336378932934630135635527477273127685274932513425274`50. z),((10.05663189600681794998707886732568462078664149796468667271917658102306001283261`50.+ 3.4542958340027501268830106456626455781036020483086625226899`46.779339025898594 w+1.5626544428567632480889904823046089215107317346782923499117`46.779339025898594 w^2-1.0039872170904199907191640886791947460039944713851853304974`46.779339025898594 w^3+0.00062686910814019940120827298591005354413400052165994633876126668615582635952`46.779339025898594 w^4)/(1+0.34001202941123045230258197257735611264327755456162558568417641657220772742683`49.52287874528033 w)+15.57433153955666439582894769211270437175207872681287755547124169398497190775967`50.809517636647975 THRSub[2,1])/(1+0.18350727951955545872474097923791262412435509451632535173076213549886777620271`50. z),((10.58575031258929461781101133657236672734052365332188630829691525524733373660354`50.+ 2.805828667558157601820048355298862942504281110786520095574265436080802678092`49.337858096890265 w+1.31736742715535885649335767968405414925931001303146958124155939011487398752616`49.337858096890265 w^2-1.29654815537017699820659308583391275063137595458208686704505619133050473774116`49.337858096890265 w^3+0.16507395207947900058522931063134041583992432145895310894564289099181834587661`49.337858096890265 w^4)/(1+0.1945420377125422059196610928651264383725475811588971200983214850762147723996`49.52287874528033 w)+16.86395759349869913876305975808628909375239983644993740970638724721742506410408`50.65823165396329 THRSub[2,1])/(1+0.2815071082006086830244479838316197520912707681076359549665780644591642308904`50. z),((10.4226371917938621662754575243429967701043208018192233902923606905062358430486`50.+ 3.01787639785741179816016670955499980623916599057120511360045297989536450283987`49.134705696106785 w+1.41483882736989917480999757324269162379344774831221396471690798936740402383104`49.134705696106785 w^2-1.2186327161061785416327387128585150567344048266155499298789237595727139723401`49.134705696106785 w^3+0.1152123990717981873103412727922569128582184252801156244559942809103140261833`49.134705696106785 w^4)/(1+0.2389768045048608765649820530517968669329273036391417890702409738980604530161`49.52287874528033 w)+16.46640021555626119695669286671778516855189305056027266300061041412811895708508`50.697173969295385 THRSub[2,1])/(1+0.25129637012645465427205501403608857860926063631255433219591741337402504454659`50. z),((9.61449876286152354937795518009274502139315011584494479039653072617376048808521`50.+ 3.90823989353064806667221116412079699368039996157700075763423444003088190098945`48.95932581917244 w+1.60709967698949668352417703193634961379026334591724540762064944823238176596704`48.95932581917244 w^2-0.66918556912548356789170962893159496321885511172969789730072974769266361861594`48.95932581917244 w^3-0.14309693792337868123467444719141062015599924156684494424266907174163002321297`48.95932581917244 w^4)/(1+0.46470244746612279257230218052032568179121745301966358625629716569701728640778`49.52287874528033 w)+14.49671566011332224772006110222630092260436681966340889203215088920504759912418`51.03505924680463 THRSub[2,1])/(1+0.10161829220682181592899627192266542698059106566335486590423549841743897773024`50. z),((10.35636163906078501844013903400816853690283435298067071805060177040272987668277`50.+ 3.100947375184455494055842859986157204366101311745330310377451159803769619911`49.03193684455258 w+1.44891831200058013328553614660156571710420786615946618025084032678729006026954`49.03193684455258 w^2-1.18387476935163134748858462835528298542115977464237109391004123248371700484503`49.03193684455258 w^3+0.09474500032493178297776026888460568133260898232651551492800524960313687888`49.03193684455258 w^4)/(1+0.25713315683653457681518967312180829933836718316779181892214485461782098413476`49.52287874528033 w)+16.30486609225729883366212187035499303848276237598085705105410852911610282837685`50.71464224349425 THRSub[2,1])/(1+0.23902124869799600570194648267072023968550971629138946988284772858726701269584`50. z),((9.64464344531331887172427866358667113323262640591838911407156710360997970596599`50.+ 3.87985926445031038950007373049671527123828324309393780746406862075784570777652`48.938171584876244 w+1.60882960424781737697390135340681827158182827946591707181940701810651961522366`48.938171584876244 w^2-0.69469728129161926316534191041908048331866463074416664313198115149728741897481`48.938171584876244 w^3-0.13310488396793671663998199837717411971417975524295665668139383634983338503577`48.938171584876244 w^4)/(1+0.45610428800070844610205239708445261033960279307909613999787184750642131863004`49.52287874528033 w)+14.57018762151042621707535487168209324856385361422754986266849043843207009079807`51.01402583337328 THRSub[2,1])/(1+0.10720149177678085810137173418564107117037211634006749597514542848783928637759`50. z),((9.81568487602554691607633545638917984038387430651899998803690422222567973837471`50.+ 3.71168434538925851407285048377168969964132189139842756037059398128061699245203`48.76311836956781 w+1.60536763741730251831104302365124431083466324633991836035977998738610871774524`48.76311836956781 w^2-0.8319584623546582272258768236863458245849906055714945741534111814811813802614`48.76311836956781 w^3-0.07695163609823825404848111610881491614129594374670785171469264072937896505075`48.76311836956781 w^4)/(1+0.40759043879558675950453055306062891119338309265496014142430234721625363724908`49.52287874528033 w)+14.9870687551793534922650891253952846981818814808550764087641051414599897782222`50.913836448466256 THRSub[2,1])/(1+0.13888065920290236326718713102330083933939135402752819900378638820270488643306`50. z),((9.74515190296962363872965173271954433089566545047714850587884899404423740692382`50.+ 3.78250390345882038422482282810951084693163908644988046972453364516083314287767`48.84992858554001 w+1.60952059438341620411467127861778155447777798396085476202720497117042081446732`48.84992858554001 w^2-0.77689310960245280113584825153380215439104654998167833483891963146065135711202`48.84992858554001 w^3-0.09999692800075749802258310229026719766740218064153797154342327743052666612103`48.84992858554001 w^4)/(1+0.42754064286000931261925699442910909536484712900198289382266720856815887791392`49.52287874528033 w)+14.81515797516451428608163480446950134434881609224356207122267603939854188129919`50.951728457015065 THRSub[2,1])/(1+0.12581700641891657333178763037412292104241364669660601137847585777859919232744`50. z),((11.72357620467994000265696227937090686400572623220184240361114724016725721230673`50.+ 1.02411241181018237972607134653823569719434219541431216233637192077328113189191`49.28069827851243 w+0.11472967277796169014208871048610391624859162184702947837978331410481355109265`49.28069827851243 w^2-1.54843138722878352055897308202678929173961903886225873538586676560736216669429`49.28069827851243 w^3+0.49482092261996878090763720604379334961319154265237663726473106602078902266386`49.28069827851243 w^4)/(1-0.10683097919151689244888469978353069729965683490256400803636499897402393106956`49.52287874528033 w)+19.63719297768269915657763165705647979290247282711042508821069840805837202075528`50.48165720666424 THRSub[2,1])/(1+0.49224772693386083890673920265787375606203618477518879883956461419209578576154`50. z),((10.83775174147881220013437043665991055126151721040660103564336639309521776449935`50.+ 2.45699208460876344581386007606250929651833800226944833746022355880906399754655`49.58506836491229 w+1.12918448630119023172009016433993488068287877329888857550292315475711157354281`49.58506836491229 w^2-1.39586640306600554472159204567792687546029720463582338920065187033213623618025`49.58506836491229 w^3+0.24072747604521452044384931704566618707596018201253403866507707087832705949615`49.58506836491229 w^4)/(1+0.1265628174739392803594925162384996343193307177826440594464447148839607901697`49.52287874528033 w)+17.47816340857050393024027503806286362320406129329606255630759917880855901722228`50.6071436764472 THRSub[2,1])/(1+0.32818115333792024743342379276551696947907673942744211254675154159440429379949`50. z),((11.2200706659121229801470221760408228381252213139695409683633487639166634937561`50.+ 1.87837807212382148014848137713396361815957288823873044809531057871006886704365`49.69897000433602 w+0.75799913944013451055491310193867355017078004177767604625578231726859498952265`49.69897000433602 w^2-1.49870512899616475000095747140452096513309497574201191529936387461154406676651`49.69897000433602 w^3+0.3525089630065860229007819534580640478631978371935644236110231433275755707866`49.69897000433602 w^4)/(1+0.02485872740556271386655875891112165675174437104373329337313610219269063759131`49.52287874528033 w)+18.40999346855753769156001893294598536862362093367087820836786840292410314118874`50.54485124007964 THRSub[2,1])/(1+0.39899174681146789952418169876365849821983900860868784703680927008803576889117`50. z),((15.46880201620217263459659909426671482878050340821655411742087427861519419360546`50.+ 0.5318770783527182378870435903423671651863306295051110846002576980700170458557`50. w-1.84521653581046559496476218259265387911645742469867574490537242155171712599457`50. w^2+1.29612343528863663972469402212701182288948006892754805556774751365696613714297`50. w^3)/(1-0.43837213112653998457864098028111883982289166194187565361097741510831000361171`50. w+0.23807190488406075357351795792185144461570562753748387842613375168544165981909`50. w^2)+28.76547245740933526585059315821747690296792727636567600014198229196440965167123`50.26557991104708 THRSub[2,1])/(1+1.18591378806183532790165669200214306661102311600352336168694547849827056511946`50. z),((9.90097082123977813743590762656632844460789683871957163039438036671730833223579`50.+ 3.1208111813511867873783245394097518048242057229478619700126`48.43440164600418 w+1.43421374464060765439774393225313871312565494630992693961183877092441807576768`48.43440164600418 w^2-0.97704728770943414180303511446038140422314121263048018653194130865274061281766`48.43440164600418 w^3)/(1+0.33281760004062680768085472489414267512390829902013450481236673263748937100999`49.52287874528033 w-0.01716106527191846052075469101201897941386642182240400641974263301474482747256`48.43440164600418 w^2)+15.19493711420140481281088941066984687666187501058500720027746142191981703690446`50.873035357737365 THRSub[2,1])/(1+0.15467676033633085929643715949361113722539552729333529434895915927366019144278`50. z),((9.7958154903393654639874342225370454946886437085961598104045719383654461978498`50.+ 2.87155005333072782068321284728551392756029123301024531321552300137741028809628`48.689289594259115 w+1.3451866502626300962018637416582334456786760940837372181057812442426665344513`48.689289594259115 w^2-0.95991553547753964656774626066904250955706580983555736039004963758215984760329`48.689289594259115 w^3)/(1+0.32538020896163154127225352744233714027740482308708752555150634780877276318626`49.52287874528033 w-0.02955056191665375135483661828318626189451632676364154895457313805064376618253`48.689289594259115 w^2)+14.93864088600362926181405566047485611669025952119484029390963133313993526780882`50.92409404275589 THRSub[2,1])/(1+0.13520058243328186566230679579001681037297288200370947707950533657230197340912`50. z),((11.12201331044157425395955869120013919609846307496540655377425033277599347316823`50.+ 4.94917638944699909384642477718879510573356652491191116718539486238847208884619`48.85811095358962 w+2.28987832008651853438848072197835719163744022482204002376245742272354192067998`48.85811095358962 w^2-1.13349602608998895597306795851589963680762359939820735602467432445191254991394`48.85811095358962 w^3)/(1+0.31303489080429215326805356166340131844036620424914469783011015258794667311597`49.52287874528033 w+0.0936936183829543483405482406856598586712073449505500252563526411571108389126`48.85811095358962 w^2)+18.17099721283797603393499543978995861060091476759295232745715314655696557979511`50.55940888849045 THRSub[2,1])/(1+0.38083020917477328026842436125124529317982204818337941506641985044473252479083`50. z),((9.91165641234976126155340931961345468151346872902090961453214308942253086881021`50.+ 3.1452378136478896402473491177330754649295443058158832865244`48.40023235652155 w+1.44324108439042139917559273546465775539023450784577690053587324522815964571155`48.40023235652155 w^2-0.97881514962472117055551672973252905696777905025385433964946859503949673631755`48.40023235652155 w^3)/(1+0.33347347080902529704777384196166212356427160794761360209198964357233293882192`49.52287874528033 w-0.01593223621930206463311038524462010939447866358212409735153547988769661129327`48.40023235652155 w^2)+15.22098122127711759355965835832522620835559141083679993181766275087720939417363`50.86825748104201 THRSub[2,1])/(1+0.15665587515319511170539517123938223140836349173176908256959663322424127683804`50. z),((10.25375328095399647291757191570486926007106044853769542027208008106765248240182`50.+ 3.8428372918709868912430345520158302371836718859822167862834`48.428933168650445 w+1.72538289986494286891236602136991138865869271335596732762282121194818758200012`48.428933168650445 w^2-1.03549389823493828197534459789080193803675705926314531141234565448074321141533`48.428933168650445 w^3)/(1+0.3455161243331789451715051093532478429953457960833247516360107916759832761113`49.52287874528033 w+0.02067578955219116712522108895412344725991240721671239294194276849119701901933`48.428933168650445 w^2)+16.05477762846612697683223042348420729571911351793784690091392997754695144409845`50.74390996022587 THRSub[2,1])/(1+0.22001680432303440771262955450936221813816134831910059994368557543349005417044`50. z),((10.35488561579860792809681768037126722150189287366675557745699024339001488605143`50.+ 4.0189358979639051069019974558382551310376529530484985451682`48.57071519333404 w+1.80458205788921387372206779113419439902374152412571009003180685199824047132758`48.57071519333404 w^2-1.05143562207090959057363260343535692361538467434409493566213409306630356989793`48.57071519333404 w^3)/(1+0.34601419161862576979067217277665463743183229511278630585426288081694327624459`49.52287874528033 w+0.0305523319949839142156188591573026993329574039668600445312786819585324164524`48.57071519333404 w^2)+16.30126856475594530948344664063015719509240621205308368153556861700691773051868`50.71504341593546 THRSub[2,1])/(1+0.23874786938952875497524900634925147471414631730260793088570778731615476510225`50. z),((10.48222944593765827624786829709096140150974416425060608639569330237746010152854`50.+ 4.22204813340160655495562765629711738903360506653715882877856016934795290160546`50. w+1.90035850005942294676273104745102844156623219942799241881190633531740143432161`50. w^2-1.0703639038858709447876002333393371613047960768112670129349798988956098255261`50. w^3)/(1+0.34485061004138166425974017560961203391711744912934950951211190680633849893222`50. w+0.04242617878737486375895969954717685350231692663117460486310760098234667996585`50. w^2)+16.61164506273688344721177403903683526691666239458652231644183781287871536667859`50.68232015090457 THRSub[2,1])/(1+0.26233365500217298866481097270815824738328340847019609679432428393422060755618`50. z),((10.87047553315826351066237088098834518351645643952181865592088879072395063844699`50.+ 4.71934221250149219484728765368070700403164861718717548659423104116337630089487`48.82927304096096 w+2.1576036670193045570173602715478355152955534718667216952892568369713704890654`48.82927304096096 w^2-1.11636349201602673851702540596401997722442246862610277240650701726711483533398`48.82927304096096 w^3)/(1+0.33025243413045958510225053894101427881946458049161063344059910671296269367175`49.52287874528033 w+0.07508699928402737374909684683452903294371951051299457978719471154589141521232`48.82927304096096 w^2)+17.5579214608533312566636586049603050790314553342954769616428763953058282436487`50.6011735486376 THRSub[2,1])/(1+0.33424203853464789107542387506110356676409978262484903459510365641060631982156`50. z),((9.64170659579310508654980800188772259572460553058115683013698784909740989965203`50.+ 2.47634699303273192319677546239856203978529838533470557640818057971053760893891`50. w+1.21517327958231731400575288221905724000423633396240535389617007675960259466524`50. w^2-0.93623894729115304171166708830984059824910933976302725928265485336187315979815`50. w^3)/(1+0.3110860382161375113592449498661440568815313047377555913085138624638504647121`50. w-0.04872673277601720354564768918641592723478433051248562359674179969303678481042`50. w^2)+14.5630296063306909403061789747524483408863391891475739846284198053366566615219`51.01602165578011 THRSub[2,1])/(1+0.10665754784887540856067328083743642588496885970367462631348176162736439935468`50. z),((9.82090894841970554939111073372674391737499266070552248022932552483171565356247`50.+ 2.93250933465796175990669911138908881767373566708525901358783994301466797771445`48.63816496123811 w+1.36644505761341194477139235852452985543293027352538535500322703860220664093116`48.63816496123811 w^2-0.9639508048962077304229154608069587878512120079654152439740377253960401510835`48.63816496123811 w^3)/(1+0.32731992615391038848033791630808489894303959796433226456611258186404325219661`49.52287874528033 w-0.0265443407880844236230442093014478409533463943678217798799173726702526365696`48.63816496123811 w^2)+14.99980144347000225770993138453533339694629173537111736650742592558369281457344`50.91119006195711 THRSub[2,1])/(1+0.13984822748932046379728651546920638103820367115201369107905953049480389451561`50. z),((10.14098556053155857636977270780066914547191409212882998318068794485729263944016`50.+ 3.63058765992461694117262432139112995276733868317767226682031421631440693584091`50. w+1.63437543808063878580218498123180103298970331222189322921030882357626282604497`50. w^2-1.01706102403673470763111267222498148042894612469185256039722380769583358131415`50. w^3)/(1+0.34338206285948697011906978591353672239461124538841955353822387571391358648786`50. w+0.00917210567188766706429279565807552716043796162957700647384459473260509015976`50. w^2)+15.77992764074554557358913349564618096234108890302105905037069795409476114331542`50.779728283707286 THRSub[2,1])/(1+0.19913070976308592534897467072832515422993530822203177279947192412312170631206`50. z),((9.8677786377994017555745735154660983790420793985874665862003989167774152611127`50.+ 3.0438810326076893325520617089199352652598561914998677896117481244617489168133`48.528272609638314 w+1.40613964651152938036697308229499906351511903290404629176883488886999476306447`48.528272609638314 w^2-0.9715824008613222613799658799390805813571656086928558531037995067615101530583`48.528272609638314 w^3)/(1+0.33066434796456554190277425473848908891431036096485435586357633118319912498972`49.52287874528033 w-0.02101318275882501243509568030920726074989829517193334970685945544621604388639`48.528272609638314 w^2)+15.11403744560092545475644905163938085431646057738482668204539559292387486260497`50.88833039600008 THRSub[2,1])/(1+0.1485291227021757824730345764163581601427022056835018143648604575543585881414`50. z),((12.88094242735507778649645662038139347729141930807251852302157518563120066706354`50.+ 4.84260702585921657897665747754976138343685424643766508051283790031825974051468`49.42824718630302 w+2.18227689339777233208556525492442888700128044298793046276297023438223269657306`49.42824718630302 w^2-0.83251690323086401327444043489697560391619330449381934585235645286288961905631`49.42824718630302 w^3)/(1+0.07838542941384195751425682270976844568980077893706289909675272144973725197595`49.52287874528033 w+0.18260249441982234557366040322705045830501364301669947173803591869541532415426`49.42824718630302 w^2)+22.45805422147514802077402124878214107144026726259793354542107339400093384500372`50.38295541539779 THRSub[2,1])/(1+0.70660747701774687661481627953710260288248086269940701302914843918326630461558`50. z),((10.33467313808589088400197224270383178078317440072913157582339337221042560714147`50.+ 3.98480052983607737020110722398528686512664178015484633585659768531052792526039`50. w+1.78895886302267836901762376987821992939699881200347023051159179629721290627616`50. w^2-1.04830560030945190421286089826953919840080182787932423493956139738129831842143`50. w^3)/(1+0.3460179932540538240295378433651522674242052441529518444178559043964551572275`50. w+0.0286107075961481394159232813831885458056541895702445014215709269183383764452`50. w^2)+16.25200447366381552410605596225525450796851551104599643917299095223494001192051`50.72059273959542 THRSub[2,1])/(1+0.2350042473741398512290238223910298191542007464765083635099730002805264155779`50. z),((11.42978904293773636951861373951917317564621836027981035892299810203217065927534`50.+ 5.13841515079043217783125870742182923884478289327199193210000981856401215794986`48.84427005186585 w+2.40802660147453170575213448433626127235837935156972851389230375901719196216517`48.84427005186585 w^2-1.13739825530291267685476651048795257978037837179784762963875648752075721035554`48.84427005186585 w^3)/(1+0.28495133884892538150010951953021166108695908452999657361755612609237712015478`49.52287874528033 w+0.11406416114123416028405837505408580334788072507404100439840473653878728126297`48.84427005186585 w^2)+18.92114234284834933393962299703125720042278804559081292708796275997359949654277`50.516398986955636 THRSub[2,1])/(1+0.43783440353191306234224324596277369030642611398475146129442722305741104798174`50. z),((9.72415547607479944330213618445844793892376210867940733423418622573604748340872`50.+ 2.69228068327982045991135958329914419209198813181659867960289617839417467937883`48.815123775914806 w+1.284554599255157172875747229639992168335500962088881984038352319936680355631`48.815123775914806 w^2-0.94863823068784359589017245768503027122466945206738713129910773826071207063325`48.815123775914806 w^3)/(1+0.31925243995913710083022953239764702334839522050117810593163266373418991285619`49.52287874528033 w-0.03831215363959306243040059145391037487128183680271720759131202842117735094749`48.815123775914806 w^2)+14.7639831562305114316406035149274064336746742477590359863332587839092907564759`50.963860944692804 THRSub[2,1])/(1+0.12192818649860995786769747928613022039517850031181096205709394246009537789626`50. z),((12.90751650166232188642751012805506414967170888944532898940210558526451299887105`50.+ 4.8209497613816346315164137922612670693382403740097885472543634358377643522771`50. w+2.16495892169113794802408903990972408714476620945752554821955891757138633364109`50. w^2-0.82133360971133381775369828589124074868781872692621358504474181789648004651604`50. w^3)/(1+0.0737775768375949429183551098831193770135251681474753726722485629359940964457`50. w+0.18352216802691656321001911421516617013069181729532275378724952124373426072512`50. w^2)+22.52282350092560476898272401376366092192580333095980143665191203504193299177211`50.381191531181145 THRSub[2,1])/(1+0.71152935206093309329411963499800349723340339949330407349444485422906817982921`50. z),((9.70707463162589324965965341577579876842586055252248003388673028903328696805746`50.+ 2.64840357414652639355949978005209374905002070625422866156187291071178415717275`48.841742379723584 w+1.27013697302897996969307025213385479697650456671402366807361888971489140580045`48.841742379723584 w^2-0.94601333815173402840614471071636919592757682059816179858050908698220565199326`48.841742379723584 w^3)/(1+0.31766036008659649138448897222723684910062784522876039021743481704285047941409`49.52287874528033 w-0.04043993950329413165479051727623516987353558297003749198863561841764329952446`48.841742379723584 w^2)+14.72235182884841682177670881143342821059728883720420879353945118857367851843739`50.97405175468847 THRSub[2,1])/(1+0.11876458497339333816104861283042614384716777001750201847139899079128572489038`50. z),((10.25062777462261282753797168335799086532010284172727402551733409204576019309498`50.+ 3.8371822671326023325825490835691782188671305746716544036365`48.42321445609115 w+1.7228961983390196092269182505765915766475024334969986083168263781965837523398`48.42321445609115 w^2-1.03499101617735772754038651984471595634967783892347090221812196375418353381548`48.42321445609115 w^3)/(1+0.34547982721896574521709822925369130307095319566646084690675270719761438424838`49.52287874528033 w+0.02036403326724091146565227649124747846053671768602593639623730379987127164439`48.42321445609115 w^2)+16.04715979799493066212267130723364242776382048192658850499739710866598591626978`50.74484802003809 THRSub[2,1])/(1+0.21943791862293819900284079196340836911035441352113383247005503599167776698508`50. z),((28.60040329882551587665742330387263847504370261327700359430277626409943027047084`50.+ 40.46773774133455520591197795299923586504012993638148768691874383257384378524624`50. w+5.5698395547510473791397059725853331203414607806094865306331382882758021976955`50. w^2)/(1+0.54180942484310525810884780926477826797127842267481597577576337664341570398162`50. w+0.13142527136084329587623692659790951337464455161205741209935109791966722797914`50. w^2+0.15259506522904161556753253986673025450191261067015633534037789147204570536246`50. w^3)+60.77126664886888166314048121236934543433375378656879233386840806797597791113856`50.10598374146765 THRSub[2,1])/(1+3.61806250123064051678944654179958166877714918828224990351796935927449521650533`50. z),((9.64757059444177295565376780345005253080770638725567799374228192563840524716281`50.+ 2.825111119612589213327014434536733574868650203104071620756`48.09549943553002 w+1.7318766436786712993536964108832199671547923061957189902926`48.09549943553002 w^2)/(1+0.34623004335340920340115461321317789043926881982828062720463571790542627563277`49.52287874528033 w+0.00691807838735183641050593738598359593023767606701834741151221708174299116895`48.09549943553002 w^2+0.09346734767603888739971109368381349249127584986170716887701952421289005371572`48.09549943553002 w^3)+14.57732199382014469229941646006390495087847009925981396000163294514877814808135`51.01204762504767 THRSub[2,1])/(1+0.10774363906200520443892193310850820502002488727372694548732812475235412780551`50. z),((56.91157718308075560680010423538113156893086247402888770523925761888765209082286`50.+ 92.5116306711015028434676695560666920047745623798692934896672`48.96061324277975 w+8.5682739843462607624760886838189967477109799134402001624792`48.96061324277975 w^2)/(1+0.51778985471841359913720769186674830179030275544104262867450715162588692745276`49.52287874528033 w+0.13886617505970718146028658059965817491094663046108496136278282488456536087669`48.96061324277975 w^2+0.15360842576607555505023820285979812705841874564413552236931895804273330333292`48.96061324277975 w^3)+129.7743977336621185824951144475478736449978373280034968887065`50.04643488400584 THRSub[2,1])/(1+8.86167168863462165583264125701037726467240821736967965882099352690253713941779`50. z),((44.51512182411886528396293513420984884281376467599714310063897028115594378786738`50.+ 69.6627527430478649431859526162491725631058459021301106955794`49.01129625449321 w+7.26377296888720527542268169731976908876975899282895269707115611689461948443686`49.01129625449321 w^2)/(1+0.52318329886850665685710120510990763249384568323752621028268360516723050608793`49.52287874528033 w+0.13724309311613106738696714526007146187446124990533898818053821236551219946298`49.01129625449321 w^2+0.15321738438736764444410709201178831209906465389466277429512225154067510277211`49.01129625449321 w^3)+99.56038267309455440651725834962207808862350573711752577381123250508891456099989`50.061568239889844 THRSub[2,1])/(1+6.56568186224152764024618387013185462561261037825251964440188269109759314779936`50. z),((10.65165147124839612028914325078669090542684323653665547867076822931621514723207`50.+ 5.0376203164664338369664704013762639977739159311190945900480233908967826076017`50. w+2.08056800620431960482038719363652788155103422985260283818900157096600761143382`50. w^2)/(1+0.39454389883448478325822993663708670183535849264485961691893281011706329098048`50. w+0.05877974369651959034551258934420457141281773955699783035121472055279064965691`50. w^2+0.09677399863456473713416862902392056736930727248207909046236466077438797313424`50. w^3)+17.02457920206162370891727165512976992309084520560108996541488263025674890295217`50.643914902363605 THRSub[2,1])/(1+0.29371288682420751313282150147954717227036806896220067173551576812811654492423`50. z),((51.89150912848549397416012111966924018692571253137070570737095142068043119811775`50.+ 83.2543257501051080504374307271357257005536773098275538775968`48.97847330843391 w+8.0410171076093851341403399578461556759706481046536472910296`48.97847330843391 w^2)/(1+0.5195782496950810687532901702104332569240019184533136810779982963904674985681`49.52287874528033 w+0.13833364714437836283504737966096742016187278025903270784004643551518771362461`48.97847330843391 w^2+0.15346858509781725898669792842428033969280694343787751662180945410920526182766`48.97847330843391 w^3)+117.53893143184040945043362593208580945718917970217792526574005246672561847647266`50.0515666970015 THRSub[2,1])/(1+7.93188774254723706990922975006069006510895437890478771866702944572161373798786`50. z),((10.34924483609006995817743103522005996594554985952130843424129616783804368867241`50.+ 4.42775335623922838466854059920975849050278339719404519010277145116397200723864`49.55183690445955 w+1.97780142111727111758404196769058998250013243546407515375597866165484055779365`49.55183690445955 w^2)/(1+0.38643788703217251025515829941620476462030377526511739015804908608775633769866`49.52287874528033 w+0.04549659835043688326224939285060062727546073317839107950697720282659067148515`49.52287874528033 w^2+0.09563168569874897653148600648687761187593472318526381211396361593468200138714`49.55183690445955 w^3)+16.28752023120962240187507170607033564051345423567689663371535463517669473893287`50.716581601616994 THRSub[2,1])/(1+0.23770312131851143280267968106591049674143949379853502250048397320197824058405`50. z),((18.68581048433405641867695367185928663011142919419305821296200961534335486060007`50.+ 23.0775001769961159386048646782309616043701245168161206082585`49.29973319299243 w+4.58983983248744171358327123241269324262614839969208429034743277113705785210437`49.29973319299243 w^2)/(1+0.6121457588896413941505268772988110565001868968144964199184539648422030488005`49.52287874528033 w+0.11180636045240521989129358647693688968880760771784042952561529337967309445609`49.52287874528033 w^2+0.15795352199166800349787603232447601906518051014570145492109063485946089882598`49.29973319299243 w^3)+36.60632207865540308920108515025235237541818468156581297041614324872577884814783`50.19347159988918 THRSub[2,1])/(1+1.7817469113515058763250760230654014109124064742293545318214682767704777143206`50. z),((9.77283321963285328820201810162249376678971232934564089993786472171238696645757`50.+ 3.1325418368732442103848339878922339341716215476863872770622023268040289139617`49.491959855515404 w+1.77342598875677715432871968291966108833860021986238004083468057304554466447065`49.491959855515404 w^2)/(1+0.35601362933499593024227192396469918031611476859113642108045678345227164430217`49.52287874528033 w+0.01463228956252547314284365177669923489397062683854404584449177739450961268744`49.52287874528033 w^2+0.09368152769481240200249013304826140021705037379438640207533725623040929845127`49.491959855515404 w^3)+14.88262594841499027190476519111197299600056504253751217578036132315080174444521`50.936355621848875 THRSub[2,1])/(1+0.13094395759968243066546524290721492784291165856020635570495514205254979623382`50. z),((9.73706873646634647889503099054570165233182775060174173850669200001087371065168`50.+ 3.0457707942164091610563222173668363660580975124043106804656`48.31838710674276 w+1.76132009651463496049502481750591671216929565597117628369638723170481181600209`48.31838710674276 w^2)/(1+0.35334918348467579372373590944596980440075421957497723941386067479266903082805`49.52287874528033 w+0.01246481306236399595649211133056619376307719862233718601387462173520729134145`48.31838710674276 w^2+0.09360764934917844819028954731250392911942815652357488824864245831850971533656`48.31838710674276 w^3)+14.79545678580069090377703503117076538219286240425464795225096981876109459883725`50.95634925927232 THRSub[2,1])/(1+0.12431989554978825790510101425503468103401992636907259333622418772183308809411`50. z),((22.8336935512303212833777482406989018399969348449877854391405348511900195207645`50.+ 30.0808788846698699321627193800165934707369463646840470538292`49.21731300399488 w+4.95745917226350522375297349137018335801600311017918231557461397935357344334778`49.21731300399488 w^2)/(1+0.56337478962980294115039044244125976176532758247184624831092987720277442698355`49.52287874528033 w+0.12482394098474961856233778690635309102333393956176769664975163255706881605004`49.52287874528033 w^2+0.15319214768774466262612467936701333919826407879465840050619365423378613639308`49.21731300399488 w^3)+46.71600245289843839379149311890625460232548739155359126250445900912478448664915`50.14368862849749 THRSub[2,1])/(1+2.54999049767451834745487257811725087432870058485673160191398739416393362294275`50. z),((41.41390533438004744301180136654873582460058832283431007594401336920253759802503`50.+ 63.9545589602595305179330076710661451944047573862663621349917`49.02826219025164 w+6.93580426345447976884442944783076186100702070972003629703916965893349062376312`49.02826219025164 w^2)/(1+0.52522828048923886277291796060677169260359366832337773892344097976845760228834`49.52287874528033 w+0.1366159626099815310821404300033325294008464627801143455712904378949153005175`49.02826219025164 w^2+0.15309349530199835163322868256260346892538849543793058082307452194839932171098`49.02826219025164 w^3)+92.00175409631276356995843700450712263024312953502801452266558868263360509314626`50.06703692410709 THRSub[2,1])/(1+5.99129496665728012854563089334706006507465164820787907656584911237842046098929`50. z),((58.67038385991132794718330046054895323085095196244322004519101732659592468098602`50.+ 95.7559542799212764758421961566423408960538744146624347156474`48.974917266421755 w+8.7527518846496649981609930976895188224482749988891020809828`48.974917266421755 w^2)/(1+0.51725236636605734550145916053814432058748909520247628036151175680164161286435`49.52287874528033 w+0.13902498122599477827593875406625019319046356252117673015238125715686398029628`49.52287874528033 w^2+0.15365238785949041973443674188844651105986636559419308533479728868751553508352`48.974917266421755 w^3)+134.061156317757550439300295167584606537227916652364506797519`50.044870611725216 THRSub[2,1])/(1+9.18742627893174747802251677737301496577498576743422444434559595506596615424943`50. z),((20.13365549449630638462284398847492539902827675411991882003318437864379887696376`50.+ 25.4079292385336513889672291426640294467298701174084341334553`49.28249054650815 w+4.69562364720974882949396264126970630696789709023978224967016213559076912354454`49.28249054650815 w^2)/(1+0.58716959264704351536892465996332724661897130990995854041304519864461118305595`49.52287874528033 w+0.11813639269507444081449428666132020481384227761834283718178383960592381162766`49.28249054650815 w^2+0.15508082098132012383012892979066655224855513117717895569230786036101963485996`49.28249054650815 w^3)+40.1351704208377243175146508899236112812436493543735545195317282547599680643904`50.17255242230883 THRSub[2,1])/(1+2.04990722954466650263974930579223084753343845369751545218602443790093968659138`50. z),((23.45575797202305660006733011743562442468687326713640769609888594873400056913174`50.+ 31.1847949090842423821999254257039630155485864849969202367386`49.20754575004358 w+5.02201742768891573637165119832536946402247207771738303886083562779440214816128`49.20754575004358 w^2)/(1+0.55983347108355247888637771767351494254601507111052471166328064742253580010799`49.52287874528033 w+0.12587730817649636612283707677757355342357192385000026967710139939412575197368`49.52287874528033 w^2+0.15300974604309239901161183783165348056784483522174804930360694924355235292081`49.20754575004358 w^3)+48.23216681071119369818038074707784840949368403541466034705425548072237745528846`50.13836764330473 THRSub[2,1])/(1+2.66520517317195331845759239217748226768209619200773404737197445544153252474785`50. z),((30.75964705269348676009909915768976721310938453981749064356698166623656493069361`50.+ 44.4053443248854741739630465961986617207780590858433220693609`49.110437827219435 w+5.80126286423126874299960053855690979655372117848554958900301373479653777347687`49.110437827219435 w^2)/(1+0.53738973053614949144164415663556193099903114744566334263728371156647203146203`49.52287874528033 w+0.13281492585866295359610778950873167387045196380602155008255796277666216269256`49.110437827219435 w^2+0.15264049142310937389392041197897513387454501390405273407636470954735960724839`49.110437827219435 w^3)+66.03401486274754840930513276473926258478142972151624788805257063742499619854254`50.096521081916556 THRSub[2,1])/(1+4.01798340991197963620737888362699194572071680120095291645333723221159214315484`50. z),((42.86392462635004788308364333133794323841446488688102443894766034618980151897532`50.+ 66.6229259874432599114430728498665986347435766052262250057771`49.02004894889274 w+7.08925516042807482147456504819713178443958609515866622639992146428329930320984`49.02004894889274 w^2)/(1+0.5242216905176551470337690562757846528982241908580676232746934106361943783946`49.52287874528033 w+0.13692532937193094267736367712065900622351166479763415587040581256114982382034`49.02004894889274 w^2+0.15315277657623896532292935981746511053546975940972710008408116799507234106414`49.02004894889274 w^3)+95.5359018391207481857694806441188335383622758496294778810242404811804129609729`50.06436364454755 THRSub[2,1])/(1+6.25985799100843112468698576944750015772463031060372632520143397382729277821052`50. z),((46.36106414050597451056352093294159592590966030533084842076805743392140894454654`50.+ 73.0624352613789128990383629077166166174867050843141581078977`49.00218946483435 w+7.45861823026820825172024959495384417728969697858771843961235623399320182042172`49.00218946483435 w^2)/(1+0.52213876162842162510894401455176777976396948844418321485470853567337885448614`49.52287874528033 w+0.1375611999965942202396768936068549882690525786757717168619275326578636496094`49.00218946483435 w^2+0.15328589201949192253585628169651598124341671102256255964699206906022004612159`49.00218946483435 w^3)+104.05951789628868604788186998695137401341947736472924308114884733061663535527508`50.058717709548844 THRSub[2,1])/(1+6.9075751418772498521851643191347620503018654376489300047611573214989948325`50. z),((9.66122033028828275713523829982769215867697156940552030129770567611947489769933`50.+ 2.8590925487887561743319657100401930327465424982467296061508`48.14113077700332 w+1.7362780566141693120649723991905631073113547451576261623548`48.14113077700332 w^2)/(1+0.34735825642173194641326894306017607656529625339493508578010953875177315186505`49.52287874528033 w+0.00777509536475817894282115553806048656625527502149678861221973304110876196874`48.14113077700332 w^2+0.09348425791599234712330369068079447642799016674022429289138052059010879935948`48.14113077700332 w^3)+14.61059064300227288076722877830965618209377068522913678114800018092738654418711`51.0029650113201 THRSub[2,1])/(1+0.11027175324699139480477355705650091048666470378471145824340127376281028743424`50. z),((11.32556291426037667998742168108221910044655465593949352536323267030709520688236`50.+ 6.24857156902465354327001073605163751119758233900429922280377302739883995205211`50. w+2.27353823320512406076553879968829800153832448376903352470872210686132002287028`50. w^2)/(1+0.39797128539800354516755378303989704879939070579267123302031613006013922562356`50. w+0.08280314178858822310853049135236193682793436780240076214776667151813527656552`50. w^2+0.0984712895316283636745135119896013893925321457633703112196634692120498793136`50. w^3)+18.66711086930411587264470883060704488062044967979836923947474539463683957306219`50.530111692813996 THRSub[2,1])/(1+0.41853032634548135155254837538336832424429327850098851117626946903985826941297`50. z),((62.95185789875626857955727369762505542117506683036509480826487330149702766084121`50.+ 97.67766825766594657568138583785959266823036174935135102943776252872071002726303`50. w)/(1+0.42114039886226735636870496013150116798021783268915079395815073708837596670016`50. w+0.10054478952072272131666015288112238106552807196472136744252742110989055505863`50. w^2+0.14288042079182616428581002912909846613274679718063287504700279487257806679076`50. w^3-0.01139794625516043482047600437325438428274023807273618872746904543469580460112`50. w^4)+144.4964394164515823536675300798015660416017051228326365685397`50.04147016323699 THRSub[2,1])/(1+9.98041270533366864697592797905707962450117472544109606586002900153648882681051`50. z),((62.50959271406352999783665561667949947708393384660168248951172000803951591720818`50.+ 96.8848359240834857802783317625273310496688654675497200152393`47.69506926702302 w)/(1+0.42095102323319031746368050706143406027585225841469758689842628759953754477503`49.52287874528033 w+0.10041394396762186453159479502665475796466689990723544739434366290290522783285`47.69506926702302 w^2+0.14284392339131046010861012148777757502424418861246939352362518810109592349589`47.69506926702302 w^3-0.01142435175465760764638446432264602781739071666485333695219715553933187540296`47.69506926702302 w^4)+143.4185016863398259196999758147879786577738342035238926665172`50.041797344092316 THRSub[2,1])/(1+9.89849926030292514441639277046731583302697860116174454645681711863940609772922`50. z),((10.04142380381940799069952033054446166782724312770588010931786771822891925319499`50.- 1.83337271722582541260123371462617620658045841554145080541512191679267487538928`49.52059978894279 w)/(1-0.184021867080387894739713803813641043842750288861913289990253585590849677089`49.52287874528033 w-0.15525700256533586847400287243564718528106598175991285688289027197240500501803`49.52059978894279 w^2+0.18135779684148829035950731606265817798978216891907496359748721687584785165385`49.52059978894279 w^3-0.05626477840863729243432124922178431541989724127326838543033477276932702716597`49.52059978894279 w^4)+15.53726469156767733475521554814798291142659351122740055151661041295150977365476`50.815200674218836 THRSub[2,1])/(1+0.18069053683545437632620689048956111683080798782967139219835508881431891893744`50. z),((12.54405954088323049504729720089852865890840944839825757121423543446984164381851`50.+ 6.12190583010831421908446397231305682098870789316084357075301490441937792676015`49.40899542395513 w)/(1+0.21858970889627925238460693844968115769832211346641912534691391333537669034185`49.52287874528033 w-0.04062642783136232493747423856189818950302907244525287917951229102685105661588`49.40899542395513 w^2+0.13450430082429015527037505641287041024045520904775188366258529845422528502169`49.40899542395513 w^3-0.03006450355656993846076561917069141491198548324485747904568414076833665976956`49.40899542395513 w^4)+21.63696590947236541968199989251769786197068389235990856671025230187742144044854`50.40692890177597 THRSub[2,1])/(1+0.64421224728248857492110763705666346350209107923839679100995366768158198466875`50. z),((10.19678390556335511531825439176492106290581914270539936342068173261737601549632`50.- 0.94194926211702132211572233451681736341565815475119331998066703829616760782858`49.45913082156473 w)/(1-0.11428500950358989002741085267693986160091612004579643379288500635478847474703`49.52287874528033 w-0.13974602136489624060719074851411325189963082820160232656379187942283422703371`49.45913082156473 w^2+0.16931676121468945624904442949148927964522376363424926504130815446959529536645`49.45913082156473 w^3-0.05054641728790195526235179908669220699090226454457554273690633991132170637722`49.45913082156473 w^4)+15.91592555211031708325929005481912268984054227195502903296861406408228993287726`50.76148130453843 THRSub[2,1])/(1+0.20946531177735921724263400701133827613270888085168601014575127653257593337737`50. z),((9.9259577842396777400029078835653424236013314317311970559567328003168399133934`50.- 2.64439889085054472225634834204419590192199483364593620853159957545075670213926`50. w)/(1-0.25222695387978158052817582554677265921512424835272321968189577618682576020518`50. w-0.16923352146699722109003091490512252966413807105995259615704921631888375057772`50. w^2+0.19381799673471039450295991108214371680473444669364269276854836011011992105729`50. w^3-0.06216872133314350241588981187344806983002771847066433784066389881666269760324`50. w^4)+15.25583811005349918026525664106252561024561545119974450585927837801041530866789`50.86196905199737 THRSub[2,1])/(1+0.15930468107487933751578248148351997632250269657826286935783998089092399931595`50. z),((50.39171116761737023726989659996664041807711918803590762368808773234615219358902`50.+ 75.15056943903787116817989204926501368578280214652663488740715091329185099448627`50. w)/(1+0.41425077944860571090379050806355373042364418364069062144197564832648346066445`50. w+0.09582397679804849059578186484088727967883813872235705235756461164868360417567`50. w^2+0.14158157750693013344844147034613265386203846006089971818143051134428825901092`50. w^3-0.01233299378543967137730135396403746230985489878797281349911526871395560157198`50. w^4)+113.88345759957931416149581713098102476074197882552688895267788160279773670600166`50.05332774427118 THRSub[2,1])/(1+7.65410504095352207900654334892674818718958838619872374432637707579689902418463`50. z),((10.02177262306492634064682893087211262086137182024505731567232875710302759783016`50.- 1.960635872747236633686107681679174504932382516577029438552837521716205066517`50. w)/(1-0.19444450998788367417591935390957187355736002940038707294072270656337906149946`50. w-0.15746227366688597427060508027129868397483700321119737278806642212220322143023`50. w^2+0.18322315171021868707400803951591973883594775463491925246771419961682656379651`50. w^3-0.05714852389012799165132837515864155208522282637430825274900654447793080407294`50. w^4)+15.48936865563797062044862329564265432106909855625420480380166738503469521937739`50.82269715803924 THRSub[2,1])/(1+0.17705087454632400973870383399536841986990346975575375587528648267355324459054`50. z),((19.30210307254812743358457379412606951959713893589221021408940417469606842691975`50.+ 18.8905488160252905955250218615383522517006645520394910003264`37.93242396313661 w)/(1+0.3327474233458993207950780021833647229819759137614546141838`38.45759516021352 w+0.0474833977578538680542917620775840318779834741281283393667`37.93242396313661 w^2+0.1299219714501434963536731440141778903391266797820147420952`37.93242396313661 w^3-0.0201233785791997617026204184617280283181371267863583539023`38.45759516021352 w^4)+38.1084186863404766042635903575946547674449343079213805160339669111371940201289`50.18396872237994 THRSub[2,1])/(1+1.89589256602834982192153310363767903449855545840076759300588681917584010505845`50. z),((9.85799459001043469167076045163509798396565956612710551515474080140648543237998`50.- 3.21021468006007389901796328007430655812449373901181702072883489636784949398642`49.544342538959576 w)/(1-0.30209145870660917171466939835198634506797988505787155668675194946352504839786`49.52287874528033 w-0.17884660961612009785242082367456822099309875680587683367281327385127735577131`49.544342538959576 w^2+0.20325362247995330096278299488168563917608651670511210137030707657506800106286`49.544342538959576 w^3-0.066649388642076467689890308173274158279102093772687531267066494391833213778`49.544342538959576 w^4)+15.09019067983691602392157555459912515350169311734545743770594882822939819319883`50.89297584942266 THRSub[2,1])/(1+0.14671698580223752292377651657570793453022505683604164648064178553623020342505`50. z),((9.85055363222601393470774454965160101616459970687547978467247772468619804222414`50.- 3.27729005304051055154996985031358000456051429830129916034155595009692928976193`49.54482125594239 w)/(1-0.30811314557153400523022644677890441889794276842163804733580455598713443092168`49.52287874528033 w-0.1799771797152425474728447412550292053208701999301601258242498817578413898422`49.54482125594239 w^2+0.20440867730519583533066861517733883862022495872598237877153874432846287837028`49.54482125594239 w^3-0.06719893171900276359761591934081794302139436867533372227223153221675308407143`49.54482125594239 w^4)+15.07205475274699962972847575760092083680034386235252845742985329397959499109302`50.8965523494773 THRSub[2,1])/(1+0.14533882060283642235821793107114256625609582985574816133796652649011700812778`50. z),((44.21289196537586888331407380261419842778031392006215124246367479053259046133353`50.+ 64.0560232388830491106636781159304455839745995398121652136489`47.86011201137797 w)/(1+0.40914003636963858178007668545869328278777702390262128732649163104183112840726`49.52287874528033 w+0.09237536864098649588257481005311931830202017291037194683138362962456962545087`47.86011201137797 w^2+0.14065576884272816116926205468294498742846396697827970739023856804341426677601`47.86011201137797 w^3-0.01299361058246625343453347847972724651294860703589516270915560250155762930915`47.86011201137797 w^4)+98.82375456131641450356592523789223260927136348103539033844410750817388128546426`50.06206157049259 THRSub[2,1])/(1+6.5097048380993415690894206814293065685599209470846819755477704694735222325496`50. z),((10.45583683452751068819314054908062221333840083837001870321418020372749934490186`50.+ 0.2419339595891778551640632572108194098522747061436884626792041046673339186825`50. w)/(1-0.03154403945685175711140078882256213357118915343033378275367020907588821337772`50. w-0.11927114241802489292830767772459913998873044987173910700881140491149884985855`50. w^2+0.15630733442554115928207282101004908218980058272267152009945412102845068417141`50. w^3-0.04427434757992177101529092105181383233636771111476574169635129223492343272746`50. w^4)+16.5473180647731135004659530012841208788768750302587941109157435356892888554698`50.68880401448529 THRSub[2,1])/(1+0.2574453893217874216699185620629506081106946674724958421349434468835122793996`50. z),((37.67344827013943889620350922561777305464631125205821580796697177840395926300592`50.+ 52.29712532421064034608400159634179360138056568805090416310734931513629286397987`50. w)/(1+0.40145842205429379037796905539920085564367717451961597692546269059976116954156`50. w+0.08728010810183573288051284356568903233500039127994452203280386332284377068881`50. w^2+0.1393224555912787575840267570587151014374701543601506898275626080825458142505`50. w^3-0.01393624284152770506955414591750348791811688812131579222719743654779718745862`50. w^4)+82.88509753604292745715668450406031190607006603224111536694858181477001175504199`50.07508403701907 THRSub[2,1])/(1+5.29851214149686253946452190687890156423708356269066039735973520362421344181991`50. z),((9.61106569138378411842469068496974481985657491060190512561648567390291236946229`50.- 6.43653680002980871900959804635555094110080683347683755519212155785575098477523`50. w)/(1-0.61099144798896531384253607410903512877029680132447933763718191596597065802929`50. w-0.23039897742976715361184623744777057754177103573065921848010895309631164122599`50. w^2+0.26523853240951770967709054334189571908515103439621444017581568129646638065543`50. w^3-0.09677257944474115164342527608672590262701492612948279262483657110329858771409`50. w^4)+14.48834819777599887485649998294970554462581745542082009278259568275680606393077`51.03753452697726 THRSub[2,1])/(1+0.10098244131574660120213402168265852989721623725324919628415092836124551161503`50. z),((43.78644780047834731798812908872063098313663321731407635893303366069003136362585`50.+ 63.28983830110150582735024601534868293983484713453642186306772371839665361947189`50. w)/(1+0.40872332831161905123321220356741216820811600238022458273430256732210091198289`50. w+0.09209622420147358710473877133193871050311890197204355228274528828433000728258`50. w^2+0.1405816656805210378302694797472748986713564930025498190130511213203054534622`50. w^3-0.01304627378744536662264593687626034333813529151027523763879778000992707886043`50. w^4)+97.78437757429809786833967982410299581773214935004025645731897756828991207618828`50.06277128133847 THRSub[2,1])/(1+6.43072165816786463282859403091395832995594654863362847196701721456480433856758`50. z),((9.61813675614809263312653060183033924019855436326285158674661204915681168689528`50.- 6.2947162771280427466830437233597821441247522154305415252203`33.12585538660857 w)/(1-0.5967857833153429094686507017383878032779332402657106985522`33.099559050204185 w-0.2282801114250038275653257839043413335037871824908153358311`33.12585538660857 w^2+0.2623088986793192277485589538208223843270652149514388129038`33.12585538660857 w^3-0.0953062748805329522284544909584561819709884844234385502194`33.099559050204185 w^4)+14.50558258059726345901909298157992798583835093823149275073325638044173732595407`51.03245461050768 THRSub[2,1])/(1+0.10229209736584337640986809164997899037214078526895803016724597479296181470483`50. z),((10.66146803544691740605651520299827475459855547189780266561072377268306018736981`50.+ 1.0217998936358764354522015496082026251779024254061674204232`35.5530919443072 w)/(1+0.0162756941653698479465099395242602887863479201424328115675`35.37700068525152 w-0.1061555610806498455116118797529364267696012383058457973599`35.5530919443072 w^2+0.1496488912175172405903254199950555642761379623050632680968`35.5530919443072 w^3-0.0409517804762622021732869431375191408563775387555935157893`35.37700068525152 w^4)+17.04850522042321351092930013480393925067819918582526932697899288384540450400812`50.641844713687334 THRSub[2,1])/(1+0.2955310461993909524936990810431255833593361125542424144385715472906588200113`50. z),((10.91500480286818350215641416337333355291282163988975290320892241958837875540454`50.+ 1.8665313857764643940605960802677529260702714131289416918164`36.716637455766026 w)/(1+0.0620530346551714300954693374698273596874672997023377377514`36.540546196710345 w-0.0925638473505802440736368179638215685124111675609696617201`36.716637455766026 w^2+0.1440568367498580892045692755582891975400143505593165197498`36.716637455766026 w^3-0.0380078336733058833483723583323619655942315820123451087999`36.540546196710345 w^4)+17.66645313274605087450257570749357466413443673253258608373135174116510942487146`50.593263677121136 THRSub[2,1])/(1+0.34248945662878703584147000129551833335199364214421490509128670892211378431691`50. z),((9.71934568761167767067901066590747350042523417136304553057431298087197444808736`50.- 4.69419957749754576894740636958384820283834253207128432860737163260187462679716`50. w)/(1-0.43990120771034603549218238369609840044778339141199886655253588457499150629686`50. w-0.20333701589152761171036202247715534584314374766233355479343142256757818601013`50. w^2+0.23034206150678866268665843001288184311616765005361835582818720940318784804504`50. w^3-0.07962666090905003625262123659526667650145573571909997779801398808996481336781`50. w^4)+14.75226020665703956268920169601157339410246181939915622151812876221030432888571`50.96670067844229 THRSub[2,1])/(1+0.1210373491536872515053350547374360218013200485070274877511875373167873904393`50. z)} /. {w->w[z+10^(-10)*I],pi1->pi1full[z]};

(* Sample Pades for the 2-loop triangle form factor with LME to z^6 and THR to (1-z) *)
(* Mean and weighted standard deviation *)
Ftri2Loop61[z_] := Module[{const},
const = Ftri2LoopPade61[z];
{Mean[const],(StandardDeviation[Re[const]] + I*StandardDeviation[Im[const]])*80/Length[const]}
];
(* from 20 each of [5/2], [4/3], [3/4] and [2/5] Pades *)
Ftri2LoopPade61[z_] = {((11.56519789141182246126591406855287307283519566607467537854273981652733406111283`50.+ 23.1082745239054623011863764599260345121471282691124690572411`48.463726356575634 w+8.5299471942926477809838787424108042878644674786352242486656`48.463726356575634 w^2+0.11325797842050491400969486817686441718383848059175498446293497639808888817922`48.463726356575634 w^3-2.2249796792690066911289994652698044802314598028430032118981`48.463726356575634 w^4+0.33365383831139544701055680393969876773800881953368517484884951645038949575555`48.463726356575634 w^5)/(1+1.819657682177597785060449940850769545074311696418179642928171427488846077693`49.52287874528033 w+0.37212336955673567074640961158589668703672978030003676967111270200117610454876`48.463726356575634 w^2)+19.25117579746587633403844105643597976774053612519597587201974382941276153857059`50.49971851996007 THRSub[2,1])/(1+0.46291393872947626378629353556276536333761627046962356477582756678927256334223`50. z),((10.40480711767882615681923496152220449371648457944687475498999317258368194737105`50.+ 31.1314531502899458709334860754221319504811454128746888679309`49.09564851664926 w+10.55861715791333472512315812555416465502912225221065915157303840700020012888196`49.09564851664926 w^2+2.68071465319120596839394282958928271795394427520403174306935348882975905324121`49.09564851664926 w^3-3.03978302467298425874721632568344929244545696224473175552191060030669250230187`49.09564851664926 w^4+0.20168478274586311300507610140966367310007532035349456292932297709920204356756`49.09564851664926 w^5)/(1+2.94367036673716614526346940053505929797587020732120433867544469915391822825501`49.52287874528033 w+0.74734059789109570516127128092900734251603137991213123004084368440977101902174`49.09564851664926 w^2)+16.42294278258504712119468343972300038044119642084788859795677970745729835598018`50.70177132210566 THRSub[2,1])/(1+0.24799400121642892995966013387949366766242816524816354074890879829946641373725`50. z),((32.01091135074920725868833440879722053735452442004850555135139563013054236950272`50.+ 78.2366673797214814309648217162595417873237882594671881866254`48.47297829895721 w+40.1522384463564706480149716186206388636755586637123526141152`48.47297829895721 w^2-14.1400996967157789458849344125240280583307026570455858494932`48.47297829895721 w^3-8.0000187322460719105603477111891199788311467776797773772455`48.47297829895721 w^4+2.79482277297895354641115395742208071082393344363671925777638932038531809724477`48.47297829895721 w^5)/(1+1.52068760767287341450078940691640141396524694475239989618906113097061419613334`49.52287874528033 w+0.29249652762588644333827767419077408978538997177436314936921877881050552330602`48.47297829895721 w^2)+69.08373490379741062903514888032224343713381419006767247381264759081265473644297`50.09177554444014 THRSub[2,1])/(1+4.24973434316467786879669608333668032818380292231081314708718587725033582991753`50. z),((30.90565898498821830992611776262205356825012119579209405897791545976310780306954`50.+ 75.1009900360442626079377226747052764027483492080035715370358`48.46751283012055 w+38.3920622953665704547396002000337978022317033515453750772493`48.46751283012055 w^2-13.3961099717105046024368438864374822663640164724666049581684`48.46751283012055 w^3-7.6683969986260194230406248004928288130829409343247316383132`48.46751283012055 w^4+2.66059364070449628285057336403943408039560853930418945334809051153914998417151`48.46751283012055 w^5)/(1+1.52170234385768214743052090253471349759316770697178017356871276940112452673515`49.52287874528033 w+0.29262290849002247490722599661488290584565524611293495996326115655918498753593`48.46751283012055 w^2)+66.3898913285298629232961388283338482125009392833505899346854460057455519811568`50.09594207473891 THRSub[2,1])/(1+4.04502677846961665343905992097344437277803311781820034781374592366167583406421`50. z),((10.35837756293862642566514522162431461357641236639774510269186052722651380542632`50.+ 33.21801362479799014677912091106681163337577167633492415187078094359485169338921`50. w+11.24861929969219399424710417949492586536310241357855249050018767416716218397572`50. w^2+3.05891695002334766344357059539007030593141499094753968959011542869562057601213`50. w^3-3.24823575094986782514810347351751337920910834640610695684101180459560728128554`50. w^4+0.19610199522237750968334733209518519950537724846048324870694308098790820802929`50. w^5)/(1+3.16432946048939865150394530310116983323294110229442362327950070609846034597509`50. w+0.82245134266818067737071010497209284099837555412027842940698550278465139419055`50. w^2)+16.30977952538332742824568786216646033231123754343251771876838479862999748438189`50.714095213404285 THRSub[2,1])/(1+0.23939462484305352243645601284657656333770442456909455789186136766718822674565`50. z),((17.04942288396298114238879173853517337008988521145413466119908556430637493783919`50.+ 36.0976033325718537739456091884619793180216277299910737501153`48.13853751411014 w+16.4189428710719673187855011777588757312169490774569903888192`48.13853751411014 w^2-4.011414489319382181813480972390797770304124274582320757018`48.13853751411014 w^3-3.5583189875998766293870688490239756381041986384827151115492`48.13853751411014 w^4+0.98289444035176227828308200059071362575153242237316696176849170833720322612509`48.13853751411014 w^5)/(1+1.56363562450108835565270506712382290067300915515903563381482248476691785737699`49.52287874528033 w+0.29993475318057514569982350793654485093763126242883498908644889059892314137178`48.13853751411014 w^2)+32.61793683699886666121315404945522201948471061193654788198313631503238098234391`50.224347925436255 THRSub[2,1])/(1+1.47866597622180214756133871376832860436878209327999597764586637576794663804559`50. z),((50.42828421110751435181404199904782147643351506463033628280505760936067294798727`50.+ 130.5770878465422445247470763884258449434531141362700689853783`50. w+69.50879071325981607864311580626484999603113448335005754234279920108187798867116`50. w^2-26.51997161895545112316225103638978709286628816534503468368844687525102720523869`50. w^3-13.5413991035043095342158196520848213836085205326273287497943508250516845883855`50. w^4+5.03354609132803767211135087398421479014188816390080015613238860747181051280032`50. w^5)/(1+1.51209075236399921350788857242442951451281188085472372432740504685065598531344`50. w+0.29156704177809133441517198085584367226795122233016805565891676451806488599386`50. w^2)+113.97259747503759546772826190470203979607710473576763861200234101219943578919161`50.053283369177535 THRSub[2,1])/(1+7.66087885922189480753872881537242425211382939078138088164758288377397224539076`50. z),((9.66533338354455737595368155939330274949070688452606547136668448866691030882159`50.- 0.42747019919218679841337160125743705358534236839239988185223220356286332205189`49.69897000433602 w-0.85787240049926488196744073211576220694452764695942627946613785174765389713977`49.69897000433602 w^2-1.38763493409345408309852511417029913719446941486957140383455910061993380421151`49.69897000433602 w^3+0.04655066735576690509806155433766623742703953781452261508359033389252190887518`49.69897000433602 w^4+0.14191884881646791923835676954393189331396296396332456493164980537138442994573`49.69897000433602 w^5)/(1+0.0066020327365898427059052463820211122169942021391315597613759976552388519793`49.52287874528033 w-0.27784024838817827055482238797396684663197032229449941143386103617856789086312`49.69897000433602 w^2)+14.62061543230142981532995911990022959579828573700670817922149327974390855743193`51.00027296262431 THRSub[2,1])/(1+0.11103354588515811155239681321080226229134281474072706519977464407604295740077`50. z),((10.84131770689545707759929295104915518015465989560698012807918209883809170779859`50.+ 24.2097626415235553168012619647613316976657306635267143900027`48.94806628631739 w+8.4503730620303737016321721790654653399414702641480133128042`48.94806628631739 w^2+1.10479292831455937727014966568570574282230328995753967455154810406740706886845`48.94806628631739 w^3-2.3427809821483407864250714219384231324217180825272591809492389474733793933851`48.94806628631739 w^4+0.25150809813800359483956384461843596544388899147669769760134641630007613468257`48.94806628631739 w^5)/(1+2.13254811119102465002107463180604979659216293810100667806646397955090370865368`49.52287874528033 w+0.47377511871268269994346778322570538112421686050267362434321764407204817018813`48.94806628631739 w^2)+17.48685477474608414125592802991739872939120900941998046516605948129205739128714`50.606486444960595 THRSub[2,1])/(1+0.32884161796920432153706416700072005242193777029915866701466557978869056971786`50. z),((28.31469782923172521938750723796261821823522008114215585032951657439738736455118`50.+ 67.7555607366547638477123023158112062973276988628920560942788`48.451647758541746 w+34.2673762304652969206684018185561916998816034658816074234901`48.451647758541746 w^2-11.650999227356769662469703884174832201512365628847652258263`48.451647758541746 w^3-6.8918867651856917491552047308433956486682183689014877175466`48.451647758541746 w^4+2.3460394025835612922772376289252951571013780021186846416936`48.451647758541746 w^5)/(1+1.52457905394683066687090814838966883164997734192043574465180119429077144200048`49.52287874528033 w+0.29299828427168097730015701546198164037926753692254651882173497208812824179759`48.451647758541746 w^2)+60.07491360993725838828366178929766073355673893534814291285727427999278306431397`50.1073773512469 THRSub[2,1])/(1+3.56514601562752227767619227044582029499326103637007917044974943849925187436551`50. z),((59.37334147820240431497425616022270258334909931274755950460426190638982196148512`50.+ 156.0234173307181968851556499985827070193569911682571898924695`48.52575191041171 w+83.7740897072951595548465827524457242992622902508084482338537`48.52575191041171 w^2-32.5276066768545907579481229705358812882665919992276621961914`48.52575191041171 w^3-16.2373046309810257458558067742300527633519885162318123413018`48.52575191041171 w^4+6.1214779793015994205892626814502271035265005394624876851666`48.52575191041171 w^5)/(1+1.51026620974898808394569519087243680432550747939272195436115300227847169898229`49.52287874528033 w+0.29140595521860712470252989992392726191047121183075215008651626256419477770833`48.52575191041171 w^2)+135.7744825429540655611788231541401592446111310115320870534333`50.04427451838538 THRSub[2,1])/(1+9.31762345975852457967892091991929628639773714405309219483142567118309275104877`50. z),((34.33070177305695147569306503402723171709518983014358965230891518524470366396534`50.+ 84.8213679838753489190515297867744507090506361842071561279217`48.4826279945948 w+43.84759927574878961100991264575362728106075813735337887631`48.4826279945948 w^2-15.7009988987018565992768544299656115983141978101561254250363`48.4826279945948 w^3-8.6966110688617821433697880665151810128665469488038476945018`48.4826279945948 w^4+3.07662381110525523575771335847100502274759628265977146780560758567481391793409`48.4826279945948 w^5)/(1+1.51886625664652465436272838194331980541336102236453914569838433920373093813208`49.52287874528033 w+0.29227797436190340696528408587931145947065563410162812003497280874103312032976`48.4826279945948 w^2)+74.73778525346414778653838733215822147711876058444105959464559472605328568307242`50.08411243920267 THRSub[2,1])/(1+4.67939064851588354313522469761327538662662433591836302249319104206183865110626`50. z),((28.24092540914813581661783374489717577184243944827702305653955174140121920800257`50.+ 67.5465463319204362367570846696551710871600074127010050501464`48.45111792943613 w+34.1499731409272975111186638553710458963322436871498096040997`48.45111792943613 w^2-11.6012851962786015485809092663729059213538545587417637870186`48.45111792943613 w^3-6.8697989993035431470110096292246913083911490581623127230222`48.45111792943613 w^4+2.337085746268451826454351628935129389185058991354879844458`48.45111792943613 w^5)/(1+1.5246733636546298723674653349381620768671416462124397592750418954999447127893`49.52287874528033 w+0.29301100411619726148995608307840738606507112465624834425574538586628962238708`48.45111792943613 w^2)+59.89510729055672008437951069369179876809117542142979446437551677288957897799026`50.10774320162305 THRSub[2,1])/(1+3.55148237379801600871808963415397386627874450147204009355115205202408649582868`50. z),((53.04684663151134466051432281402612801058126213410113521566375919595247955301666`50.+ 138.0253409931931736831124573912045585464301763180967970202836`48.51990029175608 w+73.6845484645668728493423314736001846527423030399407099104896`48.51990029175608 w^2-28.2788144312187983211192537208948612096066234634316437685323`48.51990029175608 w^3-14.3304345548747131436397458337378372934511193855872111357456`48.51990029175608 w^4+5.352003114243007479668700286397714585995311121876982443811`48.51990029175608 w^5)/(1+1.51147660359775910254248689959475285744270811504626446878857172856064944639934`49.52287874528033 w+0.29151127522288242057296180262031991349254650719754259923166827784227658966625`48.51990029175608 w^2)+120.35484805523434120428679276429493518893711618291382522272201216000179555229644`50.05028753892047 THRSub[2,1])/(1+8.1458717465375432564824546065612416970817429105080608669255291731405102441364`50. z),((59.76725659312365887344692305133075408918992203845837807858891956480094680692233`50.+ 157.1441681258828716771358365561226891730273210086492459741734`48.52606440746416 w+84.4023399819164498660803764382544341752784736498303425570046`48.52606440746416 w^2-32.792132001300531529739203950916550367562142947075524979305`48.52606440746416 w^3-16.3560554935564576762754038781174580369483722619567794758524`48.52606440746416 w^4+6.1693917896617067642971766481770568048509270557466590247849`48.52606440746416 w^5)/(1+1.51020119680806414071638349142242324336722138082785420154198520765239275867982`49.52287874528033 w+0.29140047381815849655651969377022402945429698366509024041293243963016514919389`48.52606440746416 w^2)+136.7345761237543009026952670119724735195179230526979179207906`50.043947365476654 THRSub[2,1])/(1+9.39058182326909230659116029075714424060453586535471484229962925419217209641656`50. z),((47.79014771255973660031453495079743081267980647599325177386900261280821211238265`50.+ 123.07410901257162243312303115722094319852922026904668397918988024622681267259533`50. w+65.30208767454247648343203167823743879344125647628169411517978308033294781890274`50. w^2-24.74778797332423247513953136400928448149359371455120046227490068074541582607226`50. w^3-12.74663939606865786219150704679644469483006738593350116316465876171393856582205`50. w^4+4.71273278817198966570548958762186590563537214854030287681763649859044140106966`50. w^5)/(1+1.5127974484759433031506088915446423210926659961522535038909535219787736707046`50. w+0.2916331021445562879107053262181335003562526751472265845042187092311845367517`50. w^2)+107.5426387819398179410791850600992337988678326951163678039530379310577255474124`50.05668614617509 THRSub[2,1])/(1+7.1722605900548902392350853605516582983850556201725306258004336167035324320084`50. z),((10.38820994533801635578864344793940485320864170430933410552076551215049306302676`50.+ 31.8079531683928457931877109246008374745316834011925334524199`49.10261489685295 w+10.78133775522877536502033501016745017323241043362817863134263402494190352735704`49.10261489685295 w^2+2.80509578831831006594102180645977324053419911527082075987397844299188487666583`49.10261489685295 w^3-3.10740468945236187726824856578627932382896326780514887580595797146187577032199`49.10261489685295 w^4+0.19970563059826792509261209210052556768097107319126546710906912648869849235305`49.10261489685295 w^5)/(1+3.01564386122139006724693176095724255201513323094591518709237717978085014955302`49.52287874528033 w+0.77182432788457805374171810225717866543149367723683091816421968328757526803112`49.10261489685295 w^2)+16.38249031447644927439973270025325443065374647511541450262812966329585529238319`50.70611721857544 THRSub[2,1])/(1+0.24491998225391613906756124836072818546471031566095136253166616102700355004462`50. z),((56.11295172464392659493743764556593971214283628962930511447625391828427994980502`50.+ 146.7475638724671520896910330714354228498372441633999200012836`48.522948496135896 w+78.5742671100680675785432042943053015120912383193772279867204`48.522948496135896 w^2-30.338064649369607822283656047699356763197868650138930193579`48.522948496135896 w^3-15.2545051315085209716215551833326252947917502995487265877417`48.522948496135896 w^4+5.7249133872233675387407478090402667837937515165083326511624`48.522948496135896 w^5)/(1+1.51084775140167773750606353471547664473518193251394651820148257774183325630247`49.52287874528033 w+0.29145578766183405998990081694478516106824097868357823950721957293477449055357`48.522948496135896 w^2)+127.82789924435656713317927651380818437931676667129975977795015022657520356581349`50.04718179779619 THRSub[2,1])/(1+8.71375554046377603854405285661015499241669909937493989544034419416091826208381`50. z),((57.33567429140427609619387280374552561478510809734327522471772191482740113844675`50.+ 150.2261226950119020311082136911605019742392689880200381652681`48.52404766773775 w+80.5242933604804844611666832578739915356405663747954432466802`48.52404766773775 w^2-31.1592154517416959146817500078592341190799665744804044366953`48.52404766773775 w^3-15.6230587278761588997639491113363920214675139163727504822416`48.52404766773775 w^4+5.8736316699715622705877700072500024687097178552064427642434`48.52404766773775 w^5)/(1+1.51062010176694490288642474736876213329434728927016986552277762191478854300987`49.52287874528033 w+0.29143610936749874083312108504033168929316926153419188227729564308447793635477`48.52404766773775 w^2)+130.8080542142436007506312674193777141787204351929716966048943`50.04604778964911 THRSub[2,1])/(1+8.94022016220368833184078589276689232042132718571220722530976445808062686748026`50. z),((18.19973381483236659818724112361734401117139033545870480260815342103944489966243`50.+ 39.2759706117359563068182528794788587083139952449562674945462`48.23692234470623 w+18.2245282135465550873264880297478586899721210188911462458006`48.23692234470623 w^2-4.8013300930659464993588730433072857892620863760458805088037`48.23692234470623 w^3-3.8909133125851141188923152524249771926907826169709572974634`48.23692234470623 w^4+1.12135935068757990500944991716116793860046198242987334000277096795060691396838`48.23692234470623 w^5)/(1+1.55444936322524094447180590256924480550443053589452761599894456156165021205808`49.52287874528033 w+0.29805900264587222946040027356045201504076996972110973098689728592756133356625`48.23692234470623 w^2)+35.4216021415729653666547525552388786824915120106842506613247954123675618838268`50.2017014938939 THRSub[2,1])/(1+1.69171899161910448426791127518217575816665232585096438036111292496395048974094`50. z),((24.31663656909132531731817681333493892575448568555353812211313434995478072915263`50.+ 58.52883844454459458989433662383473600224716139335686992284169782771677460653827`50. w+31.22871205311783164622419024642939342950951404063900551765164493216112700369729`50. w^2-3.66776098111799786231915464607688692626513429576800633786141610942528517585124`50. w^3-2.68927884951734495391826496762626025428983402682583334622377707667798669528025`50. w^4)/(1+1.61690495654908229845317456860529328108504303328940534339813952274719647465958`50. w+0.36269885170917640882706430125729097599862716793704830403549396138993893247221`50. w^2+0.19358039784823833527983971761014330650174253410289534089040129099955944800454`50. w^3)+50.33039554981094376428852054116161722211989906923814757496498169058255673438556`50.131626998084386 THRSub[2,1])/(1+2.82465143772042077142402207746980957237678355304078488084869794457132584004062`50. z),((51.48271719027593335037723186306466984180402530562401241772198087182329210437154`50.+ 134.0699576246710068868833344826595231564989701343037917330486`48.031960197964395 w+70.8322423659988828315482208613723759939315194965062828258131`48.031960197964395 w^2-19.0456600525089113607297284636602523070211325867271632205827`48.031960197964395 w^3-3.1838653997640773867214121771386503398068249731735037408303`48.031960197964395 w^4)/(1+1.52142429708267653223633555705712709222638915415210714737984991300878603118871`49.52287874528033 w+0.27420582549432765946253175741073764433885635267044523674158161652282474558751`48.031960197964395 w^2+0.18294401736067657148569774160779075139476433582522604668426438803094076624607`48.031960197964395 w^3)+116.54257840833090572257999120636088796759029370628599366406389184344924875499034`50.052035047004 THRSub[2,1])/(1+7.85617399179653338730310010878408138076095895523371571456283517369528263308688`50. z),((19.54519099616669228783800127782582892069504737282427571070689253289804946438804`50.+ 45.683429685576939067755124137625238103517622664806178215045`47.40236385861118 w+24.5551187625064473539276284061104186548385670669034815275642`47.40236385861118 w^2-0.970943422520763863439467499695601385205356633841964951004`47.40236385861118 w^3-2.620058493640249873186188153324276579427885844038089359334`47.40236385861118 w^4)/(1+1.68270097595975465801421571236225526105706290772458744659124131495529888592908`49.52287874528033 w+0.4228432047591937021019500473572263208054751234534864778839`47.40236385861118 w^2+0.19677733910897489947365963370107267238155272532644119218210118018856860211391`47.40236385861118 w^3)+38.70089951836667899477648518556609937622019013015186306737445486225879376863752`50.18047590200153 THRSub[2,1])/(1+1.94091571041806876977487371228024117967141502408254496776049952899978251398519`50. z),((45.36714447648777683841986637847189609181115813080654490673380943067810354337948`50.+ 116.9499394501169562398921680654803682733143559179670835788365`48.066131092818864 w+61.8262942596033178836574872116880195913234396434798360620381`48.066131092818864 w^2-15.5961602723997691988782622953707620060514122114450407359496`48.066131092818864 w^3-3.0634193497582385554688772409856515307022261586974800627693`48.066131092818864 w^4)/(1+1.53042456466475577889530188553251995377702057334612206746415732295092204666037`49.52287874528033 w+0.28256402695174749678612048461130527452173433301504893083839138485332400082432`48.066131092818864 w^2+0.18424187180652894493293615311448160339556582814994669107963201909765584503879`48.066131092818864 w^3)+101.63702672215397845466122327357930977179275986354762840064166542490019901257724`50.06021884297482 THRSub[2,1])/(1+6.72348788703241598455489903198831612066319468428810244842706892165732474211139`50. z),((9.73213692237382081478580835198923349310796374956973357154483325251549141784309`50.- 1.22435289549784078741076568167941173451573273577564228877500231607918891085531`49.629999668940556 w+0.32060869881886074581416803612992843852702402070893605479044960471288182476563`49.629999668940556 w^2-1.1847345830648248141639967858729467819628859302892078884521815006542949604013`49.629999668940556 w^3+0.39538683716317426473460929550679988463799963704609408004533330015736173929642`49.629999668940556 w^4)/(1-0.084555562836863766949501063998854455365517226679116770221503177562694232241`49.52287874528033 w-0.15375058270658815312486329953827173215191315376938331299772120412298742841737`49.629999668940556 w^2+0.04517804506714935497221070628892599976494915796644531311452462197935706542301`49.629999668940556 w^3)+14.78343642183755489438900901385124714457300843172993476587969590613485628616413`50.95919903052461 THRSub[2,1])/(1+0.12340645742137077590926176031507906922655121276329669046142871232310058728933`50. z),((33.82118339913639033538502101628028764668291511872693100997881357746216007463647`50.+ 84.742732961157303728676617589475746084454827989141330543384`48.13887944916798 w+44.9187171692682007275865115596421191277883327966333370336476`48.13887944916798 w^2-9.0666487636236367335553023993739559834757503226173084062734`48.13887944916798 w^3-2.8466415551578342701731476107121465923844462692433671247335`48.13887944916798 w^4)/(1+1.55968189477572087544920419542813812309747780603048563468401549363564793946778`49.52287874528033 w+0.3097325766207134000686754841914326161338715435155566348298056023355498130175`48.13887944916798 w^2+0.18803756268904777281061585443042967282394960692514608927001846995396220735761`48.13887944916798 w^3)+73.49593059602432046718474973434219042278033051430399643278970076756570060819636`50.08568348110955 THRSub[2,1])/(1+4.58502101066321863681292691078971791017069235811786908187869886945468931630682`50. z),((9.70644287770493469766742119726873957655468805257639043218588905656297314462462`50.+ 0.00597949301446856223388431663439445990804166810321194610853922906366261443152`50. w+0.68900493466339831341488322083950239764345774632493646688852425712094623125814`50. w^2-0.9819115561105643360216757446352405366987650308486157156156129905555465874077`50. w^3+0.26906022434558565074044151144856024568603677471576946345047935135279806932257`50. w^4)/(1+0.04553452817306036539247325823555678327748818616311693950595201334531465705154`50. w-0.11255557835682756177431707118868328059007344967606978296762460737912455231827`50. w^2+0.04354730121167926039135299916103480885165459093224041842420868681613398136808`50. w^3)+14.72081204816678713681739677877643545351184249241536082689051150268463339542192`50.97443441707156 THRSub[2,1])/(1+0.11864757567248409415638974918925588193810152193297475230272183685969545953416`50. z),((60.10953986215007586707927528007642126374461577194214404718049356658967824817637`50.+ 158.2552326392061485121934634653941659578025026032627270473667`50. w+83.56664670563749995737053941971652645548252833292024293679299290366360078250064`50. w^2-23.9052831280829602651297028318842696833384909261569547860029920522530961157112`50. w^3-3.35739737807360563839537299106654523469304243493179168920099791942262912194793`50. w^4)/(1+1.51242813778919310749114332892513131669699283765628999526845225240895363657228`50. w+0.26585380317895168077676793718136020535629954515129265935256223183799350383961`50. w^2+0.18158537024249046758176276270847079125393974160559227941401450261517697184803`50. w^3)+137.5688268467134247641849561007815290000253336552765529622403`50.04366699764902 THRSub[2,1])/(1+9.45397727629761313696666455263610546272099209800452820386041702502887244055079`50. z),((10.82972970047219975952522452078049360192597783939325664883453325247048927148224`50.+ 27.2547160199883748823046823730618968900440261828813406160836`49.09969010624391 w+12.07025168259843976924314153922070387880528747506112975220640868361574350576629`49.09969010624391 w^2+2.76495937459990512175858183349512924158262946854462016983895237547319299649324`49.09969010624391 w^3-2.36067395165270727961189813238207219667470519364964567244159872791394085422635`49.09969010624391 w^4)/(1+2.41743503702417207499138292789872321912334064140278769922833437923964645900812`49.52287874528033 w+0.78257169040912431644978761630514230042915901243280182138790338209107628135804`49.09969010624391 w^2+0.09547820790836994105045861953669514448153664348291633132011380188728131869323`49.09969010624391 w^3)+17.45861120104248229107015632655990332277128064540744537821202400472723280636112`50.60862824018962 THRSub[2,1])/(1+0.32669536373075041277791887084577739730793644433884250431920091729248674078252`50. z),((45.48653766181317981448842637307900022844017435064096512685611914161014298971182`50.+ 117.2838938026682143932576254729347068390528311185880020749879`48.065424946758284 w+62.0018806982060215661191516057774424188129734075123322465383`48.065424946758284 w^2-15.6635507481561320441780925670583741813409072600932220124237`48.065424946758284 w^3-3.0657433964753691420161646927532069687049749448115766007537`48.065424946758284 w^4)/(1+1.53021961116472933100949075283606435522883966963496074663069588806168258933839`49.52287874528033 w+0.28237367909961875099485903263635709169121765146382374995039277322034427272799`48.065424946758284 w^2+0.18421299955042858570927756718817536552674050022675932182007163299919350934151`48.065424946758284 w^3)+101.92802502732215420413481642045949360812209309608520615234467511720038642914517`50.06003447123852 THRSub[2,1])/(1+6.74560110657058132234808506757484531670042863354097143736740737468442062324238`50. z),((12.06779597973417942083063327679844970672846586096017119141679465242456614160924`50.+ 27.3721260257827344986940044767960002492771858866981910617905`49.0156678228821 w+13.872064333019535621736410711718166755329838847076873152276`49.0156678228821 w^2+2.33927961068184704789633699193661063549864267051810127839767617610111574573974`49.0156678228821 w^3-2.30324875362634002405434462999335799741120011594212075833731396335801326817716`49.0156678228821 w^4)/(1+2.04119135659580165282448711722903715092640986541754732947238112150662895365646`49.52287874528033 w+0.67690205402295551503075149635854942391549127077461108695739312471687368225691`49.0156678228821 w^2+0.1460873769265206099618574493564972802192192013753359047675407034800744807294`49.0156678228821 w^3)+20.4761635677808764148035511767275331149647408410666180382677185333753719121043`50.44693387395995 THRSub[2,1])/(1+0.55600184685625426773006393769971286488949482028454390206881181903463777442013`50. z),((15.87444838878287542093216077292468694930685638153363175908947870764068538195569`50.+ 36.19923752003207541264519012745000565345394689401945528389290190079740440818167`50. w+19.56053421446345661393940343019930759367649129509566809660357618734518980820894`50. w^2+0.99427565844029871040822217687236409516283321289240739933956536055629651825275`50. w^3-2.54961122454127935306790190737282612092442362398749713708497944073745193772689`50. w^4)/(1+1.78530759676077428735528535481019902643008679120066613778212826379232221642905`50. w+0.51297127018736526219223639271271030338720799585146812016028306856938373378377`50. w^2+0.19431926737623751077705250535253727697420877157630891725654278837574121776207`50. w^3)+29.75415875970440683209948299659462897801935461974906931100007771486418925374809`50.2535786308423 THRSub[2,1])/(1+1.26104493786146244457813648461943515905607172310417112611184704352593259875238`50. z),((10.57869274673662371093721560685917076508155980553735022311401288096884136643953`50.+ 29.4754522795122550954828988990270226619242296306594581025648`49.129739333918465 w+12.38899692166934347037029834067935492204614929748731752322344196309294441195149`49.129739333918465 w^2+3.18933937035335881341759718068273312326107424548331077165913693660753074083646`49.129739333918465 w^3-2.5937374929607867408014973739918409609560782389351332867456927604300036333384`49.129739333918465 w^4)/(1+2.71663885521782751901715226458675608777871299936882728609864323223866998705879`49.52287874528033 w+0.87059241261588609814077086703595170153685806584387666637102372186004592377508`49.129739333918465 w^2+0.08265521479754502739110513143587133821437309756865211150013034934889610296095`49.129739333918465 w^3)+16.84675611172113694635976861908828718660315302332705325300493025113488141900796`50.65980974962429 THRSub[2,1])/(1+0.28019995233003015377876782962406897554483157983656715260419599494140211731121`50. z),((40.92846039768833440943087800701304750501149586755417830898920033842974700673984`50.+ 104.5448548396674717500128335274683836030282022513599474405336`48.093392106384684 w+55.3071867027408285418544941208640077315222031838254004098742`48.093392106384684 w^2-13.0891668692865002341847627257787465156258815905662593545725`48.093392106384684 w^3-2.9780028037191551187574443915129121940276396211815876304681`48.093392106384684 w^4)/(1+1.53914548930193237644515930819640868309189014941268479106996688307801111957921`49.52287874528033 w+0.2906636696801566865820129645739934417166574638649199334868578943889949234376`48.093392106384684 w^2+0.18544097104181435049750865973685013395758631121053642697289628658279110522082`48.093392106384684 w^3)+90.81857388845793077097274450255995528709213025917594017688347007006402266626041`50.06798231723012 THRSub[2,1])/(1+5.90138405231575096150282267965256901198002553034730589107040861824795457544909`50. z),((16.07312962214374028916224701987655812978105601357058077601476362662645138109809`50.+ 36.6975924011492721835037822756905165375281236811828446178185`48.59007422245555 w+19.8301662028275569048793678590015162089689420748955818327751`48.59007422245555 w^2+0.89534273169488095487844330907699930582438159788633214723831120885924680480085`48.59007422245555 w^3-2.55512801197668295081756260904985485119933898524784338729092581983792413927821`48.59007422245555 w^4)/(1+1.77762209698115900266871745503850807608368519100579604219881164690555888004279`49.52287874528033 w+0.50645997852560468374299276316293559730320655448650515559784879009553032036471`48.59007422245555 w^2+0.19484530155653768801969190757599671844270430849359124917576376884938005443569`48.59007422245555 w^3)+30.23840668406590853400607981106438065954185414682949303430176441923053797770138`50.24809813963752 THRSub[2,1])/(1+1.29784336751595189806892227578506373897621692934272189677712466558976820091333`50. z),((10.5036453161930910284656966263192687088579719419285004917137847130477534075591`50.+ 30.8142800230719155395900032956332746064881066610466882269556`49.14170329186519 w+12.71103896236707192043027444548359285066965289614098774472265403324122820041194`49.14170329186519 w^2+3.42193853611763561755819699050999075349998090812897560819059595412879809197352`49.14170329186519 w^3-2.73113565700218809371468684568747928466784298112957532941130153182730976479928`49.14170329186519 w^4)/(1+2.87312024331784880485525395381316328167035222919786943128717941507944166183002`49.52287874528033 w+0.91898610732189755338620464531969840591116318824146799249267685441652734395919`49.14170329186519 w^2+0.0786876423004212764913933350900458083959719019558155976756301766800839844069`49.14170329186519 w^3)+16.66384219552170173995841609549928928870689718995096766562818961145338469087928`50.67716523249414 THRSub[2,1])/(1+0.26630016145954353652222887210029138433878596180535489290125736471768674160204`50. z),((34.82854992733494909908301073087433526391181129487054475201031187833923556730186`50.+ 87.5430600494343790286021443193231747190154724479556940712002`48.132611965379176 w+46.3860427203215164564730860384049335153890485648975648780107`48.132611965379176 w^2-9.6375392644489537801161183151982359183886776478189659101194`48.132611965379176 w^3-2.8647330612308093753580949669210510464719641129644308100741`48.132611965379176 w^4)/(1+1.55607834169375256983536811939992642744336857005498626828752747290569698570371`49.52287874528033 w+0.30638751668478684533221147628835683164335085257153693407411648018269587449026`48.132611965379176 w^2+0.187605003984515474968518262856143407355365752638801865392447123379538328057`48.132611965379176 w^3)+75.95119595802952427106075018248492740842506340676652263686899108367471384612716`50.08263221367192 THRSub[2,1])/(1+4.77159880513901877368686860335553618073976382976641949294093493782842506029333`50. z),((17.76751440295063875667873923712519001026538664073381952229570594987541202117191`50.+ 41.025741446965712110553220362239164900467344702616276436262`45.60007613724175 w+22.1257261351763332043528339421833561793591806994032489566778`45.60007613724175 w^2+0.0076848215203529387010847907710867171703485730478809473714`45.60007613724175 w^3-2.5916468277880003235264698635839755352852199457582313732122`45.60007613724175 w^4)/(1+1.72345801836477946116391113410523581397645491573531662241608659184530525360942`49.52287874528033 w+0.4593550658595123569474225043561277617680124587689056528899`45.60007613724175 w^2+0.1969467476885008321462423527591291801708441098857344965095`45.60007613724175 w^3)+34.368149082459317252682266034512999334816218950380136247975854197300580537506`50.209642574820485 THRSub[2,1])/(1+1.61166615847332714776900429468096125952323853178225468286421937106880847160314`50. z),((19.87575845193890866727912763333058377580271257524622145636844859735948415339711`50.+ 46.5595618406528840726974185736571414102716642681144551885178`47.56197250491652 w+25.0104750901980517344785315681143037702761242988388135301788`47.56197250491652 w^2-1.1556562472064878308733064783804710023720230374845824790452`47.56197250491652 w^3-2.6249157572109548230657054292991405422484980191307696241314`47.56197250491652 w^4)/(1+1.67642968686762729958036062722092513800667619715715033396207920833495887352161`49.52287874528033 w+0.417164926104304902949669666903501819378369339345907652334`47.56197250491652 w^2+0.19662494246302005681776552519746014240818865622407481151342325702297237303913`47.56197250491652 w^3)+39.50659516264733958425881734121062874137644521414575660533465040999615435483932`50.17593640925764 THRSub[2,1])/(1+2.00214123766856311444270427964888098896345972239697546790970611116199997775149`50. z),((27.05447628151452989566336794085518701891373929264509315293171903997413127034402`50.+ 66.0262000242433838692558822240874241105049781209070384490641`48.16548697325745 w+35.1338777667878318804682902131039151165870306330434292120203`48.16548697325745 w^2-5.2245851336168933721689140558039028476117681954610391373628`48.16548697325745 w^3-2.7316686807509469076081357219409096446426901233675126821873`48.16548697325745 w^4)/(1+1.59431380887277319972733681871510516514584219340149416773085755249183482907585`49.52287874528033 w+0.3418333024570454814062822097289974745906124063707517278310630975998955428714`48.16548697325745 w^2+0.19169193726856753385254042692947355018722896144663538170944489534862376918215`48.16548697325745 w^3)+57.0033619671644559361067029329279651972667362037053746061549000040727859979737`50.113991396567776 THRSub[2,1])/(1+3.33173607957929174134618781221631893719210262813472380805061581783532477114542`50. z),((10.99859369664550241172804941991577591443263454418768524641420686323575062429181`50.+ 13.8295440579591508900859106036066398628835370020209301286677`46.90800665711703 w+7.236040419418111251450996571256718811162662681102275009721`46.90800665711703 w^2+0.00746870271221391247388856078477483474861007044388668884359325470389713058449`46.90800665711703 w^3)/(1+1.13904700131817148721765365163557419156252848283407959446282927121186844000467`49.52287874528033 w+0.4433929715966666348513654769845158056284977152926633063621`46.90800665711703 w^2-0.00444919700608101867665015561008150643051508331274608689378584521948074282186`46.90800665711703 w^3+0.0847854572953131961436667532349233176418319875924148900383`46.90800665711703 w^4)+17.87018524989986863843828516033791257611313232209560571766885523939019509383679`50.57904243520339 THRSub[2,1])/(1+0.35797124107077521802585061664598593537128825780305450829165569391851421699705`50. z),((10.58535239905861281156314861144502282264666105933670584408950180206070940508798`50.+ 11.8174275576158233193392743137602555470417578684827138831332`47.46543210898182 w+5.516206696377456997349814736137462217867514875622186373464`47.46543210898182 w^2-0.02175743920377569866823575318002156146564583028523122344947748898869810791698`47.46543210898182 w^3)/(1+1.04592714591308991341786875090558629138752149217663196796775669612725857611839`49.52287874528033 w+0.3366532541627662105366594341516003306290314549277653827079`47.46543210898182 w^2+0.00240237659629339838772350803988492960532273886408272949293407672236396009525`47.46543210898182 w^3+0.06956742108389557639651409659626197821685706304667916841796211588560790173778`47.46543210898182 w^4)+16.86298775453581108084012605382772015338302416973823243171280516106076075423693`50.65832039089679 THRSub[2,1])/(1+0.28143340927686197653189414068684492827983127852044170740377204758746282103121`50. z),((59.78431367457929460751971705964758272947200426502068850292363900918096351421677`50.+ 150.8450584843485340337073934620314023366610726247930040985382`48.435571248125285 w+65.8818665879120451504935577205986121728747554565868086638924`48.435571248125285 w^2-32.22846825730591167906877119080155618716433798980960690753`48.435571248125285 w^3)/(1+1.40402272806776172701178840140259875688649849837901757997451709241031784420497`49.52287874528033 w+0.09998159633358916437310313563663977021572495254834449386557820752191333191799`48.435571248125285 w^2+0.16339935128772285769512453087028488336591907577279956826222101026594331655373`48.435571248125285 w^3-0.01976767635700961631187701710571347864221811550902377694337890757573693414198`48.435571248125285 w^4)+136.7761495333352364273426232613709395977087831938812789842322`50.04393330856057 THRSub[2,1])/(1+9.39374102356918337624031344930972759394946420457319154436771377659599627836749`50. z),((53.12972846640087671639494127350611818225129052291900405796511503707451263185349`50.+ 132.3040399708609224746510362439200876852236201409761212946715`48.463552859281435 w+56.4853658334086531816018732600068174194740438925112404906208`48.463552859281435 w^2-28.2094118308564239663757997267711690914046365411969426848422`48.463552859281435 w^3)/(1+1.39933541632924864536076242545968056731586685676527132899949543452697003754645`49.52287874528033 w+0.087613212099990435100217370747675079206149635860958218599374082561649064747`48.463552859281435 w^2+0.16300483018537558850991720209504492702313656781736125381778221300102318408153`48.463552859281435 w^3-0.02204069347317608828908870829516445952862535582101125809511933397919009525284`48.463552859281435 w^4)+120.55685685009435052697341553883602205552002665006956309509111815488577479382268`50.05019821239524 THRSub[2,1])/(1+8.16122257418857701378351427550456304747489603435161431866274637034202337558919`50. z),((9.69795690754079408897964441088962548709236659671045180628957811816190496893522`50.+ 4.0018330862446976082103906535496456085411217608267165985997`48.73874057723557 w+1.82127707592214923941798222517772997849042545322383571702403917558390928218612`48.73874057723557 w^2-0.38570823102493019788209968417943055061877227694609748709313206924930280238896`48.73874057723557 w^3)/(1+0.45878152403086645124425641616385196122316699517859357981536970592292316794767`49.52287874528033 w+0.02259197509642861143945351130568349081009682749954722388957372328560042802904`48.73874057723557 w^2+0.03412929295264581145656501369435257121095985603023141055237432164817307455964`48.73874057723557 w^3+0.01210061839809814427021482564102347827690390173705173462159398775873333593509`48.73874057723557 w^4)+14.70012910107276053250232314565496482170718864628107176592152126119147575070656`50.979615309628585 THRSub[2,1])/(1+0.1170758601619001247119310913461730132343331425309754488783288647823669648034`50. z),((60.96444799443709345327833084344353049976070004934515346671274496990581423886324`50.+ 154.131714971932038789609104098216055372161743205616943518402`48.428140901752755 w+67.5431999586005380433883364979787640139975078292720183866133`48.428140901752755 w^2-32.9428060430630342196234804041927881054226946555495507152799`48.428140901752755 w^3)/(1+1.40472359979163126245277763210223531773494441121967741188720149360131184641257`49.52287874528033 w+0.10181302901994013452446024907355219354241887570290653009604654356123041264136`48.428140901752755 w^2+0.16346369591683810528480373663926003428866830403492306479835827692499792488129`48.428140901752755 w^3-0.01943079316617904446864961842731295271401305570631800741679088358555634729417`48.428140901752755 w^4)+139.6525037072643687345554962438304499586722641615099794757699`50.04298212642458 THRSub[2,1])/(1+9.61231773067699215636176402054632462762336136584670144238658619382949697201919`50. z),((45.2451546918821823049584893686199954968226493194834021617822161319520402154908`50.+ 110.3097843888354917111031265732114745655956968169953722256655`48.342391038542914 w+45.2576389220173809182667768956068010414431496454454167521495`48.342391038542914 w^2-23.4769365126498515419640025333617909734589795100407155996995`48.342391038542914 w^3)/(1+1.39141714089916052433704627191066618994216143026985604882315663253675592047852`49.52287874528033 w+0.06623729875411630017561419282886598528699386459867351412730101639763404703361`48.342391038542914 w^2+0.1624809853337952879699750583995179416326946876046867053983772292283665100545`48.342391038542914 w^3-0.02596212345587527846688916390321981047146173991630430411395207457888851754344`48.342391038542914 w^4)+101.33969969740539060611782716483260470408879340962396673224588535695292325747309`50.06040839971498 THRSub[2,1])/(1+6.70089374247512980190923240592580709278041446999578256502521346197349650372089`50. z),((31.07425528467186066052953657075190615936355442724713544339226124196441208403396`50.+ 70.5980778014275580836837491273307424054071082394465834153338`47.83906673603881 w+24.3791328935675833151600893143386544215125585522266769091725`47.83906673603881 w^2-15.1831583045086092719810809606443630673596282132625972076555`47.83906673603881 w^3)/(1+1.36124197319527113742513371119045664088046289319383687147140611976327276427719`49.52287874528033 w-0.02100756671388164704169490625655172146451954368763656581469999776136944029586`47.83906673603881 w^2+0.16215531449744693890065109571835409904872088891816451373810643371185296589668`47.83906673603881 w^3-0.04193119835487086324232808572993856671753657877945079221494496028743450630747`47.83906673603881 w^4)+66.80081291783038004427227206743218294290223049407358966496552432463220757309804`50.09528212614821 THRSub[2,1])/(1+4.07625307482870589977795532522310457067480466907092523837219359430338326410783`50. z),((9.6782219641569272330708284913030939743587690274681620827967709796842719461864`50.+ 3.6199985695037080229174399319788858139874303588204834904065`48.404966394821976 w+1.71102707272124100841477523044367747414137242279386895144525212568801232406463`48.404966394821976 w^2-0.42523379193866459240080896310740592672921819629982661764206013314946422944747`48.404966394821976 w^3)/(1+0.42300617137099780333655115392391607915424264854925821797927071738706368010125`49.52287874528033 w+0.00929340910483759505455496654581074299309743253701921371641458248662003689009`48.404966394821976 w^2+0.03561536036302326793311386860003795244766717911405016143740819792588028552621`48.404966394821976 w^3+0.00886575854657169699465713461224164276576843529083491587260762548609455045572`48.404966394821976 w^4)+14.65202890957821909072946163493792814165188930800187481393069949443808693133279`50.99196702320296 THRSub[2,1])/(1+0.11342068391016258966174643550811877726309517810576477600580438531942697765017`50. z),((59.15273604953988089723458136568486603084763499169067119437306602703689522624984`50.+ 149.0859691782273203307269557889118338470181554463739355438704`48.439648827295564 w+64.9922215959296174572378592815893359929230718733606981385842`48.439648827295564 w^2-31.8463442372745349466676278235734239684599435601155555540469`48.439648827295564 w^3)/(1+1.40363353045477715993425269706173977132534540629749138515403439488019777271558`49.52287874528033 w+0.09896258612680469095039172077003425198528312683745737397256364169426777200346`48.439648827295564 w^2+0.16336422019254288060156705882544662743104747148751915923416860492278531212319`48.439648827295564 w^3-0.01995508161025398142815194463942504111021714591650978320675525418467978968732`48.439648827295564 w^4)+135.2367985396608353819835789170421709697300846278791754088161`50.04445987328234 THRSub[2,1])/(1+9.27676437502910903813110005477242564443290800532075693615293377435775469489532`50. z),((9.69902194499675388299052159894421693525337853953143413854871149010060559217594`50.+ 4.0217207649025620240237859804914735647245411293707032968305`48.74934171443378 w+1.82710926813868742501538963935647565928432947476758040503235970570648904572225`48.74934171443378 w^2-0.38369548220667987935785974841110099631217431402011147035216917535734303126356`48.74934171443378 w^3)/(1+0.46063396272412094680578194544911124881719275962377794981139402384673186115907`49.52287874528033 w+0.02328682164277512765290678414613153762451752708655196050356152944258786290367`48.74934171443378 w^2+0.034051279271120224487980311331376420770042882508538394988391800028684057772`48.74934171443378 w^3+0.01226806397663722569455735705635990112371756412002558218762384785533684323277`48.74934171443378 w^4)+14.70272492841232129332828399580765544839185323194844102866710467284203301490319`50.9789608729006 THRSub[2,1])/(1+0.11727311938583170241364081443860115492878886059919092657571409394822713448276`50. z),((42.03747072656872286960967386668896869527343786448245356765309594500964341551827`50.+ 101.3488646427621311998532273723883433012239441202642661825189`48.25504623422393 w+40.6418201982873028910420571686483479117440430538992302096061`48.25504623422393 w^2-21.5664163054121913489175828894043242351675260486427110088832`48.25504623422393 w^3)/(1+1.38703674599046779641158924702246673611999222725921424067278574576412756374392`49.52287874528033 w+0.05414710890325290564147465993550725050150915023342322070886626696784929060645`48.25504623422393 w^2+0.16226884765031447704058937437520907874884264100693385968717061089761558698288`48.25504623422393 w^3-0.0281772257483343371257878619888644206724516418268481228050217703614870563307`48.25504623422393 w^4)+93.52157678798380442162825557923957465189320166940968742175398088558937597594422`50.06586052041434 THRSub[2,1])/(1+6.10678764219222534856337709573583795194469923861984467754550520860103873303756`50. z),((26.56911696913517092272618715187465362501027620812027678265714469846513217137872`50.+ 57.8293420901840003346399917140645122618128391336961386036853`48.45189975117761 w+17.1398895673562855144184004752768762654280071671341838939674`48.45189975117761 w^2-12.7236560976820297934505275425673654125615332080666116172022`48.45189975117761 w^3)/(1+1.33949340994484419267444286370276924084004358735363959266724471620830565585428`49.52287874528033 w-0.08977863777163692318746550288335351218157207694514789999621602389477477969806`48.45189975117761 w^2+0.16356878210071222040793922776861627977379052318459746623287986652120196221493`48.45189975117761 w^3-0.05453741311901912434926592834297147460855601583968286761747563359172586955172`48.45189975117761 w^4)+55.82039045237454399332975874661692683130119130203247059533638859371040513691231`50.11676267421419 THRSub[2,1])/(1+3.24184102400902937059638984596458904792492158427837443459274883457357932981776`50. z),((38.40208501991330999286365043824577148007434858854678099511246885517179390229574`50.+ 91.1789048741925006590175138371929356713366947892608734993224`48.08582957908474 w+35.3564137712505082818072781128074548795039795916452146186929`48.08582957908474 w^2-19.4176274551168253252738430901099305316250729677226565049583`48.08582957908474 w^3)/(1+1.38081731515864402314547046715264700624266242366637758522634453166942760712588`49.52287874528033 w+0.03665080458388973891344396116528510215919526849644348001059493653988849994235`48.08582957908474 w^2+0.16206340357742768979017994838842822846205096406470928177287658415995765447421`48.08582957908474 w^3-0.0313804497302559431677452195623074977718672264565815313429312094601819714883`48.08582957908474 w^4)+84.6610117868400468358872735906994261602719657974080822933166704009651600684898`50.073368063245816 THRSub[2,1])/(1+5.43346544195040726239776452476655676041011181937261263857647115112472439778556`50. z),((24.48819181363651571297084161204351719099643267758684080214550726073864665617027`50.+ 51.8641382352859449025996970077363742412471580538959511556436`48.63742013021403 w+13.4919679110576423948074951501646082810367339357375394170688`48.63742013021403 w^2-11.675320154778879015823382915601486704766941748680092467164`48.63742013021403 w^3)/(1+1.32399689905574701234163209185685293819228139816226274410421178182197952510706`49.52287874528033 w-0.14181165662665592455840631697355682631606593746474028654440442640500777812918`48.63742013021403 w^2+0.16539784237266740084368845717037878831922481992592868471569798923263064054285`48.63742013021403 w^3-0.06410855300100753222741167610095856981248035790864014800458314037518538535823`48.63742013021403 w^4)+50.74852900750620887792830806948502769879714662463136776565816964551525869628089`50.13036203377091 THRSub[2,1])/(1+2.85642577036103149257005679247452338217388196696158713027542506335356249604712`50. z),((43.45378762035826896211690872990861557525402031647362324970505381616753861629926`50.+ 105.3066723020623438557058858873117264650303270982422686144305`48.29813172724461 w+42.6844455799205467214519136323364410320598310126957153729763`48.29813172724461 w^2-22.4085894691878032512988924353394505219178263007755628253819`48.29813172724461 w^3)/(1+1.38907853128706996569561986572180527993757900220189333883039134512029515777987`49.52287874528033 w+0.0598063126964407567931168550754959825082720098065033804921610878689056022301`48.29813172724461 w^2+0.16236081446443570917876832096967969932112211667115860336970718250244691229832`48.29813172724461 w^3-0.02714058004797757201335955842378385654580627774733809656147959708208782919196`48.29813172724461 w^4)+96.97358131027308374514314167949518831658765016405091733278204518307272979895604`50.06333630337152 THRSub[2,1])/(1+6.36910853029501475441647013823764754938012723849320918420604364069622446215258`50. z),((10.09178790455623932821393108017654589997104334121050601987312110178747161400656`50.+ 8.6748201469280119346042873016609876565037783282092627451551`48.13487939126604 w+3.577592850545702417212931309888153845966953625222249465817`48.13487939126604 w^2-0.06772492983296084443739128881421047453260389351985388294931533008713398246666`48.13487939126604 w^3)/(1+0.8514471327906240637622323166314826630052529173988324725046259994884294602088`49.52287874528033 w+0.19639563225514902132748486729050980801783128794768695430402724757481179165787`48.13487939126604 w^2+0.0146624989623595478637102448424539717643061775644400082275000865207639836519`48.13487939126604 w^3+0.04808563858018589100875926935270762062408455996318532773328246737285918277068`48.13487939126604 w^4)+15.66001766038908040981197762588464002311070885079716005228748238152393685307194`50.79675755112672 THRSub[2,1])/(1+0.19001864390790103411279363756318647385134415542237268508320763807822574009511`50. z),((41.3109366585927000234074642402777908990220954615432035103028089179581399526153`50.+ 99.3177649285083413965931103039069980474770370497068803880628`48.2292509180826 w+39.5907981353500561560021745022903634488915988685031193662468`48.2292509180826 w^2-21.1353810749027472542652668897305476760984207651693495109528`48.2292509180826 w^3)/(1+1.3859145456602332132541775215232778217202958267059249227362506238234257793662`49.52287874528033 w+0.05101896961517142895691224580223932365835034034121273444255751597631811882768`48.2292509180826 w^2+0.16222345384459049407277619526967413402007248228354058052831150271765382461673`48.2292509180826 w^3-0.02875009968505068552781636860550952014341816695088918710274897163964753071328`48.2292509180826 w^4)+91.7507874263318582739985065395912903008785854699960985624946696095729761612444`50.06723524524909 THRSub[2,1])/(1+5.97222378661434916592074223352706035705973261978277321113077983177548151189642`50. z),((21.4682379550545583974346455925167278955197360827660322032748022050915397415168`50.+ 43.0341354225429155230512673141835047052261511973590588329789`48.80132397114606 w+7.36729475422842580292377775230044458238475701007266697239023448276584265519875`48.80132397114606 w^2-10.3906297712459212584962480523667232281603144794010532796855`48.80132397114606 w^3)/(1+1.28810704611945657671477865619911611149716812875979789279430295688519176762882`49.52287874528033 w-0.27154199443422553689958898482222690106253009272480334742657095872791281972552`48.80132397114606 w^2+0.17206709986123180746000750608332506349004587261237747800399329856789773451679`48.80132397114606 w^3-0.08812799184985588327885269641195896142400385147282842023981759810731941439919`48.80132397114606 w^4)+43.38796272276983877989503407272417945197731076300833215273871692083083462021821`50.15695280219399 THRSub[2,1])/(1+2.29708980417550128854925219434570493796592672874401358642970799316351523183118`50. z),((61.79963485452344090463148917898813063128493558266676421973236299325149546249837`50.+ 156.4574819728021819992091487137040364638521261890247902872237`48.42302524996734 w+68.7181807952332138477159396778969237498509186556571702062116`48.42302524996734 w^2-33.4485846170188430171188964995554468909221694410687654343465`48.42302524996734 w^3)/(1+1.40519994056025157897645238987062774955929157256029504275130357334076833031185`49.52287874528033 w+0.10305509799740964537405106929543993582278009755078672776741041993353362450216`48.42302524996734 w^2+0.16350821909657132276164233901734292063729652860802059476904848791774195939548`48.42302524996734 w^3-0.01920227119083517782834333094456620816861097685514838259354997584548032801376`48.42302524996734 w^4)+141.6881136972438126138368376836173207815312317752760007296221`50.04233350245139 THRSub[2,1])/(1+9.767005540891155594379155389096124804422438526362822946185180762618648267977`50. z),((9.95432675474304865066450504316445466296304511134803122881472358914307498491807`50.+ 7.8094542958351833200028105089504909148564510125586278900811`47.68559095518845 w+3.3126866059209496098761463562710108059399209294864638110668`47.68559095518845 w^2)/(1+0.79484127247397636007185592546673617431504703297463827575245283885503164918005`49.52287874528033 w+0.17784144546229563284879548410522407366404457448159725140038796591886258050669`47.68559095518845 w^2+0.02612006235141624035345388365516196738228952212895806386457344250174003534887`47.68559095518845 w^3+0.04010435211706050204584321300205599670454516911828860749195668996542681868171`47.68559095518845 w^4+0.00164599527950362432068089966343704124278629568528989893309967671033940028714`47.68559095518845 w^5)+15.32498210946474900561606212213369080551603664190378158820782740592840321007697`50.84983986791233 THRSub[2,1])/(1+0.16455899497146404124350207735439213650916155644631980838565383555076128377316`50. z),((9.65446211080301227905313673315192307049275030795186472059346784901265713034318`50.+ 5.087308049852286399166274129579760740728996675957115763772`47.95679429680722 w+2.7405511465722643243157518223255886191592634148915145256013`47.95679429680722 w^2)/(1+0.57933919493055152104514638496018195428248949633753212361798917034274794045839`49.52287874528033 w+0.12378420968236662315119552420704551754702086321336269157064250051427666383286`47.95679429680722 w^2+0.05529301778244714820997608718916801152759364870506957653450810475552787927937`47.95679429680722 w^3+0.01283076537161988750577639851556948523103379621267422934224931156453356244116`47.95679429680722 w^4+0.00606176418524403583596608187989756243439916062654199648042721696748271596568`47.95679429680722 w^5)+14.59411876137177403017152484572173054577625162936378178552558712478940252122765`51.00743305566921 THRSub[2,1])/(1+0.10902004033927742668438431871640038576961762563437738346357673096718860282656`50. z),((10.36786109756556835497025389193547160357044843197404626972973151819966033314542`50.+ 10.656443000475407268807423544935406229757812198620238282336`47.173985974029485 w+4.7292898207228692565895602272657082676881336187807599446312`47.173985974029485 w^2)/(1+0.98409840987705770894983268198815540423966841184414326760310650134919062828763`49.52287874528033 w+0.2850138100219016680593440726293042183091702462212349734255`47.173985974029485 w^2+0.00879122633669791766523308126722750423085136123115554125041750317038735773621`47.173985974029485 w^3+0.06118222271779268977873096567872885007397142840586195066338617244863075542907`47.173985974029485 w^4+0.00041015936911289934385481780268632528922079301187852969745935079515799613811`47.173985974029485 w^5)+16.3328938471590832237638652536323781989918653946181798778046309991412561818126`50.71153540536264 THRSub[2,1])/(1+0.24115110267411060233061867053378018267349006781226619172585727873662812989624`50. z),((9.95290995492997693556763831356465860015822735283725200207804766315956351105536`50.+ 7.7980079261125399122771455418679259333667681215545805599609`47.687658826648715 w+3.3086124753352744864206850519928072460809509137257642610258`47.687658826648715 w^2)/(1+0.79399579224690357755162890612115917255436156232571948878898389464337050950146`49.52287874528033 w+0.17749882786272953794825883960141968415871748165740529170398311883426231941891`47.687658826648715 w^2+0.02621309978959657268830038515360813838724005258518562048591068488555575183608`47.687658826648715 w^3+0.04000906582020043774894295738686472024614520295408969372397404728938603656646`47.687658826648715 w^4+0.00165603370916941703546583632915186342966503073504084772459801764303373919037`47.687658826648715 w^5)+15.32152892791805702520821968125005189014708165015688339934355609206695981563898`50.85043508798289 THRSub[2,1])/(1+0.16429658464023200864553057179589332304759851123433859489707741912484768092131`50. z),((9.61328342121652560126569037690335482543552242357837945892662708353174353895386`50.+ 4.6738713702334347161752464815300944997973612628622379133586`47.7386439992575 w+2.7303981548671119370389408738102635841805128975087422609897`47.7386439992575 w^2)/(1+0.54457428244529886111339445294662863938361005600902553227947165590033487635332`49.52287874528033 w+0.12150046264750564754385376591984977523286970430075473152973416672990366384844`47.7386439992575 w^2+0.06114337247853475727988028516667690248285986957965107088758825215625750190023`47.7386439992575 w^3+0.00760109148046873153077202307136557100127694634630899756554369193034890411425`47.7386439992575 w^4+0.00720815750923130635918447519339512297792894908329783149084194463948355848041`47.7386439992575 w^5)+14.49375349474407769498950445807068423026149791918243812358523118653648433979558`51.03593358196468 THRSub[2,1])/(1+0.10139319463080466547832527560024026111343898546459314673717254105144842694913`50. z),((56.32100753039609827140002528545993283365514538160335008295551259508633599542242`50.+ 146.3906005571095457476086774724700565977645026959129004247585`48.74156397672601 w+88.8898938860506270713535643971060301005616267547655145716716`48.74156397672601 w^2)/(1+1.49396083270532385048842325559410242354624669204978722501768001921805708590941`49.52287874528033 w+0.48733928541879727169754960552747020865673999982042450675780924794901345245964`48.74156397672601 w^2+0.31519958026646051431750424671032940939958638961399094613425203917593595981658`48.74156397672601 w^3+0.03305418031870503039622172854075286895688440728638894303060181635812940025393`48.74156397672601 w^4+0.03985687844433775390561776051578346320619410850357417384901886640314641373982`48.74156397672601 w^5)+128.334995915655438865173125165044375900215915037227003630717`50.04698490666744 THRSub[2,1])/(1+8.75229026668159442069375468320637475501387220101342535835228386936754103704713`50. z),((9.9373958672008221589735920249373403669510783161884394746556245545846386227563`50.+ 7.6717875328584026815446966865321109820686909254978908846666`47.71018315991171 w+3.2645731470018327287897998439921477110497439884313212432386`47.71018315991171 w^2)/(1+0.78463321778090620611831309381921689642912369352993238990400230732419367720715`49.52287874528033 w+0.17377584980275127141226538002332912254326956832482399439075399394641528101442`47.71018315991171 w^2+0.02725386124254171644685844475448274717157249375029127863101543650126394066537`47.71018315991171 w^3+0.03895003620059752315661413629972022814320770992301183876543794946287219308422`47.71018315991171 w^4+0.00177043952220445088456754979128466726280898192967821882486680427918957062766`47.71018315991171 w^5)+15.28371627367728036630787589971000212198090495734170769471449772598518098709997`50.85702462000067 THRSub[2,1])/(1+0.16142316747698154316355401071629093686670124301356005513819873821624941243749`50. z),((40.07236972500502613213874583023930969840251549542746034032207384619833164704618`50.+ 100.0818771729554834735787588614974792629032664751926512306356`48.62712269058301 w+58.4222867863593347603005584293736627943859313832345854619908`48.62712269058301 w^2)/(1+1.48938311111101267113029704370756951947726019544307937504310694805042036689745`49.52287874528033 w+0.45370819403740322052960770569009880809304105509902726048809769043983033615448`48.62712269058301 w^2+0.31201215069794689653531935992196967636081737211665000805007332936358243553404`48.62712269058301 w^3+0.02525884759835284024467964678248410443044943672816737974214847337807177202547`48.62712269058301 w^4+0.03828963905694461970432574435752751471551660378258147021885323493549272558267`48.62712269058301 w^5)+88.73201480937687880888210921700868624089173176505614259065801368497365386336678`50.0697163108044 THRSub[2,1])/(1+5.7428245755916321266080146621556038542010756595951774868127004732162588245831`50. z),((10.26103518241109519666544225786161930784125509795747404325528632689032843387597`50.+ 10.0031450451267799812697907463348098064646975869023926494903`47.271777655730496 w+4.3343914581299964654991197968316867219914468689027379466974`47.271777655730496 w^2)/(1+0.94467588240893844509489266563758757242607421360744337360564736388550097192514`49.52287874528033 w+0.2570135589419792261051541438299207933012744461829018482677`47.271777655730496 w^2+0.01191464577485086035906533492142973184368982811198407870993571993162859818754`47.271777655730496 w^3+0.05664081593957643812881047128578289257562179805478516220061207949078152840452`47.271777655730496 w^4+0.00053159489841755044156982206628962925260531956731832416380869769824772066971`47.271777655730496 w^5)+16.07252588584482126572632470329133754866212283592688195600540284645204650654527`50.74173569531514 THRSub[2,1])/(1+0.22136551015693302804093175964967491753462270488084313453584954277514097273723`50. z),((9.82631929811727353928204873584696319448923791268334829557963797002388956900483`50.+ 6.7199042227856917820002029150413246298410745297726475481087`47.85909030440418 w+2.9857032887394666119794394445816866161334814458257812774984`47.85909030440418 w^2)/(1+0.71183301365783939940472443163068848404052953389398357997826879937724590780904`49.52287874528033 w+0.14916274874212285333776124769930105084359151405903015562582518613410071759029`47.85909030440418 w^2+0.03602154556627734782494896437322471095175619997192697340677482930829922126241`47.85909030440418 w^3+0.03041375579798617097089808890094475692732737430626547788147110959553786725563`47.85909030440418 w^4+0.00287656596583691089466830277107082851423438661423636428261886802698851757453`47.85909030440418 w^5)+15.01298814745204649729974123602996469655733665438647947188383227332079509718622`50.90847089316818 THRSub[2,1])/(1+0.14085029683117185216885506311799699410128415608388234437946038364202812508522`50. z),((41.38593604346831840137191368674255937614705046872535139055548882000216245692506`50.+ 103.8295536427729983637131417680989842383219202284102250690881`48.64280415574142 w+60.9037471124214096226957034476641746829827827780749474864448`48.64280415574142 w^2)/(1+1.48998347601380684585214665446470815856081594642568423341349322141291964329584`49.52287874528033 w+0.45779790710223557104356490322154327524255632981209916077686130533249874797398`48.64280415574142 w^2+0.31230603101493039398994751405798515190553128215369656451091092539403069399647`48.64280415574142 w^3+0.02620179012388468739642618346103800947165013930676196383578768825287285444825`48.64280415574142 w^4+0.03845265122919542036973177569028375910939115592590233790793740412876974068612`48.64280415574142 w^5)+91.93358424030392907765163764131650935839661609219530420629222777333025674442109`50.06709067784515 THRSub[2,1])/(1+5.98611467878262299659556023313905634786869913407032041761050581256328737186535`50. z),((9.65839930348633375420925966120907121597306334315385058079501164196862117767654`50.+ 5.126519751719653094153509819752500382660397915635060176822`47.95892222374991 w+2.7426882105816947009063317159255844434985676904564422378652`47.95892222374991 w^2)/(1+0.58261470332129865501681212027017925464759778339099681550910470655475408264861`49.52287874528033 w+0.12409890973503400062354366077384366806305678686976902452850377415136511569108`47.95892222374991 w^2+0.05476020549509552438089359024006067877933551626017693466642034157361894670179`47.95892222374991 w^3+0.01330785633266820958484987450443006496699894336371332303035506358019853162101`47.95892222374991 w^4+0.00596132179231785776120136732805370093327123543113512515665696323131910200007`47.95892222374991 w^5)+14.60371492378962452608772893277557193041169217774463695757145910122068825671273`51.004823259048315 THRSub[2,1])/(1+0.10974926124022797429333086712942401332427926248962324019297851770811976888424`50. z),((9.66942565860738907897967428671631701670888322626672814321076539267144261051503`50.+ 5.235983655552573993139363353354204710348119054725075450189`47.96297697324368 w+2.7496963098286360297430477858047820711106987628019107444107`47.96297697324368 w^2)/(1+0.59173748186543243477968339255243694026441516689152772444711339623109160302781`49.52287874528033 w+0.12506306637271308990992932105371804767950343782069667588551758992633222832725`47.96297697324368 w^2+0.05329236939603060505388283385065815578412193112274916550688166489519288076761`47.96297697324368 w^3+0.01462335950371558237319820685302468975758784670664435071467544330100230319233`47.96297697324368 w^4+0.00568808125526185809658028388022888132376686216481597215707927268617101251323`47.96297697324368 w^5)+14.63058957868441137822071714763489881165879248274191753186319556083654274027443`50.99761460042371 THRSub[2,1])/(1+0.11179149012316733703663174670126908160080687803568211798796951435167617760326`50. z),((10.41803294710345175152849276192608662794340409733385610144545671477980205090605`50.+ 10.9477465499490866888074094584426875018906990603089372142339`47.13669695182992 w+4.9185595369594452866581963261614337840348359701038664306978`47.13669695182992 w^2)/(1+1.00084443212681288219897878039099955528065218844131472910729649955536542842688`49.52287874528033 w+0.2980443983954765421786039236149294350008288526072090927071`47.13669695182992 w^2+0.00750498420146382880369530132613477597519156941135081396060353006745236564067`47.13669695182992 w^3+0.06319759901002886330088038609526552706570196338797362669034856258144550523648`47.13669695182992 w^4+0.00037135547803937308606520945484227073348076364111533366898986652184394835513`47.13669695182992 w^5)+16.45517824004871997071533806019718170431693971889840824561287632442841178789198`50.698354167057374 THRSub[2,1])/(1+0.25044360224553260336998760758234683734012743571046267732564481921336000899184`50. z),((30.68493488313774892575435190865485241246692585700147185439837960000411893559066`50.+ 73.2554801751107776717243836839797899111122601808049085352494`48.39450212708175 w+40.4701136070835425108830637364736874545401341793580834425727`48.39450212708175 w^2)/(1+1.48217762592757726361404821333205452985984177989988869436922943456934697719735`49.52287874528033 w+0.40779870705053827020753354316259090309676576773395631300500407411704267462602`48.39450212708175 w^2+0.31038883108576390265003088686402231166911679955105937987198770103025028057092`48.39450212708175 w^3+0.01472543926868306030228145591712070686102899127649286618361912292845362307015`48.39450212708175 w^4+0.03690010783639500675714198799803392584325747848190652568305375995481157951232`48.39450212708175 w^5)+65.851918081788884366026007183462832610156230169364116647390531226999685687834`50.09682007386872 THRSub[2,1])/(1+4.00414571387383611963285633674018989041879800552694943644725973896430886381825`50. z),((56.15348385185357475002985368573627327172159855141057766606549460033383209072869`50.+ 145.9135377704003969350637932524587753339333354248624912976609`48.74090368437244 w+88.5774812147057719895345392797588877664140865015082731206957`48.74090368437244 w^2)/(1+1.49393393349789474201570960285962703034425015381859206976001713085544696197084`49.52287874528033 w+0.48711803327733742103447860516958456981628334025652639542814968798666707593724`48.74090368437244 w^2+0.31517274755126294334676778138560337430506679302966653297904563724520267889083`48.74090368437244 w^3+0.03300252775290970645037432185079335977918794342571641634946947653391029818709`48.74090368437244 w^4+0.03984476110293566370310796767237656064145808630746490812394196120939865985009`48.74090368437244 w^5)+127.9266886374925501553179013765124911800873626030463233939238224356636252177403`50.04714331125743 THRSub[2,1])/(1+8.72126263414666056726924881526975183310087534145790424760206891745454974828185`50. z),((9.84195190766212822892371541712130180084902004581718829650952844179105098799158`50.+ 6.8590274562558772638955256947096216931223480285976927708967`47.840075724642105 w+3.0204973425884401711516771059354351925191765903417264152323`47.840075724642105 w^2)/(1+0.72270213595227180795413290803416655011187504193621635125435585069273314986811`49.52287874528033 w+0.15235752664449000398329036752542342457920124204230198830110276982276081772223`47.840075724642105 w^2+0.03463480892887840953935681309571259041547210926469670121464343655205288211796`47.840075724642105 w^3+0.03172775280197729906205473916048376240222755763887091454395112914183563145994`47.840075724642105 w^4+0.00268569964776259049724401373486482686929936322004660798708097337819170932887`47.840075724642105 w^5)+15.05108967619935490637119783544675116672448374938765754373589234879250892209732`50.90073470249262 THRSub[2,1])/(1+0.14374566582461673752169424265280208659017673104693350308827394166290693964371`50. z),((57.75311442533743748168323799064210450449335649480041415785308032331896756250827`50.+ 150.4686511117153722584319085186406559922444994287318441094005`48.74697372704799 w+91.55969935829649006791352120790206081753046782582955721031`48.74697372704799 w^2)/(1+1.49418081159496746325297530198054107143142982835190728209286907302829859663493`49.52287874528033 w+0.48916504638703124400148718987649263590303832682428190486696839499502147254736`48.74697372704799 w^2+0.31542404738343978069887842459762721975052000865363380985845453244537076606928`48.74697372704799 w^3+0.03348064194886871282400493263442690282679833528324024037828131001967919429381`48.74697372704799 w^4+0.03995786324800190641157011653739007492335697974971510518361438488464558463691`48.74697372704799 w^5)+131.8254855789622072592732165738096816681296265985803737908189`50.045673028600596 THRSub[2,1])/(1+9.01753567481478453357395337783996295319503477761928402466333306570743910994176`50. z),((9.70741023172817646662139999757334427642897250767806174669055888566082636374167`50.+ 5.608625927727746341220434579593593715322405511283692757485`47.96011680775757 w+2.7847600165588373896692920424030079443683905905371207607494`47.96011680775757 w^2)/(1+0.6225474902064799029662953868781375096142086520575401768067833207632753717028`49.52287874528033 w+0.12925178846230466801794224906660781582417781655488737917754270719937042601354`47.96011680775757 w^2+0.04850563734309355026223400450653934934130572762694512966731418555662084326609`47.96011680775757 w^3+0.01893016596119218577625971879048210093861432972450016129141428805930219870674`47.96011680775757 w^4+0.00483289245683972294461690150787425409728730943159343581123714981985184464661`47.96011680775757 w^5)+14.72316979061660748836174760721748490807200884341396144571754423813506628955563`50.973848646476746 THRSub[2,1])/(1+0.11882674261428878154649405442859958778371975561415320460808370050565368014832`50. z),((26.81869185855272648013248842495551198683385401171325891408177819937083882875815`50.+ 62.1679696641933474987779432825168154343798286868067091424275`48.038700762986295 w+32.8556681121104248222230109959780211545772652290164196162364`48.038700762986295 w^2)/(1+1.47629002625088785147784351869496368024406982346625622717178040726794571098981`49.52287874528033 w+0.37179969931460567157645368814976287218263604195423837791516503632620882116142`48.038700762986295 w^2+0.31112361841417116369667857381311038706540275508821864788508262658259702145199`48.038700762986295 w^3+0.00648634367618987827600557695083346533265330495207407833948055596056523140039`48.038700762986295 w^4+0.03628606225207858544248046964941516713257477232648629046536953987969053861343`48.038700762986295 w^5)+56.42868203648048485369476601813497204204488833151406910587782365390103233011708`50.11532094587577 THRSub[2,1])/(1+3.28806564148499430996356302382941266219559948540115999704411101749155869192954`50. z)} /. {w->w[z+10^(-10)*I],pi1->pi1full[z]};

(* Sample Pades for the 2-loop triangle form factor with LME to z^4 and THR to (1-z)^3 *)
(* Mean and weighted standard deviation *)
Ftri2Loop43[z_] := Module[{const},
const = Ftri2LoopPade43[z];
{Mean[const],(StandardDeviation[Re[const]] + I*StandardDeviation[Im[const]])*80/Length[const]}
];
(* from 20 each of [5/2], [4/3], [3/4] and [2/5] Pades *)
Ftri2LoopPade43[z_] = {((118.90056289471833860742603948225064057752894046473065170203727695115672008679581`49.11873502411788+ 188.83214444641325385142013606119012716777129676374928987423471696962146589424754`49.11873502411788 w-27.27165265828539031507803687700709781456843159858938673973247540422471636803645`49.11873502411788 w^2-47.84672117086533420733425474702713843026562227718967518739170418928705881046576`49.11873502411788 w^3+21.58992043316244179314569347235625718306559293777274984090561871745198854013908`49.11873502411788 w^4-3.20969401303125014706039887355331517431560394545803526515445664035936626383056`49.69897000433602 w^5)/(1+0.91986211605009870450938326393447628971097560951886072070134900081053011000871`49.69897000433602 w-0.25775978141223983822113737598396286613701934913991297715267552041751206229765`49.69897000433602 w^2)+127.38694482164124073240906552415095941639501644920399113370678936806782827445371`50.04735435535827 THRSub[2,1]-71.7651573463083489964933890162657714305117450898149399205867270770851590864142`49.219115156050215 THRSub[4,1]+121.64557172243233741303700209254140996859973826973306725110186084862556479125974`49.639869028780005 THRSub[5,1]+122.45459341429492521029086167870911712580896791159988295389884345669709124713526`49.04761466417259 THRSub[6,1])/(1+8.68024702243239557027971158493913357545123949937986257344875814613022822723086`50. z),((5.70751059900847542691458463675582218277196679279434761155811394997580066785951`48.99624663599612+ 10.23512847968622364175122908782691576839727168986511060790376213622003492562613`48.99624663599612 w-3.3484645317339301720804033254685167091559570886293287606123016285587179783899`48.99624663599612 w^2-1.7444102366513051729018909340559335500665588084119445017753720330029592630717`48.99624663599612 w^3+0.7832618673617503864770997929380460423463148021047584787473911491417947971931`48.99624663599612 w^4-0.08812228014545317218631078103381298861463494522777465870782315921958789673658`49.69897000433602 w^5)/(1+0.63149872495484960173335513959369222791923888896984881536874338386270089996618`49.69897000433602 w-0.25634728224082323777472642255166720614181154700883883858108165817276232804936`49.69897000433602 w^2)+14.71728297012859411542187111516794327652502750763662087272494568297625637214887`50.97531303143253 THRSub[2,1]+3.34795055470008208149807392305623932940158087122997358673450204630922218179311`49.98753858138168 THRSub[4,1]+14.05397000146882055553447230576586764352630580509572893194135852191400106566304`50.56782770485426 THRSub[5,1]+6.38801741405965167451503330996706684544289539612452841709089447904226124110145`49.80371924645483 THRSub[6,1])/(1+0.11837939789948717198205718820936980889861874019483224234402849619209632687642`50. z),((57.52168060942669755986441808502897778407946491872648133607707186885473207787119`49.12540878839923+ 91.68997510548405286331965960602017920929615761426164711817798776133200415980392`49.12540878839923 w-13.35460501939796173348041489728559321938005121650449061713197020300467564753876`49.12540878839923 w^2-22.55999673241881182875820845920054069640714179650701019603726544813128303971845`49.12540878839923 w^3+10.06145066546704747924245195324802383046884090432075847635124777829802832123554`49.12540878839923 w^4-1.47727395308257996990888083971569192660162862960229828698861956464212325855362`49.69897000433602 w^5)/(1+0.8991660713461136054902383689215628904306816108172292558997056032248990073183`49.69897000433602 w-0.24490483216153532232986608783542058364582269493986305098949323443370911247695`49.69897000433602 w^2)+66.29187077203267468817267266204876908088752412030631033708520375518793218321229`50.09610085597817 THRSub[2,1]-31.03510797990263830033579377486431120684008353721648605617233666849856169224979`49.20983152940533 THRSub[4,1]+63.3040735210688403448623530598393025219486769931727149865052389456066841867469`49.688615529399904 THRSub[5,1]+59.51754417770228924416426429828307392847437823253612808039487911216630191654054`49.084261504859086 THRSub[6,1])/(1+4.03757810936543483795969653566349377682508899574427081186023517707698518794455`50. z),((127.04234347764638726528087953401089983357457805773017495483925628557703651287338`49.11840655372701+ 201.72795323586296597441858872699444709761585556267660745097415549224215211177526`49.11840655372701 w-29.12610527481422953802147644817972015710870500613630346463043831469962470393548`49.11840655372701 w^2-51.20691548765715589373414326334902930229071976726354278737936710787910420341059`49.11840655372701 w^3+23.12263497431633439055094718805494193637519911172271980948063089390683620126747`49.11840655372701 w^4-3.44014218538960953203677416291652512335390279129172225886546624347575361399874`49.69897000433602 w^5)/(1+0.92118463870324735630200186271994409313285204675805849557001828525857918918185`49.69897000433602 w-0.25861588267828692066000310325479619582896341981805440820052683318962151942383`49.69897000433602 w^2)+135.4910788346656656045989893358979327002184247359466297206052912158424859203837`50.044372022453146 THRSub[2,1]-77.16791335499129891128667155743042028639401728097669897851906164226826418369271`49.219457656617784 THRSub[4,1]+129.38444964834431169934148542286885765294860222747709085965173905659744140605292`49.63688669587488 THRSub[5,1]+130.80306159003537459378129808780564280637603537105303385462033411652512102076564`49.04537353073653 THRSub[6,1])/(1+9.2960873603792182082948812682339979177647763833445338439526346588650694620668`50. z),((66.95790354261055788662271480916832735842378881175451810292855859425226436868122`49.123370531784076+ 106.60881318794292443162876011004773634643851593530935700004025737659942075535733`49.123370531784076 w-15.48093451076673282113654814135026154222622636843310201992667977022272440900368`49.123370531784076 w^2-26.43828647289060674455075083083083914921466320402106028473625396476989143202301`49.123370531784076 w^3+11.82837389885175987203664979713255442875100355457159141434469975129791130376773`49.123370531784076 w^4-1.74260794748612205648207234533227832412758361867668717612303116995884275691563`49.69897000433602 w^5)/(1+0.90458405291146151043539639528264368153858481975341778732895048742227733025355`49.69897000433602 w-0.24816601674131352340832697173474155632340348301938047784105280498005892639665`49.69897000433602 w^2)+75.6844617966110432509527987289984542738029554484440895509020046302471035587953`50.08295310112607 THRSub[2,1]-37.29683532962155067552254448616410133545037108930833886538353725187134260930462`49.21305734651158 THRSub[4,1]+72.27333726108214326637652925990963917795064264052395504457475519524570610062685`49.67546777454781 THRSub[5,1]+69.19331547299633727659661503815388715398305865273103111639903030995169326985262`49.074372536530184 THRSub[6,1])/(1+4.75132943942444361231145594683611204483202628372802867729820069728314728450838`50. z),((107.80032348680514263177995941322042259933599109893924128666579132397433719557091`49.11928078252526+ 171.25260795809573383779137836399973456526646729664918909689086483829235438117276`49.11928078252526 w-24.74512072033312304676818505813343213187378767679626308592311864145002543808501`49.11928078252526 w^2-43.2668267359873739285935529680366750130730260674342708331744077665761593481838`49.11928078252526 w^3+19.50101321680691197443484780729564913545263041091412530107246958308409598318254`49.11928078252526 w^4-2.89564718933745668291469273835218213435609276196654052806755658134951632386238`49.69897000433602 w^5)/(1+0.91775750836025143451039512161525512362152947408108078304611451321528498646823`49.69897000433602 w-0.25640546843332122971553629889965631891096147888049634971092596715039501806007`49.69897000433602 w^2)+116.33803152532741658381505329727273322936664142303451038873031899974589164114432`50.05213225298217 THRSub[2,1]-64.39921514876579956409738086501362063915949507236861942393574683153720133086711`49.21851548313079 THRSub[4,1]+111.09463672101966307467172178560563166442583603508988141309709708592639742586008`49.644646926403894 THRSub[5,1]+111.07256285032016062938442441097877121556457544914085850010117765879257086300932`49.051205167965236 THRSub[6,1])/(1+7.84063029257433516106442423844696894098607690128698488937558585749804316819596`50. z),((77.07920572075356883549426237814451075060601554662883384989803919347179915335913`49.12185293668636+ 122.62004143588761266006562336006239254951613990518172081401561230097750548610688`49.121852936686366 w-17.76968089035132813667235102761143377040400224949717662239382194105634401586065`49.12185293668636 w^2-30.60366797204567996400084976182545243657013255526218597655536941209816622552385`49.12185293668635 w^3+13.72684773995737927103975244630307673410598246228464441106075703035533734245525`49.12185293668636 w^4-2.02780824687207120238819054869724479576423325343037657066670123959835072517975`49.69897000433602 w^5)/(1+0.90904109382984675180407349581328917841916063901183050199644933120323390078046`49.69897000433602 w-0.25090614886247717472727441534071097126044405403245246333092016086417765543053`49.69897000433602 w^2)+85.75896434584190671070566015214440778346605185185823926765434365878911330123254`50.072345946999604 THRSub[2,1]-44.01317036244212631535778543492807034189243535825110534321842993756601577092826`49.215257345036186 THRSub[4,1]+81.89377854049409863983929972802698280884007762818335600364693921550647117713516`49.66486062042133 THRSub[5,1]+79.57155746449095723221921011134411458676018641414889755277458362709195316295183`49.06639763235813 THRSub[6,1])/(1+5.51689983159630886861065708920774292758583716594729296901654919097485147918392`50. z),((112.7216684404730504240305754691121510872828299450850498635063449155806415306726`49.119022809118434+ 179.04623248717884871988952767297737939760878096766012774467550578182323437863191`49.119022809118434 w-25.86498885586765091105946507053135234785122855525268153647724285036698316177239`49.119022809118434 w^2-45.29714068001348912944885510047579035991872321098566950181686889359719103637863`49.119022809118434 w^3+20.42702158724524430485048870772522148739490257103604623298143832135250832239386`49.119022809118434 w^4-3.03485929353245771104317989422768963566571955553006604184392893461803042590469`49.69897000433602 w^5)/(1+0.91873865508047279885569955425352790909053530486659860316742531974010797018447`49.69897000433602 w-0.25703559490105960925861268352263129667453297987270194730750564616121125573298`49.69897000433602 w^2)+121.23662079859703546615572633643223732439107251951823211094336952691293643101684`50.04989994605014 THRSub[2,1]-67.66494133094554548565782955778662336917578247002443390541111384964856452412088`49.218803527415496 THRSub[4,1]+115.77244490312643381214142649935681634267628191052509330918466668780487259997012`49.642414619471865 THRSub[5,1]+116.11884127910602159381214436983448853291517639207495977910868473766901397834283`49.0495276175648 THRSub[6,1])/(1+8.2128784400833378961610203784594042228619459335059955694680576867571156381467`50. z),((8.29110948891161686462830154080494315561958316272597763461974655386637082219978`49.05730242952701+ 14.38714269065661035966406604522143961785211421927830533375633611446202434921926`49.05730242952701 w-3.15283726417763508779537032613717489881529084053448120297569096824306545694921`49.05730242952701 w^2-2.71163119754310490378951916952029278693139025011405310280844279033643179679489`49.05730242952701 w^3+1.11888490079357177883243388836129579818690628213363723512053415300682022356587`49.05730242952701 w^4-0.14022435874630837135083107696974038971346693027338511155315990311148011577251`49.69897000433602 w^5)/(1+0.73500353851897833648518260332607756920145688719093873631248103650868545500776`49.69897000433602 w-0.20780806327401721633012909580204082476540014294700376828265847981097858839242`49.69897000433602 w^2)+17.28893562355176838294515578662823198518965651515583434137228451288387680265297`50.62187466865882 THRSub[2,1]+1.63351545241796590314921747541604685695849486621716460763627615970414189479027`49.20318092120504 THRSub[4,1]+16.50971739171494219249846384209021035047131619640961143846256835838903191151209`50.21438934208055 THRSub[5,1]+9.0372036567424264918385016265408137485924734351126451474798722206216875066131`49.49655527981179 THRSub[6,1])/(1+0.31380156597083316002820625900957293439057168633816612279737449786662242067763`50. z),((5.88907404163222161886819278355112527390248194152203018788716489592084186202601`48.99881570991692+ 10.54454999489078409838483561965989146441526484210022208254178702917259412019807`48.99881570991692 w-3.28587730325688058130092620435166073764757341826154858030846903493848852691187`48.99881570991692 w^2-1.81250677530800188063392172630590001388118306838964203110440843252849831938299`48.99881570991692 w^3+0.79986947246896052308993878416803322048884135563663377311107291050085777209889`48.99881570991692 w^4-0.09100921717265806617452834301509671746022429878354939127493821658342136924648`49.69897000433602 w^5)/(1+0.64473429995791674454420819132651999947102934076800152539995117605177248925922`49.69897000433602 w-0.24817363442030230387608763750746601304388748919261595725168559738409920314248`49.69897000433602 w^2)+14.89800688621818022406919196050797937065704361959769728170621066499021618319843`50.93294489441784 THRSub[2,1]+3.22746794397369134239986002616288193331357012992258931408032539163324897442666`49.91971379533867 THRSub[4,1]+14.22654862895231582532972978442192768002804425842822319909952241469015155890193`50.52545956783956 THRSub[5,1]+6.574190034063751518707219718206536929140132080985997324256885956033647444897`49.765612319870044 THRSub[6,1])/(1+0.13211276871749371899413855573524610883713914211568126748798844565417172343435`50. z),((74.42361594986442659329996279915400778026428721026500888299191251436282365174071`49.122201828064696+ 118.41833083081138436136426882214770219833577486278012703027552977190946207492513`49.122201828064696 w-17.16853246210091714850495042751703454586863771544875388456012411266396196042974`49.122201828064696 w^2-29.5103287597319720848134343236722474792970670934502166571169329636430480434438`49.122201828064696 w^3+13.22847275205834402130590360207770066693449997778346979263764428133023054850879`49.122201828064696 w^4-1.95293034993249884487050516005782999644470462367622906055517854253600125473075`49.69897000433602 w^5)/(1+0.90797898621612531067963744940672152688161445910309817464824073583280950569596`49.69897000433602 w-0.2502486179294329450849579588174729627371828435376410179781598333265996584113`49.69897000433602 w^2)+83.11565368821636122901314440345271479268870078599594073490594846092150810635977`50.074856731170556 THRSub[2,1]-42.25096325735842932756277493580027501470753464767623965471949980565427897434645`49.21476806212276 THRSub[4,1]+79.36960279676253387839940968619515843434932792619021218740825643961032263772382`49.66737140459229 THRSub[5,1]+76.84855277721445670894507011543784570290905487335295606438263798082652954465178`49.068285133529685 THRSub[6,1])/(1+5.31603230817253898140182792090040978050658369626831048330705462063468602329248`50. z),((38.36723923343540172566408341358136048157286010876499715253664024177450365365013`49.13380901897442+ 61.4522312495727347907552493121433515889041044561738783564447565255829992747214`49.13380901897441 w-9.08039134391905820904427333584507044729260828742310041564330161195139019719012`49.13380901897441 w^2-14.71515177797224125921858542361229462355787982294543884690797911148591210487767`49.13380901897441 w^3+6.49141385268860894069088931415673617691215294680008455726869027437740425467948`49.13380901897441 w^4-0.94171873250398415327063730459944656464293389540760742728824633882752239631422`49.69897000433602 w^5)/(1+0.88116575495202866244727084762799310305579260428597530438717555365643326389821`49.69897000433602 w-0.23467402998125982649334794997098052111375485523926382850107789592702529103196`49.69897000433602 w^2)+47.22599712503890846689530498188161045924923319345438323769098876451726979516778`50.141853306508956 THRSub[2,1]-18.32452554857346081948421532141953879241455625264853465657619334138478676688566`49.193805454030894 THRSub[4,1]+45.09750530936148127594037658886874316324787452049494068015878622238950531709863`49.734367979930674 THRSub[5,1]+39.8768473273284953823899568577501446633380293267694990638109856939918174738582`49.11872675238662 THRSub[6,1])/(1+2.58874544554893715580532473316125543482506629255173833725527651320168181420059`50. z),((22.60761019111717423785028400420210899234305962245024338960433505070846929750723`49.15647054936689+ 36.6789005813061992610528766152627973760098121669933791123537967745097068451223`49.15647054936689 w-5.67568840981111634466842779333266926323978170597855115897624384366133228796272`49.15647054936689 w^2-8.32665334740406946920514491747773139060877494689010034162937860795276836836811`49.15647054936689 w^3+3.59546394570246650424768293209011255246584506601321880875175480676650709780932`49.15647054936689 w^4-0.50852554308049955620844104364231574131296519477883266907842073816058048443986`49.69897000433602 w^5)/(1+0.84814002023953072953144812150964018368610140695857559547271148729411074409356`49.69897000433602 w-0.21882185361469787655048026650830201619272588563818229549484103440685847395496`49.69897000433602 w^2)+31.53923862625275000835836759101415717245007307879882208714248849017296628462661`50.23451122494965 THRSub[2,1]-7.86668654938268851379292372750790326788178284287816055621052649182191775985901`49.131007157376374 THRSub[4,1]+30.11775437233778192776782157840340914943829150190035283568470038640087276710763`49.82702589837138 THRSub[5,1]+23.71714366285658211612046880999422793374523485323641425024246892094539038893782`49.18896868334913 THRSub[6,1])/(1+1.39669474159255080505553264504310365598481154496692401850482720882793889164181`50. z),((8.34570463019687344497701368592143822517768387681498663807016811917295586130661`49.05862743690664+ 14.47235024608228745176152295260979816780870843661543216026453498273059707325395`49.05862743690664 w-3.1567386679622805202767882200363849321719962188026807593192556741676686740961`49.05862743690664 w^2-2.73221558470117632062323970943856576559610095842210856054407580084681597786949`49.05862743690664 w^3+1.12718899921009753413254267554178732904209497851274610432074006517070919198302`49.05862743690664 w^4-0.14146669997780666186335705766088192750410582154156578579770156762155114923493`49.69897000433602 w^5)/(1+0.7361961339100850040970479561311266146672298780926665754304238387409668735722`49.69897000433602 w-0.20752172760300789835680595361778498245984597348110131056643484727857971218028`49.69897000433602 w^2)+17.34327832376693480507378096640098064785236752060553919484157339028295384766329`50.61755967717283 THRSub[2,1]+1.59728698560785495506346735556754774851668752925069470532341690810475719811664`49.18692742689665 THRSub[4,1]+16.56161084787617063449199857879392732025200642496139172183480565299080418955841`50.21007435059456 THRSub[5,1]+9.09318475263755840458722509555730028357381580795676086487789023499547263845605`49.492965767666384 THRSub[6,1])/(1+0.31793111600192419906500814148196090517826306876716838687235872557839427367135`50. z),((5.73148075275379546670210358304110670644044942703355788466473290979997675106812`48.996535486282674+ 10.27633397591090772203978214543085981627811305901020714582931569341682642621492`48.996535486282674 w-3.33929116016959447991514394699124346459401033817770526003997300982688497012991`48.996535486282674 w^2-1.75341448589341965415070560390307186355140034297023283020777314763719773831544`48.996535486282674 w^3+0.78532883688830729353711197215080528719434263343842395063850521701150914318483`48.996535486282674 w^4-0.08848994535199017222804057250581548423786820226873565495158695479921869991901`49.69897000433602 w^5)/(1+0.63335615334336368884409602171059158404379411526086021964617436712045887090047`49.69897000433602 w-0.25517636060223427143090819434160722228347561883728428501045530916489687080103`49.69897000433602 w^2)+14.7411422888963091372456364867852967394625127794927973239628144681903168774293`50.969415328446985 THRSub[2,1]+3.33204434218827206694889700864467035410992402332585595257592285616651517827269`49.978301125303055 THRSub[4,1]+14.07675397259294300342235911988058439827626749876819175892441319359528919634287`50.56193000186872 THRSub[5,1]+6.412596075161133062910379545159898020705959121248158537281107739385818590703`49.79839584770359 THRSub[6,1])/(1+0.12019248871332071937966562855089116192924553870954336133025096784874335779789`50. z),((69.23066350468290000771222768699629331272483469101086475567787918630403101114749`49.12298145827418+ 110.20345580660686526094162037862602038306998785420995377540377292965058329190481`49.12298145827418 w-15.99426590159616595316313509253090837623514041639734821636275083930555905687976`49.12298145827418 w^2-27.37320799784820288771025044539397269786758230906732669408426056445716842537032`49.12298145827418 w^3+12.25443017826386279605130969230140177265120835270107472904974008480586554346815`49.12298145827418 w^4-1.80660412375610757528491152525607900454726796329799117193385360042769897272498`49.69897000433602 w^5)/(1+0.90568805811619405163536882159212675745007550299971876037478682271494842398144`49.69897000433602 w-0.24884002677389033826209372119638941496118323803743750093175459818560949642248`49.69897000433602 w^2)+77.94671280232981792722397609591207741045931717004474662427624774645405322218901`50.08030832392139 THRSub[2,1]-38.80500266676740045970332939743985009322127890370877691429969932934264238490154`49.213638751969306 THRSub[4,1]+74.43362784153067070675135606796838610322626367109080087885651089284371760995494`49.672822997343125 THRSub[5,1]+71.52377181742834718306630824250128663198275357850784894650065757012577212371346`49.072383850656635 THRSub[6,1])/(1+4.92323990162106507603918879190354020292512461414342956052170794033842924233957`50. z),((51.98448091383703514341076685176442151793990280245043641363783687411189073513918`49.127050480444105+ 82.9409963959498340845204719002105798676104023448481230025724243978832366580676`49.127050480444105 w-12.11170903127009018463787666128479279521835086833600731003204065559047047187542`49.127050480444105 w^2-20.28746431753726099145031670743770820690822794490066273240781356632317864649869`49.127050480444105 w^3+9.02655814932428802417211635655294739351674877963782707242593053133004145008219`49.127050480444105 w^4-1.32193224291381509775023714184733060047617529795603478609331788916528800258034`49.69897000433602 w^5)/(1+0.89517555847807552958146011178009582081790909381438993774099982257839501066223`49.69897000433602 w-0.24255413147855395792228054562908837196817989529160485954231682747567111059759`49.69897000433602 w^2)+60.78027439174819737162785490432011634631500706690193140356641797221447441702472`50.1059659524209 THRSub[2,1]-27.36071039304632008930591526971187605045840550161356676715981281318292318145721`49.20702973189538 THRSub[4,1]+58.04088667157080647833261406457569045300265377121218536380561597803848084771388`49.698480625842635 THRSub[5,1]+53.83977689197113511829091910991215006351022519351820815513632865576291983624686`49.09168508801757 THRSub[6,1])/(1+3.61874700760849909726539376877502941025145271035226193158307450857238381001226`50. z),((6.17858394894259489741934345051908449367325705558159628104589667340898731595792`49.004315557074044+ 11.02743909730306251214689333828926454686062205648142889816831036630913911601779`49.004315557074044 w-3.21338435120795594187545865299966122632525066430148327200221473792857735206079`49.004315557074044 w^2-1.92073767290491064984116293481397971964820359119751857785330536229555905064695`49.004315557074044 w^3+0.83014401248046945175032216679439783518624428109824477189440542886805296457001`49.004315557074044 w^4-0.09602221568039390347909266305858080449473438557977544805187181664205878569179`49.69897000433602 w^5)/(1+0.6625311764303611881002344374101197837294372416973834239693957852747611503068`49.69897000433602 w-0.23787654242833446720228324321646558144808554641626494445096614553925838274301`49.69897000433602 w^2)+15.18617813611174653231687351239997328321462622997350633107313835503034322435622`50.874657822127524 THRSub[2,1]+3.03535377737798047023473899156821932494184838967204994783570693160649761365484`49.819983507465544 THRSub[4,1]+14.50173190221750119907246002019342168630896668063514029132549733084197536834647`50.467172495549256 THRSub[5,1]+6.87104945235981664976036690089414259563211183880024703419640035638855289123321`49.71372019410118 THRSub[6,1])/(1+0.15401115781567474966270987166578602731920864073929478140272878427975042149861`50. z),((6.26037201999879445283627207179993432271371219531855946492039431069952422288372`49.006090266490794+ 11.16203509018963440194098995555363789828181754453921954037106708835981882594667`49.006090266490794 w-3.19775460199485356645287737677589921987248970033520172391695304639598255515376`49.006090266490794 w^2-1.95126921929610716380482319432512066495193923951273258834420792325578771749496`49.006090266490794 w^3+0.83937747039722204009765144932235176610864392496732305063105014428422441061143`49.006090266490794 w^4-0.09751266500484499144379927227225672952222728779337176104205587923052852357326`49.69897000433602 w^5)/(1+0.6669695461843989510546711430922567814396338401544511714712731408373498092423`49.69897000433602 w-0.23544894025491250333129948488486467992043499129445765218180428099187484355509`49.69897000433602 w^2)+15.26758802940904700881126109727742753090647189921252571855440413341148022075597`50.85987603238968 THRSub[2,1]+2.98108051517978015257181393498324982648061794351270368951486307935240628272167`49.793277344909654 THRSub[4,1]+14.57947262382659597229126915764366261480272627146795923022142018025672525379928`50.45239070581142 THRSub[5,1]+6.95491379891315027746056840991219458679687398286223592975099696086610335885672`49.700662164949804 THRSub[6,1])/(1+0.16019756787748392797692015998006577425328983175942848122998655486932866625265`50. z),((7.69567392065820292850807290884973664166098205956712060521342890151292837069582`49.04239088942129+ 13.45498233784191306177828365763614938490976989729365390090468708219323316020138`49.04239088942129 w-3.12192753739080930347129761743935216002224531125386238614277459378547802683832`49.04239088942129 w^2-2.48770595998032948206764120350522340266282075085068453201191074523404297156999`49.04239088942129 w^3+1.03021287291322753128128583592851610213303705425507187262103503730184555207097`49.04239088942129 w^4-0.12691045307223445593954952341030017728647978351948222226040198395495666622401`49.69897000433602 w^5)/(1+0.72052711739493579273346751437818198524111061044606017739275691527793117298288`49.69897000433602 w-0.21190376114478276161498015349870291683404651544833182202335790228345282944109`49.69897000433602 w^2)+16.69625327451312411576014867019616301293762835421786338838949567875700415322482`50.67401088729206 THRSub[2,1]+2.02863701844372874793922221970409283845984697350914524295813538245539032774245`49.37412422619772 THRSub[4,1]+15.94374743851804453283664250631562458863801438608585871942244100276935899195188`50.266525560713795 THRSub[5,1]+8.42665233548834370206707630341229020830761611209592607590374197371689216168502`49.540243126132275 THRSub[6,1])/(1+0.26876310812444570318598680254131113205715489612169137248000540547133017017034`50. z),((60.84056852207897407999309918587163654060129523175075083336059393281034122526006`48.34561261667103+ 115.23067277907730346713490674086560016460761922371328983173346757010749679759335`48.345612616671026 w+42.22075342860211282766287704272211158949003418451341504672988435626187841210305`48.345612616671026 w^2+6.38039412609285242201968552284527662444656462529381685447094766262297167447638`48.345612616671026 w^3-2.17695452256138895799277651195403476552414214323115719580109331145115760125813`48.345612616671026 w^4)/(1+1.20194219100470231923989113597746297723759347240617608323869540771264484981994`49.69897000433602 w+0.47149420641854332859941190419195183496586637350357382574123541333190493511188`49.69897000433602 w^2+0.18467445434706915405035730277230481931029753054656547545880082539809179617525`49.69897000433602 w^3)+69.59541256419775161671586512232565174403268654801339216999464508503761701615506`50.091024850396 THRSub[2,1]-33.23746917467935625269792208171556631560352515568787394477863088839835158087781`49.21114420507783 THRSub[4,1]+66.45872355667122482908509286576476124240365232985942338774347858420472469592054`49.68353952381774 THRSub[5,1]+62.92068552195878300401583940031372003112837735577771136252354392534384286765796`49.08044303763963 THRSub[6,1])/(1+4.28861718281100638671247493245826684354639975802048384761165331964877777398451`50. z),((6.89289918794814174649936025061612629471045517236819369235740366022701340358218`48.515388905784505+ 17.31502320765961677205726655749385047812429925621687410271629802112629802903076`48.515388905784505 w+8.94352981543765537165345154680280146093547628216834747197699720080016695621718`48.515388905784505 w^2+1.07040406802611763676230978756860479080961001973179098924888070706836952798152`48.515388905784505 w^3-1.10814317476848868260732787989320972990235200793395453655357956468383029640166`48.51538890578449 w^4)/(1+1.43937885327323815420143729298965301673531663816989153830079475704285285826414`49.69897000433602 w+0.73128283626884082009433429543287522514473073432241821185092439110358520136427`49.69897000433602 w^2+0.17819984304536235658055379469752685323802865259645652016234356963786661776499`49.69897000433602 w^3)+15.89719047124945480743869764094188734228931525044027086663208418391180283209859`50.76393167643455 THRSub[2,1]+2.56134555395284162015352290587360995222538904269420692412974304568552454182662`49.601042591841235 THRSub[4,1]+15.18069866863636664877810032231541629119337818428050974167339613284853043445237`50.356446349856284 THRSub[5,1]+7.60349832881180214980598560497682907969322224931246158528316867167717317525105`49.61695958588539 THRSub[6,1])/(1+0.20804161635101611153698260289196526248679441041757569424518601605541758881442`50. z),((43.39344215636915523738147319919560621422806403663053229169486999054767862702578`48.39318585277426+ 83.29134131655072148178113273838801633365159917949694163442840633488739023585754`48.39318585277427 w+31.07652736831951832253407946402131229946601400700405411535727788159126805645453`48.39318585277427 w^2+4.8636261859305371524170189587755646844491740940023216680376982738077591646796`48.393185852774266 w^3-1.81929120635553663044534935807556634403367253047982390273742317687842535622856`48.393185852774266 w^4)/(1+1.2078579551739824095310878606210502910802984137794912470829434577686356108638`49.69897000433602 w+0.48490880102555442360184540725888738576190294508828512533514126480553482881626`49.69897000433602 w^2+0.18552342685206650243646104857482895332926019907100879653486058969365303267086`49.69897000433602 w^3)+52.22895951750629385367982622334062538386740355256837345045122381436142179732393`50.126073665510845 THRSub[2,1]-21.65983381021838441067389614905888207549333649205786146508301670794755476832336`49.20023540212334 THRSub[4,1]+49.87498247854571683286604763181383346926820299661522385908706188670924725458653`49.71858833893258 THRSub[5,1]+45.03064565430766526408251494952671825785870533811821380926604756101365101876675`49.10682862959697 THRSub[6,1])/(1+2.96892499904111027338104476244521245756308069168375597476370239672652520720034`50. z),((5.47478404857235849726950970684511407417143650530217797193031588152916173315308`48.06125393968069+ 14.2880045402684136568801494280449586603306857402067085979009466432955843014106`48.061253939680675 w+6.93731121331539728764633009054213102633624268076673146832191037699413148286669`48.06125393968069 w^2+0.31170653496699171447698561242761490395293833449617318961073796646828971351116`48.06125393968069 w^3-0.85558903737824850363686519153317503077343540107048931858255847396220149239075`48.0612539396807 w^4)/(1+1.42597397443534825889109784020393606925390592596793492084749006057807042000793`49.69897000433602 w+0.66437340571550122519002564544564957489665410404112695063100898006475338782047`49.69897000433602 w^2+0.13813884284844807548456032194981817056406354105624457625688880624125998026373`49.69897000433602 w^3)+14.48563251800539335557032290465940897530082507388296147341932374068775262111979`51.03834154453865 THRSub[2,1]+3.50238418944888258806577273006192886355104916039907985293825000783489134914577`50.08269422615507 THRSub[4,1]+13.83276011431954150359084164324897917737629964323955679456138849482857901492744`50.630856217960385 THRSub[5,1]+6.14938285738297896625617422025286277488819437679986501941422676425821421963939`49.86097553717553 THRSub[6,1])/(1+0.10077607439918312355297595754971138819944735233847023037557507879820592494239`50. z),((5.47860893281877155920030108152718409048037235409220547490571554547990672942083`48.064408818268106+ 14.29724142738059154464849401028861837625072021922764175169747413515956429677791`48.064408818268106 w+6.94516958333960204090491347356378158460543777078182363143332111367721368605402`48.064408818268106 w^2+0.3142204092706421263917577555063040685709072797709118791928770106108826913803`48.064408818268106 w^3-0.856632619965219798666311420727807747938725650287067361759819145588328653384`48.06440881826811 w^4)/(1+1.42621523006222703858271679518906974343824602557280378727203267893993378637556`49.69897000433602 w+0.66481043705145019348262955566073097448424237860526583890458245649349592747683`49.69897000433602 w^2+0.13830374926391363465667583840776639860415718648764055871066489766941686004225`49.69897000433602 w^3)+14.48943971646788124153118320808988378193499015728087299425436274684601025315956`51.03721066788759 THRSub[2,1]+3.49984605714055733075853252777494565912827243813380550571489067039605292778584`50.081039417406416 THRSub[4,1]+13.83639572104736236904688358796297145532011017463649598252353849343148805085093`50.629725341309324 THRSub[5,1]+6.15330484030573499584480129217061947418813327089884191686841993435707446820516`49.859942505625604 THRSub[6,1])/(1+0.1010653867901185443813978255250448052618032235881747900688332775133220809888`50. z),((62.24626282657015405941907445662246656083811185025850227069014316565849594481907`48.3426631941349+ 117.80611913236911172952090018387261336487068353229564943550087802956529450730475`48.3426631941349 w+43.12147165004292988876145327252813814501477401691822341083069653592295121742528`48.3426631941349 w^2+6.50272545774333130606542213556230927284667090754777775914227751172705207852001`48.3426631941349 w^3-2.2060669116270228164076083064288228646988783963171963754439202614476429314286`48.3426631941349 w^4)/(1+1.20164417798289871833031812147141337554622559600392907047818896695997660788337`49.69897000433602 w+0.47075586868433342484957866665763805819475459711362409750487581947740268032388`49.69897000433602 w^2+0.18463028853376969165087985787163761598707582973900008947181522285475755510147`49.69897000433602 w^3)+70.99460711493627993346991765978311939896753586094561911826905362527591838169668`50.08903360963324 THRSub[2,1]-34.1702655418383751305339571066872114188934246976426919102949032485572191579061`49.21163583171512 THRSub[4,1]+67.7948559312549080403030130990965765230903769096007007892397413219806020228518`49.68154828305498 THRSub[5,1]+64.36206484265324862693394930843699407874124727936662307510080445550758409539734`49.07894532310449 THRSub[6,1])/(1+4.39494321883105892841521923149675419548755811806434138941377265740666841093719`50. z),((6.10330859468888705688322923741160201962023845677499642126984625873917509560107`48.364301036037375+ 15.71722548595031587322090927316769119356721307672728353902020699018253449368452`48.364301036037375 w+8.02670367529608412859040092776072323440316062472216462251048769328034763250501`48.364301036037375 w^2+0.6944636092856689554824968882098441432895806824591090971738336334251765561844`48.364301036037375 w^3-0.99827868394988346473574745445948152391737819818136372925038650704782281073682`48.364301036037375 w^4)/(1+1.44703867057069814671663148948141183839550972002593242241830554664735940799925`49.69897000433602 w+0.71410188239758240382660962436757522309000840586437105082002685551736973326368`49.69897000433602 w^2+0.16079854750539133923995651158810337903379454739811473610220404543700744161703`49.69897000433602 w^3)+15.11125084563316355625272529608444861527948740707195498638048411977954563947289`50.88886992730182 THRSub[2,1]+3.08530530436370245427750446911190243689860760493975084429747642177369600357701`49.84508194458061 THRSub[4,1]+14.43018161030460849031420835796678575596604822896005751112175164574797927478531`50.48138460072355 THRSub[5,1]+6.79386315471843964069102049276399906248328077013659995071296205655359375212197`49.72631442800305 THRSub[6,1])/(1+0.14831736649687228059909383762172633203884819503169855027052241477195040164521`50. z),((104.89314842968991691508304110695370086043491904438204082651426044987219774569919`48.284728950640506+ 196.00569366793003831390489537568998185292459130933473380559317529551204036845473`48.28472895064052 w+70.52936086170812680248564106195843283513521570411903686451788016320982296269347`48.28472895064051 w^2+10.2187833703402423806608808753104311395174066575746616439249378731281453489321`48.28472895064052 w^3-3.09767150149976414677752301748386155785031399705426020707119464655962309829225`48.28472895064051 w^4)/(1+1.19700990998989996892776030910132057870917204798986616545164680075779189458546`49.69897000433602 w+0.45802159474664160506044556663248289465841007779895570580014612102247736861637`49.69897000433602 w^2+0.18392216695010771848006950253822367355809105904160576987784480044227948677743`49.69897000433602 w^3)+113.44429888021224501008795130715300600916170948674528548813603677785794459165517`50.053547448580545 THRSub[2,1]-62.47006005202235184827931287160046915902287378150913615687289201694523663121474`49.21832566811414 THRSub[4,1]+108.33132559428087371487174538652838380606717353095705911525265722570720993334927`49.64606212200227 THRSub[5,1]+108.09158612189739094160554681752723249606564936583601487933734167071722792323232`49.05226868377955 THRSub[6,1])/(1+7.62073298001367856092766158874406775989286032640025519542258236514382250611295`50. z),((7.16840209399933964902331322808868296756044715928921683795773539994089498570521`48.546262954049986+ 17.83868888684932358984175440652096123875294529153233308694745931610711576456388`48.546262954049986 w+9.18553343997934427805327469623310825794253816056715059977498910408140461298449`48.54626295404997 w^2+1.17561162342246469171007195618968471066061875469709884995699579889720953936382`48.546262954049986 w^3-1.1334448221029543051440740372784501167512272720667173816732142109119585955516`48.54626295404997 w^4)/(1+1.43238317737221068407597707670425913337254814952347041778147282401524706599248`49.69897000433602 w+0.73034175338431132060487573278549809845756993931909613877572989058372315954019`49.69897000433602 w^2+0.18211837977840482977680006516169676364440123220818814610923533584311199450547`49.69897000433602 w^3)+16.17141948649683324569021559866939080430183533119784037601314054866215906468786`50.7299008243254 THRSub[2,1]+2.37852621045458932798584426738860764421704232218916058454237213585195372010041`49.52225394749186 THRSub[4,1]+15.44256808853142473081656560401445770819475191453585355002191992324932427077517`50.32241549774713 THRSub[5,1]+7.88599516351098438803503716171371016650491573036163751443169008505009364848714`49.58772449604467 THRSub[6,1])/(1+0.22888052266146891818567282193734604895426198017540651683808432903187495791562`50. z),((34.54560302546219321422352780856658374559066343509309797347742723950527511734071`48.42911174185841+ 67.12726963947940035040151620440423927819383839547266588861370988940138985801389`48.42911174185841 w+25.47095117434282055208244492832574383601323115235935831195501393495132545831945`48.42911174185841 w^2+4.09585877914381102128269988723503524104170765111172203114630082681856831917938`48.42911174185841 w^3-1.64271681981362656514369685752440823377641835857711018021756473276254426150846`48.42911174185841 w^4)/(1+1.21409958780054324151706234496356583076032132611782832828958911832669589743499`49.69897000433602 w+0.49732486232300556980510282885473847295882719788211066883779068783932593030379`49.69897000433602 w^2+0.18636951113842574029705549738946460932850419775143597183370819959328963745797`49.69897000433602 w^3)+43.42203168246944438566101002975951855025366019866225866026571432419655979492998`50.156804488616444 THRSub[2,1]-15.78854858686048476532801868667147751975084092278711827162601038117098010006106`49.186740024648685 THRSub[4,1]+41.46498588814740421001511852594390092338580984438245052186419871873684216904865`49.749319162038184 THRSub[5,1]+35.95819489785615314226009654483261407432383614701716382068804446731828189927802`49.13001399180868 THRSub[6,1])/(1+2.29967873466717164674312442763078562861750294203005856234013167755108289516834`50. z),((6.07308378448085462209186314382081871009715578665730089747063242579950978946055`48.35544467748223+ 15.65224487398124869847390417292848033493105324981359299120665332466274134585002`48.35544467748223 w+7.98286439983952896552657625680876090345929842959758043500388654730801368685891`48.35544467748223 w^2+0.67768528283403318004586647584164365324135064930542956059418073001579330131956`48.35544467748223 w^3-0.99268190253946599282471792136182411801761937570952173843353843386206882257406`48.35544467748223 w^4)/(1+1.44674272623917233206453622663492108488324145600822535737183091985090179413669`49.69897000433602 w+0.71260718329180175835393843599822166674821464296253515984625078586625140176838`49.69897000433602 w^2+0.15990724986812300793595566306085935345017760709010180716880223327885211021333`49.69897000433602 w^3)+15.08116579114794025214849425537285781751079207297915691656459169072933633623117`50.89475084817487 THRSub[2,1]+3.10536200735385132368032516291962963541107116100161622417473804114050220573821`49.85531113325885 THRSub[4,1]+14.40145249949753477737105646594109733939556263392961586853998506042415580196402`50.487265521596605 THRSub[5,1]+6.7628710561756897351456745559978351033233319096765820161883101658692664079179`49.73153707163468 THRSub[6,1])/(1+0.14603117649908199456698223378573424035942461899576065102855747330294830795746`50. z),((98.92675795470848206066134166322553192650471562372864036371828140897291981409493`48.29034147729472+ 185.06076811168072357569099306345305949095464310538390403985009395292445930425426`48.29034147729472 w+66.68918325283095579217101159844749582666631891277206410517648371595643942462696`48.29034147729472 w^2+9.69853454447336038980910645861318620801942339926063738709139854105002491634277`48.29034147729472 w^3-2.97234563482503219182494782251965370402460222671699983073549864378202010041491`48.29034147729472 w^4)/(1+1.19737097613484679727327119247794356121376722380177410622846584627639490815052`49.69897000433602 w+0.45912315353632415665613183808248143207554175641489831618214839783964563967124`49.69897000433602 w^2+0.18397897555694387144600737217308981275958079797878122864380199438685204288702`49.69897000433602 w^3)+107.50549624474587667103758702662411998089990121136917172692028749382047529705712`50.05670706703879 THRSub[2,1]-58.5108582950447729555790700179145451401816682645917269827290591609202571014776`49.217881516169015 THRSub[4,1]+102.66018682139098635285247065914103082655617640510988398219404431889276122339119`49.64922174046054 THRSub[5,1]+101.97373260114946629580772764876189987832194449918674282213059682944443601965685`49.05464317883934 THRSub[6,1])/(1+7.16943809568091297587503675189853683416649265482505774789145936108670106427022`50. z),((11.23143030058462531161802753522150661272114490085675738287123112756558046510231`48.62011213500922+ 25.04528790860505538837009124349628956699293707689997138636293614700788522305868`48.62011213500922 w+11.5100448017914081972675922794468792392439386021742336780716421994746907159321`48.62011213500922 w^2+1.98381611896180893211789354286939217391192643380647559414480264145007762311412`48.62011213500922 w^3-1.25280226086086845267249829431028670260130055243485794971107272118995906945692`48.62011213500922 w^4)/(1+1.32310108886282070059281066064792182535917966670207682984791546086065681127724`49.69897000433602 w+0.64220508995829589188145685438683986660109158665925657020889845972711265981077`49.69897000433602 w^2+0.19478460660665119462762975901232793996533751245954453324883682585571594823155`49.69897000433602 w^3)+20.21566076142243530989100626825623571488729518700775661543088065135184351275645`50.45711778382956 THRSub[2,1]-0.31763463949581204814801617900262229617326424835078357506945459927450257861207`48.222301062867125 THRSub[4,1]+19.30453402829549534476592120075866802667218156017531181808288988840371438329374`50.04963245725129 THRSub[5,1]+12.05216757927686025468126887390024329614683232359400983038394048240610186282902`49.36229947558125 THRSub[6,1])/(1+0.53620600734446329257252116728802365321193561749504081036284601217053152772693`50. z),((43.9532944010828813943016115142687893943622086384537440629508903891762794470733`48.391252016827885+ 84.31516046060365691659555206211650467764253135190461829212523663665929028159032`48.391252016827885 w+31.43267693008962202493531301423874531442963420139927652986034930642520763442837`48.391252016827885 w^2+4.91224201240761684705811603597162633208690649690922307221104485026782129200216`48.391252016827885 w^3-1.83061635668962077881785125236571268421762645898307515270767180836116894986351`48.391252016827885 w^4)/(1+1.20757093281585948950571770520325726682252058477561691194370499833395628081293`49.69897000433602 w+0.4843020783298505908195649328466840769664319751633000354411657815333070286946`49.69897000433602 w^2+0.18548336130816195183578269260871039079765561102639826452132546571121631475765`49.69897000433602 w^3)+52.78622307582008067668391006141079635188350151326162474282598919559538881259783`50.12453212783742 THRSub[2,1]-22.0313428490942422926766187077723293875040684658533623266661936287701994451737`49.20081015617125 THRSub[4,1]+50.40712997800942387126029420665676331273165791696405868880712284792570475428823`49.71704680125915 THRSub[5,1]+45.60471033223693804564207007340162296935214866286223560618377334916713700921063`49.10566699979498 THRSub[6,1])/(1+3.0112719515379306220841069503647609676322448260179482145030832806805849190885`50. z),((51.48079941489460533027391113179075138519152200986763476896176908929140855087776`48.36822344366621+ 98.08902046346919127405083575573899528278914794694312419293095062750647511685746`48.36822344366621 w+36.23239864052789917897792387124050489752072080546310845950836451824570680786537`48.36822344366621 w^2+5.56629321776560715971616469272167526934601918797429207605534279116393102522373`48.36822344366621 w^3-1.98405086980911753406461588585889914407818369718446593339169927594452225386143`48.36822344366621 w^4)/(1+1.20447494215554246612530487572537620156723205440906914558447688798588041127882`49.69897000433602 w+0.47749680242336547350383922991051554780331851016136653435883056970477208737902`49.69897000433602 w^2+0.1850441292685876893064748397462028286994286417168154681211316521885612196371`49.69897000433602 w^3)+60.2789218527385441902368632276999352267145402723344899201442151282552243087866`50.106965269695664 THRSub[2,1]-27.02647536703988463504525415196508863739142763856860577821167758387675644263304`49.20672699050754 THRSub[4,1]+57.56213026268045494766305557269284390799499513467403920412929954709716054273689`49.69947994311738 THRSub[5,1]+53.32330891278642970901852628788953389929916032170036864964540488838354957290669`49.09243728462679 THRSub[6,1])/(1+3.58064878310258706123531367117715639325953868219942473835510307663670072725164`50. z),((5.51927594932427085376608340124626456085648674178644956419079335462181394614573`48.09623231957504+ 14.39501594864445344172625013577873640377573172454760949036243636571518900441352`48.09623231957504 w+7.0277328801762700423010693902428470653579268744584939246949835452735447835071`48.09623231957504 w^2+0.34084117580016431972740327758581029957721353996923799758924934225478369031903`48.09623231957504 w^3-0.86759272838978319535997224301837037112257978755608404730213138660000101273292`48.09623231957504 w^4)/(1+1.42868098256366857037924437396639270032046593773492545743680646642659601002947`49.69897000433602 w+0.66934432190789769649372890403776301943722790432573812150969883416099803277467`49.69897000433602 w^2+0.14003659376516669130224440699334603583978438015168393503356443502106937779444`49.69897000433602 w^3)+14.52991869380135270018672306406562294553270920171662704215786922103869380816896`51.025401206090336 THRSub[2,1]+3.47286007225157635832150595712445288339645974184330280711255302093426389111295`50.06365140574849 THRSub[4,1]+13.87505029705092299629542177144957166754427515405358796890222783561578547077438`50.61791587951207 THRSub[5,1]+6.19500423144510841705879698289913632762878572356270061396481439828374514416597`49.84916703979879 THRSub[6,1])/(1+0.10414142021216256171521601668961206719644960838149233023319752158843095008062`50. z),((92.66605188055900579966465039282763486105776345079254345045648057751404614745096`48.29686666573664+ 173.57704218300007802493791568983177307003500521849502084216086591300621120042175`48.29686666573664 w+62.66091242323318427123993396290630799793798354060169998935658498883300523381213`48.296866665736644 w^2+9.15271329372437036906516850680797518715103288103761602318295824873665208835511`48.29686666573664 w^3-2.84097350999188932566686378908134382370810878710703943877452912686147109185832`48.29686666573664 w^4)/(1+1.19781172657348270904156574525541934997715252864350798050447474535264779430156`49.69897000433602 w+0.46043639478424459026999808901675127278426313014484860296281328339528863701882`49.69897000433602 w^2+0.18404789686238183364433878985725599806814248020445191883014755073794048693209`49.69897000433602 w^3)+101.27373888844329515448186432781116874335374336871638103371348524783679614738015`50.06045061423119 THRSub[2,1]-54.35635339084305194454192155203924431515089636948986652059119099693113766836193`49.217318462256664 THRSub[4,1]+96.70929689696196143260497021421888663986711849165821152086622896735396537307618`49.652965287652925 THRSub[5,1]+95.55409197274717046965762809310440760404635076130164371731464389705340264266552`49.05745661558561 THRSub[6,1])/(1+6.69588132204659557764671522765647828186364621261831764637537980752029384726796`50. z),((62.62211388708647485754485537973161136483981346219193561758556352449892357653423`48.34189163611166+ 118.49477335433698199133122504193336995403914327017674434384301382142235729912742`48.34189163611166 w+43.36235257740143699319590049648110420661141677900692923407093444964016368601642`48.34189163611166 w^2+6.53543665036262119440931859332896665250464317716817562921464783630820285757843`48.34189163611166 w^3-2.21385600138119393018322250716861793514593058453530475979949303598027839402572`48.34189163611166 w^4)/(1+1.20156736581285373018820911740515917302181649467841811284381057589598317922841`49.69897000433602 w+0.47056433094228231817107450766535152246282495054502391250337006819120627076328`49.69897000433602 w^2+0.18461888088039985727529573786035231460334430424400671570892399286824413980716`49.69897000433602 w^3)+71.36872028739740701328068146596835273812741075836951700777299109860151188901845`50.088515922627586 THRSub[2,1]-34.41967432347912651707446631081070031166667462925862383663086156410761482945343`49.211761518380484 THRSub[4,1]+68.15210769529278267451451003393136228044099239843438084395505104318856435410975`49.68103059604932 THRSub[5,1]+64.7474572743920998039803911414968712423543188874385198984639155208208980467292`49.078555962734455 THRSub[6,1])/(1+4.42337241091852250744490081530279597026130978282040054816589817392309299752285`50. z),((64.52696258398128430760395557622265033822728640789316614835024426731716364824354`48.338087054182274+ 121.98516937866108493089227127711982846570364962065623299701748260293122111432012`48.338087054182274 w+44.58345986060546701004301881480592228542327732957505870744589265631555527789426`48.338087054182274 w^2+6.70123587092863594631501133737634076114886844313250227334682349885504799411778`48.338087054182274 w^3-2.25336291189160166256370533731679775398421201659710910387658370512363162321813`48.338087054182274 w^4)/(1+1.20119541913807563669055270260296121451442585678938346712849942274536851297023`49.69897000433602 w+0.46962945684618429963105074007146606041236671568856788505801263174678687020879`49.69897000433602 w^2+0.18456350041324859247725850459702589350238803578603926693720628509818176322168`49.69897000433602 w^3)+73.26476120337831623769321342334749616469225285539417530092070253275422973050211`50.085982451136886 THRSub[2,1]-35.68370160079973266668282094906346259604323602727506269872933585354276005710757`49.212364040897064 THRSub[4,1]+69.96269339978986295434545991752340186064635744775444457428399353822822790069161`49.67849712455862 THRSub[5,1]+66.70066254241074517948975852270267481279755404044624952043138909916422315657448`49.07665060675598 THRSub[6,1])/(1+4.56745424329963852587291032909184440238690306627006534099570315663572630573089`50. z),((5.73486570403671226787088069840052247160415603833434640320769375201603161712862`48.22624046073574+ 14.90036932372398524446236962566460859900940468201541555873663398039318503416672`48.22624046073574 w+7.43586030414452382772736586049085459564066469590835342528809641048649786472796`48.22624046073574 w^2+0.47815406522393437688629687916751548068889641676940473585588505929644024629086`48.22624046073574 w^3-0.92156329612928631350131819450189891357986082796233401390016109471331615001599`48.22624046073574 w^4)/(1+1.43890484547814451995420790037226704403526321379302276993066336210541311032294`49.69897000433602 w+0.69007581091379416191275871499237257448395033249586986597648329084925741468026`49.69897000433602 w^2+0.14859222998822371582631395406660867586113011511132316331926548652979740346476`49.69897000433602 w^3)+14.74451158859001953170549549855149132547417608346651988073615675322504819034162`50.968590423862445 THRSub[2,1]+3.32979814239246513730899100080054063010214848734337424806036133281002763633118`49.977004100929165 THRSub[4,1]+14.07997141679901511271491446423649934619447414435378359524276345484445498984019`50.561105097284184 THRSub[5,1]+6.41606695696321913804491093259123144581386076899023177780651617868449968735785`49.79765175001262 THRSub[6,1])/(1+0.12044852478808009684165615969214757025045101474535604812177840216202323114272`50. z),((5.81065253080440032941616551312068956964187705626676091672938751182231697368147`48.579746643756444+ 12.20049087785083650312715004446356978684219662034554976225486385187203757588224`48.579746643756444 w+0.76000871613466921733717290328982544794372261213304777912632885061261747594029`48.579746643756444 w^2-1.18438389175595774061723465703885241242818208361052213732296047441360647202132`48.579746643756444 w^3)/(1+0.94710289693658342270683283719167316991393818962725884718632051154779226005588`49.69897000433602 w+0.09427289212427170282050848724087177509068140512705320085078343902372742841522`48.579746643756444 w^2+0.02931168448438590281369763049261347607343202042341088248946826956219547208869`49.69897000433602 w^3-0.00773459166272070917937972069384528880420000330683877800291124971204287258913`49.69897000433602 w^4)+14.81994798659797583412897111417680645989671096808431964764143830783029866578304`50.9506142199618 THRSub[2,1]+3.27950721038716093569334059038366387382045856426484107012350696307319398603684`49.9484244483709 THRSub[4,1]+14.15200787059109822461192639707006632957436307388400715674403898296351225973288`50.54312889338353 THRSub[5,1]+6.49377771138186220827104171377951342521207871589472250721157157408771474003072`49.781465993233375 THRSub[6,1])/(1+0.12618100363999056465868351651601340780292780586470017937740935564992578207853`50. z),((15.40813380155602042966421629717759445392774032934211031065671849153308145447009`48.79823367288764+ 27.94603257985393018465451512386183986024108409113002240359605614234352723531779`48.79823367288764 w+2.82649219212127993603783669893962875167391074446962802881584231958728610933564`48.79823367288764 w^2-2.43612786125846302547686168565502561840126292539644698106026161157402568750317`48.79823367288764 w^3)/(1+0.97829777050507519567594457945976182921807128028485281164654185519890409692607`49.69897000433602 w+0.11425888212217941635962400639969972398490663799580320852036080911877201426789`48.79823367288764 w^2+0.04891815529024424025423252441803854089780943073264971596580032553868122701139`49.69897000433602 w^3-0.01957498512878427113231151118740886308629892070430631245607911832224213123371`49.69897000433602 w^4)+24.3730517104631467677389881141519058659089007438627450315445350724716794427254`50.337165656078845 THRSub[2,1]-3.08922860552295302004667074293306906352100128625410918581189088002105986525801`48.97469883432828 THRSub[4,1]+23.27454994772750638839306296144920887058571474875634827320415887935771295107516`49.92968032950058 THRSub[5,1]+16.33490105535186389400855025319665650434240825331417049362128282522332802232416`49.267917532967715 THRSub[6,1])/(1+0.85212983621002342054645452005558160182135342654271428241707093279691567913771`50. z),((72.60111695949600639412753510732717721193798475808671397092942260275181711063554`48.542232647532884+ 117.38779521620956261687048171892786145614818405034203037273474084561558475298137`48.54223264753289 w+6.31055517428985235307622063623429732868127086119008739118242524629922132782868`48.542232647532884 w^2-11.65596603828057070622210447190129460432421761576166543478503102563588076935783`48.54223264753289 w^3)/(1+0.93272878991877066967149236806097384270946638773095819470274063299703416767456`49.69897000433602 w+0.0504859404980275475923809424641146507741121068896479952881833046388880473784`48.54223264753289 w^2+0.04552134692726386600312207870953826654425141106070309231792700842191398768056`49.69897000433602 w^3-0.03615766909860429530311388322374875202518889560160535040359753184482198123471`49.69897000433602 w^4)+81.30158170407113180750655132463789974485995067778554172533696605732466792304317`50.07668342283417 THRSub[2,1]-41.04158193459494304655837954992373164948836790886930698167351153658971885213709`49.21439993436692 THRSub[4,1]+77.63729165635512000003687466946076337748625927029153054340495567046234976549271`49.6691980962559 THRSub[5,1]+74.97978774892158899834049128680313245119920985248612161344901888757359247006783`49.06965844042448 THRSub[6,1])/(1+5.17817936768803984815577020203629697378937043548217168022315963861234656531105`50. z),((29.45310500116426315866240371064231750665522984727139060869415924470505494246716`48.76219901125319+ 50.38039796695131629645580510936672308056641299561350903427281314078445854437014`48.76219901125319 w+4.60630206117726782457944074270691833299127744079580689049104062591804488789394`48.76219901125319 w^2-4.39407902459593239760715035337982726503393026810134678702921690023018021901602`48.76219901125319 w^3)/(1+0.96667154511276517701659180734299867820236198495090235890726868207335233515337`49.69897000433602 w+0.09681118719207593076919428680548650125102641138705361045653730021094721786734`48.76219901125319 w^2+0.05275521052206947653351297236519623810331685004383927901527216353199164114778`49.69897000433602 w^3-0.02676983381323731432675203169298162411310728423023502639621957222117698648753`49.69897000433602 w^4)+38.35308072885256320146323083456243203098501310687685439292052956587007956625242`50.18250988357662 THRSub[2,1]-12.40924795111589730919616588987341984023840952826351542672922054228665994760912`49.17213242354361 THRSub[4,1]+36.62449428479638429849073717284666352314953265815881680711739820096459299497304`49.77502455699835 THRSub[5,1]+30.73641849921206594996219328573552960522347997644595512273902277218855119655949`49.14945711128385 THRSub[6,1])/(1+1.91448465183310725464965819999016296960802590610844270031749982790487523606431`50. z),((88.18855409348752989448396543441828336954427403883251208576346586404498340283292`48.452650069353375+ 141.19379502149272179172537529560899559476005978069343511068549937773934094728413`48.452650069353375 w+6.14353350419554693657975888899461213806453214899775887548195086720205347948916`48.452650069353375 w^2-14.56181974017610732175358806998022493430292823053701201614086140047201594407768`48.452650069353375 w^3)/(1+0.92408918306143585769937024046044637763409944691527571186600846168321255146916`49.69897000433602 w+0.0388238695906460928745309843349673529906503573220833192763330044137803644831`48.452650069353375 w^2+0.0427453123071477744879720291975171070590704108426234054733294683073060046094`49.69897000433602 w^3-0.03807365515838436360724998184982401004420472192186751225796546579618230035634`49.69897000433602 w^4)+96.81694448826826231237877149934467401811484846679198767629477647917099697300342`50.06344663583568 THRSub[2,1]-51.38515712405969671647319299972824783165829976820693761564538515115393821877742`49.21683868280034 THRSub[4,1]+92.45337174216915047341490246291796704947918749097947539232442619788787759953494`49.655961309257414 THRSub[5,1]+90.96292823386004945404105523346853973454895633051203497869784479356528948917123`49.05970836240195 THRSub[6,1])/(1+6.35720555913938773958341796392661535311963580637118175902315621570830799283995`50. z),((47.62159232832117321993177848804046738722350842692974902746413766016806357880755`48.67585699772559+ 78.85540955250988640989979902838362242898947921041904867888937002326798346666587`48.67585699772559 w+5.83275898005306592231849529683782628011369044358858326495173606815525524030965`48.67585699772559 w^2-7.27071072121813827076446966953229659001091034636437796825824507076071077103873`48.67585699772559 w^3)/(1+0.95034121731610740737300549915260356738380592368510410917621837881541270578828`49.69897000433602 w+0.07437227998019760992981868398233848735621968725507024072138537931557700516182`48.67585699772559 w^2+0.05034814667149786059033331494686774213965002434708072677813738235268804911927`49.69897000433602 w^3-0.03184654473102815942438983659408169089037560891841908731096087224222195665282`49.69897000433602 w^4)+56.4375592545884291170587520071411211726154989933320271998900316895781836972605`50.115300170824156 THRSub[2,1]-24.46556696827314125292651333825921260132540011923363063137555529142539603494737`49.2040621527402 THRSub[4,1]+53.89389918845695429357021763646466043909875142676227583044059571132624245703758`49.70781484424589 THRSub[5,1]+49.36613182877030553191840333574975554606801483200173961549760475435034147877818`49.09871263941546 THRSub[6,1])/(1+3.2887402291696053901821986165780659519608726746011149748778210747016157477607`50. z),((8.11139921569199718586363671186215674532497143657886240886066006349204698421207`48.72509387951276+ 16.03747146092358310006068523484003029464260774951092060805345068394685650075689`48.725093879512755 w+1.39267439285805002517188863489449295528059243447090481191671236836659089147389`48.725093879512755 w^2-1.50289203951705973600938504318018668435830948934536886414932505596268260539832`48.725093879512755 w^3)/(1+0.9690005612592269781501745400362077404114313657994018030393288583688053917606`49.69897000433602 w+0.1100894788306854299340818395844651793164479476502733790122102446262914446628`48.72509387951276 w^2+0.03704063418607481870168502572153802262965465740681591683899608469759019344323`49.69897000433602 w^3-0.01181439040562122970326988554326639310239414971146751476488561430919112867337`49.69897000433602 w^4)+17.11005630804394798939129344688038441976166596156488519635860919363625818128501`50.63659016320866 THRSub[2,1]+1.75276832942317949885179236858127856724382190194446403764539303920255430903569`49.255813118690874 THRSub[4,1]+16.33890022803515611919245316452002046172261200775427637221709640503670685891781`50.22910483663039 THRSub[5,1]+8.85293125078082325445092045337777480353271299406392048133527518063082402429079`49.5088268505708 THRSub[6,1])/(1+0.30020836798854549834787912473977390998902335486882007773835495416138880151512`50. z),((56.60514022337734675074466607208817299307572330503640045056505744389141053730768`48.62915318125336+ 92.77933930791227068751301405559822655703810241320285096432590219648220378308922`48.629153181253365 w+6.13402016206977643480288980596485957083039622173095181099833697167162429607018`48.62915318125336 w^2-8.80094324328665924679462218139597244094965869561917858494149204282302641074709`48.62915318125336 w^3)/(1+0.9433881069589082771986333594445569386993956673059402231193295378718190302332`49.69897000433602 w+0.06491983335758384066371988561608043674804773790409056500481235661591232268633`48.62915318125336 w^2+0.04861446999074129144270036805060582115701632481946312534561165788320912751122`49.69897000433602 w^3-0.03363349958801828895006301886621202969155971836025882199367859170638135416837`49.69897000433602 w^4)+65.37956835350915620022699299317742970252989324364845430229237090948960005317511`50.09760438459618 THRSub[2,1]-30.42690636755362597503867399561675162126832961944458203297711477136634027222357`49.209426105442496 THRSub[4,1]+62.43288888405258594777380732876641367894680263553542480386406820454055171923302`49.69011905801791 THRSub[5,1]+58.57773645790715958463304037536422172610240655597194010662157118034552638237874`49.085392704936304 THRSub[6,1])/(1+3.96825143870200710627098219448906905205302305466402305030819341912235577525974`50. z),((40.62706440917692282676853406936247470081180672189882895021716807353530194079863`48.710843470793066+ 67.94953623147552125305907577361550317736985145729846716620149006797714820164561`48.710843470793066 w+5.47139965850494519584725536357924701432218981725695898095951516174610057367323`48.710843470793066 w^2-6.12462401929281213970282482514932063961181281937036345777835943196953841907075`48.710843470793066 w^3)/(1+0.95628901602284592961214635412063464434714295465897864052465810542724049668203`49.69897000433602 w+0.08249257282069338539211637173055876333378699317934162123033831765781103983322`48.710843470793066 w^2+0.0515711498314269153642633691410113029675130544901368225003639678260391197271`49.69897000433602 w^3-0.03018509849247269017211031159447691592410358092140703016238047614407038032231`49.69897000433602 w^4)+49.47537315325281018966615904805179185504255716017540237032911404698416624464482`50.1342922594831 THRSub[2,1]-19.82410956738272863466478469886632638961010556379588074500161019636271773320434`49.19701283720354 THRSub[4,1]+47.24550119193742379121072701234931523906335410485496744896625752469323075841871`49.72680693290483 THRSub[5,1]+42.19404052238636350686548536823008577488235196138834241892131879259913973754679`49.11302386466854 THRSub[6,1])/(1+2.75967752677543696932963738792337738899012563474659552464372264950851089566143`50. z),((15.58057983909188495315581442323102821220594229978401149878014071371591765775727`48.79837119393901+ 28.22468451362177216291596394197662062089125433248102923861309313519697405261818`48.79837119393901 w+2.85469630704402319059968992729707510522003497233950971113335474737471739990302`48.79837119393901 w^2-2.45857326591582493988098014018853911077948571308469430965436662631276429287454`48.79837119393901 w^3)/(1+0.97823329334937117638694730659804557275873107282440714055567710174686924105324`49.69897000433602 w+0.11411456374238312339516554892016246252869347901708746234501756702891052739204`48.79837119393901 w^2+0.0490584384692195196874439258293357941751346050543535354920379460273157438897`49.69897000433602 w^3-0.01970374514268493016935236784598923627050210742475880420316797491044307879915`49.69897000433602 w^4)+24.54470037919981895038552501705710584220198466858030969654866792143209485575591`50.333616008708375 THRSub[2,1]-3.20366105134740114181102867820320238104972390273248562914797944599467014061153`48.98277622472741 THRSub[4,1]+23.43846235235501432011286432945856621137808241470680792711156953715945835994144`49.926130682130115 THRSub[5,1]+16.5117248154295346907186817061910857410954150798342077511310126478678686885551`49.26516234398451 THRSub[6,1])/(1+0.86517357092529679382887594847099970211112207271984747117501348248790578228441`50. z),((5.6344557209592040977222096697801528280944447118853613226788638685450560293405`48.55674386701298+ 11.90320515347010043469795880226090824480934045837527177567111657554059555865408`48.55674386701298 w+0.70303881024327777591104766550475366217576397135733821428117255157910654680847`48.55674386701298 w^2-1.15750619800216478559198874496100046435111245705438894441589379303209466369914`48.55674386701298 w^3)/(1+0.94407811643648633757368723587636299668966401459949724864357579079108254273661`49.69897000433602 w+0.09211779776254548729030385963834152475428306289743979736910890806797507648748`48.55674386701298 w^2+0.0286326465529232321384002188836409062119596185285934067020263822278289735114`49.69897000433602 w^3-0.00737453641671306189556652195952703785774002431188479108476724282933048998272`49.69897000433602 w^4)+14.64456588865161674494954317222952406559525224397388823054271764997446170676368`50.99392274781857 THRSub[2,1]+3.3964286090180669951462925516818521366880977136717953481893207349770852920498`50.01629005003758 THRSub[4,1]+13.98453030368315825656483220366509266995530828087572484504543835938976683153817`50.586437421240305 THRSub[5,1]+6.31310796172734592085730038982975873235075560950046561543046379460002340354148`49.820555847010006 THRSub[6,1])/(1+0.11285356232478942510532454795840064200561718356013528158498114015635576007672`50. z),((31.73268886494376766740222320446803872181136865605297223012891443978040106059188`48.75241698450692+ 53.98142721385335574899727462137255531870655934572824098208617669514033992144878`48.75241698450692 w+4.8157616387014330607744367894550145298181711555307849414531258573077061214532`48.75241698450692 w^2-4.73589601385814311008196048646658004100057438281740809220722937880267526940441`48.75241698450692 w^3)/(1+0.96448832824356297870043042532638462048919525212649286872552522673979937534653`49.69897000433602 w+0.0937763302709972435502178041621577637379477109501713952042507000015166084519`48.75241698450692 w^2+0.05264812917743739020378662349814093244630986478247115768665981446120973631733`49.69897000433602 w^3-0.02756797088997371176350859558060441840074444102651696115708281745455672765593`49.69897000433602 w^4)+40.622124083414846236747843873700545382556708087120596166281383142316073385673`50.170020161887834 THRSub[2,1]-13.9219435208240859993859079159654954079528728484260099423031229265839891605564`49.1796400231685 THRSub[4,1]+38.79127108060680498272420686459439654835688013749803105572218185623363728208403`49.76253483530957 THRSub[5,1]+33.07387197721410608305205751520126933788444829983941032027962851508146914046914`49.14000379431111 THRSub[6,1])/(1+2.08691127064813066664586998494109112041325193368642711752714160700961808302802`50. z),((109.63272051868169732212587449048216323653543864979437636468788329879645283260292`48.318206598849855+ 173.73984190179452186737983912106000986644940171594505849122083534885922028523928`48.31820659884985 w+5.51552008267077562924641161694208228731214138624023454566981933198692117716321`48.31820659884985 w^2-18.70555266641182466939346358645167634158626792817625914351334235237579179702944`48.318206598849855 w^3)/(1+0.91435123623435620027961342644958576894795746625954933447851207933569582195675`49.69897000433602 w+0.02571002191348312726266196930816404853161685421203891675234657459999596322026`48.318206598849855 w^2+0.03941298084448725229054735966699136801783620223665670860417670811245197769001`49.69897000433602 w^3-0.04013640322065474464403111719742385769210920089189009256113307596943645904143`49.69897000433602 w^4)+118.16195578368114013379191707212651482283136726650141264595856865993008134560417`50.0512781006759 THRSub[2,1]-65.6151646543349485974152900482494750348026456346798875954212466049933278005096`49.21862733648455 THRSub[4,1]+112.83635609027294874010824054999101993252356992009870647611994641885176912826743`49.64379277409763 THRSub[5,1]+112.95147719222952242607762826773658023346197196228998143390884637750273614625394`49.050563280348264 THRSub[6,1])/(1+7.97923191612211442051340691020218992856816871258098319252560904860487048308817`50. z),((79.01831914546661856910211724205241983945920042601276066496001685526436391610827`48.506004326265135+ 127.20647161557633569588554167383424449495988762505876108581916749760848465400052`48.506004326265135 w+6.27678409016545316198864030790791958548370695456393335155728256191902283178223`48.506004326265135 w^2-12.83946972793370955972046293212447384104735289347445137387995894935318093745192`48.506004326265135 w^3)/(1+0.92898656555208989268806800934528141270188197158291299367372209039742181473682`49.69897000433602 w+0.0454310310806751499291091565587424747138560254704605515024056268147988798485`48.50600432626512 w^2+0.04434335382989360570289322396733478214026321445292233928557661484081942452531`49.69897000433602 w^3-0.03699926064897523226927035486423730133803323470327065277800655066549245447779`49.69897000433602 w^4)+87.68911155384707979617225149756221158197577223378185735064494872507575686267836`50.07061665217674 THRSub[2,1]-45.29993516777890837233551299853993954089891561286685073187883331509044481189332`49.215583184881055 THRSub[4,1]+83.73693335478836259115277004138799488268876798090937698749107509979435391106406`49.66313132559847 THRSub[5,1]+81.55989730618514518136586207762742063469076714606874015136123415034491420241951`49.06509768891903 THRSub[6,1])/(1+5.66357343138558711607658515287388320532248007061352678390426523899412097670764`50. z),((53.56389276453913429127499789081193255146617845191607630883425489533243537414037`48.64515000978546+ 88.07508417540426328520132402062336810522220725221568227087778502965908025757931`48.64515000978546 w+6.05057541559166994278084616530113843087594698563810896494868727635391413726916`48.64515000978546 w^2-8.27622812308927516003350477597147910742423438755148873826093928234582831882333`48.64515000978546 w^3)/(1+0.94565793471933860888504720064083228010849454893220632286715427516409122810053`49.69897000433602 w+0.06800169946935912809871451622585673280525686577837182802296658117366510350023`48.64515000978546 w^2+0.04921012350933695738228688042901823227292534810750327304532077959625758470586`49.69897000433602 w^3-0.03306504126933942524957663744983634163814393469377981153476460272413509558778`49.69897000433602 w^4)+62.35238324060218176166220956122130790488279175286370170394196021676308128986419`50.102950537607555 THRSub[2,1]-28.40878295894897634932881837431267042283692862558808030074350764288199443001685`49.20792191846793 THRSub[4,1]+59.54214003781253230702948034381141602544141602073773201345998657504460889492605`49.69546521102929 THRSub[5,1]+55.45928375999235680558340284003223539262755202818599651055798262949071037123668`49.0894155854929 THRSub[6,1])/(1+3.73821295464385818759180773925914385524448548403775315460207208127051448637502`50. z),((12.80217575686432090112521976064861692632675222966073365526989026221770723732626`48.79144449561134+ 23.72207757598288452769110067187029742376921580568801321460074392983015670063804`48.79144449561134 w+2.37412920376728480802354161961955904670632692129848736235302998106476795022433`48.79144449561134 w^2-2.10091757371410398874250371579498815585624704151006811514761956131421237024646`48.79144449561134 w^3)/(1+0.97846485441391122969318622547596127802964515216048262293693198486240000687933`49.69897000433602 w+0.11571249871569962265145982147565755329720768544082681260482320488610988775383`48.79144449561134 w^2+0.04621455914222420672429362479981965065886199536317676074267910459283442210365`49.69897000433602 w^3-0.01739929414682726079791965921435419419709659463952710308696813762459169173866`49.69897000433602 w^4)+21.77914328817236374031233255114804416800476526090574753881411762358734503589464`50.402550114857185 THRSub[2,1]-1.35995632399576433509556703426382793158491096428277752399161258076483692737092`48.75218843942577 THRSub[4,1]+20.79754986371584086293943988483242270867688695882581054038103797144345091555234`49.995064788278924 THRSub[5,1]+13.66278804741332469037241767607601211333909367057041025805599755592405357353272`49.319042887711184 THRSub[6,1])/(1+0.6550164325052751243172336581851493092242129208558080095321823061589573556215`50. z),((14.30620670779665408421414539290203642446831006378914268402376464584001379898587`48.79656128719227+ 26.16302358802848065889769454705167445130910652365510300598079353052264972039635`48.79656128719227 w+2.6414104469944754524407715630817781907501082791392786404101091539088554090815`48.79656128719227 w^2-2.29352390545317398119203526108547295255920713033122949630373609211632705212351`48.79656128719227 w^3)/(1+0.9785767542920566600801382273518883925529100057199469276214732655067802727272`49.69897000433602 w+0.11506036379370116572465521506289024161666179181424525218356465749769751421077`48.79656128719227 w^2+0.0479178830607014228264964411398927416315291856566571427746429886106450460927`49.69897000433602 w^3-0.01871098279555831526962681690156561776932543432761421138315405152011149641558`49.69897000433602 w^4)+23.27621978906090504452087912976779963987379304873370094836215801574913301761285`50.36187154923678 THRSub[2,1]-2.35800732458812520456793142001033157949759615616807979702363950887269558184965`48.90973169451561 THRSub[4,1]+22.227152615534618393011329919058765574941030803550632026489414218564111962955`49.95438622265851 THRSub[5,1]+15.20500039289409127712936528836392392446426631498279033684230785690626489314082`49.28715024063248 THRSub[6,1])/(1+0.76878060481014237882862326251620674682177192371643575609876896197319496042627`50. z),((119.83635329090782520997423380537922427509009761368534119555881020170636606175606`48.23547357914319+ 189.16177210589809446563239280520578954768631426671280155674216843809669641426108`48.23547357914319 w+5.09185828804261408245284640757540346735802392343245775386231146210137940832362`48.23547357914319 w^2-20.72311416532338691676229855595532004666214926743428077938896018689709392341148`48.23547357914319 w^3)/(1+0.91040534991147319572626240633358944411503060903752053694942714792818321946424`49.69897000433602 w+0.02040421216222401883960791452421301912874889788856774661831690321390616337747`48.23547357914319 w^2+0.03801456866928077433446344844938008977493676904497569046547565741037483394188`49.69897000433602 w^3-0.0409494358700669324823297400447044405093322870583612314355875652576651429321`49.69897000433602 w^4)+128.31840824067794613028295599831084139120349089488554046240279462431537289339317`50.04699132116079 THRSub[2,1]-72.38613295899948592840931599903902608038406138693597280638406391458352216570228`49.219158146229844 THRSub[4,1]+122.53505376712615204996833336360056891382485040866071857808126371261229814792546`49.63950599458253 THRSub[5,1]+123.41413982581733902244122780976433280936942384109494281736077487997508474620093`49.04734185392624 THRSub[6,1])/(1+8.75102975453464895635516313185148620944807145037799661958921040773802367083712`50. z),((7.06920483461414999571035221192164448641413764470499751494881286949496832834917`48.68170326330327+ 14.3079889542844838883071082995913956386100964284035436287480910056995452587279`48.68170326330326 w+1.1265853823300918441576653020384717343109518249864055255281199659317956894502`48.68170326330326 w^2-1.36396900372537475246571501893787932967053067571334749816065186662117637032716`48.68170326330326 w^3)/(1+0.96206334159386700170249910545555977295000411527885449829508198083615011960641`49.69897000433602 w+0.10506936676828794799201636474957874285421630693193129784810800199838277724241`48.68170326330327 w^2+0.03384044927333493522096388425359539578356313407205928971855892579738266356006`49.69897000433602 w^3-0.01010828483785191192682334785708991942103802828834122153263886630163962808691`49.69897000433602 w^4)+16.07268090276884847105163083915038637920037403775790720846381773145960683320962`50.74171677380974 THRSub[2,1]+2.44435193293991251107823410706794392761801651781578269624192068065365520775255`49.55041956941728 THRSub[4,1]+15.34827968648621417311157156448001881088213671494507859375887044491776405581612`50.33423144723146 THRSub[5,1]+7.78427967822335476901148625819606598163580269801848888476377846572622550477891`49.597847746975226 THRSub[6,1])/(1+0.22137729003060330113587648797225464828153330828628718863914296974652614105788`50. z),((61.49458929612360851550320512080580128291978826485531048184808922403042417558233`48.60307453385383+ 100.32401209567007240057437731842590331689270850339668766681890552937277192959277`48.60307453385382 w+6.23221277362871290322981368542003633084848016296900528288656363722167352277152`48.60307453385382 w^2-9.65754944531099805161955025811107042654967248771715502890109566427291359793679`48.60307453385382 w^3)/(1+0.93991007670408188217420996962156334709895380504765453261393994538834800427559`49.69897000433602 w+0.06020368421765056934610291784859500153118386291514453764087288859874419914317`48.60307453385382 w^2+0.04765443165966075755437749771119950252948465991840616169538733454718495472395`49.69897000433602 w^3-0.03448114008191413697256624346373842590288065475619443379725277285980824056213`49.69897000433602 w^4)+70.24640922840084587081037323313088649606583220776994355235054064336948459758855`50.09008739017313 THRSub[2,1]-33.67146695081475242209426082225238948362562226219224153301589459395292996850014`49.21137728090858 THRSub[4,1]+67.08037957893676780993752631348633851609260729986423215277131709261124659208354`49.68260206359487 THRSub[5,1]+63.59130929556349329615536016220759738555367186854298313380267472972322737615351`49.07973791128286 THRSub[6,1])/(1+4.33808699723420964315270487740250301204781221785121371828609462683979671519302`50. z),((81.9294492792399286949973567862926125330225162057985196148562369605282570618193`48.96859688568419+ 136.16172067149356095787703395970495701291358187615343794899244939226660966593562`48.96859688568419 w+22.46949290754176836790751109255433001416959152479354365356946298808052611843939`48.96859688568419 w^2)/(1+0.98242043358786672121063492439811870472609417229892472791481882742883980354495`48.96859688568419 w+0.20388958408720614013946950582687705458561218938269462720730356799678216651924`48.96859688568419 w^2+0.13088720536706955384958753224821463480895887548519568782676919560669379425614`49.69897000433602 w^3-0.01804985323834993360640642035406253665019580970505280199850777410556072271842`49.69897000433602 w^4+0.0047560564449948391846250601915455062902067729727877091888151071635671897644`49.69897000433602 w^5)+90.58678098784306566038374211618581898675454914841018734291903598578547860197549`50.06817066475 THRSub[2,1]-47.2317147904428989484765067442890111440847668892857373933948914888969259714261`49.21602867978794 THRSub[4,1]+86.50400383798889677934283815190434469251611312361384013248636696735276139121592`49.66068533817173 THRSub[5,1]+84.54492951501251660268511314862152016958611156479781636563042555931085656223429`49.0632590806899 THRSub[6,1])/(1+5.88376990402810928979699619854301081193218489690483278331789289302185067988814`50. z),((133.3477857698529540362893701915541371367514172378142379779991039701025113384962`48.99961579668906+ 221.86315404678955245653829538327428541605117748272345202715470330677811852893169`48.99961579668906 w+39.34142351421169658472655031812822095246344868845361330901944317753345631625788`48.99961579668906 w^2)/(1+0.99819948973391118383881960385841618727240228993783408486189583309816787917893`48.99961579668906 w+0.21436372411576229133798232850586854159855001079288166142877306877323455642892`48.99961579668908 w^2+0.13273856549589497548349579853605428927616178231920391574309117163513806347671`49.69897000433602 w^3-0.01759471377297930974815844006368371970994052511145201360669373018676499191995`49.69897000433602 w^4+0.00432770335658482563901379084252087108156257381491669055537189153844173631993`49.69897000433602 w^5)+141.76736555437687886195884346316592476834424646147717214592158674857548106613155`50.04230864574241 THRSub[2,1]-81.35210450146544108285990764227574833181123176466372726206325866409026094753215`49.21968049449544 THRSub[4,1]+135.37786198256865128689508489913886505208669126953166727968773771179358924312596`49.634823319164134 THRSub[5,1]+137.26857411205461805627628780803797249477298606138321216094325655825307761047352`49.04382297083791 THRSub[6,1])/(1+9.7730279598690873858572071265461173252188657396772497264624176998534892919763`50. z),((8.71714838057890295990508946302010525493076471097875461405883556210604244711627`47.45644930315154+ 14.69221657885678912103110754654118376512744132866379229074753058910515605437176`47.45644930315154 w-1.77419650486581822131047778581394002149840917858077368461842779763822473044085`47.45644930315154 w^2)/(1+0.70263257184146245455390798321861786225430536154914434493266535401562855513327`47.45644930315154 w-0.00331780735151221905858979374709826530436103733372630034210093373640434248111`47.45644930315154 w^2+0.09375451991876201554112434854635000868324523917301541837761579881264315158674`49.69897000433602 w^3-0.02551725541287369066522369944868881638963479972195808910233047830725369477409`49.69897000433602 w^4+0.00785691713899584971596471693744362596948221619066256853045149970899276457688`49.69897000433602 w^5)+17.71300456494178395309412779323349591376554088140815892227647521619215790711686`50.589943838747054 THRSub[2,1]+1.35080282482462218971656947101253757124123862204894822036681569083195449181424`49.07185313245136 THRSub[4,1]+16.91467340111875155206464010976580382969327378496741466755241287328383111822166`50.182458512168786 THRSub[5,1]+9.47405799007708142125415843130589217038720113336680021108243883479560129732078`49.4700878932802 THRSub[6,1])/(1+0.34602694128652531555841205925659658532896319595661837508886303751931347511382`50. z),((94.46677543074671288845557789741555696654375496268860590707705191683281680845566`48.97975530079173+ 157.06388954810938691732681986533172976199829769396767435205260285762251939435989`48.97975530079173 w+26.59813441147201611268069584703627171350778906735916293192619229913914078597826`48.97975530079173 w^2)/(1+0.98791064669155788122020105745101331815475327419877958930848695883496175949294`48.97975530079173 w+0.20756130440969155690343249817966986835737481763587620317738982707077805849315`48.97975530079173 w^2+0.13152964621282320484320817797282820722551699180804432324342372658106716395318`49.69897000433602 w^3-0.01788544812632480258228444898522829296567383850535904561415365659715462685608`49.69897000433602 w^4+0.00461075227145213706442620606078648741265440077776884649073676760792448961653`49.69897000433602 w^5)+103.06613611930579350114509718303780182996706093789209008148187562028471991310415`50.059324113544115 THRSub[2,1]-55.5512848780847175089840767888569997062264414156070058857701179118964201788439`49.21749212856482 THRSub[4,1]+98.42091017261791169597761712280038943022728966517641394380257106688986343413729`49.65183878696585 THRSub[5,1]+97.4005287685963133076074910398159997419745243184158505754601437553260686382725`49.05660998738711 THRSub[6,1])/(1+6.83208717878777324187211080641402166397785392443998663723356890903629223130568`50. z),((88.22682430295278910136901875069343668778192734151374610632326621124030926742895`48.97466236481547+ 146.66128039902214654132351992047571963206653720766302779458821935662598481294442`48.97466236481547 w+24.54496210013235530919822595197402596690672106690323799829573371852796547364454`48.97466236481547 w^2)/(1+0.98538003220043164784291260457817335225268928785949962572738941904886380962296`48.97466236481547 w+0.20587228762963784977615681334573820209550702877461503159552180534547617496968`48.97466236481547 w^2+0.13123335387725417454779685088891315851388520430845611173627469119653895421713`49.69897000433602 w^3-0.01796051207460464797231387240906387955498323683944491657061093226936212339755`49.69897000433602 w^4+0.00467820703358885945203686315573976268376828427183610646470653560949305197235`49.69897000433602 w^5)+96.85503774109594260925285165865921795881585612617054943430468755992412832136902`50.063419768137116 THRSub[2,1]-51.41055262594481691438924643927127712545897154112597878765199253832269245101903`49.216843101625706 THRSub[4,1]+92.489748119084998305796978269001133309519676880932669953926233827997360895566`49.65593444155885 THRSub[5,1]+91.0021699725123499671086096308545951757251044564558537769711055656920941029242`49.059688168724264 THRSub[6,1])/(1+6.36010029923835328804850803296938246417410114009140168269012406073996552617328`50. z),((5.65339501216682383455617627284901927553913226439985994849887679954949580287374`48.812169395980405+ 10.15676066058465915142194094402134890242922984244429693637576772362949269020954`48.812169395980405 w-2.2480572208406774479181581297667346159171791913861183578577930256595827282596`48.812169395980405 w^2)/(1+0.62984033047550180373233741628650611563636957110055047451224470017885546423311`48.812169395980405 w-0.06371353036709376351580212899591587598785571207771382189193803692251563612788`48.812169395980405 w^2+0.07984527896021512149313211825950111277052873200379209301184326547493412711397`49.69897000433602 w^3-0.02385831654085671806662461803922986009978659710784739724259189081499238567533`49.69897000433602 w^4+0.00666293939319623727540920286169059741870259452316264621817682108810424842034`49.69897000433602 w^5)+14.66341760695757074737604499349945151056679336885585877036626673516653360475313`50.98900322821584 THRSub[2,1]+3.3838607968140976601952913375019005067070702970838149883069546781823706933902`50.00874654068286 THRSub[4,1]+14.00253236860816956136697909197492940418063041976463578483982959709804845342004`50.581517901637575 THRSub[5,1]+6.33252804659790028349010171926977687685888165381388449440644505733401875420033`49.81609933253851 THRSub[6,1])/(1+0.11428612113412781475080378468249007269563493528609752963295815183519027318186`50. z),((5.75094976395096349206394525921211464809968816138390534506835791705069021222404`48.793750302273104+ 10.29541794022732466156929189834665379968131300679420072244853778241266250808416`48.793750302273104 w-2.2403604097230636793461876802976382779704402268562505965355491460603611871908`48.793750302273104 w^2)/(1+0.63235225869468347166322867112821470419094589177982353937583017506758836418749`48.793750302273104 w-0.06153941755443680009657140528966791409027231785301341888535479014817062776818`48.793750302273104 w^2+0.08039777811631832993757064000370722902234455085866749547475226570026683179822`49.69897000433602 w^3-0.023989993395588921833576866258428428823087919777641337140837622822017288037`49.69897000433602 w^4+0.00673364492537103767879868555342545000840562293394512044501223189300151004367`49.69897000433602 w^5)+14.76052127783317141623055349312106181487208760650773779416933606162812417230392`50.964697141185496 THRSub[2,1]+3.31912501623036388095895233775416030383687413864922897243824179387464364835629`49.97086578082698 THRSub[4,1]+14.09525954388149171525781316142104876544821199060521341532110040137971416437266`50.55721181460723 THRSub[5,1]+6.43255932751572284392554975216706412996981176637124379855143943838550145427837`49.79414144516627 THRSub[6,1])/(1+0.12166511528597671061569128464795487994061067014636271639480934612559721962644`50. z),((13.34854747921025789341498135898353337490002632777376861803727833400265914429636`48.14776625275142+ 22.00675553032935607177012459683083092579599237625100421107236223415968478688741`48.14776625275142 w-0.52093260804801545484348464939735605466529653628892425112875136289023629083927`48.14776625275142 w^2)/(1+0.78357721943915802196362866225433622040667888725358063160441022513798325938141`48.14776625275142 w+0.05992681500065857301919085898420418637343018262653733371568080880529509220577`48.147766252751424 w^2+0.10613115963048710328946315089458183351061477156571528089797975427901134314244`49.69897000433602 w^3-0.02446178769055917969930319120315154776977045843953509863696441766688594367406`49.69897000433602 w^4+0.00788483735329952403779831041682457074188535056705028561905254785153126756023`49.69897000433602 w^5)+22.32298865635913935231943040308187579766759003120755074056409863739706191468037`50.38669019031426 THRSub[2,1]-1.72251990278694807643363226888638235136012747781731299182493325663798151322797`48.82369998970737 THRSub[4,1]+21.31688393546318369453137429506841724094065747533314300941942612872361247213882`49.979204863735994 THRSub[5,1]+14.2230299858529302772048585675603208363272016844125288657172690467754516580615`49.3065739159545 THRSub[6,1])/(1+0.69634372482259044314869193854640234136552178193125544428637002234209150314059`50. z),((6.08859236887290462746347166397324414269603769390404985378973235403977476484011`48.72725158922722+ 10.77867164369526549481082395388329715140477460551180426488234182508955692484999`48.72725158922722 w-2.20925587458417064148137329615757034266564222381306715755756514500008242620493`48.72725158922722 w^2)/(1+0.64097544979819442820323232494567998655390598604319007571535987482971273992039`48.72725158922722 w-0.054139068471409404417290767966444713806149611314467952907406068657250321958`48.72725158922722 w^2+0.0822440938695202900803613186353861594160457701844352668615479427582699452796`49.69897000433602 w^3-0.02438838367232323961158326472811446994795769919669730903590613395059029930552`49.69897000433602 w^4+0.00695593418889359110806300594553887093759574324708303533844216234210475541866`49.69897000433602 w^5)+15.096602665795361940639594724101965698072897178321873105254589163343036661018`50.89172042841618 THRSub[2,1]+3.09507075758890353135292485043355771503633442410647209838140639273136865588026`49.85005118448089 THRSub[4,1]+14.41619362893369750161732748393087201661659687678144951450866601230004277265422`50.48423510183791 THRSub[5,1]+6.77877334215958096984084968017398628153920740546481394643713612681834505509448`49.728845046291134 THRSub[6,1])/(1+0.14720423830734336534462659956927244394007573096509073235102196292252673282411`50. z),((7.1645003115181969504972289437114660251439976189203081191388679542483217475292`48.468689380409934+ 12.35068928883754758207230576471358212176352955620726210781352681123600357568988`48.468689380409934 w-2.06837504005414439224826884034498891992495642443403909002336917802116484276569`48.468689380409934 w^2)/(1+0.66751471777024522294812017178526225286750734405226662678138911815138412697655`48.468689380409934 w-0.03187723271277690361615702158765492513018521365334892532904832471572244665095`48.468689380409934 w^2+0.08751224796281420986858956674980081665045276225066611697384260596045726092474`49.69897000433602 w^3-0.02518485306834876786804633169029604214037969831732181142435756089165192054214`49.69897000433602 w^4+0.00747200837380419650124268547713309252327822601511720542582780577288291014577`49.69897000433602 w^5)+16.16753574536738615467456380920741383467751011436769911278536782407559824687909`50.73035687166124 THRSub[2,1]+2.38111537120755405532961212702992562396659246674258809336088728557632759863957`49.52335837644503 THRSub[4,1]+15.43885938894077990029311458232104777517980669856122711079728067701888615526047`50.32287154508296 THRSub[5,1]+7.88199433021159733993323990666214099622117237584759934804067876840479398994307`49.58811466559349 THRSub[6,1])/(1+0.22858539372532191142099645394417090939896678063829809048734036380439209931529`50. z),((6.22543776101236970707264000841716237019882738315554700088019253823493181351709`48.698861201764906+ 10.97597263559801351527875122135538474559390184257613571217129740971505269431324`48.698861201764906 w-2.19474984059887205126860912597496659846403904537086744260655874096507578319527`48.698861201764906 w^2)/(1+0.64443531907710956635924747710489485082742193514850489262696779444644115273993`48.698861201764906 w-0.05119536564644462791241682669312505888717084583272137100567993104327340205897`48.698861201764906 w^2+0.08296442596580372457316007981113521301260830292633632184671886365870984437187`49.69897000433602 w^3-0.02452667359899831321731845140538283970674962684589171695870434583786762559107`49.69897000433602 w^4+0.00703682449194944818238990563226584086685943262569341556325435297243927781965`49.69897000433602 w^5)+15.23281530204455290025974297948395259918113894259017353801433249555411491362378`50.866109070233264 THRSub[2,1]+3.00426233342277622493949268017889978096417324792760514320824417125731648747646`49.80461626121622 THRSub[4,1]+14.54626711515751966312859285390069529171064898364666770147894517349057232959434`50.458623743655 THRSub[5,1]+6.91909269732232898943054197972464933860671097025426726865328144298854732879047`49.706163207046515 THRSub[6,1])/(1+0.15755515745620178936894142353461157295946758344961209701016478491043955370414`50. z),((102.91093028169442981732166952531011632301222145823639189193400790120499887199944`48.98552742999656+ 171.13947569646001236756094038182449742386663523631456625179843245348345944679928`48.98552742999656 w+29.37214600010949469899741172815262360849172270767681540510064021272981246404463`48.98552742999656 w^2)/(1+0.99083054173491587790474466930764278684606836148819792157026559596837212501937`48.98552742999656 w+0.20950262505732268707316028207106835079493038832136832611617378364239189166054`48.98552742999656 w^2+0.13187195693501761319773876828827355889534046375528059320831858689782816115293`49.69897000433602 w^3-0.01780047141810178345883825285909455380708061474559672025411506963202691201632`49.69897000433602 w^4+0.00453188079451862144192123753098959337202877152686057226029588810524189956356`49.69897000433602 w^5)+111.47124625974635226465169533820797571758835614822947263044362118688692575120317`50.05455732496863 THRSub[2,1]-61.15469163837842335132180889230378229797397155583192758507794828963122407090647`49.21818677684864 THRSub[4,1]+106.44719912911548895652328524887273943583146937898641820377224385448590580108623`49.64707199839036 THRSub[5,1]+106.05904729855757996979073673467348157888555595995199739520132043216861061330205`49.053027611189954 THRSub[6,1])/(1+7.47079895984301319545994606008166993841172007686419868850601275540427133672943`50. z),((7.83827130038982378977462130852368383581600139371513362818075570468370114524428`48.22910186955563+ 13.35730002131548362102731728905281138748731559506536298125052374005265985034658`48.22910186955563 w-1.95222997962257465873954809195897310325490493226939616159062860491479254572063`48.22910186955563 w^2)/(1+0.68325158731626893757841036723952742799232750830183281804932435772312150272567`48.22910186955563 w-0.01897161160484453141838214165088899108299008458915367293506661242321087900879`48.22910186955563 w^2+0.09039667118653879804162894545671573754422809442962022370793865782917186290289`49.69897000433602 w^3-0.0254174463532775120734771310913343629941332806747589198075262291359150434825`49.69897000433602 w^4+0.00768045429900581025264879047550169106006167151596749705163295606279196910513`49.69897000433602 w^5)+16.8381913018869331635145044977002385802353669271234752312487111036658915006149`50.660598851418364 THRSub[2,1]+1.93401166686118938276965166803470912692802125823873734771865843251613209614895`49.333915990546366 THRSub[4,1]+16.07928827053357130106935036861797519456833502661739458979486445495350322313187`50.25311352484009 THRSub[5,1]+8.57286969844818919940051711869357126149167021896081588002515080066348449810681`49.52894846917254 THRSub[6,1])/(1+0.27954910482747535727674256911097838654222545702089530628872291696946293555525`50. z),((37.46129123729003530817648221901177109879760331118809127197146741241045314839341`48.842709403077+ 61.9739943206439433046469923657624923982688604086652249306974386603151773977051`48.842709403077 w+7.62866615197970364298130127395006957911200835050741174270925064537928619321776`48.842709403077 w^2)/(1+0.93196343033544005848775207928934065934589210426789566490553787246084628778759`48.842709403076995 w+0.16910404400369526107649285727320406832229777836931520414750321806162346730068`48.842709403076995 w^2+0.12498285235461003545415040046254320906358299074453296151737051719742318164243`49.69897000433602 w^3-0.01973583467128499278580181755009001878320588765335169786277896254597158240644`49.69897000433602 w^4+0.00592794856012468394811883395605005903005672200767867543127139462901589426288`49.69897000433602 w^5)+46.32423811854003886807368384027317577629810467175886755935138854773684549820865`50.14513135338162 THRSub[2,1]-17.72335287757421442026980122701391567044713723818485753768312653019783723558045`49.192340188559854 THRSub[4,1]+44.23638888918989127244207676424539722081673974234353008576742977603452760359885`49.737646026803354 THRSub[5,1]+38.94790089630401517037852460909712128983192138310092958096072295010818678267628`49.12120025979799 THRSub[6,1])/(1+2.5202199781249841359083701512200726769592234715715415904780281261018614823645`50. z),((46.65515483343399421335985672592222601596321779486086267592879225652236750401513`48.89439088251719+ 77.31839351017404607754903215394655723450065323394471571969140599174793344735991`48.89439088251719 w+10.73752640555163040858248627748323995926629314136359354277444179522145018795068`48.89439088251719 w^2)/(1+0.9504107013381535883495030089609173892627571560755256349359858495485264023592`48.89439088251719 w+0.18201100804230786731514503071312582818661638197584116911267758475176482574885`48.89439088251719 w^2+0.12714951624025731025127959268005484859998151381856840102621523696299303759862`49.69897000433602 w^3-0.01909450258837564361694372460298612939699496586247145951961872000782173454609`49.69897000433602 w^4+0.00553166897810092690522511847594997714085063410596321643914479869186919321946`49.69897000433602 w^5)+55.47559044518573030153731474533106179884458092937731059557062808522288702098256`50.11759611468243 THRSub[2,1]-23.82425442867134204257888849705250635214478807659715289516261955518853158409651`49.20328340442635 THRSub[4,1]+52.97528664175696524895180032451410564941812253192989852488847688318685196779315`49.71011078810416 THRSub[5,1]+48.37516030998168148702874664122628019666453318497190599704846021535980225709924`49.10044178419882 THRSub[6,1])/(1+3.21563936537283648872351182969149577801223592209777359335520208644655011407653`50. z),((7.5427139298035914656885905409792494916991612362600104473459077009988226584186`48.346724337049324+ 12.91381352787174870978448331170130715672615851596630676546315451330507801561408`48.346724337049324 w-2.00555043093534083873643030836263114907628847074387896641223700093069479624305`48.346724337049324 w^2)/(1+0.67643934006365066716141135685698142510293756585564580397335228479109651443074`48.346724337049324 w-0.02453486924274013973492918994053366365858093000023965672558233265882787862968`48.346724337049324 w^2+0.0891670500668574391448508604395451739118872532732492019862073534112408910334`49.69897000433602 w^3-0.02533529584661326151567835355199249827288515612293062460548151141333404470087`49.69897000433602 w^4+0.0075980117493773232218263195584537717693047013473324328291678627602868191251`49.69897000433602 w^5)+16.54400055142746238690081710493996318714783345393941925866276602734462000146108`50.68914242241318 THRSub[2,1]+2.13013883383416990051210992987489272231971024036144132944262181673031309558481`49.41704510311378 THRSub[4,1]+15.79835679764833698273520969471677102959287043876583339824115319685856065871665`50.28165709583491 THRSub[5,1]+8.26980929571288098281049480779216428885807635858944928635799548232142641923086`49.55303223666846 THRSub[6,1])/(1+0.25719328853758945452426772597731704959820160222585521396680893676032833815109`50. z),((7.27475643477384565956560317569065219261379005001476689052999374655802772539991`48.43563126258377+ 12.51432382652218634888950226712139088295417798977917020254146420466705935898113`48.43563126258377 w-2.05071432468381785073370457149808170429166199427734004045394129931429168230243`48.43563126258377 w^2)/(1+0.6701398798208410191638500041056186884794688730190051847185407500379293470828`48.43563126258378 w-0.029710823310559465453996127854704719852053561523995039342130413596219388083`48.43563126258377 w^2+0.08800442580833842454684517957952408607268349419027247100577846882621535161022`49.69897000433602 w^3-0.02523443917515034129441796888893403427120161251710322890716411146335720289394`49.69897000433602 w^4+0.00751128864547134443153548210731733394694240500835820518136441547106407031059`49.69897000433602 w^5)+16.27728205816951443867634658505311078767972499680680592879250625719255483734724`50.71773230987599 THRSub[2,1]+2.30795116267280186599509027646612765529844921178318354935612833016502320499414`49.492237094285244 THRSub[4,1]+15.54365939795218832979315503209892892265013025882933969745781706077301674785687`50.31024698329772 THRSub[5,1]+7.99504942016457036769903925760449944851488209103330518110610003208939276139552`49.57733003134706 THRSub[6,1])/(1+0.23692511346044232490273839297566504341611915401889179322014127112823868124992`50. z),((10.3157550572085358428522425295878080935210187460663021229719824893966997112248`48.254968419407646+ 17.17233641772556674866534787828499508938964746947558046050676341733356542522877`48.254968419407646 w-1.38990728371840778650698639321557525462025778710288301793894033494689234640682`48.254968419407646 w^2)/(1+0.73446081211387039165892600287775902092697356963569232789765204756743583436538`48.254968419407646 w+0.02191587462058720670940101094882096834398333820084414234085260977790321981676`48.254968419407646 w^2+0.09889327011971153958155177357831814373460463791798381027373193335146622957339`49.69897000433602 w^3-0.02533599036621808871366058737423701144368558976844354608932573581193615141381`49.69897000433602 w^4+0.00798831870137487507006347815267168359670082488777303850220241185867813805888`49.69897000433602 w^5)+19.30421948526121500098340929985294073358702086087985349289680410551760565157577`50.497148244054685 THRSub[2,1]+0.28999287794500149112371513326624102469358530240115183995326309794832266217514`48.2528354314657 THRSub[4,1]+18.43417172166123446967940375729695271153176508401405335432066010765392316090327`50.08966291747641 THRSub[5,1]+11.11324696470418548848813087533533709745694163629100776405069778865620849557214`49.394400828578384 THRSub[6,1])/(1+0.46694477565361001865739097968869539127765820435002710576048915981526852171549`50. z),((9.40796869286036904853707061854399160019618469149943293146048957511410924307642`47.83294516455873+ 15.75656686227990490862684540560343897437926319297994298701821089819407456831595`47.83294516455873 w-1.61654312706298293749881711000722524328348518668848573882132412604600117939455`47.83294516455873 w^2)/(1+0.71692672572483637578487677941335385585902013639158638936172116760306171375252`47.83294516455873 w+0.0080813101127730185782338896980325855323302211121068808493716886449726941258`47.83294516455873 w^2+0.096114325810711884921243442118244043718232165944798292267222701078863714798`49.69897000433602 w^3-0.02548247927514096333750260551113901201475437809285529411239174404702790504494`49.69897000433602 w^4+0.00793816266462179755966198406069182984321033495486674400301311276760509141706`49.69897000433602 w^5)+18.40063061094301156602523728882179812319581185264434718957843504861370561901646`50.545405448583786 THRSub[2,1]+0.892385460823803781095829807287002764954391307891489375498842469217589350548`48.82124760761051 THRSub[4,1]+17.57130790643773386234537722161213500642420054484568933790654502918998653240519`50.13792012200552 THRSub[5,1]+10.18241549658246964573180741795653686248721141108049758623288181660050147623389`49.43353471840404 THRSub[6,1])/(1+0.39828025494963405293564295920965566634375573496669838843062053020045542379439`50. z),((118.54116124491693033502030231663109706704769932857050810434763008323237332619621`48.993778690264016+ 197.18950903546139807254398348396421850982927336457796953503496510899769039724664`48.993778690264016 w+34.49642903306733765998063869395640660709525196272731694589026745361724715519426`48.993778690264016 w^2)/(1+0.99510354205544401764445833670217096150500252269598703994873626420148196745451`48.993778690264016 w+0.21232833145349444477313981755284049687001848524560029847947085552119041422627`48.993778690264016 w^2+0.13237393446947234719623201511115014625837695284020056336111089478687823097111`49.69897000433602 w^3-0.01767954664727457381281923217476783189884701198183107974909073562462351877082`49.69897000433602 w^4+0.00441439840162285882626780921117148714991661805123479870069633963927749473211`49.69897000433602 w^5)+127.02920499988775321578556764328236359476896336422691318573280778268979891552525`50.0474952798228 THRSub[2,1]-71.52666413180602398541105709568670754942770969983022128860407268683313951378926`49.219098370546995 THRSub[4,1]+121.30395535659505089225283176710102680812995327384079739166908253224479841466319`49.64000995324453 THRSub[5,1]+122.08606797872041230007403991263244626133741428057849899120235354077609239332242`49.047720565139436 THRSub[6,1])/(1+8.65306205580034885321329347455872560797811476387597980314365704586838825333709`50. z)} /. {w->w[z+10^(-10)*I],pi1->pi1full[z]};

(* Sample Pades for the 2-loop triangle form factor with LME to z^6 and THR to (1-z)^3 *)
(* Mean and weighted standard deviation *)
Ftri2Loop63[z_] := Module[{const},
const = Ftri2LoopPade63[z];
{Mean[const],(StandardDeviation[Re[const]] + I*StandardDeviation[Im[const]])*80/Length[const]}
];
(* from 20 each of [6/3], [5/4], [4/5] and [3/6] Pades *)
Ftri2LoopPade63[z_] = {((71.57432334074678820898178701954545657168977606038509604977540074348754887857195`48.11973652163982+ 167.72132213862967615582091717394004147818829539154421592892443978327926405954628`48.119736521639815 w+77.87816583240400772603014775220316787391120985411819065972119786506768254140148`48.11973652163982 w^2-29.67590344143509591226243929738174949269025537864255919121831674193068226701168`48.11973652163982 w^3-10.40630193580600513681590938362222744398573604977344127656317641346174085663746`48.11973652163982 w^4+7.13261155321090402173320683660415353062808770413591786935545295862121414064878`48.11973652163982 w^5-1.25159200993410039149204980722933133309032123455662367992637925212762969356012`48.11973652163982 w^6)/(1+1.65857418323405445230642450708344577286194437572185371055778882326181968472786`49.69897000433602 w+0.55464232165347423028416846998677225044587443780854010166368796246886205768719`49.69897000433602 w^2-0.11653563877312235952279923010326058225449540182641302626617571203928432381693`49.69897000433602 w^3)+80.27953584993569981053742983953723226579815752399787916612414728305308520455769`50.077752495377844 THRSub[2,1]-40.36021803183798838191229855985661999678050580634419860886496568707533037314745`49.214179700893084 THRSub[4,1]+76.66130975784172655586706772474439151625923345914022023980960158839826859646871`49.670267168799576 THRSub[5,1]+73.92692790310904130028466572272640499510367953039020039786300094731935120624214`49.07046220121487 THRSub[6,1])/(1+5.10051319592973029684994008490701904761680156167008594112225060916712216191952`50. z),((93.67736124100611874610650676775351414634433414556642460952046619944061793599945`48.13319803124992+ 219.78171854425114903833316971037760936891002265292902119556552053454683242426552`48.13319803124992 w+103.23043902860836933999027778892848270186194029172782729287660567129618891830957`48.13319803124992 w^2-38.68359602112097893313369715366657849489978729515504939971754190187394636136151`48.13319803124992 w^3-14.00432183414167715173178080608416161401725703746002251100046725244726299596366`48.13319803124992 w^4+9.55980195930346646278257736819205936415245486660398370245578790935418153486372`48.13319803124992 w^5-1.67956149673462075327766920596169412339261073630982332590651988366738707096035`48.13319803124992 w^6)/(1+1.67116659326673314841280559306799582857555856545271475971668721894602280709708`49.69897000433602 w+0.56678316637149720329098555455124287177197998545966281449962755501862126484172`49.69897000433602 w^2-0.11882757311987830481430378301439397430375037470235015977952913026478415579695`49.69897000433602 w^3)+102.28037208154046838348396300453685154255713098154422545385538352724416788200886`50.05981273783185 THRSub[2,1]-55.0274421862411674305433206698563661812864881113750961340191231832027188247796`49.21741724954138 THRSub[4,1]+97.67056078833272239659731002052534590897526530936497927643088963843193190359915`49.65232741125357 THRSub[5,1]+96.59107447620893956206189732382162382399799150730792508293030348576129847672182`49.0569772142065 THRSub[6,1])/(1+6.77237627201029923822213811800227482828853362630318880601429262469561398497526`50. z),((85.57937151161148171847185900097318529920617450285102000390822477502749223971214`48.129091351575994+ 200.72084327999458589403955147219301540599683866038268122675558167060503703547933`48.129091351576 w+93.96297152630739963576994318851594207114949783784120457589346133750126492942455`48.129091351575994 w^2-35.38619442228804175571634563285852151178739716785981355557107779782077589698319`48.129091351575994 w^3-12.69035953904953301448777924812898337435922046721093479981176715075115917617973`48.129091351575994 w^4+8.67222303446884897583401122098004809405451217306067495181569493249576510374375`48.129091351575994 w^5-1.52298957552128051582031484528253403991375604313351113209758652155693170749953`48.129091351575994 w^6)/(1+1.66745677645179628187883867869883325671143948371694643400504729420567453913772`49.69897000433602 w+0.56318098204410988225520581764007470715208533388652950737807258966908422813608`49.69897000433602 w^2-0.11814915273750342599282633340249805556904660495888751921966707201879119853296`49.69897000433602 w^3)+94.21982643864771109078753752713510608573510365772443480726019845241247761743858`50.065333804384366 THRSub[2,1]-49.65374509097932923541237035158853587673846989549523570295566646664825864840015`49.216523007684216 THRSub[4,1]+89.97330668982739225440144872619158525320318960601328654031672068201208610962201`49.65784847780609 THRSub[5,1]+88.28750883049721288971391594599238133266916539949504824050691972546824062005798`49.061126775918595 THRSub[6,1])/(1+6.15984825300456226129317401263648941598248180491706815150389331138620985018899`50. z),((54.72648645558695875871876804907299888457883823205429706210535400101545486817146`48.10186873780563+ 127.91747727321358591613263566145451184061115960770774031668954584099493469245643`48.10186873780563 w+58.3530344904272300584878258927703036286925811093670201224015075210285346197652`48.10186873780563 w^2-22.78249537940548363742936755779109476053745918390516632166980615469444308418786`48.10186873780563 w^3-7.62326743323177266212001914680151145745630109986242966632232785552294514668006`48.10186873780563 w^4+5.26656497420776174192879808215074319929646083325183432016545164723101150142596`48.10186873780563 w^5-0.92325119023911859766854203112989507530413110724732980808677506687684181362504`48.10186873780563 w^6)/(1+1.63992791141258276491017871692328456925491175261360999625892484933549231093339`49.69897000433602 w+0.53705116586402333943960724951984496363713408371092071985711846981679177415556`49.69897000433602 w^2-0.11318763418400078626256999200768632456201937843290507124378392671899345597511`49.69897000433602 w^3)+63.5096012445734817908756843577669995142470458520059692757481967649670966405966`50.10083880088272 THRSub[2,1]-29.18026162826317636880446823867646482907976469168292534861433200835133799717219`49.20852783720546 THRSub[4,1]+60.64720183121434610793813432330419983468778813072053217110292166503221831237507`49.693353474304445 THRSub[5,1]+56.65139110459225738910566660062925635589686659397379477617364032662616367406281`49.08782642213802 THRSub[6,1])/(1+3.82615097806480492565693509507163775182559194952871937151425569781278978349514`50. z),((79.39300067325517902097889481857727806031899732274819169506222381126581077380401`48.125376381926955+ 186.15065203940128303496267915753796117629304387753804818414001834226183627535597`48.12537638192696 w+86.86864009605941640987100227622079117958168431048074249408289754587820740206929`48.125376381926955 w^2-32.8652559576445857758213942726429176071646677587619126861611144958298303019363`48.125376381926955 w^3-11.68360998198599888226266063987706220893748025251592242343110113763762057747017`48.125376381926955 w^4+7.99299688171426084501441126986052044480368581809906343171013572408140358683033`48.125376381926955 w^5-1.4032213632190228971089497866015192730257399485869712528777459100804561342536`48.125376381926955 w^6)/(1+1.66400140546017254473732675115741874868492681040636803160261318497395003168016`49.69897000433602 w+0.55984556775308302429136942214312087935966077561384565466339731228472031307995`49.69897000433602 w^2-0.11751977539491448775719111963812628349695679637177119821229523139177359012586`49.69897000433602 w^3)+88.06206060135275649923960020833214969298494296164889305944602102132231583454942`50.07029201959323 THRSub[2,1]-45.54856786611602617438041213905323161490502943144487453774621484592148412647597`49.21564334571684 THRSub[4,1]+84.09307346138001786594275815006484608665681040066381669130455301214013244285111`49.66280669301495 THRSub[5,1]+81.94409051538799885950438930474943383100566920229702493835485009539984280046305`49.06485366229488 THRSub[6,1])/(1+5.69191416058425533318201320764016589900302548367130216431396619426852977239195`50. z),((82.80295793706696042266460187534899995344637358306599828204583996665879209925258`48.12749434931583+ 194.18289498625659664205989465574725266023126803742398474172348276267364410545793`48.12749434931583 w+90.78085422897047644279428654806608239692913001834571763919423088310620255541895`48.127494349315825 w^2-34.25504665948135253555980609538552194431689649591471955308731978849464517096897`48.12749434931583 w^3-12.23889793664404585185983247596281007378903979789377484693463110842117360255402`48.12749434931583 w^4+8.36753279262193965593822332096111180831030221511094748166794514584501419633396`48.127494349315825 w^5-1.46925735049457109970283445082581368965061398373966787228596538481887300806118`48.12749434931583 w^6)/(1+1.66598297254002513275954148940726442276497389351907517701899872889285566735832`49.69897000433602 w+0.56175609232798955210495461860489960283984221467200699737591564412901113096589`49.69897000433602 w^2-0.11788042386737671523443211396696379266937815050754821389876330963686652999476`49.69897000433602 w^3)+91.45625065144600107021818608420835078553819210217310780637886516974342400460851`50.067469501665556 THRSub[2,1]-47.81136123284485588836613605630403234327386219179435103570144427820222290651478`49.21615308283916 THRSub[4,1]+87.33428620697402417811803454826440937413257043217302835344588772470778309520987`49.65998417508729 THRSub[5,1]+85.44061310127788398227125375475802606297484720992694915173331159417218745200485`49.062732045603845 THRSub[6,1])/(1+5.94984167562112528783733478710888487033664014109737580156481821822618103374828`50. z),((115.73930533545981138534610208834007597217515951500772805594633734158994612476401`48.14142838289322+ 271.66636217120326767039833302080213716897746017166690826579599306051037203644997`48.14142838289322 w+128.40579461529979782466476263086933703857000209848755944273322514103589842500936`48.14142838289322 w^2-47.65748421792231677134713153348295817859113804018555973450099021751532295200247`48.14142838289321 w^3-17.56918227143968521123236390789711895487625026186285218631359505095370040478139`48.14142838289321 w^4+11.97202021612943150357490363205964100597520297589987909606834246654472493774972`48.14142838289322 w^5-2.10533190352293642717593730030652273668075364001197520685915673416157308088463`48.14142838289322 w^6)/(1+1.6782571410744990667711356067514064253143277995472865344847880458152588533424`49.69897000433602 w+0.57373489115496455956782952238825883913023466357456724698609373996033348744235`49.69897000433602 w^2-0.12013304851937562518547215289737610891449088754734780300530740487935787029928`49.69897000433602 w^3)+124.24030451993169860171015992081238790616010665644869149534295565777028108570254`50.048623383286 THRSub[2,1]-69.66739714516865424269411861404005709035513856131140682834417127022012762724474`49.21896203552807 THRSub[4,1]+118.64075157353685812841510436003954518479714907869509943123258361582416127176255`49.64113805670773 THRSub[5,1]+119.21308403437775663284651195721535839957699740064881981086277668996094811151813`49.04856830689046 THRSub[6,1])/(1+8.44113103253297533277494344326194945326797453568417605037178546833169199246297`50. z),((45.90139842564425154091285672936856541503866052863898605254008143775250003047391`48.08694390407005+ 106.9746219705777267774214391770174282354057861930675912602055153919378025643896`48.08694390407004 w+47.97043104075907627892484079040186567903401369502651101915101453801047140782275`48.086943904070054 w^2-19.14959031143765863477014447018265582656940593495358208086164155362462953087844`48.08694390407005 w^3-6.13455237038476794288581098471158367600015712729020910379395703797277354998426`48.08694390407005 w^4+4.27696680023903652528981561193442797062640863951489717357566840034765241546894`48.08694390407005 w^5-0.74965649793801947072399121367710228618742174855081816715012362250295456755102`48.08694390407005 w^6)/(1+1.62266862080308638446843372138634865825029471837690223002780365516986479771868`49.69897000433602 w+0.52109225201781834377240728147991423313186595154654064995257078685945989774019`49.69897000433602 w^2-0.11012264904816732741985199695956290198035860452290735353174467221115367681485`49.69897000433602 w^3)+54.72531931227009334335525206121674632580132303384755939807790324644281197169728`50.119451671921674 THRSub[2,1]-23.32407367339425073712418004097629603678261614624398543016746966266848155123968`49.20263963474755 THRSub[4,1]+52.25883048498088499956094324041952122347568421191548720081157576815152904966919`49.711966345343406 THRSub[5,1]+47.60226900953471661379069969414490611436872634159530270255257739248758924835767`49.10183943633664 THRSub[6,1])/(1+3.15862559594306894125058704741235733435809867782865727252199943341202744891832`50. z),((11.4641235635118786044856044852062162849523750199546529084419811377434787633818`47.59336336068108+ 18.33935069085885977714615058231401380249337540853272640650259109178465801747143`47.59336336068108 w-4.58875050467961097591522133179927050457339379224935941235196694112114870413096`47.59336336068108 w^2-2.64109215265128632936353534165193489850136179234812628207707030594850048589406`47.59336336068108 w^3+1.88024318418084618232280321289926572254850600812095141119091894084760260077532`47.59336336068108 w^4-0.44522177683269054915671376847671878714219428275536299364416466515723968643655`47.59336336068108 w^5+0.03444292355292432763301584084647922821756669014305163153363917712649322364584`47.59336336068108 w^6)/(1+0.69823602067017597038277377767921388337402070517075437792992825270873410124125`49.69897000433602 w-0.21766913239578325959078479480155442535155793177832567081055460521626488605141`49.69897000433602 w^2+0.05594632344298992769331685759332446536671840913662721605803403069197940849985`49.69897000433602 w^3)+20.44727807995402881052775099388568399636971587421847771909345264375718838199831`50.44803872719004 THRSub[2,1]-0.47204618518354104857251266275558781716154470649126431084450259421139915810651`48.37796374410618 THRSub[4,1]+19.52571227519545429606208635399525126489319646131379555332622677598831070287975`50.04055340061177 THRSub[5,1]+12.2907680034065345263882196199443483194012398138157058783316060679283334117548`49.35506297245071 THRSub[6,1])/(1+0.55380681299372736400228403891309367737383101750329809144077957742830615879935`50. z),((37.6418497051722118470364902270022289168885014471493807205288138362483688397996`48.06600454796189+ 87.2523069962879499280397166228800280659250284680626284011803842787310420389828`48.06600454796189 w+38.04926569820991444628679152690424322255719941899858166541703827679555609685179`48.0660045479619 w^2-15.71917430052810851203641058651632711497275152542761004245822344714619553301752`48.06600454796189 w^3-4.70110866401398000045621080369560261934185860842009258416491823940660883788948`48.06600454796189 w^4+3.33508502311044934173637353704185731252946080066718019844292262472862310564405`48.06600454796189 w^5-0.58512765730212576512802544772551192542683015300414862065739647772601317331848`48.06600454796189 w^6)/(1+1.59595487704599900123951087866536960134006748606741818598928127351556555824885`49.69897000433602 w+0.49686729316574009418138926674830977077590128381769532335183668827560422941294`49.69897000433602 w^2-0.10542077832483527603709541888032124331723588675094473565699205823682875767467`49.69897000433602 w^3)+46.50396170676492390559948107797603397249896011142617700103170119998757939896298`50.14446588379432 THRSub[2,1]-17.84316860305747111195366605214915446791437419796306383213666829836499316941668`49.19264137244396 THRSub[4,1]+44.40801227392710812532898997506882684777420121198879781666029408008508818624677`49.73698055721605 THRSub[5,1]+39.13304302923443856884260534948698093211219918836408511868414909723812973836065`49.120698064786744 THRSub[6,1])/(1+2.53387733314052923929140761177893206077810193791366136771588433784653784039636`50. z),((92.21837585440214766926755637412728221549687330131640039129123483048124116030623`48.13251244055904+ 216.34841308173246837129258803025106396462895744688707232806095982786848421700954`48.13251244055904 w+101.56210592918040012267580404190266884662511016643172040219651961194132288190053`48.13251244055904 w^2-38.08969284368056579099270227184215401098037784188756432260766889021027520720457`48.13251244055904 w^3-13.76786598983070098809098461836152693851605102634754778645043714690768284062019`48.13251244055904 w^4+9.39999914141426670604774604794069808368473930813166503779142662182253820734684`48.13251244055904 w^5-1.65136713612107474604771915413361653044387358401194215956103442767690794888638`48.13251244055904 w^6)/(1+1.67055525391168408542839320453817223642688335123777486861283700472064034643541`49.69897000433602 w+0.56618799291073145365564557520082449885831021148367779222256801435184571045711`49.69897000433602 w^2-0.11871557322142665366643805903213892056918758340044527937914225454482076986584`49.69897000433602 w^3)+100.8281328599535603029149532318718201063607015133988201617118985743080580651424`50.060737354876856 THRSub[2,1]-54.05928270518322871016398082141301189048886846594482593925679988124531228020048`49.21727367196397 THRSub[4,1]+96.28377448432782598063528122678161672694175012394362783107170326352298255026898`49.65325202829859 THRSub[5,1]+95.09505122369416842375674107433610010689557322722521153219110033563337494152345`49.05767211935736 THRSub[6,1])/(1+6.66201932436303966129735799148501657833887622988941266925724282566791822785466`50. z),((102.68697832112464235867666028859176354814654978644181443572298964744204909248017`48.136993004582116+ 240.97670027348041301445884597735037061373042601755597733351710170867279755638366`48.136993004582116 w+113.52203442931876490191289701060060204559066671897659754565977451328284008765879`48.136993004582116 w^2-42.34969642532002351944310833544350268407011142846718970324642815695794145726184`48.136993004582116 w^3-15.46229098856534747582719939842201586498343317390541871009028734684787985748538`48.136993004582116 w^4+10.54575326473807270853396617691456744767805654944886944456676499076995167761524`48.136993004582116 w^5-1.85355176378809642725295095266570392688471619122437812250543083113171215207333`48.136993004582116 w^6)/(1+1.67449283639903202880367622625787346669112593198123010051723885441291503048364`49.69897000433602 w+0.57003282520258313961110146501410441531573470664278848635745955528810431564645`49.69897000433602 w^2-0.11943845007920870140099933720948203349544494967879848178480670882670652009802`49.69897000433602 w^3)+111.24832982488900202715590668142956398497049739331469126638406121758911632531098`50.054673824478755 THRSub[2,1]-61.00608068180685652632461645445150780956206571922207334237157497676601778697926`49.218170569366706 THRSub[4,1]+106.23432961409167033166750078258880062600087096074603275794090867666139552044469`49.64718849790049 THRSub[5,1]+105.82941008386379346420184544691025576100340624890563186807271032846918780066292`49.05311516164297 THRSub[6,1])/(1+7.45385934206820558924027905044123844150906057504834979182919104637700564929377`50. z),((75.37372336844658923371930902965428343658027032479489064305996139818246320156145`48.12262735283225+ 176.67921093400388440996532856348198484058030947752215477452569653972764867917149`48.12262735283225 w+82.25088147985708129645213366863951245960740227388071848767301419510001405599189`48.122627352832254 w^2-31.22625899662932416050168367852062645706239431204279900739690839046474288488328`48.12262735283225 w^3-11.02778417942946782988932039017449872732965678904386967821516719175795385790109`48.122627352832254 w^4+7.55101719884094789767792044070431477402119903024705217370139715205558856774766`48.122627352832254 w^5-1.32531615079924552694959728460980158348312065358770760738401033238194532454174`48.122627352832254 w^6)/(1+1.66138341460081236931220143516389714293275202388299150128693037048447191062223`49.69897000433602 w+0.55733038409386030100739597226745599860894764167372562880142610079861676218203`49.69897000433602 w^2-0.11704440760434361751328848879711376291469848352836303288025062136339132327568`49.69897000433602 w^3)+84.06136792953400693576855039392425793606519255165696640334981003767787759543307`50.0739386078196 THRSub[2,1]-42.88143941823685979873304559611463711029186249145025676701540752349185863372927`49.21494921373675 THRSub[4,1]+80.27269337431116312900031912976466104581184308038617803069178915747741485875479`49.66645328124133 THRSub[5,1]+77.82277966367711192719717581608794041678942535746201631049261011293173558342564`49.06759491340097 THRSub[6,1])/(1+5.38789797291082847138236137287345128717453738581649999268070844281902838843807`50. z),((67.90681057473682008432708065786301155201579919840870219081890040743109698033607`48.11662924500613+ 159.06935639425124996485473144082138280410547181492408903409610708737410305838379`48.11662924500613 w+73.64892700581103270324310581234968275426512634893513068062062930796765494988878`48.11662924500613 w^2-28.17823527427304989302192905240727876701557457479686036229694884922433062038197`48.11662924500613 w^3-9.80471381394541204964896956922754175739887147397535870567061578305281665912529`48.11662924500613 w^4+6.72806827075784843489183759939059350171035977961508899543475327245329401741835`48.11662924500613 w^5-1.18033877876866983465317091784155312416667327194813965673382012452928752703843`48.11662924500613 w^6)/(1+1.65549023418739788063630924815679047656436415256407423991864217310771141327038`49.69897000433602 w+0.551703722375632933709563218523002463582329268064069181214349427768234228313`49.69897000433602 w^2-0.11597859107487869410848971459229137971508890059616554195701070434355460865683`49.69897000433602 w^3)+76.62898120190885874955614788760742052475879093656667717331713920881928507693221`50.08182791521252 THRSub[2,1]-37.92651493315342767459144392523674550275426141472339728032696030425279695473031`49.21330740275 THRSub[4,1]+73.17528685427833117594533993921128925366075918230260601184713251584168863877457`49.67434258863426 THRSub[5,1]+70.16631149994078245045259144758181897324624727928895107335710478029478959904531`49.07352645566829 THRSub[6,1])/(1+4.82310430751289232995049845908801919232836687795240988073493901442916918997793`50. z),((81.44709848961144428535181748491004980131858875003497899295988032215396050223757`48.12667395653825+ 190.98946934137725735666947140596954378403481053276340996316690756986374810473989`48.12667395653825 w+89.22584294479220134574701723126596221992111393870459648660663930648278638362581`48.12667395653825 w^2-33.70251514166411563919718036194407880419263402347937076628450892313221324149242`48.12667395653825 w^3-12.01821822490320248401364923788407208388312074261490718881920093802902100635001`48.12667395653825 w^4+8.21865512277833177827126288447640420402002428360566367039274251618511814311576`48.12667395653825 w^5-1.44300622055774544413480870703568649044307703236443413469989066833447764232062`48.12667395653825 w^6)/(1+1.66521906908880941681042276026493090494703794510436690786681669219849369806122`49.69897000433602 w+0.56101886903999091828382896012979410132853333219790376453159419199710429503124`49.69897000433602 w^2-0.11774130361631174478512493600500049060869591155607983585436071720801224895059`49.69897000433602 w^3)+90.10666052762899619388657809497789368495605752760462069961752856118393274851192`50.06856414113563 THRSub[2,1]-46.91163448363351930414506406348372760955243914208202629786055320582922873578303`49.2159582250701 THRSub[4,1]+86.04552257085314783150716138521096314822657341468669621096214587186339966993278`49.661078814557364 THRSub[5,1]+84.05033374744781541310607924550657305443829524250733425506952543824373134323474`49.063554843842475 THRSub[6,1])/(1+5.84728512403826419627585617288406070235585046993881631456091549196465272533494`50. z),((12.45094861902223412824228105253110846019149603245859517623725668779755826882286`46.48234805005194+ 21.89263906847317430887092152105795354155511042573003541487080504868041371539143`46.48234805005194 w-1.27529599760450228320645090335100573788959798679460299429359499564359394553644`46.48234805005194 w^2-3.53286231137835189951342603857168762293364658285206371112777151320442971100498`46.48234805005194 w^3+1.3352927758072110611455122770742256292312108989998278184937532757421690951184`46.48234805005194 w^4-0.18527201440972961692677656411816320144717220504581378400353174262957555754512`46.482348050051954 w^5-0.00282496516778328677754829125299756237501798779667095425834452601774631457539`46.48234805005194 w^6)/(1+0.87728435716842201173006092521484976559623153991144846534994498071463157774257`49.69897000433602 w-0.08308653463019178300384403824205200645038602211270849029743127201054305541193`49.69897000433602 w^2+0.02229686898223834520649964700229460371266425834147177697584028383223683765821`49.69897000433602 w^3)+21.42954018046252435200278183257756421305301020116035339841253264504811825620406`50.413503790452296 THRSub[2,1]-1.12688758552253807622253322188350796161707425778584809705722259507201907424377`48.691603674618214 THRSub[4,1]+20.46370348744198540281302585984884575664663704109368796540202045429517413040512`50.00601846387403 THRSub[5,1]+13.30264464231107762112788591076203800108086067700156372194889476258584668767228`49.32768117865854 THRSub[6,1])/(1+0.6284497819966246528224490310010112094810542025907091054844336641923629082615`50. z),((109.09669516898919794923313545611202285640821794816565392831647019114368741394802`48.13930560922604+ 256.04970630234147256694663830379103601803441201082996518295380411872198858198264`48.13930560922604 w+120.83436012752299825227823674886326847685566242314163349594492637530801324452443`48.13930560922604 w^2-44.95665160380520015986970619844945537063433106297337708829878156677053343130038`48.13930560922604 w^3-16.49760335855862966666812404153067993569046373201288339996416543365203321745451`48.13930560922604 w^4+11.24642494574862805817935652047138982837136958184737096291834572102376829653106`48.13930560922604 w^5-1.97723095560784599568397683402218312007686796980026355726075257437089119531005`48.13930560922604 w^6)/(1+1.67647205081684379243160605760927474878206474144841807643557802291531338103669`49.69897000433602 w+0.5719759608080313993241656562860794039221982235536179735324478665484327125757`49.69897000433602 w^2-0.11980320516616138146556803371869241427206182279801597425947164056073506176536`49.69897000433602 w^3)+117.62840894782130607856662489495840988274482832523861955932136111899919317062601`50.05152504953146 THRSub[2,1]-65.25946676376172589393176193013740507474495300717135887099644157770606901718997`49.21859520707169 THRSub[4,1]+112.32685639248415247603660940245334727433814806132888660672159662018663239886545`49.64403972295318 THRSub[5,1]+112.40184427990549308220720856542559340727670379757260426867546657216503310536561`49.05074885974258 THRSub[6,1])/(1+7.93868721841865754988871709009718878046624419166906957088840030426456558998993`50. z),((11.56494922719234107407410725916926750024125322599770933449204508557960152098701`47.53649481088552+ 18.71885426713428868066851469583490293022868585205913326368235823216880192986837`47.53649481088552 w-4.22050009669448959704946600264379646641270960725286840650891363083019823617276`47.53649481088552 w^2-2.74043749365565522643600888108452239769983381301003693585280708759043057836392`47.53649481088552 w^3+1.81954261208222736995150687617064383398786001991175882673840891346869609475495`47.53649481088552 w^4-0.41659286517492466065125137864239988892822451624303798033167447944778904806882`47.53649481088552 w^5+0.03039636143849407398370428473853481701964142808381155774597000442244625345896`47.53649481088552 w^6)/(1+0.71935427591100013294329759462260361059846462276828139127636828803869538721511`49.69897000433602 w-0.20193448705610661988562367688839868815640865847747492909714865686778968498395`49.69897000433602 w^2+0.05192629829949618195361988649211060967967407774814151312692557286005468844933`49.69897000433602 w^3)+20.54763753844053348363533484354812587898219771798039633506924376721431501865098`50.4442253099426 THRSub[2,1]-0.53895249084121083064423522919721573890319926899921005482836334318281691587518`48.42858464536981 THRSub[4,1]+19.62154849862037279797931738503223978530273689402474457286143143630073527042812`50.036739983364335 THRSub[5,1]+12.39415323173106567189792502407044206481765956074248762587720117923544749498265`49.35202824875874 THRSub[6,1])/(1+0.56143321733639489944365251125222651841300249967060010515192332371479151337948`50. z),((10.68375149083109476354586804386080901957527509763294647160695299522458182783204`47.911362070316784+ 15.22964048246329888815991591257731154660489612568299449304375435229685197138365`47.911362070316784 w-7.74863867319814772000575886647776501895036443803382619317854073843753159027001`47.911362070316784 w^2-1.78184084399089425962605793558834037219528824254869502035110422518541475077338`47.911362070316784 w^3+2.4027572493063946488666237849353021649749319842833203630938040577478659418803`47.911362070316784 w^4-0.68909224967495069757102355264276662053520462146113484618321950987240081278752`47.911362070316784 w^5+0.06835654249754566673676624951408815791011461498397000015615585956603472289139`47.911362070316784 w^6)/(1+0.50516436129653626249690565729694791843097483013635093892043463015833435392616`49.69897000433602 w-0.35989848230681155398784971981189916267193450641222768365007859599055980958591`49.69897000433602 w^2+0.09342330269254888369532940540025981879880072420171929052258969321246471026285`49.69897000433602 w^3)+19.6705143496359235162963917251282110554325622867964715734088773590315140971412`50.48016523165321 THRSub[2,1]+0.04579630169519581424839351641606081012989101845673978627854759560571703179823`47.42197018739528 THRSub[4,1]+18.78395755142769599336970729782401579275417356341396506754869378550116936528687`50.07267990507494 THRSub[5,1]+11.49058537165239271072867459918563145006050434573515474819094885679423781314326`49.380742514182806 THRSub[6,1])/(1+0.49477984756902630535149598383600958503347774555161285786210556606373257400705`50. z),((25.52807597048197854774047263223305416856983787182599454571099906286143252017449`48.005185141840606+ 57.79158018909770432540878562035553593540652424594584937554460408900586342808538`48.005185141840606 w+22.58978403538010118892954979944967518651758776793946477008245337523631126572521`48.00518514184061 w^2-10.54272493206853661629308931561724679530671114236755921198610623673948395193198`48.005185141840606 w^3-2.42373418169283232329853801417437537875171607647546854942388868685458292525802`48.005185141840606 w^4+1.88551983229133947028157679972024731279619666794659284902431012391475877940023`48.0051851418406 w^5-0.33502033876594785769764472760361398444025320540465824609260057749776172418575`48.005185141840606 w^6)/(1+1.50454155297403228629975638809929315359956062666423297316987940247629657524823`49.69897000433602 w+0.4169294743681718816132104860780312261702768502152793730822604603907039675834`49.69897000433602 w^2-0.08950265183820736940637813367223351994440719977877580705208298660901411220333`49.69897000433602 w^3)+34.44620053898860885402192038773471225417780926174582434412870233411488674781033`50.209032414733834 THRSub[2,1]-9.80466115787326107756862559198827332236694029817616206086800238778319806864781`49.15332314432482 THRSub[4,1]+32.89369851908847890582290281711996424450305282632389524432737356612001229784076`49.80154708815556 THRSub[5,1]+26.71174851237682660195421951678809391395374949850018286354693008703242512526111`49.169576299568824 THRSub[6,1])/(1+1.61759735794374437115250841912097427419746757708046997604916801282521687590311`50. z),((6.16582773864250601846944085527207825752721834612828083623017264432762188848829`48.33701587265642+ 13.72476171836847489587288068986661505305085713305080891131280720299679797776966`48.33701587265642 w+3.45199390483587502126307846575224390621723862667533067223183720478200104210537`48.33701587265642 w^2+0.73139596167186722554416943176800582959067780771306090014348216168834851240302`48.33701587265642 w^3+0.67196747033658663727835186913110762815871032504423227994588730924269796169852`48.33701587265642 w^4-0.34949179296193941665384508974112719487839115276785240102617477722566582797604`48.33701587265642 w^5)/(1+1.10269615596341024493266502152987059164723660070651064376248340926432944748056`49.69897000433602 w+0.34795667875361701601570363169665123034521080391551305694809337255732722139225`49.69897000433602 w^2+0.22353096563524153904009840770707811599311278226735555940185515858736748241494`48.33701587265642 w^3+0.04480716477345548734024896912857114429973532816236096418980366610573764681046`49.69897000433602 w^4)+15.1734809089244885958467869875455963298786577257083179596332726383673506395715`50.877023950593326 THRSub[2,1]+3.04381859550281909454813000813780396049916072584884219546228407604849267017798`49.82420028048155 THRSub[4,1]+14.48960694339502378010705336201905096639387723460002609763603098979017367417623`50.46953862401506 THRSub[5,1]+6.85796941235522031610961178678879074339160861944407041277352470469183368629737`49.71581429855302 THRSub[6,1])/(1+0.15304628424998326571450893788104249610409963160043542332864001841931846285637`50. z),((31.03848736340316339686467212856249761126899003348028865191497808726817593001713`48.24529073336672+ 44.6974830117219412155925960373296969382956724550558124891189483051120766392045`48.24529073336672 w-15.82624279156121658521203155424664789721572047666527750533675013011568197410411`48.24529073336672 w^2-13.93773163730791439416681376177718752476640278570039122347793230127794037180217`48.24529073336672 w^3+3.28383344951592018979785903442072596943253631802213441092847883360787936688209`48.24529073336672 w^4-0.3024313647460491759062014679347725082963670754222738491302679411587905902126`48.24529073336672 w^5)/(1+0.70133951876079970055855175079151171282254462806168833872845765213139629902864`49.69897000433602 w-0.37347262742751570579248758571267654042797510473953754155447361825198189772193`49.69897000433602 w^2-0.07396956657785342043847084487299072626661026275837385178138786905873171536737`48.24529073336672 w^3-0.03945534105940917343380516836962413530071923374565154759303391265327841078061`49.69897000433602 w^4)+39.93113248234856182426684542515134499038852927186779531377267029325147664271167`50.17363632736861 THRSub[2,1]-13.46128245344656305773190895026602847984075363825747604063064769387425799858203`49.177548753205784 THRSub[4,1]+38.13142270693871214222220736876159761867273483968757155237592359566250738705986`49.76615100079036 THRSub[5,1]+32.36204744643330820079018446758299230253860410144018475946899098906861350180585`49.14273954828688 THRSub[6,1])/(1+2.03440220546791816424407743877334762280389751302486618964154953884753151185142`50. z),((9.41270005139795826609009704307694546935034066750056474459971452640338236905291`48.4335091408609+ 17.74556811890322436304144295445942218091213231808630839913182101092778074836916`48.4335091408609 w+0.46800181178040642207739852941646130272909197233475113541560765217884479909939`48.4335091408609 w^2-1.70746220513809781317537215855370968773521950320820962362842943438421933670169`48.4335091408609 w^3+1.09066868833574060247423404539678808929218989535358376627705772897422814934606`48.4335091408609 w^4-0.23832071717342993820455101351934947980935914863296704229482464283871751145598`48.4335091408609 w^5)/(1+0.92755332810368993802023889847668743891358491564773872547441896440509352264643`49.69897000433602 w+0.02786633957106937498578914401077661141017048125573431450418391276765030196526`49.69897000433602 w^2+0.07827653880808125634196098611044650847996631216036288616358349536726266669555`48.4335091408609 w^3+0.01564833810320584620818581834948800259652686596891888210177890045453489117828`49.69897000433602 w^4)+18.40534009227350704952451794282731829286470592658036199812648375988027529423685`50.54512652496032 THRSub[2,1]+0.88924580660347345876297603794998931850846192526747950313347666170654290040099`48.8192650340993 THRSub[4,1]+17.57580512983661797558286897119410670055600198485002342676028290427350135178133`50.13764119838205 THRSub[5,1]+10.18726696559182928118336152972926070518451690105069761421877539602688419239569`49.433307129374874 THRSub[6,1])/(1+0.39863813261669452351573629977539924883728284508857261036659910120079541934464`50. z),((6.74386234602756643380653182501525280582240701748814766877303217845295067483037`47.814182555902335+ 14.35655976220585699364012983608889330148565646083599254340903936673888396442033`47.814182555902335 w+2.69101779490616530276982084350579647735629798553823479592564441517954716379329`47.814182555902335 w^2+0.21000967328434305321027718413381109792803471572983348594856945754804974707683`47.814182555902335 w^3+0.77805853543216264619508890352414339740128448182214139355010220369385164344321`47.814182555902335 w^4-0.31995250815706480209227834361660715480276986539107982232229419115636714601647`47.814182555902335 w^5)/(1+1.04671786537830618137166184133849421629947273590629960140048236024838379368411`49.69897000433602 w+0.25324834516333581806337283675697291033846271763163501168734508824588018591124`49.69897000433602 w^2+0.18328382212260175389193305355520772191613370021160579204902929958677441611904`47.814182555902335 w^3+0.03812903567769885649756785704080463758926453257032483907163677781632391511246`49.69897000433602 w^4)+15.74884275695034144123346281006236361281503095115070195693556114399931941415281`50.78405449754607 THRSub[2,1]+2.66024403015225053095701279312662577187491190888725286392742507229384682045704`49.644588966849675 THRSub[4,1]+15.03903703647383783418812589636342137544226735485770301650760435056784262070543`50.376569170967805 THRSub[5,1]+7.4506780311983140390635007956084629239634471154806569530525311525583980669798`49.63436015515704 THRSub[6,1])/(1+0.19676854184844996979944828446178324540949307892888291878367281993872954733875`50. z),((10.36806828002289963195328024167720398222728345566156797778522725942008351949166`48.01066152826896+ 18.99968178571550011087076298014064176008769865335313106472453813610104642125866`48.01066152826896 w-0.18231224612842552819458053064766673956665069792789855735040114894734207917277`48.01066152826896 w^2-2.29649601889650087975424719004585175270146290352814115807993994587806061240957`48.01066152826896 w^3+1.18365948074568844064705226874493437527688730108317605130495075748786275733242`48.01066152826896 w^4-0.22315661539228932749944784638831448218199663465071404323582638961688443344496`48.01066152826896 w^5)/(1+0.9037560584209051050147194777287845844848995096789724197484703611373223934106`49.69897000433602 w-0.01850474742638641617010982120089551413362529202024137183694540278145549315761`49.69897000433602 w^2+0.05692745199469004855065392955542825384356516547222411698370950803207552523332`48.01066152826896 w^3+0.00984922299928486580520595395679096037595966967320150998046930158911088073418`49.69897000433602 w^4)+19.35629081830963565924993578154358077156693623452000864274401751479777037023138`50.49465337752017 THRSub[2,1]+0.25527865591272105227936414547248099937364171997438174005512082509487951640459`48.19319413717953 THRSub[4,1]+18.48389618194947758212450070408823622480335048552049290947712251379196733383869`50.087168050941905 THRSub[5,1]+11.16688821324776526817804632520625358566027418274809322615465140135497471251351`49.392390704561926 THRSub[6,1])/(1+0.470901722477335289710119291055553950298579239048376822281547098135050049793`50. z),((105.91452472123724469995351213044990766252110042733251267263247790218657087668838`48.32724550531374+ 128.9533579242780648537124407345862615240943119831366232024656534101136288197218`48.32724550531374 w-88.27856310417553332576509924256265627221658744734243400462741504414497810574153`48.32724550531374 w^2-59.22280464375390250760602280262509643061021116336438200579485062550083077576912`48.32724550531374 w^3+11.73181061472865260810279222951437161025204553312768379255955429688523217775751`48.32724550531374 w^4-1.30425027595159769664772575544227572007220481485239963813853740085385928002842`48.32724550531374 w^5)/(1+0.54618233079431907573261336867454090610431116304051833277697357679953871203054`49.69897000433602 w-0.61087032297754275155876071757437333919715985936824248161237266125215920878182`49.69897000433602 w^2-0.1385877433272678128976225817384459167804077073585275606209744511880651497222`48.32724550531374 w^3-0.07041598393658782720204446095637383642422165769260896881582576349636019824738`49.69897000433602 w^4)+114.46095245618575022427232168194026243573175049922548764535604160006119468743744`50.05304156540337 THRSub[2,1]-63.1478291026713553244022264547919734434029011231626042616862285650807366950626`49.21839416525238 THRSub[4,1]+109.30215824645028439646237277940342602625703989867324526265776014911560572477804`49.6455562388251 THRSub[5,1]+109.1388911160061986468246642999067213117366552801979983163110621925855709446498`49.05188851246903 THRSub[6,1])/(1+7.69798938776756674888698728203884310600498390114793690007990828698330496206888`50. z),((10.20560469928494979926384541992463232270273387548392266892924854272183248849978`47.62009154785723+ 18.78641517282899671274346774548153499821982357644079111757600030295891606462266`47.620091547857214 w-0.07304084844148122481781984930506242977363359636091790859649948819229383728755`47.62009154785722 w^2-2.19823839712047955576243807735225813282725430389428219929681868428902128828898`47.62009154785722 w^3+1.1680018924908287538383137603854991564895760893425357416167675057993411470017`47.62009154785723 w^4-0.22538363999511604838996277640009115979027544952711688328178007557194581432084`47.62009154785723 w^5)/(1+0.90748841963986272153060873108505952498112964692871899361516151048740166972982`49.69897000433602 w-0.01126967809851425466808522997718022918681058029002065683886446683711400526897`49.69897000433602 w^2+0.06021343239394917927164659958524569181954196946454547429610355371889975254543`47.62009154785722 w^3+0.01077584445778010865375583151002385737321833534439876558801231616649045271282`49.69897000433602 w^4)+19.19457844874554979628745070059672296750747698005309326173353325553419237155972`50.50249368237074 THRSub[2,1]+0.3630869022887782942543541994370528687466145562856586607287769979372648488524`48.35956245221722 THRSub[4,1]+18.32947224409811178492865902106941390321587393023003205323857607382823353979607`50.09500835579247 THRSub[5,1]+11.00030032504655365941605299158055778792534405825555707765730347914266516456762`49.398711950120614 THRSub[6,1])/(1+0.45861305595695503693789017029120391524040665636145255993937638820853352845188`50. z),((105.56976951152256094949481174279739652307336424157149389033806227384937771116191`48.32699230093832+ 128.57715006143729189905459845280072578878742717735703652742590284244720442400542`48.32699230093832 w-87.92273898573335578895703228701804599512125299422915575629689654016162759070079`48.326992300938315 w^2-59.00779398120586887183053539111915907425131863855207087685571431223123449582877`48.32699230093832 w^3+11.69180654670621605355357945891523268194818849773503677431814131635137017734021`48.32699230093832 w^4-1.29917645110556160024045761453266555857114389834744440544761723267535240478911`48.32699230093832 w^5)/(1+0.5465035324374067262576526202279191474756275319183937925040198880358311006135`49.69897000433602 w-0.61039889826056148218271320050603936496684086935182762776875386920307521955888`49.69897000433602 w^2-0.138465962989218804021888208807177609333459622642321640921520498629929156897`48.32699230093832 w^3-0.07035865259084967805693524200179403542160301680606931387537166308263905411502`49.69897000433602 w^4)+114.1177913512212456666285503197530631237478471399293756001206734041897032477696`50.053211247703054 THRSub[2,1]-62.91905503269501895263971221333384056874696555029852956486264976783307573528661`49.21837127017186 THRSub[4,1]+108.97446352965841852731095903910853046052070570226114489885546570298668167219664`49.6457259211248 THRSub[5,1]+108.78538393567775559285087261920587844855091912208422208815152557891487140310104`49.05201602856962 THRSub[6,1])/(1+7.67191227076630466323812903273333993401702844756878745172516619838990734535754`50. z),((7.09071343623314877202293310150761748403522507088028178481843729808708709023902`47.38746778679724+ 14.76840522786975117454550349869684819593034241959039205932597852453260149090853`47.38746778679724 w+2.31951307558849951547242820134735114134222988371252106222808750054997596304394`47.38746778679724 w^2-0.0772831532635652536656469330895345724530297160004274287846508841460735322069`47.38746778679724 w^3+0.82989010231164996092145730684067320855564490618824168289861914768099130999466`47.38746778679724 w^4-0.30473917011085815547393494226796452707754357478451887655344093722456751385414`47.38746778679724 w^5)/(1+1.02212568369493087110146375475943983584622195631778857007190872239322816112325`49.69897000433602 w+0.20911110974443621770718958243321555140903508986069515317526056111257351800518`49.69897000433602 w^2+0.16342527253042767534547573463929431646627069180201461465493406769685190142983`47.38746778679724 w^3+0.03450104713131023533702338208518763767865140008990389780665189770059535592946`49.69897000433602 w^4)+16.09409005131783002150886917649256652535199062020512675876374677322467924505272`50.73911492152032 THRSub[2,1]+2.4300791672405914774400752155064904968502721295176363293753013194769402665238`49.54429605619819 THRSub[4,1]+15.36872391739996872670461933475285228580986961771306465194797432955352908749379`50.33162959494205 THRSub[5,1]+7.80633429813013611707877901387225095684992292498383606116664718972988411282592`49.59561609816861 THRSub[6,1])/(1+0.22300419023442138781460050351649604024751857258335233164589419415382686754981`50. z),((71.30818138182665079962422998714162553381378866131588813125015236990209722553562`48.294496517203875+ 90.81064854467214748688948709168152287531166492001880603113645251585559413547517`48.294496517203875 w-53.28332863204335307943172996858494902647453570804943878584288286672362980896899`48.294496517203875 w^2-37.85836816613902533802355244575832527455373419374548203030954301680339357912311`48.294496517203875 w^3+7.75263713399373209113664988827738788185161368076106644008687778710101877707849`48.294496517203875 w^4-0.80749359798427424486603802105677183277140409798528256848540789397503835147856`48.294496517203875 w^5)/(1+0.58859850316138496364651630977237782277794689217924712927536128132072939373787`49.69897000433602 w-0.54794119380284264722060905031319679762555030857426388595162085111295180152054`49.69897000433602 w^2-0.12219223534439056781577971348889457905667406252857909627495656467071439599748`48.294496517203875 w^3-0.06259932479811333320009998984109304771841646953085147444591552811654071492774`49.69897000433602 w^4)+80.01462449797662239155532863616496288697078670564495005410709548745106988085347`50.0780344911672 THRSub[2,1]-40.1836104638652701025908977576084404108955919274422458675202644900073201573446`49.21412101679882 THRSub[4,1]+76.40833805096906242033935693671057167000890768240043020648441968641534544438713`49.670549164588934 THRSub[5,1]+73.65402965294827243528318576207388610787050753483500254211190849703379585432282`49.0706742181652 THRSub[6,1])/(1+5.08038234712414105250436598667010173726187741097209080117648623098264521834732`50. z),((7.88312405198392824933285978908617996088408304086097274285669702526170430128211`48.34210791739667+ 15.75791067438089417541327169250923294498122960217911996620130654035668898139331`48.34210791739667 w+1.60469837114485103483508663281598644901708716904338673960201285538002817378718`48.34210791739667 w^2-0.68002911901839981443087427190615265070896979120730408898536440664310882319398`48.34210791739667 w^3+0.92988682826236408793369500098145328324693293082583834339071748252691169491718`48.34210791739667 w^4-0.2759829061873765166246924213466063222786982226039824948130662045483202214672`48.34210791739667 w^5)/(1+0.9802285673879188358141781026249736078733226546717033901184541844175861971308`49.69897000433602 w+0.13050757158375825424090351462507942359219582281339429892932577025046424995859`49.69897000433602 w^2+0.1267974511242085119077364358100685943487295580824220053067634402155282300827`48.34210791739666 w^3+0.02711875879293231278945173150134629706904426336304762314812434487433867189478`49.69897000433602 w^4)+16.88283665999615325536998965720199278361624447683351166485005686066862989731479`50.65650990874211 THRSub[2,1]+1.90424809478837598819932822836687299134076955843204639198442792784763983168245`49.32120551558774 THRSub[4,1]+16.12192144710871257107545042474458874621199484467328672844672926721593822943694`50.24902458216384 THRSub[5,1]+8.61886108392754435244586268787366830659731090720430720057642971418822400454201`49.52551275784607 THRSub[6,1])/(1+0.28294174522329702433726015961812015644643978348330202069533953287379973625604`50. z),((128.59788321327468989304872929162791238403482911215951407782018600643608088681793`48.34167109998583+ 153.58405833228578699815137213716627561978426884045589700803374823266291543952911`48.34167109998583 w-111.92329659451598273782345985294559813194181490461884804372331538319820826310945`48.34167109998583 w^2-73.44078099273857608418669103141990109912370847897535524490378925191971263124595`48.34167109998583 w^3+14.37582095444862938177849044106365766777180627132564938144182981918662631819675`48.34167109998583 w^4-1.64178485569757437627552246514861675489434494346787740363435294685252445312108`48.34167109998583 w^5)/(1+0.52788361558604634442153011020733367235688213452179703087145667997898525076496`49.69897000433602 w-0.63760048098445035913381874852974888092875519484422396886092717021531994711017`49.69897000433602 w^2-0.14547369589675193096643911800675633224026773732430957900214178830348638855996`48.34167109998583 w^3-0.07363473055967671650558049770111214585480707981822718494380919510319455379477`49.69897000433602 w^4)+137.0394259501049659126802864979679315163224919151094496098124868656930176255438`50.043844497358194 THRSub[2,1]-78.20014476528416578334086966547708616379672873375191223799052540883528532046711`49.219515721907996 THRSub[4,1]+130.86301223060976453065731594465681319541133821301421905122384252839631265703178`49.636359170779926 THRSub[5,1]+132.39809032444057945750836181431786437120526554805005271464736466224210411938494`49.044977112792196 THRSub[6,1])/(1+9.41374763219835018888980688382766456474071549879112348508118926222646984273291`50. z),((5.79555734195438846981935560597871672803460752257444380776976581386582572964189`48.49551337020916+ 13.38012042315640745268267717762517487998545227487968817739204988040201539733843`48.49551337020916 w+4.09083289265659057783031940868637110604700917757928357051602533852569488440913`48.49551337020916 w^2+1.10017524067639534188903434046611846404740939512822851445054510247528201853335`48.49551337020916 w^3+0.58315064531130839661959577340055523593386339385847980959601986194988729533988`48.49551337020916 w^4-0.3714532723196144489824038372519090416147737486702944376552279636041061789307`48.49551337020916 w^5)/(1+1.15478587173187276708034524969640858877957364187482716036452535162469801488509`49.69897000433602 w+0.42971605912516846003935759746847620874927444495611751811268577578715632751686`49.69897000433602 w^2+0.25543075103065679066890899006875565985543319661437421932057230994971492821297`48.49551337020916 w^3+0.04956114780291243678146064493577762978015572296050106076861726617618205048567`49.69897000433602 w^4)+14.80492259600357429719802255503050159976585592954241263264636374142944988736896`50.95412143496804 THRSub[2,1]+3.28952413745009529364730629648120044724102858995944574678689000734042650497969`49.95404877610626 THRSub[4,1]+14.13765967948118536835339437650599371382250629235157415295664748229695252641747`50.54663610838977 THRSub[5,1]+6.4782993154170578380501351188987577190099607497581105656272147272014062283141`49.784619428601275 THRSub[6,1])/(1+0.12503921087020565505242581055530725659012485379844655691521590746029312586361`50. z),((6.03553789428642000496611923177408241997967559566064037148943656372181787644864`48.40030232992723+ 13.59649734435693883644267187314661582769025361004618274068927492830061876640597`48.40030232992724 w+3.65936824998199832759276129809725371767709533641380713693036172931224554204612`48.400302329927236 w^2+0.85769393813093395924425011237464674337292902580634295195790268318125521564441`48.400302329927236 w^3+0.64309367935962665690197364770538570109983544432408747746418594025478382343563`48.400302329927236 w^4-0.35693604602178001000724665322987117476924701800819889027264731376090687526268`48.400302329927236 w^5)/(1+1.11913795594540170189507697202368409417215121946517327690028403315489589757729`49.69897000433602 w+0.37436668743236756365578165211805056120772780277748036659361754550594208519921`49.69897000433602 w^2+0.23412656318281965280381409751882317600376929086543101391738741134672921588645`48.400302329927236 w^3+0.0464338545631389933798051086956200156982065332318906475633246347527694532354`49.69897000433602 w^4)+15.04379350842983119261045169990651832647167562301881704318427323655283121426794`50.90220248153828 THRSub[2,1]+3.13027686249925736337235353323052262943714879430850947309495034392483895371356`49.868146649583515 THRSub[4,1]+14.3657645983222455519267101466107518994536186483243548581100770215360192567254`50.494717154960014 THRSub[5,1]+6.72437202439444321129206045620665988625288884177062899836410028871723181467444`49.73816393817992 THRSub[6,1])/(1+0.14319122355877082389423271729478303358601704814431223934004804596270397635006`50. z),((6.03311489425627284506508265916879088812475219799058025365043400127757038394774`48.401390831688055+ 13.59417679709881016418609675769918633699210320815560147852693467310329945420243`48.401390831688055 w+3.6633868516977202645953915229932658501135819069566578113021251898040953074676`48.401390831688055 w^2+0.86007699963820456557839217541328263711102616171013735904162301622430538587237`48.401390831688055 w^3+0.64253446129997477632276200793931313882267878333986349817349319059421055602236`48.401390831688055 w^4-0.35707736117791272345686480303115894830074990849357262148444331384904853223612`48.401390831688055 w^5)/(1+1.11946118842891622801372949738029084748679994292453074456741920441090928565706`49.69897000433602 w+0.37488002680093431830538596099144719166778358163094405083846261762107376532047`49.69897000433602 w^2+0.23432974571569268883322597662931225755264295859403995663455405762216313044039`48.401390831688055 w^3+0.04646456465791616093569778014512766613297247111092844355682688443630240153179`49.69897000433602 w^4)+15.04138171204722554048732790406399288137190439080928650951450538549743487650972`50.90268907255932 THRSub[2,1]+3.1318847267543277981211027304588729261703296157815298288747955779617698455524`49.868980026315484 THRSub[4,1]+14.36346150242610850236559421243182341747375507847490278017721276333496584747507`50.49520374598105 THRSub[5,1]+6.72188751398109245669610182888470824142381716350034037056045288040205207785319`49.73859703299355 THRSub[6,1])/(1+0.14300794901062838898734720032678347647375990339380693903049653428456353818465`50. z),((5.63716210498324684317779780693906932965315830444662152825213860851751274679848`48.546842027780784+ 13.2550374786021363822752829294815534605332856433937216553991979238193124025807`48.54684202778077 w+4.41944451366911024843638666944471777154441052183455581722254566188590764906735`48.54684202778077 w^2+1.26783587017825201974782339847542839992572127065743346892624856616158278831885`48.54684202778077 w^3+0.5376824108776197305461164929145006319968275196178777310015397676896106874405`48.546842027780784 w^4-0.38162535648567369557438403062879402896219673075358419926887166045555820364876`48.54684202778077 w^5)/(1+1.18312321683477162299283726565304655514635006618317694118318386735368912828801`49.69897000433602 w+0.47205781862126231358934812128729729224673274368348369243321173520965423743201`49.69897000433602 w^2+0.27092260411415222140926317030813429422468107547360853881977328595205082396273`48.54684202778077 w^3+0.05172670873809794850389256611350446964223959598625950809175060233150947286838`49.69897000433602 w^4)+14.6472597586961547105904782354206157047158627288169992232873280953281188190588`50.993215558563165 THRSub[2,1]+3.39463269565504168471900250955445771060769072377638801969291377140798055051968`50.015208118408054 THRSub[4,1]+13.98710276008497066541590939962240850501503144240185132232527418836123775678781`50.58573023198489 THRSub[5,1]+6.31588305013287596054997575979997671455439674773970056470648898632582255452683`49.81991496427177 THRSub[6,1])/(1+0.11305827190090784299141517420292583104970677247331990340518540450619319524544`50. z),((47.53456446906303377213652920380710190243440837522923204711376761965689316732039`48.261131506437756+ 63.94221389653875340502431871734471581381987406134589871758861174608222096864252`48.261131506437756 w-30.5045566319940125920000204104176857478163278923809942773902334922251017079999`48.261131506437756 w^2-23.55366092832409377696243757219061190648339815077991868779550187011886181811277`48.261131506437756 w^3+5.08165416809364330775824687343040834947233939112043969475411299956405003979003`48.261131506437756 w^4-0.49166592761490494028005751586763203704402529735767455126144509647595292564427`48.261131506437756 w^5)/(1+0.63952538584991428816688597681808766158852009046568149809101733765508301458834`49.69897000433602 w-0.47051487677324462568839435448958019252474076455436450467738878060993477851531`49.69897000433602 w^2-0.1014508823475446736680905349442741163431197087033714341908663463921137226494`48.261131506437756 w^3-0.0525683206474068053653228247385744889483360720874564542894462829785996352553`49.69897000433602 w^4)+56.35093380121113520970852372683801378161546722225311815646553293048817109091675`50.115503219735054 THRSub[2,1]-24.40781666602161198135969448472380767399204560518102460242588945203205429738603`49.20399407061206 THRSub[4,1]+53.81117797384151722691335120089693267855701899807311131212522156664366901948767`49.708017893156786 THRSub[5,1]+49.27689467652588760503479301253396850926907250253453569846326827017152559614266`49.09886555216145 THRSub[6,1])/(1+3.28215748406729921665412048541431212910822878244687912920704422646456998332153`50. z),((100.93724827271698258319923640124566042850569870201900473731275095388961641827868`48.32347310742042+ 123.5158270239993406520326957041642071947390337880283996120311338698649704687255`48.32347310742042 w-83.15324894132208109345366540225426642197652623503204350581152130418088386804845`48.32347310742042 w^2-56.12224881834379143347360552274863309264199008526183335961173151532234403238669`48.32347310742042 w^3+11.15486478415637749969415162766000142836403480463818888976147418727159997713296`48.32347310742042 w^4-1.23119204860532642081622674278710943898450186077605121929615007925701300383559`48.32347310742042 w^5)/(1+0.55097127654490444448160600897171471189645411350205614254075570415196256478648`49.69897000433602 w-0.60383363061779735896691333895008684809906028903199640442074895743411581751905`49.69897000433602 w^2-0.13676863208778230319965429887515550390116513649177127532157278400012473577392`48.32347310742042 w^3-0.06955824010328990626813832836478289048012070460992699202448358340754279228887`49.69897000433602 w^4)+109.50669030826476701739109958014501684566812640515906283267594654229315031523104`50.05560147518113 THRSub[2,1]-59.84498767072403318648141172026180971669381839378498771989949852656870711359352`49.21804014498182 THRSub[4,1]+104.57118638516211299026992392899481371848291588736553871395772936241837819111356`49.64811614860285 THRSub[5,1]+104.03526131302885299507612215799738053938937620374291560252100086860071614403851`49.053812303269574 THRSub[6,1])/(1+7.32151060909122821167048401411714680449270973266677953708093341620073378719208`50. z),((9.7104132366878311450524296484655070717487402989519138968118915538570562780856`48.1850223213746+ 18.13623928575274552521036314396510446604508827773587675094649768566729275433141`48.1850223213746 w+0.26294176987520670449497386869217530352750131423115681157265320717785557624464`48.1850223213746 w^2-1.89415659608206145026318742798977053435972248046495158982617287566131833870471`48.1850223213746 w^3+1.11993296346230898000251346301924226330265348620329891435665526911793729297045`48.1850223213746 w^4-0.23303340491807203575023284136880002280567432022372941714763606434982347123611`48.1850223213746 w^5)/(1+0.9196211864403043025207765453005807046412093877978347423210979198628655832927`49.69897000433602 w+0.01235588991685787504700495752196730854979504250695362093749970340068048236839`49.69897000433602 w^2+0.07106514325330020623181304909068666528064172756929481381279824472795038718597`48.1850223213746 w^3+0.01374672472398875677483783715714864811542890476471266690750780852812031467302`49.69897000433602 w^4)+18.70167668922043849021204120779623368114319749412207516649561377848501186817369`50.52819802517713 THRSub[2,1]+0.69168807530551916497129386130404572632280088023967072422072331597005185110983`48.68247617719692 THRSub[4,1]+17.85878573517542676685033268657535551211129158788669580476633454244216518043902`50.120712698598865 THRSub[5,1]+10.49253791063576649367448251045119190142340212338711256586031725908654478009471`49.419524859419354 THRSub[6,1])/(1+0.42115701368609862681861825004783678065244533181592295099119886087911411807148`50. z),((102.42425214969951573197965698853423933090119722583782717145590734152439713523851`48.324626981615296+ 125.14174741897043175899225784947347638193638033312665098496166047079802443746737`48.324626981615296 w-84.68178820454510691438267324884005518651462684094748053054698437791193642683777`48.324626981615296 w^2-57.04774731600119270937561823773512646674016219271773678304716732390419140551872`48.324626981615296 w^3+11.3270955106933173769695788116799240225497256959473749574350801387063675857796`48.324626981615296 w^4-1.25297440035739315930365520348004523610796322973007983994254068270729341194922`48.324626981615296 w^5)/(1+0.54950556490864238769843692510455627081096257412390518782556024381380992877358`49.69897000433602 w-0.60598911359606964195903280606997002070861087834017596346554152589660023999602`49.69897000433602 w^2-0.1373261785097616289532095669648310090450957221439061368080507132934763118238`48.324626981615296 w^3-0.0698214368236127367607499270558465482795250674130583984622391591905763780713`49.69897000433602 w^4)+110.98681846625296071434309092271715830342129471987593304853207346959200852556506`50.054811130924215 THRSub[2,1]-60.83173977604949565111607261530990402186259727026290119713691647810127925382036`49.218151418006805 THRSub[4,1]+105.98460466168205000969387162945947919584461418620543124051084243617141144226929`49.64732580434595 THRSub[5,1]+105.56001433452661400318214698893360993041070063318482391623496421564769378796733`49.05321834882571 THRSub[6,1])/(1+7.43398686177351589256682646379286801254451362529251659268054991341861069824855`50. z),((6.7257116790378792693192979707996807081497289591471511486856683468202803818996`47.768839049559524+ 17.45572265919430626563967664741068296352372823656066722260371208720293953282446`47.768839049559524 w+8.06430399135090715075986240698755225742805375635954766430350734053827236581696`47.768839049559524 w^2-1.68116875572387405037333451708421593601804625016706422071696592537332169977085`47.768839049559524 w^3-0.49634949260299882874699477158232061316250948943060476593479206553567366628983`47.768839049559524 w^4)/(1+1.51207230459778350596761156629994524578490880994383891942421604793979135533076`49.69897000433602 w+0.54903078177687470405194698456780709650934133811255482251272586039325301791292`49.69897000433602 w^2+0.041593760457393536208268890052312091404975452037011490939956054168909855526`47.768839049559524 w^3+0.01182133817145715270257670697031566373285724781611885655536135228086018521271`47.768839049559524 w^4-0.0076621028363054136639429312413451132692373232884118267567165610675642278458`49.69897000433602 w^5)+15.73077601636307507423152308083589512545189087959252323851031161587653753725962`50.78659680951024 THRSub[2,1]+2.6722885238770947756249726126109380967836719565927053428775914243757014050525`49.64994972300553 THRSub[4,1]+15.02178457005370334803696412724964614892816466854974858947457225657391711263296`50.37911148293198 THRSub[5,1]+7.432066590594080659879491210979464335644321299564169565431251884962356425685`49.636564478801475 THRSub[6,1])/(1+0.19539563419280430010432723875899981425821252238267031658123441436237116345739`50. z),((8.72395576361645532744466676315890531634777016810198743287034029157382456094522`46.76935670352289+ 19.27724421510045493536518698441434979270660822372054971254440391602732211140497`46.76935670352289 w+4.88849839734722797084137456637352518625357403422148247522929387580318813894743`46.76935670352289 w^2-2.759128126081517868200590503259884067413451844158379936075583522126953991433`46.76935670352289 w^3-0.066143317936743611841770751666851736067246833140327972218969340842608439135`46.76935670352289 w^4)/(1+1.22714974670135268439916729652454097634482395202998373560938256982585252799022`49.69897000433602 w+0.24513518921919687009009524677099987887412874396363190961130270546649080873419`49.69897000433602 w^2+0.00046449067716519728266604413488655404492255207212379358683550352747837817082`46.76935670352289 w^3-0.00090963153493822577003401354757457053613689735621365512077888048557058062261`46.76935670352289 w^4-0.00664569979616003902460358038346773723214926159296240645623241877363971155169`49.69897000433602 w^5)+17.7197804714959339893279925931028609147754627777598210548105147008422759607046`50.589464167583486 THRSub[2,1]+1.34628555378852216556065960443296090390129069114784013201078936773187578942263`49.06965444777243 THRSub[4,1]+16.92114391525088204989372541763282605335689545346467597950366048193461344260047`50.18197884100522 THRSub[5,1]+9.48103818563384290556351122227682996577766585202163044185327046426457464765654`49.46969196579227 THRSub[6,1])/(1+0.34654184844076258251807162702374732358835874125880109694036490729084557996648`50. z),((5.49062812779008916191569972273433246529923286751682745122460005584053651058615`47.956404745526825+ 17.14556186649999835459515884992220764521504994761596121618231091762048022818225`47.956404745526825 w+11.97408897354215336283575584293237439004747660178595792017033026592165244986131`47.956404745526825 w^2-1.05690066284697919263827420239945129025900865705034707549095420158946116618044`47.956404745526825 w^3-0.977560591930299882054107778497115458432767212625948221138813926132093137924`47.956404745526825 w^4)/(1+1.94044514745034315911500086274453657980104987829695274011321384787451884220934`49.69897000433602 w+0.97053816779877266361984760009284565214111562456054757667791386213922429373107`49.69897000433602 w^2+0.08434161426737469042631281858097168773248400348197937483271145709498151416326`47.956404745526825 w^3+0.02429135407147320205131932865455769910219721033773896564571872418284211291043`47.956404745526825 w^4-0.00879270931201065312057370551831851167617040633615460872147210418593548386222`49.69897000433602 w^5)+14.50140333619259716481567478601413200179575333318428355595792383577532520712438`51.033679910615284 THRSub[2,1]+3.49187031065741338190220480915878017922109698753153179791251661110984295847603`50.07586143880672 THRSub[4,1]+13.84782013634612380492578143021941342118926973374801021984764132045532808428665`50.62619458403701 THRSub[5,1]+6.16562915507865638256479682990043722455653884698922345828656168287708493952144`49.85671854641877 THRSub[6,1])/(1+0.1019745128734848217702713233508255902318691974267924808784130497181651006663`50. z),((23.40408967818196460652330644672036932918872906241405840440977813601793719507151`48.24371993107274+ 37.67647906384075439398918547115273854629092257961666628896067176360240362558363`48.24371993107274 w-6.99673309202725406124921572895809960715537317305960499248337308603865743007791`48.24371993107274 w^2-11.98494793747237448582953099656889403093932440065447152888638679358188500651927`48.24371993107274 w^3+1.05918234699870371910157144685449254100626109498711790919538524604527989498954`48.24371993107274 w^4)/(1+0.84000435005640818859832796160216887705450946448677900927544424689370016592364`49.69897000433602 w-0.26099358043341182479150583212595244579644043829518347466055910669839082612653`49.69897000433602 w^2-0.11830872671491631707941110507552282421011367577171306931123369024601297511964`48.24371993107274 w^3-0.04752268338157970271480429250850948680470885737239346619616865180280966819168`48.24371993107274 w^4-0.00696153913279444199192447546252701098344881606644971932792669403426615589381`49.69897000433602 w^5)+32.33203529229563025718873548979052289104947956670006536822263078513622511031895`50.226952876165214 THRSub[2,1]-8.39521766007794201301316899335881374694805383481232274359728802179742364365374`49.13810883871674 THRSub[4,1]+30.87481942194277567205313223004039615708962655401655851163156883864202365371288`49.819467549586946 THRSub[5,1]+24.5338426125105587942376484174091405950557859604686712546191610618415294465927`49.18320871186572 THRSub[6,1])/(1+1.45694006403592365446524401242343732572255064650950163755046177198356205804826`50. z),((5.52790338460620616291606114929030609653472365449891069237555476659639842876596`47.95233813662853+ 17.13245400386091220183634100346434675528681886172387979981135458280328758917045`47.95233813662853 w+11.80241343961263284607846925628809656865778217635867626331383384775378372631077`47.95233813662853 w^2-1.07443246445723643775684643246136513239874646046582044432884878146663090137545`47.95233813662853 w^3-0.95758319040573221333711852127079064309666153318469946276856815173485083183163`47.95233813662853 w^4)/(1+1.92065073363549591223988448057963327071844877353908614207622699524248703493828`49.69897000433602 w+0.95164019308899741413710249334733490062544705917166958555416709835277391447291`49.69897000433602 w^2+0.08267299313383705890473211219600432401310850936081572990808541784576550155867`47.95233813662853 w^3+0.02379026480472466677191993039184757987148503284983565346260206239052155552223`47.95233813662853 w^4-0.00874596695861975248657324897077631314115813398852825610322166384508243364154`49.69897000433602 w^5)+14.5385062369071083410845049723881305932482989538266673374932866193857954463754`51.022944907098974 THRSub[2,1]+3.46713504351440593105631801824278111825273324043660927688894142203619613230866`50.060009720781586 THRSub[4,1]+13.88325079665669741923231052718088198825380794815249578292570848955504494785501`50.61545958052069 THRSub[5,1]+6.20385068317097824133257732570178452097731962106151217019312395332934894639914`49.846928627837066 THRSub[6,1])/(1+0.10479399523620363092427784771181074329113799754081387028570029772303439445444`50. z),((7.1691271602071590598727736878589271571044382455252590323317030569402053507563`47.65860217226104+ 17.78079771071839079810832269109263906102032556220712255922316340395272689034332`47.65860217226104 w+7.17131061515821130048488568976584291091772296777468303252010051763769892136251`47.65860217226104 w^2-1.91632840079385800702320958949480580655430905659332201928733001972030582073786`47.65860217226104 w^3-0.37818820494777571634024012891646454998607405792190595682494846931595722963435`47.658602172261055 w^4)/(1+1.42409817140672277660206786919539908701390711316289917275993349666833768395384`49.69897000433602 w+0.45802338441056894245092826847165847799890379500834939028643743216720985316`49.69897000433602 w^2+0.03044455011452950839596218789137882011434778784091983023457025492010353804483`47.65860217226104 w^3+0.00852608392937483453536441593072497261548974043660294662676202141707347508274`47.65860217226104 w^4-0.00737887455003274081692600421983231003591878039817778996985604769355888866992`49.69897000433602 w^5)+16.17214120008965653830213306698736375794777808958663640033894238798874107172897`50.72981615414221 THRSub[2,1]+2.3780450680593737995778992885099590084530804832632965683251709096342323820729`49.522048740069195 THRSub[4,1]+15.44325727424619136156254666236177897071033416230839647840329997765569314917595`50.322330827563945 THRSub[5,1]+7.8867386362808079440027793570259336183174174183073375758152548149705473406335`49.58765206163244 THRSub[6,1])/(1+0.22893536631807563334934495219014763009951104558698812322716815652969539684007`50. z),((53.18387746810151624074505617351922024616510083365059119319838885171961068396567`47.76413811733678+ 73.68342474448918512172952017902415378498483597089319495255042417769806605859565`47.76413811733678 w-36.22920364286982660571509362471200312429356411889271891371258349522516221255837`47.76413811733678 w^2-38.52238269336593466617408322198720057758228329892127875275693508138052483267132`47.76413811733678 w^3+0.8956183590746133627413983156237481167375903917494998922192510274430351664722`47.76413811733678 w^4)/(1+0.686410373513159447079739025812145393432210402792793431272296891645261380791`49.69897000433602 w-0.54493254506052104484995627656297989928244330029155335496833789147169372436677`49.69897000433602 w^2-0.25181149646975823509903454769426738342195194236453315860327647492380569181787`47.76413811733678 w^3-0.09755797696758636650220435693305104651498489585470201505975142740008133547495`47.76413811733678 w^4-0.01493461643861055005940002164091553167932202391124535117152411731484977531135`49.69897000433602 w^5)+61.97412508712316701247926376596835913212724286245526840839380925668500558102493`50.10366020189502 THRSub[2,1]-28.15661085662963318320685451081070457433322936531579143704474033616327729079101`49.20771481415069 THRSub[4,1]+59.18093010846654428228762196560163496986165853719497160176891301579969936091365`49.69617487531675 THRSub[5,1]+55.06962137885961976398571608575797116348703258770637807500010685190340853911854`49.08994967188996 THRSub[6,1])/(1+3.70946878176921405804341903416876645627513007874935705186682335418733353088229`50. z),((39.19121286037107168303629997444928893954503009207469452408111204317896638765363`48.06062744914901+ 57.37833501591273121162463563029129104773641889558045518979909524015248893745811`48.06062744914901 w-20.80823501770796702240966930929868419779707295003924300233429000169350646840516`48.06062744914901 w^2-24.71883381595317583571135326694170526986854307598172394805078155234659411004642`48.06062744914901 w^3+1.24026198028857219836360676470503904338607723288424298051118617197497233252507`48.06062744914901 w^4)/(1+0.74516323263314010507551840841057383640880274752011976997945843517464531144416`49.69897000433602 w-0.43131362333616137417143810734173162188092033662870482920328226984821368647604`49.69897000433602 w^2-0.19282874346787107179694602866475977746698963475766461976249185796606949262159`48.06062744914901 w^3-0.07644192403039746194291474160382627768063639865300755497929800764046649440213`48.06062744914901 w^4-0.01093559253929643579931632783057694796535500463659634608438665602513883016663`49.69897000433602 w^5)+48.04616080150622271658818988670029434613919840914681886007504569915676028862986`50.13899894588053 THRSub[2,1]-18.871301332885003652612805257965328050341199729776825071498897964477780429194`49.19504421426864 THRSub[4,1]+45.88070392888665161918456573807717460509702893538311244603980488896515211571207`49.73151361930226 THRSub[5,1]+40.72173838427319040267530834074906638300516704466401233883862497463673608162164`49.11657347238266 THRSub[6,1])/(1+2.65107041140902689238498029855957900019759923201589617211901730728743464190494`50. z),((6.33651815624398718450768076089618166083000002845716069256698610803778441355432`47.842335089880336+ 17.23718986089757204806569552730045377427052197298252112344737554988527119735706`47.842335089880336 w+9.00763632453763795304220467828199749188848185209872357143760039332307540698067`47.842335089880336 w^2-1.47794248582379150010209905513406662289955093387000280308717999818441951610004`47.842335089880336 w^3-0.61782145915096519278569664336625125062985628611638340358180796682317331054892`47.842335089880336 w^4)/(1+1.60997555176377690608992347323454887902778607629426594815912965110942766772659`49.69897000433602 w+0.64814196476593956860537091688700722542355626096178148808822926623073046033056`49.69897000433602 w^2+0.05283860712361623978267637127591291495559626955919332641790349764363041183244`47.842335089880336 w^3+0.01508529185756927389166407912374238576439921788937932612136079103211501003648`47.842335089880336 w^4-0.00795073735706379724720773651102717338772014681429589786451291870668627437509`49.69897000433602 w^5)+15.34338207549265317364550180676157917134911184534191337189607361452374854858167`50.84668645424566 THRSub[2,1]+2.93055115112404270934898679532714873285219131275977858728708342527756073083793`49.76889095228951 THRSub[4,1]+14.65185060637344096256793369255804486214642367549250077122021277681488930959272`50.43920112766739 THRSub[5,1]+7.03299298425518122456463157488730201730890632773324327583815221304092718817256`49.68904644862945 THRSub[6,1])/(1+0.16595722472415858210978757371251286648837676660036449556451507211025637205968`50. z),((15.4520268806433123498472245732591604154493653205104779976466674449246797417177`48.22641343902554+ 27.48428055046680544901638008010136195805431647823970065545958334370991131162654`48.22641343902554 w-0.97952894307289871443627321077153705224692305659429834753553251241659038082418`48.22641343902554 w^2-6.68107132502666514868598886977051982799657207216632661624155503871049021915259`48.22641343902554 w^3+0.64774817242278978604898651692095213764673948072511383316318226587260626494644`48.22641343902554 w^4)/(1+0.94380820871718125306280566242297253628741465980496653525749224014333637986184`49.69897000433602 w-0.10377411594221821019654874434022590375202943017279541700272971364152807296786`49.69897000433602 w^2-0.06916536033462864295795951435071204791806391508780437108937878830273405561676`48.22641343902554 w^3-0.0272535638114907307115451493173193764312313187338432921535406582001352472603`48.22641343902554 w^4-0.00584484561279017947614244062399334739247945587961158164511686817999089259544`49.69897000433602 w^5)+24.41674183347058437707191947616216980564274589469735246486351258690050759336644`50.33625465578749 THRSub[2,1]-3.11835535419457809293529165093991169001023138681051414135787588964027863235189`48.97679832060189 THRSub[4,1]+23.31627094197306622727101059191963775741483022214830195122917513953695085881408`49.92876932920923 THRSub[5,1]+16.3799084060367839159094088061659645363043436554695187764278908573028377880859`49.267210236712835 THRSub[6,1])/(1+0.85544988744246810501371268395953673121953130218475075878717312354533291412966`50. z),((12.52776663357156998867470926266380366446233903663320179185443230715968920842539`48.12147348379938+ 23.7856406871195561797467133106727416626202511566277503727623236013673100273555`48.12147348379938 w+1.28371909148598423452386016871101579933863828391546208733925111343536547171953`48.12147348379938 w^2-4.91718322201173403145590043447918995004102011312321835464443940675936900343341`48.12147348379938 w^3+0.40544114738746865734611793141181131967067658974400384502190579587179735679132`48.12147348379938 w^4)/(1+1.01906422871710852366528102572810891416311452409022874862884467798524723612489`49.69897000433602 w-0.00302831804895154100734575524943025349739938543034208947879747451880712889452`49.69897000433602 w^2-0.04506556384411680840076956049092009605176197068862724356672624084274172475817`48.12147348379938 w^3-0.01751801773414938400167563006458428199198066105573908691102722038254202154619`48.12147348379938 w^4-0.00586895064779825340756061385868341106023902935857362522066503981199525156897`49.69897000433602 w^5)+21.50600299816945781894665859148765267180521969800858543726567198378796064108881`50.41105371919286 THRSub[2,1]-1.1778627973271603875184510611569002674518805890180027896259821542319139975003`48.70613723456907 THRSub[4,1]+20.53672009984674318047257800925356006513656990879079187388884975858659805947507`50.003568392614596 THRSub[5,1]+13.38141276228884056419871796250344203369671334954936254431320950206570937346046`49.32574709149468 THRSub[6,1])/(1+0.6342602593926457543953762085262098226794469521033050451182795415271873958939`50. z),((63.66358067001917965480166340074953042631952893798729962235877577410116454063619`47.29205245699876+ 84.71207383902611086821268055782626565231462907384188805840788499429898519643765`47.29205245699876 w-50.68965995876296628482713150691892887123090514566310473021414596668966903044386`47.29205245699876 w^2-50.74131366048344811884027083726445225115184652406336504536954504661100755258666`47.29205245699876 w^3+0.37548784969394841542098232653501830891274807297859482941794810689141217708911`47.29205245699876 w^4)/(1+0.64074156185166669063985259439042760688404958400337171865011666704807884592395`49.69897000433602 w-0.63100908688177083108320302444051420710629259191149984920989705619191210999558`49.69897000433602 w^2-0.29734755444932759523163703359046790532992928834078895174433508196375969416026`47.29205245699876 w^3-0.11306403120832038065461283765745910547806049644612356758908504039159856460789`47.29205245699876 w^4-0.01809080556322506160059705715736188369714015424437746165569317526075942378422`49.69897000433602 w^5)+72.40537145884972014591557694860184073248415199652283440049598111061002638014969`50.08711249261637 THRSub[2,1]-35.11077510444733527216439663256635897457116878802750209844618823877995782354146`49.21209785976286 THRSub[4,1]+69.14203664448461986242536145118328370620154890344590639818008239661450043851523`49.6796271660381 THRSub[5,1]+65.81536277796655173639289634515042605888528782988973325531226001793992728555265`49.077500459021756 THRSub[6,1])/(1+4.50214845370534580588517781528716734484774177972426602204489454098474449867714`50. z),((8.31786708266133591597847078304898895518492677869382205714195952675063761716402`46.91325904727703+ 18.85004807468628485690032646119306361101030233591998750401622420624698846089727`46.91325904727703 w+5.39862817296999427540172968352018288397519837028836821156868263992034962397562`46.91325904727703 w^2-2.53677640378074453940552418188297252930059211087256886294880100403332890288467`46.91325904727703 w^3-0.13652665146983634878752017716948449930270709191427931752158872737830943220148`46.91325904727703 w^4)/(1+1.26711380146212701164680832638520897474406529656937726719410345151874840907368`49.69897000433602 w+0.28960151177998145736647897743608174206827617058639207600889979547537723037637`49.69897000433602 w^2+0.00725829240639034847627236045770082480224138026187456945956104242691288808848`46.91325904727703 w^3+0.0013216643741761010226197471019096620914610170861481004187365200664675029`46.91325904727703 w^4-0.00680541974692265177276713708752827663615316064942467528625559450093708855172`49.69897000433602 w^5)+17.31556949355171410203522067385660133313906511818535453686980426483362996201674`50.61975110889381 THRSub[2,1]+1.61575953908466875708917421726380062499222246419748447730459632507097312188107`49.19523208973709 THRSub[4,1]+16.53515086409989198860652244826698554799534852968019276384892133955131415141805`50.21226578231554 THRSub[5,1]+9.06464051992040525637795549166881088418756492579427339006145339377679062089484`49.494788252530995 THRSub[6,1])/(1+0.31582549739586114819921790088018641630929489084681164280214749093588444877422`50. z),((32.52236737929627648324723876319031059363044669138992238827782762948507926554513`48.155473159283055+ 49.18736502137297387598039550000524377511904649128225523202250673146218036820316`48.155473159283055 w-14.58092479650211011732498033274990762682540364601240205566539863966969659017119`48.155473159283055 w^2-18.98423251809562423065529367789794789702350569095130305614677041438992482778802`48.155473159283055 w^3+1.24741402447643500437852673276040553850901261838152436908670345145914723465345`48.155473159283055 w^4)/(1+0.77803872730521515696496158969281476682413484878964968167981773337918900224124`49.69897000433602 w-0.36940253280843865004212843081414431984118893424578267307619881729841038901858`49.69897000433602 w^2-0.16321119063672307813857074750859908924780165076997624245705250702223565171243`48.155473159283055 w^3-0.06528334430056910031800704609395342823723097409867831540037506332960373591784`48.155473159283055 w^4-0.00913152984228990220542801276614827171545349133125978496176842556504184757476`49.69897000433602 w^5)+41.40815122358830906056834860420801575158048325247317747684035477327384616150583`50.166087701884514 THRSub[2,1]-14.44596161427306121526624440297047565396872295866106414934243734722250434444495`49.18184045694436 THRSub[4,1]+39.5418717091847612655690106800125067710675238295463060546038905028573482208894`49.75860237530626 THRSub[5,1]+33.88359730436938571995292314926665175979158840672477099703471133013802230461693`49.137029887967756 THRSub[6,1])/(1+2.14664217081116341666795155064470298700872297998682207739758123392447144315531`50. z),((7.24121725773813023546594800276049236966185083330863346429535471351320546903358`47.63694903759281+ 17.83953575955400566552929210098619534014630832713008281000728256678577117921129`47.63694903759281 w+7.04017482652059876608277829694932345469964937510033529642146661443623236905549`47.63694903759281 w^2-1.95483658403811924024138190613638288163623542785545767647203042230759843246009`47.63694903759281 w^3-0.36059611802444412331530609754716044021609194181870639629444872383819840446928`47.63694903759281 w^4)/(1+1.41162670671376783029021725699959688819255520410231732811070402122944542175348`49.69897000433602 w+0.44494921839468604021394719071114159203493628826489072085959809971771709097951`49.69897000433602 w^2+0.02877067595848042075884961161837931510854535525268519786958929255743218077855`47.63694903759281 w^3+0.00802379933834745104651120719676002931526760021954922190646082899027758422936`47.63694903759281 w^4-0.00733662397284395533546340707911707364530171253610898835103728289816268382134`49.69897000433602 w^5)+16.2438979620721667972374941270187690050356919661656331625041260672888745485185`50.721515978065064 THRSub[2,1]+2.33020722673770029362099191515568884372780456554396539354838179010081006421324`49.5016863438713 THRSub[4,1]+15.51177993446490195552560636504212625524403680539749866307174612261420065830171`50.3140306514868 THRSub[5,1]+7.96065881613499115771253718115522571401757185364161106661436965510550380621201`49.58055871577245 THRSub[6,1])/(1+0.23438822636188271584147617981576275402127933985099192490722837291683568820682`50. z),((6.2787937902891061549484755448079748342139762651801029405654256417182186722684`47.85186622718746+ 17.21170169726141407248146756564078545242494296132748450405724710830846541332362`47.85186622718744 w+9.16409937833187345421333820547659869039850000800813242193113190960307997588334`47.85186622718745 w^2-1.44814296602972206087378289385232764542313312085483475850880243795880442193333`47.85186622718745 w^3-0.63762569768275348085550396254105198748364935278259395422451263083216672462214`47.85186622718745 w^4)/(1+1.62663271661071007771983245152701162184876991237029524657905783225388988062243`49.69897000433602 w+0.66480790792231542019325942505287826733228366749379955017733596426319129435453`49.69897000433602 w^2+0.05464688775125047832654789749116476097571869562943369327987862033252030004479`47.85186622718745 w^3+0.01560747314107838773570403299252573166831062736845209093869619474805166247577`47.85186622718745 w^4-0.00799749292876521662286015868583602812325406028501337018943302353446985605186`49.69897000433602 w^5)+15.28592461974935650780646834144577480827277505216744400414592462534566825867076`50.85663611233026 THRSub[2,1]+2.96885612161957381990834243887101830823641584154275816578718275139628092411178`49.78733721350069 THRSub[4,1]+14.596982777779264108537989026969208941934547457756844326747690237309240597522`50.44915078575198 THRSub[5,1]+6.97380322505808318174386657211148384234245399565962106312439431709331260206067`49.69780570978581 THRSub[6,1])/(1+0.1615909816554175396764742701460919360021546669531476022732198651012032307632`50. z),((6.41770163495671813995234939388480848494056659036928391289107248196213102654209`47.828385249032955+ 17.27636551184699526541170533367146576446586775699043619586078389987474048314804`47.828385249032955 w+8.79554508223156089118939827259050973778985023099034954332430759806396650811166`47.828385249032955 w^2-1.52002031487319805724619435179542149115331423283491671591393404425019103826386`47.828385249032955 w^3-0.59081995857279019140679357532952781558666568829920019377118319657949098302188`47.828385249032955 w^4)/(1+1.58757473376480862198698543838140632576505814477879692902072540984399557537658`49.69897000433602 w+0.62564370689283182365994553265743668024997307758782559234221848283483379309634`49.69897000433602 w^2+0.05036121810340886733534188463690641455839302669651166405799041134978588543698`47.828385249032955 w^3+0.01436916531563117216774217566303990858123761800608995179431726708730256020602`47.828385249032955 w^4-0.00788685360110122810709494091307794518730832392032063745611352994355880595837`49.69897000433602 w^5)+15.42419017200547730697414026755472670130303766919268633596402994026901839710952`50.83318830889738 THRSub[2,1]+2.87667908678215995379656115479838371288290743019259661124177920811404749848596`49.74334871081665 THRSub[4,1]+14.72901665438461842779293885284530846382348064978737771223297806273915482640768`50.42570298231911 THRSub[5,1]+7.11623739025775528734536169430597156355940488696668091130107233088626622094783`49.67719433285618 THRSub[6,1])/(1+0.1720979037140812884761451420979859956887874458013089602271268363154789535954`50. z),((5.75527561041971141875534222553911967617035557715497022300462327346425140863618`47.925890981562965+ 17.09503041557681000371439300279529700242955566941312257993292170352791061209969`47.925890981562965 w+10.85677352623486086777040707513657216484460904208852140810725784458551295819714`47.925890981562965 w^2-1.18402429139253030294437814149208335520611209679423554493948389703590951060515`47.925890981562965 w^3-0.84579979414252614111738314805504880495675670487300538605501148134107737831649`47.925890981562965 w^4)/(1+1.81285067397128778194093600887699831084004284229725152563642852741211669514331`49.69897000433602 w+0.8479032945921190076480533998054372639667101888193887758228075866245438312969`49.69897000433602 w^2+0.07315331043068820424375613214439743075043667493814310693244102364592436487481`47.925890981562965 w^3+0.02097224008598332816329363655826961397490159726124154859254946623509754120436`47.925890981562965 w^4-0.00848506736417132450558136976307741111287206315947522000317329651013119970712`49.69897000433602 w^5)+14.76482712213165458056694581162057434820743157694165197085241905559556476182547`50.963657392891065 THRSub[2,1]+3.31625445336470843806802412542115194827997815835995285464951979789634992200866`49.96922174330789 THRSub[4,1]+14.09937132230721761534178793996321520744637338768044185426423362847269438420852`50.55617206631279 THRSub[5,1]+6.43699499010938284557191642651997831312369226966105770754114869534952838335678`49.79320442222314 THRSub[6,1])/(1+0.1219923202166531549259553021323726580199248012846884290269158452311523324254`50. z),((22.5865347798881219616978880251145275471415595700317628018159515525584083552013`48.24823554601606+ 36.6312514123629851286695974871949959072691736418525374699449326610738695102159`48.24823554601606 w-6.36080171549936685059222512513421941634409477882594656818151083366791459715441`48.24823554601607 w^2-11.40507298911496092657382669688953556366117279877006737787390119545994225756531`48.24823554601607 w^3+1.02922333726722263601805061801412448693282734400171189155253162647424934988805`48.24823554601607 w^4)/(1+0.84742214975867151536716896148302218672478796880132717854757167448129532176463`49.69897000433602 w-0.24881838864767930998778290230588036799785383379443203843415109022150499306923`49.69897000433602 w^2-0.11386443236572290611836211176258539286282785800510696280070798228291132867207`48.24823554601607 w^3-0.04571159406224343436593132709486398086298279157861541837037239470732339104116`48.24823554601606 w^4-0.006798738599603591694191504785351736657629077655858424561047658974402597224`49.69897000433602 w^5)+31.51826066507580866685163704771274201416334167773090301758179726502801167520195`50.23471823305362 THRSub[2,1]-7.85270124193139428612177003197362649569062857549954784317006567505861468690926`49.13080656376997 THRSub[4,1]+30.09772189503398139432012838044611717735558369138801184714985960825342290867824`49.82723290647535 THRSub[5,1]+23.69553323032965820334599481187949680929289432917506405153620437242810683282106`49.18912652624272 THRSub[6,1])/(1+1.39510060769991277564935639617522584322673535896006208344891395492370660706908`50. z),((7.14702472840778440119931896181042189637195351681983671266277146671334908758686`47.664992518409626+ 17.76308234649980182494246636721496246199790714212404507138437181927677365867555`47.664992518409626 w+7.21221558333423453036240036000465423965770872657018946001425127379905230827995`47.664992518409626 w^2-1.90453586679063077237701992884629483452787154567518093338265256961907017632569`47.664992518409626 w^3-0.38366379864051508101559862928531489666630850181301356455841826857689004666696`47.664992518409626 w^4)/(1+1.42801330031897907111985302305475590377630906864153749371887113612523038974969`49.69897000433602 w+0.46211827864764389712895582279298587803399461374202842120590826034684348743078`49.69897000433602 w^2+0.03096490265948211787832512082579195809206303787618453373637774588110341669282`47.664992518409626 w^3+0.00868177076963472259551526014673996709419339753154169761911204171681111831843`47.664992518409626 w^4-0.00739202529964557171023522330090383701338127861021758221288324032629376892482`49.69897000433602 w^5)+16.15014096715640214445246649189165171899929514433139188471439458184119282041429`50.732408050839815 THRSub[2,1]+2.39271189001487672881101033857376703441873578010012624540820278039926454961603`49.52830816423406 THRSub[4,1]+15.42224859932318809366231685405662164525949920310111441084500010488826149998215`50.32492272426156 THRSub[5,1]+7.86407511119509590057814161848246936225954498996168765598617792017222667841372`49.58987008735069 THRSub[6,1])/(1+0.22726354908717227648555319300226606681455803637669756601760690111547036065975`50. z),((6.43845228755615619017399183199878807575066066328473031512003698606288256639873`47.868556749500215+ 15.43096255869445918839235528587005883297840747537871762635607092067221781360636`47.868556749500215 w+4.58820464463656004576168825287304452671826865110987683471507473552495700248357`47.868556749500215 w^2-2.33311447322796804744941970690842394489036510388474521961885018952560190031247`47.86855674950021 w^3)/(1+1.29376230941380931311659899024403100640508153381518154319157039562213721912595`49.69897000433602 w+0.29272988017376925826306796695459844437124170338414496616288297375547018180466`47.86855674950022 w^2-0.00414585235087417232722618427858307074712519029741724720825983722725955834027`47.868556749500215 w^3+0.01394289484088669713678580213128199538771753518773023675255507588180334342502`47.86855674950021 w^4-0.00795226024020516239518317119492357164245590265528575935216017146244509995893`49.69897000433602 w^5+0.0012114190017383448318716531304619775159369551365144689636589004180801660564`49.69897000433602 w^6)+15.4448448761958820084285376334624938597970903741511005495909432871053648115924`50.829826583672286 THRSub[2,1]+2.86290928398855681949362957752653894055353896022032046882383697688981655549737`49.73689011861892 THRSub[4,1]+14.74874044400464118209508389515766087081699549077702050209020659479099220722541`50.42234125709402 THRSub[5,1]+7.13751481981849555529492921708020995587538164175570933315148482119793532795908`49.674248160162755 THRSub[6,1])/(1+0.17366747302134690717085899924407808358554286961046565168367463763251930898519`50. z),((8.3665026157833755977353250197537082407765278081870881679880226111757523544834`47.613449330983556+ 18.50540569480228885996610171288836750897514396107667486716386873381145901914079`47.61344933098356 w+4.4750322692766878407583628462324100786093801973759145734009879013414909879423`47.61344933098356 w^2-2.75184734390377134159582839281540646634716869693378846054609836515262183864717`47.61344933098356 w^3)/(1+1.21481458069956145623092556136217445291257175016671789962701485379445490672989`49.69897000433602 w+0.2281990109677648552714620306449916794207557789295345022769943277248481964003`47.61344933098356 w^2-0.00321126439183928511269124365143839581534191811080944704532333134761356564533`47.613449330983556 w^3+0.00122733533840337011118263201935511927330466993094630911104539386136928608719`47.61344933098356 w^4-0.00669219074412033461981996670682422396296797017473805772866812263458169273409`49.69897000433602 w^5+0.00027918582744237745327089989324264473112907192409754390863678772843052118378`49.69897000433602 w^6)+17.36398014208262170444631466719015564338480053429109938145714004261047970352643`50.61593413790196 THRSub[2,1]+1.58348577339739702214844488837476441816173218679365458091303913988640662754134`49.18069861201288 THRSub[4,1]+16.58137962817176206461577145237102651280787490182025001408205897701412256673359`50.20844881132368 THRSub[5,1]+9.11451071678261257242930821407708188664656138354889125517322945649137748232532`49.49161457083233 THRSub[6,1])/(1+0.31950426555339471702282925264417159190925563443833567581012122161476295898446`50. z),((11.91681646214050276479500796589233673896139013561165488132183580290192872404829`48.510055420713734+ 24.04078972534447288898082540171459868324539947825108114935038805233511392940644`48.510055420713734 w+3.91365280223880262041612376323919954946713461145060801585481237215393785375695`48.510055420713734 w^2-4.08462606730790652285835427161246026447800005015195702223887705230474596920025`48.510055420713734 w^3)/(1+1.12570646787385422419232249779300554650766217953064376059790254696224427942451`49.69897000433602 w+0.12720626415345298785040464440843773585306931286163282852868078760462841502005`48.510055420713734 w^2-0.02259291183500970461718329563658873563051117082566832747186120265735462999995`48.510055420713734 w^3-0.01648491647793453534158168981077185331773978614134522941166172057044743310565`48.510055420713734 w^4-0.00655994459090322498098414004867521380267031104405007834568050931368244730804`49.69897000433602 w^5-0.00070074164082951597338744841480959596235747119360194526474849831166988662878`49.69897000433602 w^6)+20.89787778352789658256589640518597969357555122408467647991745283351208883722566`50.43145071564198 THRSub[2,1]-0.77244598756611956326460960362245161529876827306873015139383605404799946159149`48.561372195372854 THRSub[4,1]+19.9560032962725972916953749466558951752588655347934604658478222079648151920163`50.02396538906371 THRSub[5,1]+12.7549529834721125054255551128611295138845370212396728999532155735561697991941`49.34188257633925 THRSub[6,1])/(1+0.58804828447997047896882663437573127599837963607724459009999186672805484987005`50. z),((6.91588864662272981352808411444659919896718090069807584860077964170810902731347`47.63697015614693+ 16.18919843165457229207933394740323058785393809363505875371515744373274854890397`47.63697015614693 w+4.55625366135567080645766158447197538348494953306798103860054286260724097174807`47.63697015614693 w^2-2.4102097509364105318946410640239317833208184191917401028639518823189417639119`47.63697015614693 w^3)/(1+1.26966720081395706643500578599987707296609715213908991505841313477226181895125`49.69897000433602 w+0.27506175355081453801137917010347570389553158688764673532434699497730290294943`47.63697015614693 w^2-0.00250062793564457172932378751768818648015526400147715269788435696527822602127`47.63697015614693 w^3+0.01041452451786882331407425072984926970679734973424468993945909546407658600509`47.63697015614693 w^4-0.00749701105008957357462633812700955962425202973612033042800918977372531352224`49.69897000433602 w^5+0.00094284088658808730682571221254776381694859602472746133461272859674432997555`49.69897000433602 w^6)+15.92007362955716070810433424376931296621297491901670707638058102117232958403248`50.7609414161203 THRSub[2,1]+2.54609011508103768637643183732199286960961593030991611763074515417850670720399`49.59439263286374 THRSub[4,1]+15.20255047518572123636215359000943164641432938771862429226116685468351375205347`50.353456089542036 THRSub[5,1]+7.62707139887521518189309583630532289852137721873169308387723248234773298470239`49.61438101437429 THRSub[6,1])/(1+0.20978052786492492912385167221435730413323174353122327605493999264493198642155`50. z),((8.27442636038473337107240003919886979405820412279053766527168983845446432712826`47.68451950388787+ 18.35871124818084082471619879061178818794064285698261978608715354802325147958337`47.68451950388787 w+4.48142244143557606245003576324222976201218456406741206834787153040272388235249`47.68451950388787 w^2-2.726024941041155773340807008835109181612037284488533592872369823932936871724`47.68451950388787 w^3)/(1+1.21776386294412255733260299719796741836250278557480289513578647504886134898928`49.69897000433602 w+0.23099956440758476891541090903170802831363090118057010928932368209358140012693`47.68451950388787 w^2-0.00297581806306353428631137255370262216695492820896285258409326458957296712979`47.68451950388787 w^3+0.00176146872956883819799325580852277055649357669623992918412918090976868500611`47.68451950388787 w^4-0.00672392581469757086148610354906705731645372932374180709324872515834781608927`49.69897000433602 w^5+0.00031555014776305990683858610488269405555803579659120064212651224087751931344`49.69897000433602 w^6)+17.27232963571393949270801110077417430152941786783843549067315359349123468754785`50.62320729731069 THRSub[2,1]+1.64458611097651849664064726598541864606532063109543050810236343929923663819371`49.208120872945045 THRSub[4,1]+16.49385984141905601391300001254534528755513840460369139309363289010780673991623`50.215721970732424 THRSub[5,1]+9.02009700959566865144258380369170908181185656127927049236170469106374834702369`49.497664664851 THRSub[6,1])/(1+0.31253966221337384363012138957351011768061828349519034136116879963982502624841`50. z),((5.80020039663141188815339822379867518751228633945439773568963051452091594863148`48.20459954650968+ 14.43347349739617335904226286495531484591751948117363670851762333780665313796749`48.20459954650968 w+4.66388656966389438359779162050012272903170675031963788450766690685510047449084`48.20459954650968 w^2-2.26674132925980203372464435836618555634562417065136614706367992438993516513586`48.20459954650968 w^3)/(1+1.33495274458781358275308707454030269049352025846506577148572465852540323912294`49.69897000433602 w+0.32020543220076808214273988207565485612666123282692980852798132348942308717999`48.20459954650968 w^2-0.00862073469920055759746481196814794600973460848056209176444840227709912475706`48.20459954650968 w^3+0.01933250682880791247178246800781723686722959974820593210923739387495706930016`48.20459954650968 w^4-0.00879205535230707842527295466418501342427652152600875600139781939098451452755`49.69897000433602 w^5+0.00162223138388420731034311011868130498860517591049261662208357162611652749021`49.69897000433602 w^6)+14.80954418177945446616559165543485257809457279070246088821497916840812258600706`50.953038889794 THRSub[2,1]+3.28644308026617518100226022954496646168855068251941357640781305602131137255414`49.95231531456285 THRSub[4,1]+14.14207296880811249581453258251392221115225144315308977593604531597995923308341`50.545553563215734 THRSub[5,1]+6.48306023888024120022176183581496961563392944736500449412843274831109865300619`49.783645849938495 THRSub[6,1])/(1+0.12539040927604323307281300320404855314521643999363908448952456811957473096641`50. z),((5.93951768245647096588507061205632263748919975815735851704477229833632684598101`48.132529660296065+ 14.64877497123924925163517666609698765404278305706506951953929999160710850552583`48.132529660296065 w+4.6422342409710975733061051663325347047301260311826990660365937644219344033751`48.132529660296065 w^2-2.27703722947283876602895436795672896406268722223116323072396911891296021998777`48.132529660296065 w^3)/(1+1.32479733973742471524655477406951342689410876235293050520357791699845223239037`49.69897000433602 w+0.31368338389460639386105532217079754244968212050645451344329910034303725673797`48.132529660296065 w^2-0.00737272475718262047268508885049719017954729956731314584510436685942386188105`48.132529660296065 w^3+0.01807196493018657777968221153509457148796523599676903383194650329630668334762`48.132529660296065 w^4-0.00858110106801314420326323018191367306218451610943406312014215727405244042452`49.69897000433602 w^5+0.00152673322043699004796834449768081267319699863055603440887358357304050717445`49.69897000433602 w^6)+14.94821728198858160301258794098646908901988907923424704610345074259759327305679`50.92204103054619 THRSub[2,1]+3.19399434679342375643759603917722212107167315683155613781549867322833091452103`49.90166854715034 THRSub[4,1]+14.2744960250410744677173327645958359999849146273706499644817981970277310436914`50.51455570396792 THRSub[5,1]+6.6259142393282314434144261462622540305587071690890133939224591828412254102766`49.755856973871175 THRSub[6,1])/(1+0.13592830126544919236052679360584601137864418442551814974188631713139628936426`50. z),((6.12590265065027519253537103382564016868314762269541321545305220651192189500619`48.0345052687137+ 14.93923167666261304136734288407233336624042926589292894187030398485962642357898`48.0345052687137 w+4.61841049802893556970162171692763354879875528658422957834324570692458684552275`48.03450526871371 w^2-2.29468393234965826370485257863449065555934266536939987394378969923019951824604`48.03450526871369 w^3)/(1+1.31232783723992065800789685711092129636323496039755066288250421427971534994116`49.69897000433602 w+0.30546825294086262408140869449328697562435996846897953695820152736322013531744`48.03450526871371 w^2-0.00595645130715344444173469421708241203095997495464600182517386105010616293742`48.0345052687137 w^3+0.01646534838376019476107318737346931516520992856989898468891695023643269119843`48.03450526871369 w^4-0.00832472855946351065435375700285001894333161902379906796040163281264342854485`49.69897000433602 w^5+0.00140432024845163809225856959847813197619139155052973003103757637810614565843`49.69897000433602 w^6)+15.13374042952010886936829996059476087279035214883370960043931706819170425554122`50.884540197633534 THRSub[2,1]+3.07031224843907224553378802610502759855803111043191443492492112283225692619819`49.837493294214134 THRSub[4,1]+14.45165758096673161600792689224775497408572595420957754560729582897957738378351`50.477054871055266 THRSub[5,1]+6.81703078435833245235027068149438050794310076121518789371933010943595635343076`49.72247351823403 THRSub[6,1])/(1+0.15002636994115899053095589280831308801936338810131832740432446021604846651632`50. z),((6.16594817632230548840681110647914060930753352223588653753373167393309762977093`48.01326439422143+ 15.00194281919728430633368328435434571671493591958007296453157064477491747295728`48.01326439422143 w+4.61393534637035828751744126885535339380797490711476497287406774576070415718825`48.01326439422143 w^2-2.29901385233271718578388917059402020471732507446903417199977335237449915744565`48.01326439422143 w^3)/(1+1.30979663227703852573165928792534474230277906257519732642559878300582369980291`49.69897000433602 w+0.30376953445765831896229389866771970603631973431256142072366259599837084221289`48.01326439422143 w^2-0.00568692079421991199102803119689734508529561558103583370451452284662831191008`48.01326439422143 w^3+0.01613088260293200229482184039925591055582850390471440692988196933103986522532`48.01326439422143 w^4-0.00827318749419898608923714915517832229383610964506932992016485065275409526813`49.69897000433602 w^5+0.00137876947913027786096121122558704057183839458033824821570924757668764296196`49.69897000433602 w^6)+15.17360078971559702095546777012461885035939418098817877697449655397372124472909`50.87700153185033 THRSub[2,1]+3.0437386749754134778090094864184556135120030889956016505681347989775789334062`49.82416040019641 THRSub[4,1]+14.48972142111794381685031140340145821231973015664281389655723799494871278277526`50.469516205272065 THRSub[5,1]+6.85809290747115038621858918345503301752709447159463064878325123298658739525967`49.71579445217712 THRSub[6,1])/(1+0.15305539409772157981961740449487436956788538353504057635906901668804867231555`50. z),((33.32929180227193176481824397897215922366834827149626122685074001060003428570337`48.9563494778868+ 52.79190062715084507271806848699074184981359861585138507571785518959155373280834`48.9563494778868 w-10.63475951553638256506225323042581363539441458828860404050415300407029911063531`48.9563494778868 w^2-19.46892899409081594554833307019353964790197576047751443643945629773185500471404`48.9563494778868 w^3)/(1+0.85177376247461751958741045693406257492149508313851600662849204668534318521023`49.69897000433602 w-0.29455387890945424436096869371956234416648772890042141768834504445148741961697`48.9563494778868 w^2-0.17151880148658450020384378194411056321618250654063723175916594890478278803435`48.9563494778868 w^3-0.07491042554581123707319521611777996801805728175770167388605917591185732872144`48.9563494778868 w^4-0.01288296855068348974746713739830011002605489010639445194495716841984210857185`49.69897000433602 w^5-0.00107349144393948250679145117907204875244577589493557343391214182148112551131`49.69897000433602 w^6)+42.2113445294714463070589279198055615542863532143801442528294994420171241668934`50.16225506371305 THRSub[2,1]-14.98142381819515271292663061336883952243930293326570866666853379305135634803641`49.18391273755067 THRSub[4,1]+40.30886481852249321551602524523954729094146274482751474776401998994562334822413`49.754769737134765 THRSub[5,1]+34.71100634552746734403692912339032999685364373104786875328469469545766468632987`49.1341325773947 THRSub[6,1])/(1+2.20767754314542470944700505575362562705422564753767493930717985262797595725178`50. z),((5.63196700584117557599205290090797295807366194887210473235039777177912527643198`48.2900473737391+ 14.17605155845218900879877315922648974456921784614861446351066215620867325104455`48.2900473737391 w+4.69555713811100130806050662996836898867272316669930311167990104489213199772974`48.2900473737391 w^2-2.25797534944084987088472902504737899166616553712309993919010445760117390719446`48.2900473737391 w^3)/(1+1.34834135169746510657759072391566441114605435270736654685536107025804263766598`49.69897000433602 w+0.32860770447141381733761568084723450313137564358034764624741723323496327781193`48.2900473737391 w^2-0.01037136962698227360824175628834170980578682203036646916683835630596355617886`48.2900473737391 w^3+0.02093359600579332578694767390683651110220960973310130919139753063320899111489`48.2900473737391 w^4-0.00907169845135800544790470511742878882747696655558562519612570921195743274367`49.69897000433602 w^5+0.00174254932548686275417876894324592088261043672016179571537936914834641670189`49.69897000433602 w^6)+14.64208868103943498131595831208511555954295527576210110574169083542759076949322`50.99457430742284 THRSub[2,1]+3.39808008075952150423534912511145780738962902581298676472333861134166591689683`50.01728614785064 THRSub[4,1]+13.98216474466389666543263210808436410996002953514923866734735550041514284776483`50.58708898084457 THRSub[5,1]+6.31055606798006033865120149212028203697997668557126042068825367217122878152012`49.821146390468606 THRSub[6,1])/(1+0.11266531711924387596577916447455983734814104694682895271781462339828573179112`50. z),((8.04602589999708007082963758786375143953737682050635040696854394019244733218134`47.61041892491501+ 17.99442325798083987952574983109777771876449310672609471140793315407452089335723`47.61041892491501 w+4.49608246456631890360721523464190994529527760713071196838855898160643536442799`47.61041892491501 w^2-2.664217629809726248455713937415114256992321877034780742028209723907210853932`47.61041892491501 w^3)/(1+1.22532091585282107024712690001455823596013864281996236575258537444401809041003`49.69897000433602 w+0.23801876972689675680196979653023670407709398837388683750969825666595667277863`47.61041892491501 w^2-0.00248517350353396680132938107859461963797444543526190915446973103108044847776`47.61041892491501 w^3+0.00311021642418587654343033382192929490961398489881247642848739663596352161205`47.61041892491501 w^4-0.00681219162454534226983131949572760881077363920138506659841503420337243526964`49.69897000433602 w^5+0.00040882255632554139182129015693809692409152595883209915083494575540093617896`49.69897000433602 w^6)+17.04498527034265561515773789086455989505254215005989729885406006838878075369301`50.642148293476694 THRSub[2,1]+1.79614902122404108167416273925849491704990444294778930264842578936753926076354`49.274681102013744 THRSub[4,1]+16.27676196422147753695725620318505488882629727466259921789008557775921631271451`50.234662966898426 THRSub[5,1]+8.7858983652758968093572176532727506962630528169226584588188244115770028397994`49.51347404827611 THRSub[6,1])/(1+0.29526356206799790135127059573859219093996403388892557506987203408438912879881`50. z),((10.41312697505077506896696826488937186680851525463621062109017475253018477882058`48.274663870504135+ 21.72889997269281190499439012818148649985191309231545919533548421510471287041046`48.274663870504135 w+4.23401237420298745678684120447319185164458158677195363309826138610321517041766`48.27466387050413 w^2-3.44633289592397276012642499537519378537614131509006694327411511814540578985374`48.274663870504135 w^3)/(1+1.1591553303663220501156712395922300878717634438463774356870485296606947177665`49.69897000433602 w+0.16871339397789587851892372806317699323619632061508532466094048299545531804314`48.27466387050414 w^2-0.01256564869458837672151641821667261424756795901568092297150716589323122194604`48.274663870504135 w^3-0.00954991436376041635876787811624279221863459056249571003550334360500183383967`48.27466387050413 w^4-0.00641632571448721774216414633195372761021222924493336561293244317963708783871`49.69897000433602 w^5-0.00037281899596707027402063240506352776754238567258495812256787356665926848763`49.69897000433602 w^6)+19.40114116759607833811472036893594967702285272246761651899130739315688663854902`50.49252656725858 THRSub[2,1]+0.22537842305509259970284108721090172906969739467597648922359423952213533752634`48.13544329635982 THRSub[4,1]+18.52672511067949006093162947605355383803266236541526960942366158005896301813768`50.08504124068031 THRSub[5,1]+11.21309077024977786377025776967768106379795162294482444578896945779595519754598`49.39067812603659 THRSub[6,1])/(1+0.47430994033469127833017097950210735950005999332017780904500766716566369626087`50. z),((5.75537102992732038641602413929290404529455125292181902936066435332625196752829`48.22754086999612+ 14.36458084811181580030198865555429699738791234226456638684978970724901621659815`48.22754086999612 w+4.67168417621884918685207272514945086612383832257906648715484947333940932352646`48.22754086999612 w^2-2.26399692625249894221918920396183217098734723353818948185674007165823315321454`48.22754086999612 w^3)/(1+1.33839230662305798980790288932313790851983478415477373492705255348755505596508`49.69897000433602 w+0.32238396813356776553578194424583013299506514621847169310456823382189351974733`48.22754086999612 w^2-0.00905995992203400155518915977261367882380298617384900173362324490758766826261`48.22754086999612 w^3+0.01975022589655292698110206097757593360123125125848738990744131831553979609959`48.22754086999612 w^4-0.00886378232046238683130906896869023264512160425482229772105660069543615496323`49.69897000433602 w^5+0.00165373867176747356674166676735263895859168084372833981981619487412411412836`49.69897000433602 w^6)+14.76492210043145565143402256282792718345076332778541301235431774293756398013469`50.96363449299026 THRSub[2,1]+3.31619113449817439082330629128291672478442365779744549364825400633501710980249`49.96918551168655 THRSub[4,1]+14.09946201990261644178942516813307491043087753586745626229248811548365223075216`50.556149166412006 THRSub[5,1]+6.43709283194072483004633052570436829750834746559421077553761837569489523283147`49.793183786915684 THRSub[6,1])/(1+0.12199953770197029091171690266114445087460863614846739644720768010905100764341`50. z),((7.72464097491567977295201577538375332146418014022375283009338211652428537278515`47.5313113483194+ 17.48109456793951668113571154822426976683785939392088325252174701637906119395359`47.5313113483194 w+4.51435837432650615529013412315618817276756185023053610968844094666802684549021`47.5313113483194 w^2-2.58287761189605154251424515619620023832926559680119642049383225141739450081098`47.5313113483194 w^3)/(1+1.23661622698463194632965807764281479364218242508213697603146522410323530382083`49.69897000433602 w+0.24810178087190603166622871230214108127101757678318738958610848110172033680348`47.5313113483194 w^2-0.00204200041083773803991360118192903080809720589578268231290308540008084616403`47.5313113483194 w^3+0.00507108904762444174163080615528360763819598016993619988442060630222144995882`47.5313113483194 w^4-0.0069615688162467014121484143901353048741879555927380592419908259795492888038`49.69897000433602 w^5+0.00054784898402119426965791098505208305899414452723954580646724794445119691175`49.69897000433602 w^6)+16.72508638875319336972223651380090175627898746330285832896173902133297434643659`50.671234061167084 THRSub[2,1]+2.00941494228368257863116365730093367623227423411914861590997315407141019893449`49.36597665788904 THRSub[4,1]+15.97128103445428656770509668319125657726271177825163910808716429963406447643977`50.26374873458881 THRSub[5,1]+8.45635474863376430957756101553445373849633431320895362090487902813479309292326`49.53790150485619 THRSub[6,1])/(1+0.27095416207161962405457608869966480632106182939244508263050136085983602637782`50. z),((40.61034023188568168311564975159581490152185469919399267349904660854239754737654`49.12872716121869+ 61.38700693240337203781818427691466430352906335760214329849848405119977799519625`49.1287271612187 w-18.29620221393704259019369862563816376472456032384846120203281137531691603541874`49.1287271612187 w^2-26.18740180367212848918719457942129903268596107195197865809544492544842484703234`49.1287271612187 w^3)/(1+0.79535030766661822560741103501091306842910929767879215732037186360346055875151`49.69897000433602 w-0.38743752166009824840121750661587143217242120165660213260129032121201832347041`49.12872716121869 w^2-0.2077636708117384096211848878833726797307986961831881091661973025912949034524`49.128727161218706 w^3-0.08647906098259754593987580569090794161559970776041341997326682382687609040382`49.1287271612187 w^4-0.01459921299456608053420916503757006882823076015989388799435958895878804070875`49.69897000433602 w^5-0.00082988459274637749709621999477292305889956834047290218727744469269525375509`49.69897000433602 w^6)+49.45872630645494975558759921163994696640883994971678127499064166938552533757236`50.13434523089082 THRSub[2,1]-19.81301166951748834527907814125842979718762742349013334810929527796362379515627`49.19699118734915 THRSub[4,1]+47.22960462420878592630846101010930049499607898784777509034809492247628914101455`49.72685990431256 THRSub[5,1]+42.17689178440954671311390658308057644103163038232111699745423350694885859124665`49.1130638067486 THRSub[6,1])/(1+2.75841251810933305968705847559031386915889829013739734921431191984215402246938`50. z),((10.2136323054535644121723828240980072642986238266689394451039006924761707376666`48.234881633045454+ 21.41837967414253935280695416801655246203759946076607564378221846190067171429784`48.234881633045454 w+4.26700543758291266690835498952151668177797746301161476384241215440352418500571`48.234881633045454 w^2-3.36926680355912086846480342820752246404370248504113144249773329550950417448907`48.234881633045454 w^3)/(1+1.16396079372129269347046763940676882061444968906724345803846089507588811406997`49.69897000433602 w+0.17434035683965205182605844125346713572031838737717708147626616957130581299274`48.234881633045454 w^2-0.01138668187497192858845567260915730907511520475824216048562414089909415066972`48.234881633045454 w^3-0.00857567777645479867358333134085973787530455054936839780828979944365614424235`48.234881633045454 w^4-0.00641466177561181348272743343101418245070035063783874961603474935867242483533`49.69897000433602 w^5-0.00032082263044498227779257025009921808674941907405437972209596523923871952891`49.69897000433602 w^6)+19.2025689362723995845357318804430591506477296677886426388817057991429814716178`50.50209981056752 THRSub[2,1]+0.35775991060421176875550007953949541331977943112862574262999530219807211548039`48.35247466744264 THRSub[4,1]+18.33710259762378545024338422066739378083706887550234865425897265289885289458873`50.094614483989254 THRSub[5,1]+11.00853172037137766612150020236422696633906772843928638117423704844236356393031`49.39839409102992 THRSub[6,1])/(1+0.45922026019752985450741178714727259732083100105948695019617286679164307031358`50. z),((32.80110331283153118952227300221984762253224924636852291081777718882075418621983`48.940044708490824+ 52.14947720493601503071653472613634931123102228574580810123494646997339786764477`48.940044708490824 w-10.12124059078314906487289503767720198498596697536771037881088329857279885507076`48.940044708490824 w^2-19.00305595766248760776983912005116911714621442741894314635651290898874023414292`48.940044708490824 w^3)/(1+0.8562648837944312059313593472294324654779229437966066759071365178691806133115`49.69897000433602 w-0.28716513585363037331647967786429481579884290582739783303558153824842494269208`48.940044708490824 w^2-0.16865370933479595216978125405976302547559975783647691153768800710148795311656`48.940044708490824 w^3-0.07397879476474444146562350165726238210786176031085181072567667529374830372204`48.940044708490824 w^4-0.01274709725529570171700927985377734295002699961281718860709486641326375026637`49.69897000433602 w^5-0.00109065419787440609881353013757733792833234738057883486700872924963071678794`49.69897000433602 w^6)+41.68559831720708532329059740374489875984748868482350513035799917105744909447779`50.164743246503285 THRSub[2,1]-14.63092634335224539041441026932839765948005991356128258502086694574490629975986`49.18257543720162 THRSub[4,1]+39.80681416756020982746607610973285345734672107372795064561735161486953708909774`49.75725791992502 THRSub[5,1]+34.16940924032768782277344730267237025895410349770279767106908965195611626118255`49.13601341456711 THRSub[6,1])/(1+2.16772562175384909898795393873374897396772319076280811882733618093537636626359`50. z),((7.71300053154697484580622538873301955668031684998827760863886363674825584472403`47.529375216482556+ 17.46249117826879825746609550105625110826399041944935682444938366157706428624144`47.529375216482556 w+4.51498031175086385284021121189104834927103222975407787044067189413346239355477`47.529375216482556 w^2-2.58005939866672336622271069290555649268979817472299570154386004632982849818997`47.529375216482556 w^3)/(1+1.23704160122887262287842313412565090431448962075592297539817606503815312146489`49.69897000433602 w+0.24847222911503879851209086595328857476345155910639836529648745872849399897884`47.529375216482556 w^2-0.00203182906790813969765029934865513974632484581857198026876270170580312850203`47.529375216482556 w^3+0.0051436156805101719028852668705011352857706926661584064206521824594237364104`47.529375216482556 w^4-0.00696757658153427454708925884697649509808447173591205915875060414447512202006`49.69897000433602 w^5+0.00055306290645833289180675232855435187032162312845203259780091916791974647304`49.69897000433602 w^6)+16.71349976933129290495473339992376015442072736439107132678170123934280743063425`50.67234664822071 THRSub[2,1]+2.01713935523161622180949906655236141080444763339367328402999834206485480946939`49.36925179495851 THRSub[4,1]+15.96021662792596646148141300658857494217910056601323814230111734769349183493901`50.26486132164244 THRSub[5,1]+8.4444188004679648085854643504244052185126508938367675304086225256756997486275`49.5388395199213 THRSub[6,1])/(1+0.27007368457593943318218222545998010364339846274682169087797129210193039000819`50. z),((14.88453174310501749247719980885666643777548359771412240142959457866316164864582`48.3091080699806+ 28.45652981201563917557299516126246423453178588997781054381990742253042558915308`48.3091080699806 w+2.91964650319466830877985973949011576847498105393956556072589108217980144198838`48.3091080699806 w^2-5.60190036457098493327747444569276540365619698088824777620098843940812862174701`48.3091080699806 w^3)/(1+1.06964260424785589312218292500592172783741008127398330794595239588220753507391`49.69897000433602 w+0.04997175484014630172712786615427021797964816237292628645488719432166771454175`48.3091080699806 w^2-0.04549165976724501689715752458956847777977837895048235812927161568304211371021`48.3091080699806 w^3-0.02846276167963776439420435974611242176204916417404542230375011050758590100561`48.3091080699806 w^4-0.00725968586169584921691903623723439732545827734708037226963959821294023522412`49.69897000433602 w^5-0.00109642658098952324913331698790180875157512032804733730256290485326960899611`49.69897000433602 w^6)+23.85187072210785353074990258363564791754648650629387430946090923212360084143006`50.34844732318009 THRSub[2,1]-2.74177461328609086205394705592223043127939179454152870442280698645567413106118`48.947073072633266 THRSub[4,1]+22.77685876447391962357775234149354497705586693200843463256274727959937972384311`49.94096199660182 THRSub[5,1]+15.7980068124762672426370122530446786213232755780090878133019831364659309031077`49.27668756906225 THRSub[6,1])/(1+0.81252483023599209329943622859160909149642259355682490215379427994283407652621`50. z)} /. {w->w[z+10^(-10)*I],pi1->pi1full[z]};


(* Pade approximants for the timelike region at three loops *)
(* In the construction Pade approximants with poles w0 in the region *)
(* Re[z[w0]]\[GreaterEqual]-2 && Abs[w0]\[LessEqual]1.2 were excluded. For the nl^0 terms this *)
(* region was enhanced to Re[z[w0]]\[GreaterEqual]-2 && Abs[w0]\[LessEqual]1.3 to remove the *)
(* appearance of unphysical resonances in a subset of the Pades. *)

(* Sample Pades for the 3-loop triangle form factor with LME to z^4 and THR to (1-z) *)
(* Mean and weighted standard deviation *)
Ftri3Loop41[z_] := Module[{const,ls},
const = Ftri3LoopConstPade41[z];
ls = Ftri3LoopLsPade41[z];
{Mean[const] + Mean[ls]*(Log[4*z]-I*Pi),
  Sqrt[(StandardDeviation[Re[const]]*80/Length[const])^2 + (StandardDeviation[Re[ls*(Log[4*z]-I*Pi)]]*80/Length[ls])^2] + 
I*Sqrt[(StandardDeviation[Im[const]]*80/Length[const])^2 + (StandardDeviation[Im[ls*(Log[4*z]-I*Pi)]]*80/Length[ls])^2]}
];
(* from 20 each of [4/1], [3/2] and [2/3] Pades for the non-logarithmic part *)
Ftri3LoopConstPade41[z_] = {((40.72531358803964341617225293263489986628260308566484526734565407630503342098387`50.+ 63.8504108508974310681104818228186913496857953469038113240371`48.76273856913362 w+124.5780149209338606502664480704252810705456762787378001743776`48.76273856913362 w^2-9.3919967449239063242969421054266156288926847820253388648754`48.76273856913362 w^3-12.9375169945383731383335240745537352133803647194685655895171`48.76273856913362 w^4)/(1+0.76733799781676257532786045123399581604968711973263858991946051625883260710965`49.52287874528033 w)+80.63425772787119977054041420273915204545310165742908421748332674466568140807998`50.567330745584464 THRSub[2,1]-17.29482072784491788323315781833099850118486696745789531994130606876398422185468`50.567330745584464 THRSub[2,2])/(1+0.37139003158657065380967096389701264387708604213027475278515340122260293636493`50. z),((163.4903063339327692748098419270266262271745478282387033833637`50.+ 170.1032908763030443851513338691398990329533989233646169094288`48.45394348454886 w+940.3376157087119104351205474333985729026891434546519640198063`48.45394348454886 w^2-403.8193653431141043268634683433099008866822518690520050637829`48.45394348454886 w^3+38.0924598309092055263427835197469616213846348980449447549654`48.45394348454886 w^4)/(1+0.65525582354657960765860507890622971653418382515256085926643129368197903462687`49.52287874528033 w)+379.8507056823534204025145521929738206793430945618570185145664`50.073035879904225 THRSub[2,1]-81.47219362138379905171213979769470509469391130736090868577920459350185573197565`50.073035879904225 THRSub[2,2])/(1+5.46032450651364792358426595860713146433116477087036762749036305633583694001877`50. z),((147.617661187664397646332049776782745035934435439701733259376`50.+ 155.9486486859689847909956158371863973608432376191608617090168`48.42882916871287 w+834.4625542080121305237820967319724207987740401336217710592536`48.42882916871287 w^2-353.3315161652923300463745417489728314661485428688643009859314`48.42882916871287 w^3+31.7100355271731171288367642755305963388135206421170186328682`48.42882916871287 w^4)/(1+0.65642961066281277965835423734554089067406607255436206981737748201130897523047`49.52287874528033 w)+341.1641355610249529423836767188401238283951363810821996698212`50.08214993762362 THRSub[2,1]-73.17451328455208599135666830974112957033835239589586009699202012606023445026271`50.08214993762361 THRSub[2,2])/(1+4.80236127704218094844048022703914083127456057367317915354492816140501302930931`50. z),((233.353999226310123385891881559436862860384187397981943700739`50.+ 232.4737924041948687950487745857954306666305327681652159580685`48.511965257072276 w+1406.4146932129737632929291479475865134953469792054407778379335`48.511965257072276 w^2-625.9586678694270125281788692242862158374564473494130781837682`48.511965257072276 w^3+66.1493576555680010189155789250468895287406813591505285564612`48.511965257072276 w^4)/(1+0.65228166020752728531698688594845950587206357741747985240226393347029764356783`49.52287874528033 w)+550.1302418976094966338312009987153283637352168719624259256664`50.04908978300912 THRSub[2,1]-117.99456184857351776058471646352535657205364669030264704032980270548215727721432`50.04908978300914 THRSub[2,2])/(1+8.35635982858334749917852430617462315920271982223540474881168340966755979878444`50. z),((35.8192404732073414335738306777545117101957251996796790005298084269729821110347`50.+ 63.5706973688440188632083884186577396182921567005735433489269`48.92679900696323 w+95.8129206009864252460959038470953381515562922573566941558115`48.92679900696323 w^2+11.2127883734290786182523789374149188359954496916759013265023`48.92679900696323 w^3-17.0276423833636137669904851773592870685559792004077225144797`48.92679900696323 w^4)/(1+0.89851839699010892329259911013356945682098695019627992623649925708814160571153`49.52287874528033 w)+68.67663252877540604709405613310146764977006194408671987804423394770911626600243`50.84208865280569 THRSub[2,1]-14.73009216238755168844994132459868583645462419282910277360356576072659853723022`50.84208865280569 THRSub[2,2])/(1+0.16802029195517084597263808239912631871315778450141128919228676648382329635053`50. z),((34.53945264085326368187544573226114369658047519913539839400146134275583341476528`50.+ 65.5484907195106766601698468536962849993747909344146208302859`49.14274608841668 w+90.2921083563648777760589561637335461744448369778597221309111`49.14274608841668 w^2+19.0919743130703847160510028656793279802425548675838792396202`49.14274608841668 w^3-19.1558375856543847171862214146635404595907057448792891537784`49.14274608841668 w^4)/(1+0.99824077277371426328821799397713933637457838960815935527578262293480297590978`49.52287874528033 w)+65.55739176830084598805054413435676156108884876510242306532614992941010213754883`50.98667969159738 THRSub[2,1]-14.06106250576869368718199415763821519397342214670893427163538849910677940594584`50.98667969159738 THRSub[2,2])/(1+0.11496969279829733091706019613795939088892288329070733399397922652484726223772`50. z),((248.9644236010326518323149212438829681693964651183295662205617`50.+ 246.4180984249374360520429891738018111744731497427445883441485`48.51929698239985 w+1510.5633938240865455038461764552879869165789177719445516370647`48.51929698239985 w^2-675.5837617819846490608720652011468117321180736249026295451622`48.51929698239985 w^3+72.4142045737653142510216142901806509800655103269025335649758`48.51929698239985 w^4)/(1+0.65187807415056528053444515828828262758037146150458317711150930818031714274186`49.52287874528033 w)+588.1776984892020555834867200564033049618343853354673460328979`50.04574083269669 THRSub[2,1]-126.15516206297356946620346474577950000395302305173161840125964297178712627633684`50.04574083269669 THRSub[2,2])/(1+9.00345331176546555699849833434989908084460409054295416098300973662583604684895`50. z),((38.81923629773117314435984811358678463378955100341000138504913043777950465179412`50.+ 63.1045750208837709421008602587436738303058736822358163779549`48.18542004533416 w+112.7863157203596797506142256593487434775252648147172439251046`48.18542004533416 w^2-2.1646962599965320637908540741408053325686469991446790243663`48.18542004533416 w^3-14.1970186739969787411345549311840328905004889836024344495568`48.18542004533416 w^4)/(1+0.79795113624307130137867389781130377718340784207334602171169792096291071057394`49.52287874528033 w)+75.98855488069790239437821419649441336663682823226839630392483310526060482119494`50.64544478073534 THRSub[2,1]-16.29838819208748727968973180415547157733499912454167829526501164149829163841755`50.64544478073534 THRSub[2,2])/(1+0.29237807371838714791086830062405460339810567125545126661942200573773334196224`50. z),((189.4419101514832077333739579205981407269609222696123413123021`50.+ 193.2618668374891972161527617627488048701593832201735760711086`48.4824077598917 w+1113.4575642667065530927706538270867086488816350277568353033107`48.4824077598917 w^2-486.3470655291500662606486004934361077787360860941506182373139`48.4824077598917 w^3+48.5194491875839919828522558022666478902946750175288878376199`48.4824077598917 w^4)/(1+0.65384426203633527757824365382049843510575859005540207694338899378789248708747`49.52287874528033 w)+443.1028310588622004080871789798183600255566244481388376716762`50.061828076541055 THRSub[2,1]-95.03881158088380521176330017585113146007164769238902342405598113150087411428063`50.06182807654106 THRSub[2,2])/(1+6.53608729843707755219424388462873423419214477565668806907536681466474503183528`50. z),((35.43083363417047413886755585541934843572697341559683082005799229144875136732122`50.+ 63.9660401082629100970487706697549088187123171160427469216011`49.000461748965286 w+93.9392830790463594466415502636771327076098533022031643511716`49.000461748965286 w^2+13.3538219611672543769056329351571141361636223805240607265179`49.000461748965286 w^3-17.5674613146011715000168459761356898863100736327463184175142`49.000461748965286 w^4)/(1+0.92223882502465806408648364751929645436602825044734196227170398417218634035887`49.52287874528033 w)+67.72996432851415849924885573085374754057914043305322670837799639304740093796023`50.87980786685527 THRSub[2,1]-14.5270462452598153655498020707499568753728877879707918336165453725390394128125`50.87980786685529 THRSub[2,2])/(1+0.15191979857133289690200434655189170937093761832210804991849259874719766377839`50. z),((114.25482187439752349766052467385364314106944873228441454031460049930814898536841`50.+ 126.2427335318164693795833056982284166225119581382003410286967`48.332769983951756 w+611.967244472695068831545158796036508524571401752144016691577`48.332769983951756 w^2-247.1547628453784265263804142187934911073472975388236073860409`48.332769983951756 w^3+18.2710923042368112685327345201425785896435088874506337736195`48.332769983951756 w^4)/(1+0.66036119188884794269954810215164624187133274339924885215491100144151222395113`49.52287874528033 w)+259.8485255511361691065286520804775410131715350125505720599645`50.11141388904408 THRSub[2,1]-55.73355286494276980504896404831777109206257874217554056580026887218360933684445`50.11141388904408 THRSub[2,2])/(1+3.41938312207124010893486996879369637294435746398062003685872778490953101163233`50. z),((243.2204647660538287157268877272397889210273857259539374134656`50.+ 241.2869824229065207369573346347661743822262053798842532579046`48.516738255800746 w+1472.2409817226405952014760133654674245813465499488369653615158`48.516738255800746 w^2-657.3241445637935146294989465404566541047383276857329482187751`48.516738255800746 w^3+70.1091245100532759993996009868608229851254423058815384871195`48.516738255800746 w^4)/(1+0.65201966233380368074778639536666576789130258727468354654280414982350241635523`49.52287874528033 w)+574.1778853392385467246010268281073653303873625405664131825936`50.046918546312554 THRSub[2,1]-123.15241527178862886097524027792037052586743404773011807921829822111822312465685`50.046918546312554 THRSub[2,2])/(1+8.76535098728287351145953392815358410502851732121795236596772368658054216398446`50. z),((34.39141858332432866850461078770665055438800352531281718405732999142264360102538`50.+ 65.9445626706606834254096794124962580601774266199491539486119`49.16376373559442 w+89.8152609573646833373538540735860931606923175504646483042477`49.16376373559442 w^2+20.2076976049188357404083432909606587731467825699744655610683`49.16376373559442 w^3-19.4886304593952506364467814099608087368928820517450620571281`49.16376373559442 w^4)/(1+1.01511919074117035725307852016173411440301645560002065977633625124709599958049`49.52287874528033 w)+65.19658675475940063058087325614013799472826832888305370896720202174499413580602`51.00810450321338 THRSub[2,1]-13.98367532316491457625732671889624026404639500199089077149673488271429050504637`51.00810450321338 THRSub[2,2])/(1+0.1088332885842585768462368882053529674001908553884914413410224450041762692839`50. z),((34.58623066045144960646170371418749892875769345914162536369102552166917745660543`50.+ 65.4332623483810070024916943883395574291152398324361867517573`49.135976153805764 w+90.4523886684119693118742403953355901727523966387614704198475`49.135976153805764 w^2+18.7515381699003158068868427578649075115586454172787667303303`49.135976153805764 w^3-19.0558183046553286703739185814832565285379010838449135305969`49.135976153805764 w^4)/(1+0.99322438066486684835619887124324249155564161161227713291594348087707294950038`49.52287874528033 w)+65.67140434267932314001093222826450236388010880192345160734048822937243333605073`50.98017062387277 THRSub[2,1]-14.08551646727535843827441868474285941551722308907243451886604298788073870383556`50.98017062387277 THRSub[2,2])/(1+0.11690876574798384769273445712328898720412189954733175478966433079822280759139`50. z),((49.38993900484602516341728607888731711266560057354986698163482548658497087012524`50.+ 69.787287504436677127063155830498320515116358826850320900521`48.58624053195294 w+180.6427966249357622089233641521411231422679164226760000184063`48.58624053195294 w^2-39.1372075959598358697530181112147064959062922284900041381232`48.58624053195294 w^3-8.528543289877611055043093833491917027453614083340235868534`48.58624053195294 w^4)/(1+0.70951945072599292469209823962555851149475304248332696071268281214190838277375`49.52287874528033 w)+101.75264320637041218826674081286800783614254342626876532463935669918748536262236`50.374530177041024 THRSub[2,1]-21.8243929122233533792068495907711462742759661114254810055925807911997519882481`50.374530177041024 THRSub[2,2])/(1+0.73056173037193522423068659918855435667858579628493620635565242918131877891007`50. z),((145.8355739929249517045816103820772356395809567562246281443877`50.+ 154.3600846553695521288914576839931970797358762271738312034506`48.42547019613985 w+822.5761402172759120389088642805238358026426718467585318621212`48.42547019613985 w^2-347.6622615363445269535048932118076147465479999501535188931479`48.42547019613985 w^3+30.9931260679602980981046023444970386996169944395918992625781`48.42547019613985 w^4)/(1+0.65658171086744191891702473120765573174511217561090001822046230477225766069495`49.52287874528033 w)+336.8206351182006865100828586150984567622215270144786658857463`50.08331769982238 THRSub[2,1]-72.24289856387740825171400841614929787385646488023536188578461427776894049797059`50.08331769982238 THRSub[2,2])/(1+4.72848903740944546389947105337139528612461454888021204256841962069936395655159`50. z),((166.4686693609779834838144121414870270822886025539834859041661`50.+ 172.7602472314601053566661894758000004139291964762124449281861`48.457871041452925 w+960.2050747236765297221202342663839722416306127746512931313541`48.457871041452925 w^2-413.2917952094585511372734715192498030142712384582195142974188`48.457871041452925 w^3+39.2895693267550171937774015496778342327443127461090342709802`48.457871041452925 w^4)/(1+0.65506629019519278779017695802648059563926662051835118414979843707373605408909`49.52287874528033 w)+387.1099021824178988103278474490612143071187232214124523825312`50.07154694589473 THRSub[2,1]-83.02918075854472467904295849090029959548702939785200272814717440271207741127668`50.07154694589473 THRSub[2,2])/(1+5.58378555145950523176532637556382860671821233394313650135900516288206280917478`50. z),((176.3507366174119683710822297308487162730763402514512523096299`50.+ 181.5776477700051827967157654162756348932954250600273719383729`48.46954388504678 w+1026.1260491154500709554418577391804789750034254049746294314035`48.46954388504678 w^2-444.7187382709191020023124358197081939830084583747465636596648`48.46954388504678 w^3+43.2606204547526216284977981382321228444246230847970353616647`48.46954388504678 w^4)/(1+0.65449318470223276229473985865687877589648064481174649905826179396741129411744`49.52287874528033 w)+411.1955718573048316028261548647725836099910728801594752793523`50.06701486278591 THRSub[2,1]-88.19519022989225353074941367797336134212672923086391243003323377831956119420577`50.067014862785925 THRSub[2,2])/(1+5.99342344268560376621609824643246997293551417494462250595668903861860158581697`50. z),((34.73943836109011307234895980988105352843066119987372744294336631400550931141215`50.+ 65.0858578973871954586811538822178863949442388512866760523591`49.11334004935823 w+91.0063370870060124713084711313959608916351249208714858489814`49.11334004935823 w^2+17.6731719884377820554700531412270343117453292174741598055137`49.11334004935823 w^3-18.7437654400808675929331056329460867332710176138339263467326`49.11334004935823 w^4)/(1+0.97775259019392809874877126534306181430533015022377172318595965049941537268869`49.52287874528033 w)+66.04481913266967327555488063183589293178431365988563702898248211595556844037853`50.95965928714293 THRSub[2,1]-14.16560825495949942186029396366008296969000516076403825551070860891643783037183`50.95965928714293 THRSub[2,2])/(1+0.12325963118743530655092814657481217367234971165048207027107126979461611372578`50. z),((83.58514235247648845791157382791623233667859183236189661333691379005018571327846`50.+ 99.0733440593158550611561041531627933552416119317532177303382`48.03129383173291 w+407.5664861310465241778175056460171262004227082045191894978082`48.03129383173291 w^2-149.3798514296930593003984402055066692006264140241855601040593`48.03129383173291 w^3+5.8454182758306996148653034300279985207024512133322067332623`48.03129383173291 w^4)/(1+0.66840193160380778929101443628271685641560797000778424324117866434218041359783`49.52287874528033 w)+185.0969831024967974235972493927361571131334634511363966394265`50.1659976476019 THRSub[2,1]-39.7004850075791294852457294293567412195288049673199379873891424225548746705864`50.1659976476019 THRSub[2,2])/(1+2.14804358167697581522462958168275719948077759900429318514231565842403365602729`50. z),((243.9385367984671953254553349728414067058564457159201716339721`50.+ 273.8118258419233832738209954975082991052997940398439570622327`49.23520858572931 w+1511.3635682122812800072517383493484012763581149463041619077018`49.23520858572931 w^2-465.6338588181673565415541440599554028512160894412621299990889`49.23520858572931 w^3)/(1+0.78270413153376245572609075098445999573999527156832541969040587403762735699482`49.52287874528033 w+0.09633219978634046207106101504639503654783695654969309904343068880668942741381`49.52287874528033 w^2)+575.9280500898601858620371237735738519886117990795316620710764`50.04676800682615 THRSub[2,1]-123.5277989667480017210844547298461735969565990558044313019847196793411450215685`50.04676800682615 THRSub[2,2])/(1+8.7951169770776440584706978899847714718885893744204416647831487652039382671437`50. z),((36.67061881095572442695537325158165943551053301029800955136527296714503857831683`50.+ 39.344069985177983600254455492788872607696333455127433196508`49.662805100094204 w+69.7569944242168218667593305415255030117839247089613184718336`49.662805100094204 w^2-49.054323163727460072738441696762662218058015970639194026919`49.662805100094204 w^3)/(1+0.2112581708639866481958135715453389753086216807807491627201997385296443288204`49.52287874528033 w-0.27472652604765831240069883390423020609981048122803568256978445600419160173194`49.662805100094204 w^2)+70.75170618282394336530376639886166761354017619210307104989159914864231137418355`50.772214912793075 THRSub[2,1]-15.17516387080409552942889373548921663243770617654605622459469790647405125258946`50.772214912793075 THRSub[2,2])/(1+0.20331218158319996184282835540685778049160704680772797549935474101514311505321`50. z),((77.1036799889263546911517542193509038230432767718875865838679436794882522310857`50.+ 95.3782570098740785807315594932802596971332018971605455030656`49.30532102748809 w+366.8717163232778456936414860722136715462028302447302006638767`49.30532102748809 w^2-119.1771437990816268900272686392945290613638835915595400601698`49.30532102748809 w^3)/(1+0.69746413963328082159022709546044789302044115403965013868850374491280758618007`49.52287874528033 w+0.01788229055212657508961565270038675823611260949605526560809860901257009122964`49.52287874528033 w^2)+169.299644605631113352242780212889505542782401384575356701546`50.185285203055926 THRSub[2,1]-36.31219639453793269871580336209846623837909810965288125972812405701679549692572`50.185285203055926 THRSub[2,2])/(1+1.87936978035900178168470822355845244494175477608518116339755128057986645285127`50. z),((79.9782374242649585071745223908785061328406557821950243426572836211439202209256`50.+ 98.58581580465133517357839241763238768619109921071487181656825967056733317490795`50. w+386.8279285894416879357523686735789626765485355748573003233168`50. w^2-124.93952214362476793814835771798127359560415270139200185300643768551135089858332`50. w^3)/(1+0.70360861165301417925335355517940819458326802834965822365322131623919583701159`50. w+0.02323540331655181410552711824548096251087921517849063163589604844062817764334`50. w^2)+176.3058346114700277242844707339859027812443788411122966891423`50.17619788525247 THRSub[2,1]-37.81491749039196103774117154949634445731868894653010933102113267760680779292069`50.17619788525247 THRSub[2,2])/(1+1.99852780827606000759283055296693350554441448621945373820993748567335503907136`50. z),((60.18636428830329833326425732635884542302825295042396204686977090158025001260366`50.+ 75.8717173530495068473321504772449650489109604372733165239607`49.358170083354906 w+248.3518397691444590988447340709234779579655487975985103247093`49.358170083354906 w^2-86.1523548653475205119560738568862876809695808462165769968065`49.358170083354906 w^3)/(1+0.6389530211817005132445672653328508207310809015806738266010373886009149013683`49.52287874528033 w-0.0308709379272309581332397592248629618428592118986738127505997007997028143273`49.52287874528033 w^2)+128.0668876148613532960871464082311242686185250195002084228794`50.26689528899621 THRSub[2,1]-27.46839773669191387764514157474096960110255128026520000640442878481958661422763`50.26689528899621 THRSub[2,2])/(1+1.17810218634445473664705962046600028801096021915376852931928627511893236346582`50. z),((46.47835476567532709382882609254606752552373291403569143146433700106274376929259`50.+ 57.9087845437086083850134314170474042631909366086419746533891628460014250018166`50. w+148.830804190083849152131858472647554785956511878429952970558`50. w^2-62.04282634913781681243696504562669678348369648993501218111412939521629701008744`50. w^3)/(1+0.51389544427440046313558729107105319916376335347024977599380405637415257156755`50. w-0.12227682232425500215070064451722917995856023419727393800752149784884963578653`50. w^2)+94.6562073700716798537213511143494714637319128323842608487816488120938025161415`50.42155404844963 THRSub[2,1]-20.30231545961453900252622160715094007240122290291480659904503829691425455233883`50.42155404844963 THRSub[2,2])/(1+0.60986884325517399555958177109929283309716118763596917700995581777050682943284`50. z),((270.7379614419841399183697313770758294233166662745651752871839`50.+ 302.160423543849199680884984360565709221671096207761853405214`48.7274089446952 w+1694.6371093872345328969232110480228607945490135213383621106301`48.7274089446952 w^2-521.8017247029551787626507705772483701227847047834726953611422`48.7274089446952 w^3)/(1+0.78544390577356386625709101351512642657089119134258871187096188242368378670777`49.52287874528033 w+0.09900915495275393530447909194449766157848780218050911119191674709402903961392`48.7274089446952 w^2)+641.2465783583776054216846445927335306586916156528084715450539`50.041767072460694 THRSub[2,1]-137.5376288882083999794412225386985578575034414902004349221467`50.04176707246071 THRSub[2,2])/(1+9.90602419033258911266361126035229225231062513348246571332209359994077269108783`50. z),((108.71390552965974923906338508820755171842709454802857754374185015444947879873752`50.+ 129.9643384357587043980781401672441012765637809762273094325404`48.532346248596085 w+585.1166708857387965997037406085886248184628750850664599447345`48.532346248596085 w^2-183.5804833819604444919946382231866216540131445053884317664072`48.532346248596085 w^3)/(1+0.74086207863104864343778796562687160050154826017185974760169633027982425272636`49.52287874528033 w+0.05667691502174711819535053957152448229795663174686067266656545592640611711741`48.532346248596085 w^2)+246.3435900642171331606009592385468066863982562251666164041041`50.11843317134742 THRSub[2,1]-52.83694979859316863503525861504325568483171176973028323938561649288580237140748`50.11843317134742 THRSub[2,2])/(1+3.18969744719984012939710043183781098107663206102162259484910730479156533679787`50. z),((185.995152063059848246431283547276933016250438372658264202269`50.+ 212.4268002426803749303734905732538689096964130134465537452256`49.241627012790474 w+1114.9341213077434360717636054761340363248328877127681063785494`49.241627012790474 w^2-344.3511665674152660948336029481019843842567652637037815265124`49.241627012790474 w^3)/(1+0.77358602014715450026605780650629599075642611597569272796000838556579521586439`49.52287874528033 w+0.08749548627739686225756727467665948939798683717976004255013030188327820841807`49.52287874528033 w^2)+434.7020101969156265899543007185259082971374478528852897966376`50.06311407184174 THRSub[2,1]-93.2369633978889248167504828117307129065337061435025693812582638683107260040059`50.063114071841746 THRSub[2,2])/(1+6.39321003619329214365493358603425491952000169869127903604292622347455652767231`50. z),((43.93363490076674887675767851058459953165937083568011165087083464214830312143493`50.+ 53.95349720382307661775942989666141701641772769414770890842573122116698474595949`50. w+129.4211423118345793765604161414532815537551181153971792746248`50. w^2-58.19257155420534678834709715157866636786767587622487707844917682636710681507953`50. w^3)/(1+0.4679638237470171896785788301428057146574915147332054731787513187963521928132`50. w-0.15165889241003593808500047329955280312583459698045120316173967562220315144928`50. w^2)+88.45393405105479279094430410031682905251772560075906345795985164595554257138507`50.4745977149642 THRSub[2,1]-18.97202225446712080280221436343917964330312549083954317766233759651473744620234`50.4745977149642 THRSub[2,2])/(1+0.50438345723499477230933362444256020128096595144479005935704838031734743419907`50. z),((34.31316402036250383921797910546719517272162306470981188434929445349551774111762`50.+ 32.41562894985379966068474048374733001272440595113664724957795903322425593244578`50. w+48.31791139459711101040889804908415219061613783512523236259292141925224874227721`50. w^2-45.76560125293394731633955123570872640958807307630775264978382111113812366837113`50. w^3)/(1+0.04085363049505305672386524663748974082605192173057617049426011226325640759203`50. w-0.31335995094164805998362348566416526070047929482354796193271263427661170474796`50. w^2)+65.00585605994207928109198146040008471297664811234609298895471240446881739536809`51.01997343457716 THRSub[2,1]-13.94276649276065459701383391483488170374236965480325687783706663704046327286298`51.01997343457717 THRSub[2,2])/(1+0.10558942944844557800999454155276812082779132180852928701173861905470688799067`50. z),((39.15005518146926243901904290165398105154918150124329172565780585387086022878509`50.+ 45.1611440582608990448330742890856837476312826974451397632862`49.464974157115435 w+91.1007161835775440396952166676445257777520260271502374434395`49.464974157115435 w^2-51.896825036033301104074805639664754937304355226827964780187`49.464974157115435 w^3)/(1+0.33079315501195943504252782786628097489730752036065237053096121117468152374148`49.52287874528033 w-0.22625647713930696912700763487484925570398996809680347986260042738645730170659`49.464974157115435 w^2)+76.79486333308600639177821678666439293766235667030659336740452093336258848523754`50.630122448980906 THRSub[2,1]-16.47132908009640942364714499208793823863005748104500015122024441913791386375577`50.630122448980906 THRSub[2,2])/(1+0.30609139365395138590935020773510752790802044835472002011028416191239798229951`50. z),((41.15169377449654174849273712585004430550390349534321136183149596036932797811685`50.+ 49.12767831849269641575945339814504539544058145037545029712537476884385452807133`50. w+107.50607807581881243354812682542047540156627442610405639187094235265645347079235`50. w^2-54.36810381214327899476701618665563268601847074835559354073786425509153553303161`50. w^3)/(1+0.39905651334388587564473403659924790446739585454272733454630602433627735636426`50. w-0.19160207022086595500334542140900076746171163188817516793573589821977611329545`50. w^2)+81.67347877954247024275150991540183588478965459987466344613471286319153504696853`50.552700709503135 THRSub[2,1]-17.51771782259977756055146457100295449695807515663311332658888255046807516552337`50.552700709503135 THRSub[2,2])/(1+0.389064620911701636896572543331224547292821943385849281397616371721318848516`50. z),((211.846782882210696745764455029369401489966662815016872792717`50.+ 239.8344964417519768620415404644300081990968124785754120523675`48.703405333610334 w+1291.8405762961420676030371091645581572856464122901190150613049`48.703405333610334 w^2-398.4266054572841558663555196893613797640737586760686042138991`48.703405333610334 w^3)/(1+0.77836743032521022037243973245984442719035742802047564399219587722864244407549`49.52287874528033 w+0.09211551538404959000431980886792639577304279643767940923213661810750567814871`48.703405333610334 w^2)+497.7104703004226685167172063963225159839137826354591722171059`50.054598327825296 THRSub[2,1]-106.75131886582624332231783770812309973640729824546748704825441253400743153558239`50.054598327825296 THRSub[2,2])/(1+7.46482868224306413421704352032988316112369253069467642109366795275284606362135`50. z),((35.97360225664799404717694414124167042077508903108982042917528175241765229929987`50.+ 37.4607679214808405755639955137903912608891281821305640766880997899961514675999`49.69897000433602 w+63.52039287986065615881215108633886940532365389504234237971468592585032388505098`49.69897000433602 w^2-48.22279531018382879765541826401467847391108953272249534115295679014117847182927`49.69897000433602 w^3)/(1+0.16779315723075886975763084325261466501490168307995148903752304220776170061043`49.52287874528033 w-0.28824884851814606475603220058547831990318087755595995314626143500951073437056`49.52287874528033 w^2)+69.05286017729270869519521667236056994352017317943552293621895259816660914083433`50.82822928248946 THRSub[2,1]-14.81078726540350378778016219559972257723312431320319104883160207417160422998497`50.82822928248946 THRSub[2,2])/(1+0.17441899718694909161772955267237078493642253908570940322447145505941331177386`50. z),((205.3597965403371804700006794973057613654528190944164707240775`50.+ 232.9608369268150519965119669702908655438735224452419331032539`48.6996116474028 w+1247.4562147307314456065747331905850541438366490069940952152439`48.6996116474028 w^2-384.8509044603141083558710571533124462458201583887362704276932`48.6996116474028 w^3)/(1+0.77729922909230339231467784413711109593257276193200718297346460472054199603708`49.52287874528033 w+0.09108073176230437393020999497671673863716688501959946933911263764799315940277`48.6996116474028 w^2)+481.8996681512931727490250223213005079514104538872407287450314`50.056511340724285 THRSub[2,1]-103.3601425043415685019513996785586690196988612027750452807256081255361446285977`50.056511340724285 THRSub[2,2])/(1+7.19592589737611700360733671061693050902861887899279444057805638133062162090314`50. z),((47.67269935689173972021898722372174316168685432467940168233480664653034038963445`50.+ 59.6588956276345151892828922543028928224107262766027437751453`48.99490091213206 w+157.7861232079427836995094610261526849210608262400744323647517`48.99490091213206 w^2-63.9456790030140081616940794381323702571727092125614479737227`48.99490091213206 w^3)/(1+0.5315330761267303905942956801753241631320981290453490907041914299090133225709`49.52287874528033 w-0.11040443991784848435926716818178276296229439721223093928758370054431141591454`48.99490091213206 w^2)+97.56719639246445099914453270142677916943102026969486720782117142806030829061715`50.40081103636269 THRSub[2,1]-20.9266782887846743540995863297311794260963525991841613813023332011966789858909`50.40081103636269 THRSub[2,2])/(1+0.6593775935042324001837270976613290888173982705850520034329253114607093792901`50. z),((181.4549504149093679436627580644416979119945955595093753221859`50.+ 207.60849806876682899617255816445925758869369350137257366588`48.6822653733388 w+1083.8559540232090529734813150985651637530431866793666595821045`48.6822653733388 w^2-334.8623458902515916980560675086377195475847440577992339655252`48.6822653733388 w^3)/(1+0.77257909502957010674042101380196787756212438622754627098504541330299994156413`49.52287874528033 w+0.08652641068551617899541201585459518675260657726935109099240773573959641562944`48.6822653733388 w^2)+423.6361274906901682227191619610138500459051414542877478442775`50.064892134822465 THRSub[2,1]-90.86350002149850261552340478609826340328132663358725496847656830359639628763324`50.064892134822465 THRSub[2,2])/(1+6.20500663900646142993069622758028578639055360408497272580687299215630499315837`50. z),((59.34256212538797553086709001906769131440207269191260922682697875423027644338695`50.+ 74.8524030918217991883588426934091399688979120098228975676689`49.362196426364136 w+242.3627566959046701471834115920105390065337863235500470676368`49.362196426364136 w^2-84.5674189346391445071414379746639560738428245103047983833366`49.362196426364136 w^3)/(1+0.63437978498841909944982419818878853837580107534490637746405031285758196360668`49.52287874528033 w-0.03451580162822388448872101101596296445860066698908711110096131983499955705146`49.52287874528033 w^2)+126.01027945388153322518923536471535064170979535082515627166005514420573577325198`50.272953894998686 THRSub[2,1]-27.02728659542478824171777349518027242036553365258773629003765783703468249553805`50.272953894998686 THRSub[2,2])/(1+1.14312434925236180421737091772530651550317851217520511677823120887107274611252`50. z),((34.66164672985086976732816617553137526852999802096268290180550333407503482618472`50.+ 33.54310550062576188844571394674161833564444624759863467150407803677594203946006`50. w+51.53352422380932855783938459624455506233636486482158933820844473840080484269202`50. w^2-46.37810394536408749110336682412527431207418975604777895516416656989914217011397`50. w^3)/(1+0.07048340678795649723119526292801413701590429780814978601374689660598792093902`50. w-0.309600715849750684669198031595349672065078158186464863431206034849705346428`50. w^2)+65.85521674635934629705103332359950072495412104679591913151094968668789290764685`50.96992382075931 THRSub[2,1]-14.12494142955291706159467260059225672278095669717479715131405101061408312960358`50.96992382075931 THRSub[2,2])/(1+0.12003496179904043971687096287910407298954008025060088196908430841200855165373`50. z),((264.9964629740369186681563326287081349970324247536949300955874`50.+ 369.1835414801448017362744962261744456877772041274336646311652`48.165573483349064 w+1758.328152030033029296918483379555062260762302455490882452768`48.165573483349064 w^2)/(1+1.06074315191509381834596076901660093188483971230249419085448530733808612346011`49.52287874528033 w+0.3952989117227337950954080277933304335524123365970009174146587537882833243387`48.165573483349064 w^2+0.20106512556019858639316408690437872102636962139659712300974248834823465799376`48.165573483349064 w^3)+627.2527618876578612830962227233464752339950817195190375843105`50.04274626483555 THRSub[2,1]-134.5361682934293754620927062736560173283021083077966616321603`50.04274626483555 THRSub[2,2])/(1+9.66802385458740536702042714778076130201611215768513064288824935487756561298649`50. z),((35.04797652653640916371601144812101770489729898203453064561111949583768392255744`50.+ 53.1611991617420270716364879614054840049230428611501973425343`46.977559605542375 w+82.0205595012187266125413019409786970128132015918643370687256`46.977559605542375 w^2)/(1+0.62672883243505719803614202313655832550040885526346732752247356370144131895787`49.52287874528033 w-0.00340610762070102551326948268488565034814427654292464365057954127449759382607`46.977559605542375 w^2+0.1346283593416249215350512391439354690498565036903216423836`46.977559605542375 w^3)+66.79682254877643195458846639888715630371360237494321276094525655073100186841973`50.921700708723996 THRSub[2,1]-14.32690153941169720564226608870421544845382835502303075955123362433859194225291`50.921700708723996 THRSub[2,2])/(1+0.13604935626989727155787638841056046437378211281400474797927802135777413428384`50. z),((50.67318442926250505074563366209927093127352870965101707539609642339738307807416`50.+ 79.89279231030137065115111815294883479623296153970917389247813030165628943818345`50. w+205.0987901323488380703565199079319173290277131181842866774785`50. w^2)/(1+0.88471096105155345493433195498713737391580021735596857140288325271567377802791`50. w+0.19203533121402727717952692410462643267279589564236474161166535368277996318633`50. w^2+0.14138561380000148503931259822227549679016460344284956695578678114744859627505`50. w^3)+104.88031119346916955144992923957241213675017597192815468414750752244444400211446`50.35715467528572 THRSub[2,1]-22.49523008065921464615890475666010838696040050882335965067177529103172015165996`50.35715467528573 THRSub[2,2])/(1+0.78375565588800148289994494939317552225356897934340827527825645420239702391391`50. z),((108.11999436046704506020868480860321717360274084566930228056781181188313684282732`50.+ 159.2665925055881050583940896441715882795519225102007514001869`50. w+625.3813683410129839098709284589786792159229605475603202874928`50. w^2)/(1+1.01730685916422048374463779208440056619529841000382842038363904008408159211663`50. w+0.34018753212557875318549303542070876103471275396960066970544609943301143128666`50. w^2+0.17793060563351833242344302332248175746726901202807353747697994477408117721279`50. w^3)+244.8960439317934879506531080799585377603094907710077609066911`50.11923871331781 THRSub[2,1]-52.52647319025082076518191362077933585504210507830722369082119459571239000390445`50.11923871331781 THRSub[2,2])/(1+3.16507825441248822759428826706921075545752281071505300764481562924934172648845`50. z),((36.70359294856511540014657043413370039722549331309682727322399591433885897465035`50.+ 56.7443982303441052494928246730349166484894391578627480048841`48.660462597810714 w+96.077114975364913605995263084612443223473140748037776518509`48.660462597810714 w^2)/(1+0.68492306862896137229038667419456494986546017312921874838443889098761500927738`49.52287874528033 w+0.02885161067065837928249512503773808069134644977745501507957087183851149566715`49.52287874528033 w^2+0.1336906892450692441546868614130808990282239815462409930517788665002483514337`48.660462597810714 w^3)+70.83207440595630151956552022300666298555350255936474734673116354713474822771869`50.769797970479615 THRSub[2,1]-15.19240163116124378103574227950078469443929757134548574949669477175947643853116`50.769797970479615 THRSub[2,2])/(1+0.20467904702185761848501411588001857480700771094382874598531361757825329021929`50. z),((34.38716655277532934614640479000981123054147099013669207704322415200957659890475`50.+ 51.58216048863795465260044178530472138614233861244599386247242983380561646269442`50. w+76.25452680776964188562513050204388495886583734190030847931031479547864428847208`50. w^2)/(1+0.59760779769068434547920002421637996018734606660376569340175556015097746504043`50. w-0.01674201352575108387098405915625938862477988540849941199262374908541894302719`50. w^2+0.13502909030364399138789202124940397179530834220555010038947469215014480232338`50. w^3)+65.18622323459776166958318079065779482508357762404929332415176211285344981011428`51.00873938290797 THRSub[2,1]-13.98145250586175485942444423508344829257492484059548370671503058600233904900882`51.00873938290797 THRSub[2,2])/(1+0.10865703064325063728600901346553587253251517993371230506927570869307653328167`50. z),((36.76311091515670656609345381407422534678411060563253276748004310343358053093146`50.+ 56.86561263554996415384240284026623275416262771467375194475098745849289736201459`50. w+96.5737544436155587923655624217110443322395622222967181010745001072306458862634`50. w^2)/(1+0.68671081214995852824449835085447788287167821559928039179277348768192674100142`50. w+0.0299585707296028087478943935823103583507129446764065135126822024471900746295`50. w^2+0.13366534631824525463748108687743966193837702153116040552353592377483736163646`50. w^3)+70.97713819128043830105733736865260189387560308668370714813243228663505636188446`50.765482858168454 THRSub[2,1]-15.22351560470026406318309396794228607389516441033462760284835726053782962960967`50.765482858168454 THRSub[2,2])/(1+0.20714622455586711488917361078347508279477505223876288768845031205562645468716`50. z),((36.0574526261301268505784760069875051917730290463931170966107818851054814713561`50.+ 55.39811067962889082119201961511977116011537551821935640769620120958339600892403`50. w+90.64952410612538944858507506253917699140377622346555996821762655397992675663487`50. w^2)/(1+0.66429319691935330252036955322657833095480500443714536913305875674560979259385`50. w+0.01657314864701428366495332606902351310936684486459845210982830421718721916794`50. w^2+0.13401049674942464485184523391963498497807618879520738900365395940988693553129`50. w^3)+69.25722959201703786471484123617889754250093746616259295529129744114180584295169`50.820943215073086 THRSub[2,1]-14.85462139359552350227252888268246546416020176902401239844390858015857633686417`50.820943215073086 THRSub[2,2])/(1+0.17789481734095853888987085606629589641676057966204566790239621261124817068548`50. z),((35.05399320568915347089403738404617411727891730685841580048523817150945774886324`50.+ 53.17510855711117070769982217709591148018834472641033084262635848189343321447593`50. w+82.07259868116153498134076852855402657939351295998805033977113085618207888788991`50. w^2)/(1+0.62697559174685828061992433351955375281498245313539245633057350991377860046558`50. w-0.00328501648269649615366458115922355376962805011417774609033800298099682230713`50. w^2+0.13462450822700460913792722384068940842393056676580698795321987625425129243227`50. w^3)+66.81148706611397857777984144197964309460364491679336405832434322312717098716053`50.921000617936535 THRSub[2,1]-14.33004685513183657246462727900040655026743258439867710834221512788313935354058`50.921000617936535 THRSub[2,2])/(1+0.13629876357470078059729106455094747354622385871838828958966363750130056413793`50. z),((76.3575624392564800476589352389340663719793317542936971762308352306651022046819`50.+ 116.1345994446897327126755887897826809807327807899941984075857`48.19114156229658 w+394.5758002939381830309062630081017334690722480850635708373846`48.19114156229658 w^2)/(1+0.97852785158917856320924727379418279719328487219691113471145304740442575263413`49.52287874528033 w+0.29375005354916333594356795215203024459663387169690507561195258647397977638977`48.19114156229658 w^2+0.16271818822185452225595913838695461735854899993678851897672373036076357899796`48.19114156229658 w^3)+167.4811242117039912915927855074294296533767894790599257167336`50.187801616400606 THRSub[2,1]-35.9221514547179128077578498451730089867233640026069302320321125328195952654162`50.187801616400606 THRSub[2,2])/(1+1.84844122950800879224287338961216866526177268530110072715673587684921430207794`50. z),((35.73731190218757595935032738913789820628729153618323097210382331303623052872034`50.+ 54.7082036522406381251865246817620568076636825868836855806813`47.46114539952606 w+87.9340992851345567122724374565696675578192853789660610482778`47.46114539952606 w^2)/(1+0.65315555797542480109027551410310607328738428362940383600041033102082119069685`49.52287874528033 w+0.01032672620927960003471271928762602341387079882968832012404735756938345666697`47.46114539952606 w^2+0.13419535149757433059087635147141634012726661241635573518638907043634753621821`47.46114539952606 w^3)+68.47694713428137314492022217288862343512175215633958038612282357670325828927019`50.84969227890819 THRSub[2,1]-14.68726268522663549437496604346739975815450497228488246874064300841875531125188`50.84969227890819 THRSub[2,2])/(1+0.16462413544329793210023358227870983663044955858072619787547528081591881646616`50. z),((34.41536244641647342015939933157112413597161268422101201355333304496372786669317`50.+ 51.65179273105508869160786381826976426638043720234947935771016314617456534531893`50. w+76.50271242125851417937459819825148985095422212380704513040361542403758748005753`50. w^2)/(1+0.59893876784834934185698199661229027525647569642590470468247243117732558171777`50. w-0.01617395410997169099339567268395382693918535366787600936726111015665253619395`50. w^2+0.13501367724657364911547721876826200444823199665645937195145390528571801547578`50. w^3)+65.25494539189604192600687011241580814833638606312012154532340682215177498094049`51.004550351340946 THRSub[2,1]-13.99619236239414405501474048784241351637715216872253036418394298841625037783412`51.00455035134094 THRSub[2,2])/(1+0.10982582519935665984169607956102295714213922961134715028033449291370700363535`50. z),((48.29482733418032691295758478838227033804795587323952303976378231090743291341326`50.+ 76.3253089931327368302831695986873402048344655338872643968151`48.243043675154446 w+187.1441054355847829861708017649949361371007816368492820908623`48.243043675154446 w^2)/(1+0.86659592594456284025821999535296521494176732212143224669939715252124288013091`49.52287874528033 w+0.17415054217153763165118383967853491641985237525020559888712175838452701759406`48.243043675154446 w^2+0.13913509806187285878190145896450182212370362173036987692855945656826520927334`48.243043675154446 w^3)+99.08351565721368611135924618241860024394475664321537215284451186755300770746188`50.39084671592933 THRSub[2,1]-21.25190568702673889724905584273055341793720092761242639120915429908736180131087`50.39084671592933 THRSub[2,2])/(1+0.68516644780729635484998958046599878544440423056203794115156361195735276992123`50. z),((38.29984173159045059661739013286622015985904468155134944061293650660396091609602`50.+ 59.8624358793520370026881650993743684369874965397177414248429`48.202901428957794 w+109.230005124377756596248173720004867035482417913506121103651`48.202901428957794 w^2)/(1+0.72747624809965994700714595098035049593173620262874081365595503216323864613564`49.52287874528033 w+0.0570241558246225628259948381629573969303485880577377021628075845876586536484`48.202901428957794 w^2+0.13327724176457298765146623150719361047970650571258039268868298064792727520977`48.202901428957794 w^3)+74.72262887287279803123818671254376768902905264496488599962029028914537350192152`50.671368239577 THRSub[2,1]-16.02686633553440162082126053135785557542966547172873676050910523609727240009948`50.671368239577 THRSub[2,2])/(1+0.2708477917169512201333452216773133414686887923654639846718529889794308928769`50. z),((34.23864749736408054287013245803785123009479651135273655452439168888915165796023`50.+ 51.2116886624510119724818470856443454461690394147858805918494`47.73373042798264 w+74.9438427671801336139716699774743674420213375330379834262913`47.73373042798264 w^2)/(1+0.59045306044991388462640874416436477378651132486206134794311789888254711921057`49.52287874528033 w-0.01972730333328021576399918727498906584947123678757637807260353901689907039681`47.73373042798264 w^2+0.13510601184431286663015204428621928572284153509735796445288103146910185884395`47.73373042798264 w^3)+64.82423613045894418049149092005435840452322301703321903965922439910092122109449`51.031652726727906 THRSub[2,1]-13.90381178282067653284622820462423996189039455603862992075137172637112889123476`51.031652726727906 THRSub[2,2])/(1+0.10250052198096186825082934756141656019783535315010307409577062204293227267214`50. z),((62.35502234780238592219680806172352474125694272706005702338560478626889487508458`50.+ 96.7054036029949715939829910310908275587122240913606671910974`48.20538138939302 w+291.9385783496814431083147536568048223541453553095941405457543`48.20538138939302 w^2)/(1+0.94223954446737974747662486528191326493002019532925747161548840245813042625411`49.52287874528033 w+0.25261957917284973539944924505239984309164693016368135591479990329211497822274`48.20538138939302 w^2+0.15223261363707106454825280839755167221833108913320997402614016566696933684212`48.20538138939302 w^3)+133.3525814179336043448154357607554183292449501120686817226442`50.25252397587667 THRSub[2,1]-28.6020985894352733293036360996102058329000176053239467107310635505064422666284`50.252523975876684 THRSub[2,2])/(1+1.26799881335893853564211938011861401968768597902078672773174421826480200321346`50. z),((245.680335321640696964635452755661652120093251971725185645148`50.+ 343.4039401342844231515874285112622683885876383763607999125009`50. w+1618.9860279065201199281813853221881868595182573770191923104577`50. w^2)/(1+1.05866369839530848686835602119310341188990884677314135160031602347544717719706`50. w+0.39258445556319868404023452102250421021236075480746660951645672020740531733734`50. w^2+0.19978914803668209970576332296735392693089273165284538307013457124682365902348`50. w^3)+580.1733545166286465174367430620046068449264643827224132060232`50.04640683559259 THRSub[2,1]-124.43835213688909364182193123407380406586624468166190093555474034528458461602988`50.046406835592606 THRSub[2,2])/(1+8.86731914444388802713974723754271054414210256528547495448146468970443301940532`50. z),((192.6762971978516006386731478035512785689798168248438737157086`50.+ 272.6149983678574637514936168044499908408897296059211644917742`48.19832544165607 w+1236.5112852629160127045267709283299345423503686869828425815808`48.19832544165607 w^2)/(1+1.05056188005171594372181864930684452654768501811939189495558159436930326547959`49.52287874528033 w+0.3820823216604838134717814098454665655376782041784564492699639516537628709476`49.52287874528033 w^2+0.19498860306556651747250271964487272610777926960771152562064542224241369211339`48.19832544165607 w^3)+450.9860376772792006081447839659731551980409006904261842214297`50.06066816146419 THRSub[2,1]-96.72963938866502792685734089492896409080132057847179359091606161486110575614452`50.06066816146419 THRSub[2,2])/(1+6.67016121786124745737928550242516768953886005434297846826584097353527830989294`50. z),((85.08274797596966773041582119200335071925377251615624455894627075687112962720372`50.+ 128.0652918649933578928839290732381383604109520314194114355552`48.18609980342804 w+458.1583893594962232529396410469018468081115733019429568487582`48.18609980342804 w^2)/(1+0.99303180833784374490960643234990964688916297217354639084317565213613214985509`49.52287874528033 w+0.31081688327178834840518605291539220008276846287348591260254360994543219307938`48.18609980342804 w^2+0.16787693370864281502466493354093251173313551933179905108424205408179172694318`48.18609980342804 w^3)+188.7471135271025317651478141521752378777865124336843485157938`50.16210521040129 THRSub[2,1]-40.48338241502916837265411466625028373792793589569514177846519820334947686317486`50.16210521040129 THRSub[2,2])/(1+2.21012330584568883826374542957945251984353112883540910526728545675152446442508`50. z),((35.54448457489896362121134606846017345345249753642319156985529278882638941033213`50.+ 54.28440721393045207984602991924201260304930154140496416419864904227671095987069`50. w+86.28942716692727614029809149396063278141234784015865630405572227770292595245116`50. w^2)/(1+0.64611817583403819686819393757355070027182316540395030283247513462313892730045`50. w+0.00651950150490024117728032295312442346328974007153818920403520120867627259355`50. w^2+0.13431306736282665368855776244418488362384824867562996738000792324626434171822`50. w^3)+68.00696699866339476815535874999055442394422526215922816992291835335772122043208`50.86831727180757 THRSub[2,1]-14.58645910099085401744277639118606553771456073606081397825459209272107681140743`50.86831727180757 THRSub[2,2])/(1+0.15663093142317312180332790611273734370966644113091519055171721463696007239918`50. z)} /. {w->w[z+10^(-10)*I],pi1->pi1full[z]};
(* and 20 each of [4/1], [3/2] and [1/4] Pades for the Ls part *)
Ftri3LoopLsPade41[z_] = {(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 101.8257099089797734280212454144955222790637928497500939939168`49.215221746131135 w+292.21531901895838717427632243308297682238276656768451719447`49.215221746131135 w^2-82.574819337457008319685864890150549470757817521685806541977`49.215221746131135 w^3-60.3416444010721352621985421299171237389793632079899412872692`49.215221746131135 w^4)/((1+3.41324272928719935866645601205244786628399848230766300166951057050609834356893`49.52287874528033 w) (1+5.37157374803291358099009392770394991875273697377002185964764239110004530954466`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 108.9210402465816542631043312334002833965792371820685790708148`49.20898991365279 w+312.861813979867057382910327264857899245588852844371522098694`49.20898991365279 w^2-89.6566584292760045414127560468546816412044866891756149870154`49.20898991365279 w^3-63.9352175357797376570257121677362614875072078062667973409901`49.20898991365279 w^4)/((1+3.38260799846015283741839157526214947581181634017108372018203450195302858918936`49.52287874528033 w) (1+5.84534902226096665302289669653760371387179710047835838870353126294024023430815`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 114.2115229188026757046809773591091601962151398856872703120377`49.20489316647477 w+328.2699020754359197896961808844087631981112148121309273780171`49.20489316647477 w^2-94.9261520242499054761552126349366103307753858774223932823019`49.20489316647477 w^3-66.6238847931175616445870427495997754808641761738692497673733`49.20489316647477 w^4)/((1+3.36314184849823084370676886824958979228488814866861862478899255600193460093542`49.52287874528033 w) (1+6.19776551632071133374415868811833408144493881501503665693161660397553883356076`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 164.5061476022683402830874287857438727155932001716954225159446`49.179822686381044 w+475.0533502412513692479290051848011543115007117824562896341043`49.179822686381044 w^2-144.7739915387102088537666018170185178610920328190966002892843`49.179822686381044 w^3-92.3920074160530170947797128598911096534787718818199872390918`49.179822686381044 w^4)/((1+3.2544530383218717801698173836472944435221902298439396103928316964939044475143`49.52287874528033 w) (1+9.52896415792458928361130212744199122282833258358306499553091482772063214200709`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 132.5975052157867961537152792600010951582515217400604911290579`49.19338028823601 w+381.8798177450509956652619974836021146642999940751844846191143`49.19338028823601 w^2-113.1886353671250763206687093401862833043614698189753849967997`49.19338028823601 w^3-76.0103226879737670594200551211567064180984637255291340088824`49.19338028823601 w^4)/((1+3.31110673230524823568748457154914776606426231735166401983663599989891328777701`49.52287874528033 w) (1+7.41861254845550504444466382877539651981270429977398346195481028129333679342619`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 98.6769538873349778325952520441016922255258067919548996288081`49.21830675709492 w+283.0610134538917266782820715402552283396273096211870500999929`49.21830675709492 w^2-79.425422163729416254561236908582320587287720782119881949429`49.21830675709492 w^3-58.7524706118234915307462455052798926236437923531595588953672`49.21830675709492 w^4)/((1+3.42888517329743686948463351989724597474578486341817312585113357732906912732729`49.52287874528033 w) (1+5.16081055166682748533785655560738929322968545498758247437598340469586144870237`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 150.2757767612692173691158288732611140292469060659651899372834`49.18512024920059 w+433.4858249264403176892605159028119668528830253720773784391452`49.18512024920059 w^2-130.6997427651046811178056923306015694306923589592021139506972`49.18512024920059 w^3-85.0761841080283978340570754892854987657339093816732449229021`49.18512024920059 w^4)/((1+3.27602958483140628306627922912669652879066799695779000001623628989529379098236`49.52287874528033 w) (1+8.5887281412315698460204392265659740724811646239099494792674631411486809676944`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 73.8858981219054089062407851781658698842240722326672795598582`49.253508051690154 w+211.3112346142805119216549331702800664263669033091960941221253`49.253508051690154 w^2-54.3659358075706041169872091019643342445264361676788190416742`49.253508051690154 w^3-46.4621396133982921467878368830762081556573262215954256506845`49.253508051690154 w^4)/((1+3.6334034281399247779917464526342939508355266473962775829784087362750989452093`49.52287874528033 w) (1+3.48107148511776667363304765239814626948669810363841908519504414561646955416625`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 145.3075571423117349532476323230332323041997795755122016502111`49.18722718743714 w+418.9784040370150748191401790823351071761931303911017317477871`49.18722718743714 w^2-125.7819998712885265584178470045113144646144973490761709775438`49.18722718743714 w^3-82.5254148184920192680071242400113409636699548458322980320322`49.18722718743714 w^4)/((1+3.28480720373231104549602046660600084400125419704349457990108409161129378172347`49.52287874528033 w) (1+8.26015434547993970108589611462643313582870684458859326395345933794371855379246`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 153.7539706624053802994777714386459037790584699495666910570125`49.1837303690715 w+443.6439659587037135672222546705346239258160203626686729602415`49.1837303690715 w^2-134.1412495635424508190486804337845593107275404030764416928156`49.1837303690715 w^3-86.8630829738993021671644906697245122664139390559512205691978`49.1837303690715 w^4)/((1+3.27030109948780803450444322762920157370231362788840257283913427588636962113222`49.52287874528033 w) (1+8.81865475242312974665182876043277925467153113553793651129919585754065175215132`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 73.8617417738662098830822621395770526511534712022388176839345`49.25355641652419 w+211.2417979848069899759857740996066391507324812049108202528617`49.25355641652419 w^2-54.3411317410766677160623760191131042847804104289516732977467`49.25355641652419 w^3-46.4504890594797233540558357179863433362694892411076225195064`49.25355641652419 w^4)/((1+3.63372200372846105511358346591119478081479013217989355366736597880532695556687`49.52287874528033 w) (1+3.47940492784579471232027666661688197368797413555306363399099641218563730597067`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 138.1845767626826696512570962096958728754804369053758223770682`49.190527694798796 w+398.1845574234996257272357308191107287047350426312452634227044`49.190527694798796 w^2-118.7268646832871571404218503781908504422969432153749671245729`49.190527694798796 w^3-78.8721587320976366441116676481135879715083454318088505505707`49.190527694798796 w^4)/((1+3.29878895590301325172155528679867843250809410982998727003413255701828141738041`49.52287874528033 w) (1+7.78872588979739854574911222695026202440656559609114826230295363623710505082927`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 113.132755354744951328516304671161781858971259056735565692319`49.205694656886 w+325.127277437892644260518244574510474142999884756328114756677`49.205694656886 w^2-93.8523171650379739327382155386678904150656345156704436728459`49.205694656886 w^3-66.0750968876064058249855873530630330150964810848116258508686`49.205694656886 w^4)/((1+3.36690947452526514384156155843164085267838917729851060698242332896914027137214`49.52287874528033 w) (1+6.12595566764957670480183238278795704601667357639359796773924666811706708683315`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 122.6531221457291567458671364015733179777257343974301094742198`49.19914642895558 w+352.8737385684039594040227058303134453242892168513755092939417`49.19914642895558 w^2-103.3193373920859504160549861319175149304741315137755717921917`49.19914642895558 w^3-70.926530001350972890575035548090200012977616153208125542006`49.19914642895558 w^4)/((1+3.33669074970480871353809036532691051627790660617823530230442524720492469159451`49.52287874528033 w) (1+6.75893590446679189818906868890139382769920500797852074852690199609859102853017`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 158.4034502277953717873208502102894149957459083090044408646529`49.18197240021398 w+457.2247911548649408477532111675594458452666772461590973456922`49.18197240021398 w^2-138.7401292880985067153238468515769792333339380404852565805009`49.18197240021398 w^3-89.2530324378948356352990298336196638986221110825757437443999`49.18197240021398 w^4)/((1+3.2631248355314416972996171820931925435777620345259146429186619952400822746997`49.52287874528033 w) (1+9.12588908183200179365805504513642823446680732026491501140475799090492873446935`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 122.853290438586063936473702432120362191936184581917960177394`49.199020481306015 w+353.4573805971524272855673675435699885225615563362623091132971`49.199020481306015 w^2-103.5181688107763972472939076214492780864640230214695877403634`49.199020481306015 w^3-71.0287137662648348388278523677160543933082656116415412670139`49.199020481306015 w^4)/((1+3.33612187762590850385560515427114148556427677118032137672080611808588982434414`49.52287874528033 w) (1+6.77222786435302910181742060681076234762501430366511660722463456569412052125871`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 153.8328974313153664729199451053202172599297807743192177098043`49.18369959606801 w+443.8744880877853165283455194125682717509482579460191363686468`49.18369959606801 w^2-134.2193318289650286171149138682533478061192747056334955482012`49.18369959606801 w^3-86.9036411683681132241901854664067463546796043892002202778611`49.18369959606801 w^4)/((1+3.27017481689881874876083591169302503024429952036916765366261154802260294005111`49.52287874528033 w) (1+8.82387129329074112327736243613265420314801858521170886361149150418800148370103`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 150.6317846407324516127968891873828920822486031321142610583437`49.18497488799105 w+434.525493617016828102315612279784954881317739992332072612514`49.18497488799105 w^2-131.052044349195806473092915725293573903841820306865396659517`49.18497488799105 w^3-85.2590397512499657494206665802015464651675105454301163209825`49.18497488799105 w^4)/((1+3.27542818249720151981639010780652330277476979730650852079122668015787635958931`49.52287874528033 w) (1+8.61226587075796124262217824286022177662758642634356728404276218061988352827171`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 115.9848757777622110392978435818188823872147100776339182541904`49.203610770898 w+333.4367869024239813674260114892719042367127829186643873208927`49.203610770898 w^2-96.6907299795761465332340696332746985668220022756603081415743`49.203610770898 w^3-67.5265808073194034936459471375622018038291492785765496589109`49.203610770898 w^4)/((1+3.35715413322958014559726251124801007345961557469738397265497879710192088832061`49.52287874528033 w) (1+6.31576007820820844631205933579491514048699514630000028064031198106429262530715`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 128.0302688737317337912409375952124107248256864480365052223704`49.19590959377152 w+368.5554014429057760210719293471119975916752404109457796736078`49.19590959377152 w^2-108.6579642290528474921125942222499081206618851124545497695643`49.19590959377152 w^3-73.6736987998787429421687865540653380938559381545409945339496`49.19590959377152 w^4)/((1+3.32221437611074723202869023397302737009301124490074435670382727404411593457963`49.52287874528033 w) (1+7.11579821357350576059827427460666632755856438446903030723433375885079547062298`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 10.5564179469232526493081709226495567562804289890224652474134`48.560988039420685 w+0.69635250212852321285272148412087055206713947901799490123754786391681981629823`48.560988039420685 w^2-8.589094857249961505978773416411527260590111247542560651849`48.560988039420685 w^3)/((1+0.37008320936805704303774559334513204744564786472275883714731642877081594208626`49.52287874528033 w-0.79704319623269196113690921180645397855427055018259313570016605354178537987263`48.560988039420685 w^2) (1+0.13657072539584742990882138328140887561524233074617173225629450835920992141488`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 45.9111049323565780368220687829260723957874517816036912273551`48.69191929629853 w+75.4816604524783606476320347936048922344241802400007605673943`48.69191929629853 w^2-64.5677639329602285448261978984765547521925952221716945915598`48.69191929629853 w^3)/((1+2.22040918686053761154963756438315081343161493333612624844406452442011315017138`49.52287874528033 w-1.0535381293016498784292934762693084769418696518931217098637082607546243771162`48.69191929629853 w^2) (1+1.99655990889790924754453511126999645240753308281349307506983486039193855636525`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 11.3181451040012808198351321761502701620031699123150399482729`48.74365011444508 w+1.69525850714867188320065054654401175685405589865075804362319991191679705446708`48.74365011444508 w^2-9.7635100837765729810791446896844165292967520734012031339671`48.74365011444508 w^3)/((1+0.50981877780177584953505352779802014046791996127251563879475610167912464340327`49.52287874528033 w-0.89266327562055040191781195136158429390870337328033289989591931430066593297113`48.74365011444508 w^2) (1+0.15167730346042687817312689077407313448744560813889982440697790486018519831872`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 12.4059408512142298114879115045693491703187309244936933999737`48.78664992235911 w+3.2290650605512918288753138102316015102567704238226900829336940580193496121844`48.78664992235911 w^2-11.4317853453264529007652171173659112077504402697144008975047`48.78664992235911 w^3)/((1+0.70063301367946067149290611275418217547868035499440737031058894238117824268766`49.52287874528033 w-1.01288850399725480531700714724026340239223725848525432092489156415617621333053`48.78664992235911 w^2) (1+0.17543477897944757724479523326329329051460988277125857241582814965022185954771`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 58.0435746010384093882768528268677561755161193061803135569351`48.6778531334773 w+102.3156423326134657627156960359453939062817758295488276184314`48.6778531334773 w^2-84.1207363607610664181523501562244783891047556373165302534606`48.6778531334773 w^3)/((1+2.25271588271758613450762599363647581989636595291905672872009720133690583821889`49.52287874528033 w-0.97994950323407244281779252077031707479938120896699720474604348006775442846376`48.6778531334773 w^2) (1+2.78550678981055574573272454698933055858373954486077995267875415794488595632466`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 11.3412345643383818717751398988174834122919092477306427871738`48.74608556904183 w+1.72649780460676493103044650399097788333433657177562591842470518193360825826772`48.74608556904183 w^2-9.7990221692761199638102985776628004710652204921089601680811`48.74608556904183 w^3)/((1+0.51397913502699285515062912467240721535250921199080222057910388632313340613775`49.52287874528033 w-0.8954152948536246472074696807666551310375884839382971022116610822084652543619`48.74608556904183 w^2) (1+0.15215404001568400974339408282558526542030306931874859403462831400358297900029`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 17.2485239720491648568038950340479609239981362546982346201458`47.935384308216165 w+11.562266672521158462238370529910117008662450579560022099447`47.935384308216165 w^2-18.8250403014373631988975173607762388400116371629252942100692`47.935384308216165 w^3)/((1+1.39398399924838290693133325509812601832276887436151352585486513758766841347088`49.52287874528033 w-1.3224990646163160396470134264307989014680607849139974484284`47.935384308216165 w^2) (1+0.32022293103622734982930415399342051070223481841737375151889110273460510249046`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 88.9279423200344082806859954026286800037571778242493374437545`48.65383745556853 w+169.9805629309606135684156174097638185150167478257000932231611`48.65383745556853 w^2-133.8748029285208634215562886753089150626395694668152042893731`48.65383745556853 w^3)/((1+2.28233737925009228059101290760638503537991199909271140448206677789353861223571`49.52287874528033 w-0.88780617074197116917192219616255620838491956064441180836826991595518598866037`48.65383745556853 w^2) (1+4.80700148480855322404167550595560007554620724253360180586698278303862915951775`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 14.3015626542822104594826287996390969184965320928926157604988`48.60610014357989 w+6.2058461504055377228413427629449902317657886190555137105343`48.60610014357989 w^2-14.3237420857807269672462314661700574483428970187996334812057`48.60610014357989 w^3)/((1+1.00486959163964934657562770093826143730213178716911328192702476886356948443296`49.52287874528033 w-1.17652303606578915632059734442819630572176810774800944216579142448984909454667`48.60610014357989 w^2) (1+0.22390553396101957513070210377659996946458797739612328001959735210012022775447`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 126.0016538098541569474674237230043431622066395394315726693573`48.63861561249479 w+250.7804541889448867457265652830197670504285990991803980829856`48.63861561249479 w^2-193.5761664096360066996810187261882071316521445854066733215108`48.63861561249479 w^3)/((1+2.29408577655623347924142933245033132916987687863844080459286419392126866515211`49.52287874528033 w-0.83971359875721066697187984862415590282076256159607900280104121555585578775652`48.63861561249479 w^2) (1+7.23956368043368024555449369816345268769028650028674261378535612363308140322203`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 21.0378535669380849609224743268673246293835174270561352162436`48.55432195185345 w+19.4563575736453769969246786482841115407679533108018098746288`48.55432195185345 w^2-24.6992311432613400159305582941633906636550438852120736898765`48.55432195185345 w^3)/((1+1.73603794254263896874858050599562558297968700910193818654222240200207594244341`49.52287874528033 w-1.36338900114291725570567297414176099582151447415753719946931280647617045269041`48.55432195185345 w^2) (1+0.48364350619076757479154134590681403813996463182147643677704749979354307505235`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 13.2080120146407970431590767918255715033536285442528917531321`48.762005651621465 w+4.44159728081461956281941828011199418737596500340841277038`48.762005651621465 w^2-12.6569188637199217984290138402987147756032562788351935860842`48.762005651621465 w^3)/((1+0.83403315119680799022471328091011946755050866705301227950200956285597946389757`49.52287874528033 w-1.08918640951184416802169141638845535945517444549117819085158978131095699666404`48.762005651621465 w^2) (1+0.19477555095660056570082510243092211346244899875538928565884436977434257722201`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 133.6231830129740311566801593469859298190728812580637637416962`48.63644622201488 w+267.36737917865981593869951219562530291496238544748248764754`48.63644622201488 w^2-205.8478018865009391823674288825130678778700820379777544812772`48.63644622201488 w^3)/((1+2.29548700680089682357774214411490336516339359180646808914246285030964559806488`49.52287874528033 w-0.83330323060737286470358162939163712247359784006228665000177345666475783918703`48.63644622201488 w^2) (1+7.73989777307746964949169009828259639337655093854722492595987928324654885656786`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 30.5119182080188134253084544097783679633871838778812042124328`48.698870886837476 w+40.8763029531994845247543653951430411280013468239581479941192`48.698870886837476 w^2-39.7726191959298699486573126155316680209573030213551967938648`48.698870886837476 w^3)/((1+2.08822367909617552113660304461466061992844355280819534550417538432381406833647`49.52287874528033 w-1.22920308323178022299821234520895527182745409752373331482937520549920824719862`48.698870886837476 w^2) (1+1.01798088059053348180018403786664936653805285397830499196747816872497560899479`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 15.6165044122020948155880331294128911305127365558521253393424`48.158254418503695 w+8.4922887006504530715472167890695632891394736588062950249713`48.158254418503695 w^2-16.3280877367668402100859281411829650422707809226595887504406`48.158254418503695 w^3)/((1+1.19187971242894646329039485105605657044120727347208948602123093236288721680683`49.52287874528033 w-1.2569462347593343060635951158021325496421873299742044900584`48.158254418503695 w^2) (1+0.26353603895551251642608797294761941908599312163524019967930370203551378636536`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 43.376404286469453685482405752359740663691009015787475931279`48.694981129228545 w+69.8386299552438323015168308786126276258538572032287323246593`48.694981129228545 w^2-60.4827092329187783184949297306256377752013024709595273587123`48.694981129228545 w^3)/((1+2.20945183172127148466477444556850476824160454984520620438900075459763668674965`49.52287874528033 w-1.07441096594621047265059452829589315359028063492954631678094914397674878194373`48.694981129228545 w^2) (1+1.83278606656605337662299930502404493020964892764720027663832600396071703497746`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 21.4792402443542426117203977640142493550466289764606574009692`48.57497882928958 w+20.4242372014932107255061979337162935241072575100217135258864`48.57497882928958 w^2-25.3911562077679194666456855598520756354421473460090018666383`48.57497882928958 w^3)/((1+1.76550732777056773942860154202109264769300007286850856529708123073149592715233`49.52287874528033 w-1.36123058556817031648717346529496350764622346349215141962232903580477092041253`48.57497882928958 w^2) (1+0.50527236496951836648052375795389488167673128518377908260947988060279841912716`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 158.1297285111059615916666633524764144871285186103586122533988`48.63080133368059 w+320.6716704136747802322372467397248867053393077333082543035992`48.63080133368059 w^2-245.304241087871285951093352527921366910828228614316927841819`48.63080133368059 w^3)/((1+2.2988739389327993205100495249007144826720654279391430946569031035047353300732`49.52287874528033 w-0.81706720260449892796314423828743535698243321375761259978148305298578052316034`48.63080133368059 w^2) (1+9.34897008736702960127962446512566450460157813404446548754585688804926336161923`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 126.8373717549493620628118292193311804174494749751704432058819`48.638366005543226 w+252.5995194521918671731048097097419696689347136521910889105587`48.638366005543226 w^2-194.9217988068004666116819566681064691700326161772166336056542`48.638366005543226 w^3)/((1+2.2942499974665740280327173668565047749991215178832885220551134994462014163762`49.52287874528033 w-0.83897097866690887023735279409776514515360526658743152720390591248838839683476`48.638366005543226 w^2) (1+7.29442380408096259768586621121841688314673825231245355271964673769068102951361`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 9.30406295871864325188917546685310081635916894660280183025733221623803031374646`49.11484269791319 w-0.81484755682281853116052920932295056457794769449159596187380205508906384564967`49.11484269791319 w^2-6.64532418684058316584273056814151963917561051109986125792693324817493769716792`49.11484269791319 w^3)/((1+0.13072429016072527689897228765688276946644410251493157583581977493420823400087`49.52287874528033 w-0.6198092267790535198220222414402635323975851765918735493501538108912038625899`49.11484269791319 w^2) (1+0.11413895962219508256197486224239014796193129770851539502745374242584561172109`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 8.2720840548430133818192820938105367646601126918816565315498`48.86222337557727 w)/((1-0.14362180290084244297236504849860826406554014327555469558102575139169089919519`49.52287874528033 w+0.23009278490200728536620321656070921354043800846567111035979276511654907177094`48.86222337557727 w^2-0.19132985007923195846383914759889694302728968725621638031736674030079692769084`48.86222337557727 w^3+0.26259188649863947261774591180686862379941567183927651251622549213143096189339`48.86222337557727 w^4) (1+0.11493124832641424734273590900109446499243461249562355535169560036468846430312`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 8.1429762253795537213005550407979427013882119781594356178144`48.87017187125871 w)/((1-0.14190200773546592668736001441893604119486442024059544552976999504194698012149`49.52287874528033 w+0.21597267591970475045341321634657216586536083297000923484490513970237622990576`48.87017187125871 w^2-0.16986422026117341376664909452264739386312621403189643133195980180174905528831`48.87017187125871 w^3+0.25185204892788472752317295213998890199948574241204682238118205657258744932073`48.87017187125871 w^4) (1+0.10601976329294503108412301926137095986274300711279507751251493786775888155444`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 8.6185151587179439734640421715567471611809415039192408609806`48.84275543467683 w)/((1-0.14628942921363677451230015055306158253226191605739902816481349967210335239393`49.52287874528033 w+0.26332645537462267580721982088210214541896334113754222956219018800119633192204`48.84275543467683 w^2-0.24344302372049793456553468955202198831500602468569881474256096810188546901717`48.84275543467683 w^3+0.28913646118463215141638530417186498298419484520372634176909920912012534327527`48.84275543467683 w^4) (1+0.1383564026044257888029229013009551929207023499125311011100635966275590413175`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 8.3028326704058880487728852053301891908352993066997177103268`48.86039280995659 w)/((1-0.1439661657406971706577116830578047620530797593531505685057421625017436393246`49.52287874528033 w+0.2333033537389148024274640182794054383504145737328617261462324542127886471868`48.86039280995659 w^2-0.19626465512923774588260382983545879089952094886297998105613306280701762299591`48.86039280995659 w^3+0.26507674724742634468968148953731717410248585791068175968404092889037940064501`48.86039280995659 w^4) (1+0.11703732108065436723912678664583425982199600945927402577206627290769288233905`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 8.8258924614059109008664375105778284010011270203758284478157`48.83212122405458 w)/((1-0.1468312713111041724088614706424445255401913729593448040366947012492710961187`49.52287874528033 w+0.28055165561686283461241556498498353838992887032531606113270227669611303886464`48.83212122405458 w^2-0.2714131572317430919506212438335172678636222819148884232047131569757733992639`48.83212122405458 w^3+0.30366496795608777607062567846459587287458195996865337667647157033514356694163`48.83212122405458 w^4) (1+0.15211518958274667000422788863125517070466770427020152611422590104742539501255`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 8.2081534267739346607018051265288209380076244824582226994321`48.866104126338705 w)/((1-0.14282760347840303075718917314638351679303928655783714584937859472044622785438`49.52287874528033 w+0.22323393476042129610800408183962493982028919338873403504256739745841073773307`48.866104126338705 w^2-0.18085514863245356888540319869567353019753367867501339191013154778323655423554`48.866104126338705 w^3+0.25733714973879325426617101501866015669728922527467584693541566899161099093857`48.866104126338705 w^4) (1+0.11053287618889411333961863574307154503655469842706342893062656301635345386693`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 8.346752868662535641402845005547268648314803902501394455397`48.85781635682175 w)/((1-0.14441789971220358458565170882962511455949858453772087124204593340599743009786`49.52287874528033 w+0.2377939203835693310757702836394415168522453512715744057904217311016103655021`48.85781635682175 w^2-0.20320141745565892278756908004633711141736091507214048826363999505995923349301`48.85781635682175 w^3+0.26857975036583769793476988177457403765240657553816226525251056655058660600903`48.85781635682175 w^4) (1+0.12003552307214285636833542959940040719907911985917710884851948107249987607384`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 8.1844178077135604810680556227929017673991306779461502759986`48.86757196035838 w)/((1-0.14250455860001489756663174752794487446614259990009829492697922434557935249271`49.52287874528033 w+0.22062189873957004000716452250459287155575703949050765402831468355129060224917`48.86757196035838 w^2-0.17688995935847090360019195855770754337977754865679258111447136765942782484953`48.86757196035838 w^3+0.25535492524870229910706456996640911287266805541224781316022075680261327817137`48.86757196035838 w^4) (1+0.10889284072445498064998113675727011412288567829103247695392875330514860504429`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 8.6571405230366859720951523399241639080986038688868618182577`48.84072376488751 w)/((1-0.14644216452051004129248144478497398034093625698920210438922329193460388888192`49.52287874528033 w+0.26667066193273365376749140436242424503845978093038536797759827242381875587089`48.84072376488751 w^2-0.24881937084080577601445185607204983472744394796922073434928502656178185952803`48.84072376488751 w^3+0.29191360877143658204361314512893007641609615288783966001127100417174245731793`48.84072376488751 w^4) (1+0.14093201912361620759782217752540592538206043357401346680972939835093203418355`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 8.3159870324338979012025490965656517655552737212645216825378`48.859616508036474 w)/((1-0.14410633240990703878308968698918914768944025185345204024868560425798335445832`49.52287874528033 w+0.2346599069322792977901062601491799430097519607880266747254249975919733316558`48.859616508036474 w^2-0.19835590742953233028950236643061468981693423047734979867242748278377480079001`48.859616508036474 w^3+0.26613156872336538467466522912174849934016441801560876542472335000223290422135`48.859616508036474 w^4) (1+0.1179365179176801092476024921623968757382377364608703497246969153478405850888`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 8.651310310857858360898156847239712700552351916631505562245`48.84102885847513 w)/((1-0.14642072433959500543703946396413479454224648920786256028099732507042402414953`49.52287874528033 w+0.26617004898755950361504691275608841745672909097553790840967064564616087416425`48.84102885847513 w^2-0.24801293597194545850452357051505667345850465019053897969337338955167274645707`48.84102885847513 w^3+0.2914965786037878978757505142295751608648224096493953860068030580371790854245`48.84102885847513 w^4) (1+0.14054365243890242308087438718034167004248822834183021768188727653333296477443`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 9.0306758165527839134233536714838237986493929992920812852236`48.82221808457389 w)/((1-0.14677475970502377033667234816688173618121657157920280872970276904595150588547`49.52287874528033 w+0.29595784155789924124142867583746310576518729673383640103383480784404557403672`48.82221808457389 w^2-0.29704052329429953442430225046257500969535944950950432658121805482917826343843`48.82221808457389 w^3+0.31715400994921032650897252481349849296468751193433657362660728054759493010298`48.82221808457389 w^4) (1+0.165553982822262022865832034641225484889262644875871221535980255247948200393`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 8.4860076258947915055425163284509985877596982430473113602955`48.84992161904059 w)/((1-0.14556223934980767223541035464449103995399626621385521784381964376992471979064`49.52287874528033 w+0.25133649085893664639950555688944104197185621266245186704204369885191392317875`48.84992161904059 w^2-0.224372017523309907583654044049523217341091625464532404496876477679891172537`48.84992161904059 w^3+0.27934407197390475306813351132486881576458914053712921034502965284433367438666`48.84992161904059 w^4) (1+0.12946973071942930001257831664533272398568929987611661130153937754445981288831`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 8.717424259959402963222281439912200252081496529065169939058`48.83760095338274 w)/((1-0.14663135812908495106132660591009043366819540293612421886448202378422299842126`49.52287874528033 w+0.27176225237441847307072071925178664879734089723392304895637007517061182609749`48.83760095338274 w^2-0.2570541819536173566183775181341554395693314231881006441899209666250953063069`48.83760095338274 w^3+0.29618152736067720537552056726936986028700174262729484928849253991156339289153`48.83760095338274 w^4) (1+0.14493956301703331401918793422925676934048860649581289602371802642841986578862`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 8.6098948057903313200938073815270339172359453799738803002165`48.84321225035293 w)/((1-0.14625185295097376641529721542631943842539985036565028076863658973421109177905`49.52287874528033 w+0.26257111855174261062936661922343904213818593346596317304743574865090370641705`48.84321225035293 w^2-0.24223220333454701297986200727241413413950937549954724624509105078316873072543`48.84321225035293 w^3+0.28851202195352140679812247507192966957234506367378604620752485804687843598299`48.84321225035293 w^4) (1+0.13778070798147161429449615941512791094139584724500937471305191118124470604079`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 8.5092495501052171117875901131944178371342946174362653750961`48.84864161076714 w)/((1-0.1457137855387877634319773268385573376428903629498146958418284803572385672347`49.52287874528033 w+0.25349986782108631010196416917064271663265266217958128087378976649514246186441`48.84864161076714 w^2-0.22778980374023949986150835437561141398951054715720011148574783084846107602285`48.84864161076714 w^3+0.28109229880245894396083782485892850885331832909312981220642609593394185242106`48.84864161076714 w^4) (1+0.13103445900312564001030154920254107391427316982288561565711037598510555386595`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 8.6379956273970824611192967189210371512240101312787634993071`48.84172769594649 w)/((1-0.14636962354934944027624886791307691152973135529532275385470423111073683031341`49.52287874528033 w+0.26502124880105000296025227806054826876607151542452452866736816327008404441026`48.84172769594649 w^2-0.24616450047627539868683619790194466576369227164160850036604347206167877715032`48.84172769594649 w^3+0.29054132275425552155362549430534578742680895472856369686016418375678020739088`48.84172769594649 w^4) (1+0.13965619000669152012637205820503646977143918159234610666317086319070001185534`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 8.426881727689212704053907229148717086326839021559132809215`48.85322501755749 w)/((1-0.1451273752329016567527338784256244445776411374430466546501378067521239456487`49.52287874528033 w+0.24571094700153096101001624392214050491848388225683661360015333259198014272526`48.85322501755749 w^2-0.21553130599400971737320418491964090122338661738539183375236453946026373004619`48.85322501755749 w^3+0.27483546342962145181063691182115513836526979213065030416506417885808631815283`48.85322501755749 w^4) (1+0.12547683159640564859886188449776546555841998488492132418011943591356366143733`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 8.1086605717267607842866448076154702994391883746896575892682`48.872362116744 w)/((1-0.14136444862709687930051663156567808694623597510755022253348446673527341844873`49.52287874528033 w+0.21203467072500956487562112888792507215028191226183263394222185351683788135006`48.872362116744 w^2-0.16394485591960182029547405761095216230196754462980454282415539885609931974302`48.872362116744 w^3+0.2489100235123226057522304163979067563245208136008270914119663842375209292218`48.872362116744 w^4) (1+0.1036310605021656419883231801273101091287522284483096945215169101951301021894`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 8.4183438148067171269858019935871277627850204830730408004561`48.853707809150656 w)/((1-0.14505852677422674690450277320276086437886675043446532089706541691837079088859`49.52287874528033 w+0.24488374517588162108398091562261287257791762441272221310712304730045860197893`48.853707809150656 w^2-0.21423696042346155972436368896206200689240749387955428343337530233176856081016`48.853707809150656 w^3+0.2741769977644118091875055773563132523802377004938885178519763375849606202926`48.853707809150656 w^4) (1+0.12489873469383575184035923870260209669940984180887226317295865818509854510691`50. z))} /. {w->w[z+10^(-10)*I],pi1->pi1full[z]};

(* Sample Pades for the nl^0-part of the 3-loop triangle form factor with LME to z^4 and THR to (1-z) *)
(* Mean and weighted standard deviation *)
Ftri3LoopNl041[z_] := Module[{const,ls},
const = Ftri3LoopConstNl0Pade41[z];
ls = Ftri3LoopLsNl0Pade41[z];
{Mean[const] + Mean[ls]*(Log[4*z]-I*Pi),
  Sqrt[(StandardDeviation[Re[const]]*80/Length[const])^2 + (StandardDeviation[Re[ls*(Log[4*z]-I*Pi)]]*80/Length[ls])^2] + 
I*Sqrt[(StandardDeviation[Im[const]]*80/Length[const])^2 + (StandardDeviation[Im[ls*(Log[4*z]-I*Pi)]]*80/Length[ls])^2]}
];
(* from 20 each of [4/1], [3/2], [2/3] and [1/4] Pades for the non-logarithmic part *)
Ftri3LoopConstNl0Pade41[z_] = {((101.28543805004208147767714060445586250729129950821508187393095280156333490776709`50.+ 238.5331535346522715717079639503853812928221310600843156322921`49.496957116190124 w+133.5156180271798604330469235645266179691259163373199828247552`49.496957116190124 w^2+66.5454654884884275104009857546208943917654455191266877585515`49.496957116190124 w^3-42.2830499795551966994324973706732808904955844688398791067516`49.496957116190124 w^4)/(1+1.85260201324145969453534897799901479780121344720627723535477412628245661814631`49.52287874528033 w)+148.2490148283306305280896832153689594314801354622920046043000483548477273668289`50.68207012850002 THRSub[2,1]-22.84446303785564248691550634763450649828242061114207839730445813828920468357541`50.68207012850002 THRSub[2,2])/(1+0.2625243825468194314005151615794729179722514108497076712411892454774076092203`50. z),((102.94591162570593062964808882457240687194029102363531406721925398948460910684621`50.+ 247.4532038875787142674700980225314870968806481163312809676964`49.50390226088992 w+140.9249158808728895327880154266726495959031690317479969942663`49.50390226088992 w^2+67.8094029958739675450450703566585889826808879308634829364177`49.50390226088992 w^3-44.1741858708583347333858512666205564780872437045934450352074`49.50390226088992 w^4)/(1+1.87322986451251299458887511594176901842237672604726158096552771021714579698643`49.52287874528033 w)+152.29610507873131737775502275376340636619377785952330953204132806683276995741359`50.640194373182 THRSub[2,1]-23.46810025894074606123679429936283073836111286930093634673762602422540777078246`50.640194373182 THRSub[2,2])/(1+0.29699037967614360264179918168090473314762127494253046448760964526454388067653`50. z),((382.0511708805659781070956283168168347851502929542779567884022`50.+ 1447.613194278872634569338679947770480438310489081155207586789`49.34901428597227 w+1302.4180759501057582177315309590307794926913292272966889056351`49.34901428597227 w^2+135.5414003624191597802712930339080797522900139727106194361685`49.34901428597227 w^3-304.8664928021832670619398633604352490064510038516425842361977`49.34901428597227 w^4)/(1+2.00932348155936399575414760590361570960087223348195817008496308513723667729896`49.52287874528033 w)+832.5623797855154832973108251178977997165964096840799815515577`50.06602590387988 THRSub[2,1]-128.293874557908318944264532492738585650479394532710692811978`50.06602590387988 THRSub[2,2])/(1+6.09030212232847692058271800835416937639880272125371720213210406485917787110089`50. z),((452.4889848032489027774834493859191302306376489945213443377399`50.+ 1747.5245746337185328616018058937777479215415407838474210971142`49.337077990932755 w+1594.7102972228342520217225361612862947853936774325108379722298`49.337077990932755 w^2+151.1968254695380251410863623135980486429702753929765359848654`49.337077990932755 w^3-370.0891719554456311580282469054223678535081931501492519084427`49.337077990932755 w^4)/(1+2.01056703631583547565020021579630184792307737228574957531463179180525804711092`49.52287874528033 w)+1004.2412274131020690242660023667316498024293190752013996640918`50.05400328609692 THRSub[2,1]-154.7487625957920550635554394426896796042153395044506774576474`50.05400328609692 THRSub[2,2])/(1+7.55236061457787844028342778882258149625284261548318453302891983227326766449419`50. z),((272.5804096079906543133128346659287422756336714099542894300899`50.+ 981.3357669364602393299721881322073168563588302998724175695643`49.38455436872417 w+848.1048901766997007166651532799611248451110897726588906936622`49.38455436872417 w^2+111.1279081393043743010499910784368213995114380679969736822305`49.38455436872417 w^3-203.4681617318850328118594859859136883063383234593154383484682`49.38455436872417 w^4)/(1+2.00548836202110940725092646355017112937538531708367231098638762558937271550225`49.52287874528033 w)+565.7481063496637561013202769238565510094188230466259509145314`50.101029752826875 THRSub[2,1]-87.17907312374178880458851463516348855792247584195852191415431861772574001823734`50.101029752826875 THRSub[2,2])/(1+3.81804738785787362276238478870608257567296257245305149632876495377311095750239`50. z),((209.4101204144734320229960030998223783748083640559362907667009`50.+ 711.9826585262205097730193513878039729427815491245526695077822`49.431792188435544 w+585.8622174178861760178409742835274940937071317105621284544728`49.431792188435544 w^2+96.9012722913634799132640515360761055903282129956038715331113`49.431792188435544 w^3-144.9012402238508082643944168660093699420155091716738360281941`49.431792188435544 w^4)/(1+2.00008065758713999644897438880665351050363475787848614144773859516294245855497`49.52287874528033 w)+411.7824755458941361807694716819315594690091935328745152495819`50.14578938890373 THRSub[2,1]-63.45370694798836562224364576542750873406935628907374985478074976128717357074851`50.14578938890373 THRSub[2,2])/(1+2.50683892425320730140333512162809523243831464387140361336423074488453143455194`50. z),((93.56932623422231377366111190271007423911762497208965755833919551892964700853723`50.+ 175.5739630438622780462112061041759475731812381678500642944776`49.451072031197576 w+93.0518092095723118368985176695890255605782058215262974357575`49.451072031197576 w^2+50.2685661731713791402774601114149916952563149457748266681791`49.451072031197576 w^3-29.38447661255471617728876523433865669295446475020417893397092254364236785085408`49.451072031197576 w^4)/(1+1.51727510601295929619600811405004253331087170764782531048660526907470029508176`49.52287874528033 w)+129.44245183420348744952852022600228219270410821772492131311745469598046688375786`51.03218102950234 THRSub[2,1]-19.94646176826245623102647515656470514781107678830354575558754706632794141667465`51.03218102950234 THRSub[2,2])/(1+0.10236315409290348376158537540120749911991198932451421139470581542478992874664`50. z),((99.07551537997896753996920182948977650959231046714920540163288125212641851633757`50.+ 225.630877316189581701199102501108373372145336279844668893307`49.48721188141644 w+123.3655157120475755033295936454014411458982231408504293206722`49.48721188141644 w^2+64.3647940826285780630290743824930974849690558098305667073498`49.48721188141644 w^3-39.5691673441065762653201893276332199815502769576906988634243`49.48721188141644 w^4)/(1+1.81367388440324870048938367879259986756592692709252604953315723232901384293187`49.52287874528033 w)+142.86274634250048867352730148759580315452655585248201563675066147339039594264777`50.74940100202396 THRSub[2,1]-22.01446486566543524066730559674647292916114439427130359323217907875755579220292`50.74940100202396 THRSub[2,2])/(1+0.21665362042284379025568367134960444808601245087828047072717957159848525744629`50. z),((95.18217550580162787747620267158950380424311252764935546555361353318177428826359`50.+ 195.8946944364507858411468833544173748975106229172847290814107`49.465936778081414 w+103.518444998519875140843690980817671134724998250758054018729`49.465936778081414 w^2+57.1344217441865844554225654799903611809135102048486718322183`49.465936778081414 w^3-33.449078091093059972456536494171077135029812871458749151854`49.465936778081414 w^4)/(1+1.66709304291147393568322751926326105687569195643355415812871027264688959731566`49.52287874528033 w)+133.37346685187089641084735554157867951640901678074533863974351751961671342528282`50.922287722406665 THRSub[2,1]-20.55221235201066791534375001777714134624410725626624867579351057702372932944474`50.922287722406665 THRSub[2,2])/(1+0.13584062653148849940073312018367343207753834447359493911165680905339546010444`50. z),((195.8596683525173473318996502714161743747418406172374751012599`50.+ 654.1292304208518220862293633086166083401763721406427549883704`49.448509494051486 w+529.5882590787497062846247127696414799220820387850727131540955`49.448509494051486 w^2+93.8131039842711855798008326689731977669987673487100663576049`49.448509494051486 w^3-132.323834771106564363800198054607537105502936420657102620146`49.448509494051486 w^4)/(1+1.99808144900299525991006263353137376832809900424423662254062195010148261015861`49.52287874528033 w)+378.755811808388026506495612143580046649710172591148368358313`50.16116485656038 THRSub[2,1]-58.36445627142357317191357038521550862013931752895736161043623265883743977048836`50.16116485656038 THRSub[2,2])/(1+2.22557588657932743679199154558542608948875516387771303675810967271521771401287`50. z),((373.3217754221330703379757374805461101150675523931995170479026`50.+ 1410.4411534251214681186267425543509056611497062899950385909463`49.35088723695406 w+1266.1930626017846301795402347210471093773795846783556782834281`49.35088723695406 w^2+133.5993456347512255848706805880438103911481676987522569247624`49.35088723695406 w^3-296.7826729684007647710455233704449123249429478956575598272159`49.35088723695406 w^4)/(1+2.00912633192322003353097231915102524980687743457724969234882165602822543191917`49.52287874528033 w)+811.2861295822614901569954861808922496345485641822319766018603`50.06790004913429 THRSub[2,1]-125.01530631976363926955867913315801732321874848331575837593131060383102774375394`50.06790004913429 THRSub[2,2])/(1+5.90910844166975352853883142645185297625448659843952953848024731430980766911153`50. z),((231.0379810017192965506790898671530622939335053322559138221135`50.+ 804.2510578869555593348349019047210146898969177452407385164542`49.41124390376023 w+675.6609931714850363892077361253068060204772787349960786126389`49.41124390376023 w^2+101.7957624412701576215381485801473770842294952386144335034275`49.41124390376023 w^3-164.9623771980282082912032700420323752117838551510964817779668`49.41124390376023 w^4)/(1+2.00247674077366010421936807801341925523795866924521814158985224653539359881667`49.52287874528033 w)+464.496294665041508271358652973734726969452014784341471985142`50.1265606731732 THRSub[2,1]-71.57665396282034555988446939686868218095129201760046539279902882407343319954548`50.1265606731732 THRSub[2,2])/(1+2.95576252763871844862765608856495711982905122613675125116758527264103061987651`50. z),((103.24589599954382311311719626028566010401186962911442491753436821465836800688886`50.+ 249.0158601167667668247505817778926346186084791138889178083062`49.505135055476245 w+142.2497898980912311795855740869869525463866251260071402555554`49.505135055476245 w^2+68.0141159443700461700211764942991519855712714332748638505926`49.505135055476245 w^3-44.5065041923472714765055768634921229199791571305090595023352`49.505135055476245 w^4)/(1+1.87641255572403842703590620233471984418412557149036993453942443237209158981331`49.52287874528033 w)+153.02726024580256258349617550029450129823664768356661117661017800957685186540699`50.63326310920636 THRSub[2,1]-23.58076776778347117665555568192657072795070376132643657317525274704869053356509`50.63326310920636 THRSub[2,2])/(1+0.3032170735055864023775501328951763838781719488348337542232591604912852267262`50. z),((105.48009385543966904474578937075056560430531391842364592312863866769923159314507`50.+ 260.3096673766815543125667621887491427287888339946694317141248`49.514174138682755 w+152.0204693822940715707929692783976015768459027555711138638543`49.514174138682755 w^2+69.372167199930931668051142107724921717055436780566219329871`49.514174138682755 w^3-46.9156897283922779747187936053617261893101398133618074968356`49.514174138682755 w^4)/(1+1.89628167961302461348526126687895742953629975605483943018931577804999061789767`49.52287874528033 w)+158.4726949052774955736213360802106383885192905090043318388625070778576924844292`50.58664127727965 THRSub[2,1]-24.41988316391263631642394588966810526793229876749889235004768612834381927592859`50.58664127727965 THRSub[2,2])/(1+0.34959170904103157308530451331074968486129854176095957545666824105991184761221`50. z),((93.81193378444612404730085708662546486084389135093960420250470112074247630521284`50.+ 179.324964825477985912404819005782603978622587779226702604592`49.453944110824764 w+94.8210028760083854549152038055283790541942186535868510449918`49.453944110824764 w^2+51.6371717461757457039886763748534342469882424652947340933176`49.453944110824764 w^3-30.12856549659672605926687756475577275590571962539496501099322625065887151401914`49.453944110824764 w^4)/(1+1.54754135938189423828196774512532916556106593225091237214349454672063919998198`49.52287874528033 w)+130.03376184694598886560218991629992074575045384275039102372369510174126640605996`51.01330428065579 THRSub[2,1]-20.03757980871386967967614277014425388809017704729600636008990292721718768849684`51.01330428065579 THRSub[2,2])/(1+0.10739889284365309667859714837612359826457063767226592959106506843043599096753`50. z),((102.25350097010364465042263176352918735878340527145879805908097270207063358926393`50.+ 243.7937079332523280487793786817273986661558524765726841155669`49.501033621988725 w+137.8521346830559810775110805487210660432300593006107039061597`49.501033621988725 w^2+67.3114305174227365488364488554670978356799288733016535311813`49.501033621988725 w^3-43.397082109255384073026966554169533421544893036801319055214`49.501033621988725 w^4)/(1+1.86529760278505613899651659465809389847292044174189315450187853134131331892764`49.52287874528033 w)+150.60848508005640067302306942391068801607386704468852401802075800069072447896761`50.6568972714516 THRSub[2,1]-23.20804610123643715709611627737932150325984617259326136441266903226410365734246`50.6568972714516 THRSub[2,2])/(1+0.2826182005472099205620893339802366712020953335824867349646452591195654094261`50. z),((110.79236014076390336102047272489489734779052077975419329302070327531567118270503`50.+ 285.6365865926444778864504578676574106925968833336202656339794`49.535137904763154 w+174.8241285399040791301437001862264494518396151634689439412309`49.535137904763154 w^2+71.8628690452029794020893293336714312074594581255153723242661`49.535137904763154 w^3-52.3522783645783957925084250242688094917795613835374159693479`49.535137904763154 w^4)/(1+1.92652927474985035599725220023260528189934108016593293804562325379466446201715`49.52287874528033 w)+171.4203391231463041142853396172035527363715750921394736157562727595037034104175`50.501687533354485 THRSub[2,1]-26.41505311566522565893911824466609132781613266731735403895451549096112772015935`50.501687533354485 THRSub[2,2])/(1+0.45985697144786700724387553553054648693638093383829750387766035356595421738831`50. z),((95.77807294362539434397156427821768213710620039505728868740468012005598830752165`50.+ 201.56046127132471745439873920595296109055595975266011127105`49.46992417170215 w+106.8687748480102432016995532801461716939989731720368213247909`49.46992417170215 w^2+58.780137095833627152216350450423597805259441894253056069637`49.46992417170215 w^3-34.598785261090474561631965078385236413775499527526898422532`49.46992417170215 w^4)/(1+1.7019364948836460039550857427578896389646972740203849141264417085625283316926`49.52287874528033 w)+134.82585413836604505146477163984943151439583996063200594461492964134639399081614`50.889145075474026 THRSub[2,1]-20.77601827558736418178893703884341361987040550810969903397620988421661985059808`50.889145075474026 THRSub[2,2])/(1+0.14820950712219256583751702973830184240959290016549021475732812835336434562212`50. z),((515.7623795413455550382012415828106230966465432153273023279977`50.+ 2016.8996685078981180911169408374284069324786018623531886796762`49.329613402577 w+1857.2638583834754028629594156658837552708110264923618442069846`49.329613402577 w^2+165.2446609323590061238937145290800796511351369596415620777566`49.329613402577 w^3-428.6718574790179974852901412118921667929713436266278289666497`49.329613402577 w^4)/(1+2.01133344156468382764749981343280488512400290488894613306733675662534929521956`49.52287874528033 w)+1158.4581584786435987771914166055051226232031434454550233967433`50.04641482795836 THRSub[2,1]-178.512852938097948053048176288035555087936778352512693717176`50.04641482795836 THRSub[2,2])/(1+8.86570921185017708924775322605365550037479835118471931725982499426958997394495`50. z),((322.5431803532220419121752896975455246902516782805988583972381`50.+ 1194.1863252230860300893781631707377099415755865603517682905768`49.36441270211712 w+1055.4660110650578048105578511668556589493040062179661950012013`49.36441270211712 w^2+122.2897402395839148920226481090248476877549008135455375081956`49.36441270211712 w^3-249.7543353008372704419114671468937202534077341145944682361964`49.36441270211712 w^4)/(1+2.00768628292813232219082506389463201544125483257464663001281530604650764271306`49.52287874528033 w)+687.5229092309384601155783249489130259574779897705172136275349`50.08133596943803 THRSub[2,1]-105.94398691817609037322356850119200301273013962688314422802955576317111415209569`50.08133596943803 THRSub[2,2])/(1+4.85511099327524552754400334730456685338917595935879648872487200056586763569574`50. z),((94.76883137114537032278793383093528373094843039455872918513889521584416653481956`50.+ 50.822593769080722301914774255387885046204299353699388946415`49.45026197787486 w+79.4087515044563999058963244226504077311435941633843757684535`49.45026197787486 w^2+6.31657067426972728418879743114197128908632030316912454566626515989850192784916`49.45026197787486 w^3)/(1+0.15333672111939747315269914197544153107995556460866246044081873422798703710248`49.52287874528033 w+0.33996721626527459053524206136268472077886444370704969566956963924587125006818`49.45026197787486 w^2)+132.36601871060261093634039930003777210139775669617100533222433112639119150331964`50.94732928641059 THRSub[2,1]-20.3969694193516537989915128386644311581290605445492121112876034759750155320974`50.9473292864106 THRSub[2,2])/(1+0.12726095506469629288485401335350955086504613580013939980595563344964523243218`50. z),((95.03841955265819473056156386444449925782651416702704751865139325638854679475569`50.+ 52.1997798018290800277430264179110987830317454620402897725015`49.50214386149503 w+81.7449556722423519424686574763748499167135492621587879161389`49.50214386149503 w^2+7.84921125163870296914188862023208523827655367590437668999747845652029720510539`49.50214386149503 w^3)/(1+0.16103712668994985023035475932545388728822127880233150274875750668978711943118`49.52287874528033 w+0.36066178149430919986834882963012001668929557254385762663527690954778201361078`49.50214386149503 w^2)+133.02308890853551502133128642454233179722536164464256255315165562931299345987083`50.93079144905948 THRSub[2,1]-20.49822078933435808338069379170629069386292058644769316744351487476894298264385`50.93079144905948 THRSub[2,2])/(1+0.13285672342036312942147777457558458052562196647371190609816639737496447714473`50. z),((97.93929001673583746169415477467370042195590647198373183984390300505857953035384`50.+ 64.6096324842355153478289713273041114597542135981315467005794`49.42421929259412 w+106.3922483526894386485237987723458720034648233084881337708787`49.42421929259412 w^2+24.45585315165407601139469550417700849705087520523437135258137074931576195687725`49.42421929259412 w^3)/(1+0.21661530864398032315994335335790275788212089814594657515179844206428044459788`49.52287874528033 w+0.57719763130863559948998416709615002388617198637743643938364526718613520753947`49.52287874528033 w^2)+140.09341194463099509304271846870180570622271051623550074497298685408345667294125`50.79095244775905 THRSub[2,1]-21.58772370070828362292141204237810541000024530570831163257804944740445843699133`50.79095244775905 THRSub[2,2])/(1+0.19306930045427903656350942687508076446012734183889324203176485436550957154478`50. z),((94.25060347450343060826807707829717813989488435516551241892249464160072301577408`50.+ 48.04939253380712071835407824210543781734805571174780175691005497433129319370998`50. w+74.88232657025452016115208410847319508130969123468294550713156639416744746627918`50. w^2+3.35974658708557465843897822159929369300429284337885185098037461571316917257941`50. w^3)/(1+0.13707533717117277926302054138107951878375486992289239032346255803271824827383`50. w+0.2997430066186756735941107082845916331054686617113405149146947350261841695143`50. w^2)+131.10293623899703128392677002972034049101848612977800698872966029544164442623554`50.981518645661296 THRSub[2,1]-20.20233446093543852748896960613802437092264584986927308119067561602549762783311`50.98151864566128 THRSub[2,2])/(1+0.11650423995656458936188252074716754138415940205366862942895703274979412676417`50. z),((95.50613268403979327151074476901745532649332945730283248054783681293482762472261`50.+ 54.4892382217595605510374955563788676215809681028616957035648`49.56573612753946 w+85.7725852787467229390746354065614569656600074335968889432175`49.56573612753946 w^2+10.5043129952873209461717631551416910428884294831719442478053071843853877856171`49.56573612753946 w^3)/(1+0.17324812524627755932006132452760045388348105971800668005679941438519830770217`49.52287874528033 w+0.39624629284704944929021113700311668274175072034108693330533912289396908949989`49.56573612753946 w^2)+134.16305119504289288699426371994005320045802940852041025340777819232899287491585`50.90386821827501 THRSub[2,1]-20.67388351700120367654723304154620464839960091229889690783252494181264074669332`50.90386821827501 THRSub[2,2])/(1+0.14256491732347936418142969038732801139860046938183196409332510140518517628971`50. z),((96.50195853874504644212131532944284209670328260168681747135911636915269389523164`50.+ 58.97343635454612572135125592465369017756958001185420471258944385974794846053551`50. w+94.26321224982664542026272948262520543218076862495738825333053956034396523730721`50. w^2+16.16720104560094678902909825166940358776707543929020914104075326819745157725709`50. w^3)/(1+0.19480747574042451272515775657404426551609504874990201895005303833702881506549`50. w+0.47094812732601439076134585459020878292884204772214465529643125086693969415913`50. w^2)+136.59018834840789486488977514837512205368107847801714687065205701258701765717452`50.852854170585395 THRSub[2,1]-21.04789372578443941164693517065473482500539795115714585456337274925941361101324`50.852854170585395 THRSub[2,2])/(1+0.16323500298615317468429886727644345545666925269490953154665540690018166153888`50. z),((96.48687392376045592074027867604928254215461435221300207473425955740999013056827`50.+ 58.9092379269262751249304559092773721028978541762062433333527`49.6484962318763 w+94.1352817794150358516470542197833240820439984109047574792944`49.6484962318763 w^2+16.08111572876467719326967124318635181127422237570017758302748414981787704087995`49.6484962318763 w^3)/(1+0.19452284983148565196516527105548126436232412570904272433426956634969119278443`49.52287874528033 w+0.46982513345273256010467942403605003651284416118125412483069496380421472263042`49.6484962318763 w^2)+136.55342245274419699633296783353288480067669838424130682593756296696316537312445`50.853571092725524 THRSub[2,1]-21.04222827737983728353988016396046294815437832717876261113126855668408012316937`50.85357109272553 THRSub[2,2])/(1+0.16292189574712469372071698878672205069451684228404894287656939534997673040615`50. z),((94.92245926727430290224636428602330216699530393016496630242499198725482322743848`50.+ 51.6127034930422236161902998081910625007229744372134253436167`49.481685089558106 w+80.7414850407279800139448605470257115747100134718337133199917`49.481685089558106 w^2+7.19028234833591149409216993048195385339416572513255719246340181442421535841628`49.481685089558106 w^3)/(1+0.15778612892036560021749838703426005476258235073329106931257256554161876628022`49.52287874528033 w+0.35177800029189801082640879510002509486295788736617820566409484754417345702712`49.481685089558106 w^2)+132.74045764761755349099798081133713804077702418759498024326214283250066231729563`50.937807959751396 THRSub[2,1]-20.45466866589623964627779861669812090004843888981184810704277673124500247677826`50.937807959751396 THRSub[2,2])/(1+0.13044976740387911419296895001948294844645894274137820521245408729721766791347`50. z),((94.58623803813581659859372236165755293078296476145407125267266411299120458042555`50.+ 49.8648134304125681898129061860030256674463625084717781612975`49.404201585122124 w+77.8195484821589280677585625553063998303592412775663964607555`49.404201585122124 w^2+5.27669771986762718778009116307200406329592437427668556746352436983051597881428`49.404201585122124 w^3)/(1+0.14783189651447714347333225380616688896710247975042397384894259434696758363406`49.52287874528033 w+0.32586481998785907752839316423926824321632755728858365441652176541061032004969`49.404201585122124 w^2)+131.92098200020769029533021873621717762891560325162883435376696610734671485992698`50.95899716693312 THRSub[2,1]-20.32839139410893379220561334969577602365882867407161535857441875883440206749511`50.95899716693313 THRSub[2,2])/(1+0.12347091505227092426862878929346545157191507957670997515678784713350948404668`50. z),((94.118814389919463394970354345976258332439949839306396104394217265488901560072`50.+ 47.3164295204437736763915205301239644994637953312587843300693`48.88590296010398 w+73.7228565324865869962089912688943005735314457315066581121848`48.88590296010398 w^2+2.60456939161447098105140609217193132738092879320271666108428256676249110646713`48.88590296010398 w^3)/(1+0.13261688992133530740434803048087610298900680511196292860944158198593645753998`49.52287874528033 w+0.28940972820052018436685880918009090970499950297856603701325431111644610890032`49.52287874528033 w^2)+130.78172527415781694005090901445793991530234074561213487428683779339470996023765`50.990772110892074 THRSub[2,1]-20.1528373899287912897586590642848742120902088685049797951969103681568337519539`50.990772110892074 THRSub[2,2])/(1+0.11376872987226149630337713243781591877850620414147379958891485876208180117236`50. z),((94.13315036221089553379607581034723941067054042442340405992424832270804724088265`50.+ 47.39672502256629985728848962433406614958374795611657743891389648987562295381039`50. w+73.8491609182679638346703010993465613833570048282918461668590139229292005270653`50. w^2+2.68679533419308102997552932717796901320542703031978424786624021891324032718617`50. w^3)/(1+0.13310847530369119146288706403238472584943198485099974394820435502667891765345`50. w+0.29053598051703603576445973728045264220990742163556628804226629117064656363474`50. w^2)+130.81666649486798313671278228003015899198513567001081073756583263741733366261998`50.98975369049854 THRSub[2,1]-20.15822166466367072765275662029244084608428407466011074454305552656583380859425`50.98975369049854 THRSub[2,2])/(1+0.11406629773909432487274933398062407331282707134980981269784501642099882814649`50. z),((97.97910154982990476349038025815638287921066302972879247116961342437646820987887`50.+ 64.7528460664805225816846390447521019323950042778488004336342`49.425410336117054 w+106.727036891509662887614074064414280128706567431676267129471`49.425410336117054 w^2+24.6885362825716066434794419428986648491608305904418562926082556357617010583397`49.425410336117054 w^3)/(1+0.21707858930699570023852456890664244493646697419982246093005429964559525295065`49.52287874528033 w+0.58012636945831860181597915343955619259705154812931125548095922743795359515797`49.52287874528033 w^2)+140.19044502591570553415596398519662058226368394219471930676540464709293779270449`50.789398289696564 THRSub[2,1]-21.60267603372327645341718885014071536343282948776786697406989050741350060862125`50.789398289696564 THRSub[2,2])/(1+0.19389565758843911579392096535173754408363077077994428738216179716919798320322`50. z),((94.48411185372050893499501133466851705270785488430543904544417783078115129504687`50.+ 49.3200581703464165646571353958020138422472134954937137817549`49.37271102591159 w+76.9280921642073658576385636641347051085345676561320224353395`49.37271102591159 w^2+4.69425345892858223491378921708770924610375454716712488787561393863159894656083`49.37271102591159 w^3)/(1+0.14464783269558483402924143949802460014018619742578972660003667612561170440499`49.52287874528033 w+0.31794482504532936385191702843531688199427231361785860980299679519565995273322`49.37271102591159 w^2)+131.67206874358295095801334862870746293886306103017686209937394954899012769397138`50.965697865073686 THRSub[2,1]-20.2900350536153342717176972947825824302988134487079745752776665714752330318114`50.96569786507368 THRSub[2,2])/(1+0.12135110969645272411364529503472196257812598328631641332206098800036636548909`50. z),((93.78634722062795740662173283925867524904355629264518500527402819114527305546846`50.+ 45.414619881989855316231794380978156454699064670972602835998`48.71113907231023 w+70.7808461615213596579312733390774097199631634925904411402414`48.71113907231023 w^2+0.69154605310480370904155510071270215588970753867814358599493534896979709206053`48.71113907231023 w^3)/(1+0.12075136490855724696555927684977104069478302897954553838131068236771090212951`49.52287874528033 w+0.26313147120199787117552907192198330497397320378783221509205962182230591362569`48.71113907231023 w^2)+129.97139943751808938734387235286871124905676887413624486516379656374827046096758`51.01524888628256 THRSub[2,1]-20.02797006015144604838785722553611691591004574234329626098595157235820595479126`51.01524888628256 THRSub[2,2])/(1+0.10686779951700763332677453466644653032257612094628258805102464467027735397237`50. z),((93.85833919954698586296267164676890245650830796983561799483431654821712459278997`50.+ 45.83299054721512836416424902199290904500471337874549217480718922116567193524982`50. w+71.42006852695107552017335251423387596743614966291465418355623439035696557098483`50. w^2+1.10685962343733634133543718405332265150364198796043829902786012621708322628011`50. w^3)/(1+0.1233976837107703163455988507816788423916466129940519319731115822281361019336`50. w+0.26884845701006601228145601326780849262105924739015321109770246064987095969163`50. w^2)+130.14686626834300530780472816717016781939917886991830294694681017348081416427759`51.00980419112291 THRSub[2,1]-20.05500865825471951652450833682564821257795385731083555386578755910940453155277`51.00980419112291 THRSub[2,2])/(1+0.10836211738820025340645181575325410394572226692864538357835639640205890785653`50. z),((94.67480685926586563801491778367537754891655752259138961633392151833186162841675`50.+ 50.33196383401157839262243401678630455565258173554730744324900119726358773626569`50. w+78.59113494539605300307956579462066819058332716320660462520910248935830895823082`50. w^2+5.78131796586136377924618770991354638993553583762033987220847451838867419360502`50. w^3)/(1+0.15053185605063016758718066148034724847294364515710738015872037743691859455634`50. w+0.33271439606687200214612875216695281346135139056159816016626003730774265621115`50. w^2)+132.13685174829543018133010861622823083090379235559154830323471545527466697922039`50.953288561261424 THRSub[2,1]-20.36165588822305709560207986391943643893596533620185370945026775282711911314346`50.953288561261424 THRSub[2,2])/(1+0.12530931391603813397343165112356953865884011875856994714482126462230255250457`50. z),((96.10117247344980776552224722865365854953271842580833613141597835163985861822965`50.+ 57.2297168531062092191524043921754846712826083962281027357459`49.62108505088556 w+90.8577641122508289747684818788115526244229908570752504867927`49.62108505088556 w^2+13.88400627660835584654277111755933019882892868181467626521968382838226178842739`49.62108505088556 w^3)/(1+0.18681922910160520222417840155327598744391061836277640462830012229248588475309`49.52287874528033 w+0.44103042432692655062718778309792607902666510031592669410426733723816887510496`49.62108505088556 w^2)+135.6133481257597633088282259335665859716271493078359544553882681763604508177903`50.87245413309935 THRSub[2,1]-20.89736732676575662582605432200031558503747451639272762835357659563954940520893`50.87245413309935 THRSub[2,2])/(1+0.15491599593997584523871333697647750272070967707719664024657636491987245612824`50. z),((94.65134869509799078042975710158339463106224552385777601374961963113294893155984`50.+ 50.20870933099203180409024974450574914558098894103989539342856295795862393676329`50. w+78.38690936113423282627083514240527124405570038811982343615358334691917552202792`50. w^2+5.64770760106128088570361861239847815706617867448802696751690080780245461501442`50. w^3)/(1+0.14982225022233410565427381030179187324473677046174728341200527972147505676219`50. w+0.33090191671524615348858655225333094311361258456030920516625914085401769896366`50. w^2)+132.07967691041332199444716680007828379791437601049237175965155327150249570521306`50.95479143024278 THRSub[2,1]-20.35284551958616814569528479668876113372206060706987571799102259410729527827476`50.95479143024278 THRSub[2,2])/(1+0.12482239920042999666433937070033678741924384163603612996133720366100391058793`50. z),((96.96642487583997251693347132604460887681412761807591474126090798692729181986437`50.+ 60.89711980980765336553415033987963415039537348559383982704258560971122349854739`49.67688550369225 w+98.1943854100192370202256911931140491385996206137145139825294`49.67688550369225 w^2+18.82527831861757606078099593508513941125560085748424729028194285008267565109591`49.67688550369225 w^3)/(1+0.20298105139058166628460541964916363089320096582817281325174626153238055412481`49.52287874528033 w+0.50542723609889354370899029210654285001744569609996069829439484262317124094688`49.67688550369225 w^2)+137.72223718799553150227454298410895719978922580217684929817923088741211629092644`50.83151781398774 THRSub[2,1]-21.22233702918820036394235965744556029588622399481879556577544148355827623932097`50.83151781398775 THRSub[2,2])/(1+0.17287580406579781600473121135561855060086429187014934480956168347151592390496`50. z),((93.94470795743221800254449505198599667869180017764990979662210721691455854991802`50.+ 46.33007943057026117707902322280857598695522308547956143607233775914816408007491`50. w+72.1853324595058967363113818295141707611990983391327387637583644991040816269278`50. w^2+1.60429502740025722172259912058084133152716013383716804563492573055227590601835`50. w^3)/(1+0.1265157036649905354996340858168976224325538680699806513058674489831799944385`50. w+0.27568723717623810288525302767803278650283113759721075975041825535247760379385`50. w^2)+130.3573737784289729237245980564217909780116268015187003515109326438420189791035`51.00337993667464 THRSub[2,1]-20.08744685717913433452423346171618274163420576597285997046285771764840957695033`51.00337993667464 THRSub[2,2])/(1+0.11015485013924424468784656411403888568839392404755312107289670704204293432807`50. z),((96.98393742581196390978492143347502370763872276710545981553927287371110346827483`50.+ 33.4809421018163387055185996064687159670672520325221454336235`49.543835945853615 w+87.5603788586837509738443847395492084151155567681628469253871`49.543835945853615 w^2)/(1-0.08014799165257223950478300481836216832437005370250358572736989949116122169114`49.52287874528033 w+0.51610749910286122862074788396354768874883355522219738535230147788501721425583`49.543835945853615 w^2-0.07986882230583127248828248097054579073420331711353985682781869631668034720878`49.543835945853615 w^3)+137.76492071593000390949034568236925311671452148123515059957330980271547826840321`50.830740166312786 THRSub[2,1]-21.22891435637889676969161404191998228702762468994672657916299800310826279616755`50.830740166312786 THRSub[2,2])/(1+0.17323930728916015715787209350416435901956691668093811161293525505863754281526`50. z),((325.7750077533058237162667277390855914750097907949647151665642`50.+ 1173.4378397052070967842226279333377306978323754712820302274039`49.23556310318768 w+847.4885169182092329772986085553333661484311322924496230786793`49.23556310318768 w^2)/(1+1.90185278331820223963828746579691388498696407291052165656294396509139375108216`49.52287874528033 w-0.49946024013185688662896275436113568355398161164187511908310652448941845107356`49.52287874528033 w^2+0.45752033551449351614691676421373604498288318630536455179719191384539814021035`49.23556310318768 w^3)+695.3998771957118560177385984851391941514982660688713366004419`50.080323915887064 THRSub[2,1]-107.15778994904284945555939614811745785342926326480490148879724404208816591621751`50.080323915887064 THRSub[2,2])/(1+4.9221931531640148435896620337749333395065704745838606978634494408956888374719`50. z),((94.02092125395140290632890727132449072853189939501298446943772847720044945191402`50.+ 44.0038173350859496866496076597004994940311051623527169425503`48.65125024267644 w+71.5647116241980367363852324866588436845327623199569706577061`48.65125024267644 w^2)/(1+0.09985503521715009726682182432875946127501654510889356588392484510916605547108`49.52287874528033 w+0.27874620281709606012039217431557740572447307478407061838083098976794117375714`48.65125024267644 w^2-0.00755042737843251087164637302483424615834161447244063714897775519718440935751`48.65125024267644 w^3)+130.54312927241229403775268072890221671789571740127544631304900445011254792258119`50.99780579141333 THRSub[2,1]-20.11607088899003348194499213539604932754689251075667700983398445820931313087386`50.99780579141332 THRSub[2,2])/(1+0.11173678874853309780430893101036196917522688206619805282587168110881294897708`50. z),((94.89051068429624735667674936543003101382914098662151091988818338557459844278594`50.+ 41.8153510915889907350979120121135908999620625634532979304103`49.35348907586456 w+76.1531160559132183351134568745160965148435974635259397431035`49.35348907586456 w^2)/(1+0.05534458548228473940231963639885660763122494424827283196873626472737122460102`49.52287874528033 w+0.34301081326614863250976389022404956104610742710116874933776832037140272107164`49.35348907586456 w^2-0.02693684997282982230476043116931470070029209371880924206704838689570279992108`49.35348907586456 w^3)+132.66258901990818875929608380754241017265366871644039901299897405273662992181758`50.939766506580675 THRSub[2,1]-20.44266948337502683150141499077284135824471159230124642179754500651549622375466`50.939766506580675 THRSub[2,2])/(1+0.12978661938072107793057226285740200023758102245484237650881237390347945712613`50. z),((290.1347503385295556456755832624240539511294092293418660423195`50.+ 1031.8040480994085978694256188456641120077039685628897318195517`49.404597222849745 w+727.393126416101016602971346010235535796543198396929373633119`49.404597222849745 w^2)/(1+1.92253605308584662288205174840040921806487195877084159912604435416986321769198`49.52287874528033 w-0.5301862710154747581443154087914872154245755833687367858936934513277027954751`49.404597222849745 w^2+0.46094434377607750209585714618631980385523462825627980044548819628992339747609`49.404597222849745 w^3)+608.5334913530791924246119702552365598932112881453329350618247`50.09310500309132 THRSub[2,1]-93.77209600084331374420799820666943823654867626050493396301322317475470257903965`50.09310500309132 THRSub[2,2])/(1+4.18241805059729420818537982762285471371230235356539629159017750013913861372262`50. z),((517.0911880565048758940556063490286799854839429210773174045132`50.+ 1941.0428698756951517714349283109132571105168996918534628836652`49.398317366847465 w+1488.4313593651268708560345620878499580069601190177953673688855`49.398317366847465 w^2)/(1+1.8537080928249201731674790312678498294644164261115527228057729697391971260858`49.52287874528033 w-0.42442214185774595904543152377210201982034513852876462531793045492201901725787`49.398317366847465 w^2+0.4517273636433083390848333604194410124730902357812034334294045177480411469856`49.398317366847465 w^3)+1161.696877880848285835503731539633918848272783515116119403269`50.04627828067819 THRSub[2,1]-179.0119240837600364293717996445491616384635118560714708989988`50.04627828067819 THRSub[2,2])/(1+8.8932909277775700129038559397378735114994244795438196541389675885542165412722`50. z),((521.3456600858711207007001008879303576537280464782559591105072`50.+ 1958.1723367785380600539307311456521167217010212999802535391784`49.398290917903594 w+1502.6502206430735474038153892074761420433379186746709078179342`49.398290917903594 w^2)/(1+1.853153275373854830326061490987251807812066341670132254378918544317617686137`49.52287874528033 w-0.42352702544065251172800113805119560914101452205429765493258483183144926434374`49.398290917903594 w^2+0.4516826796355900051650700366182460399323270833068818252592124665249826877734`49.398290917903594 w^3)+1172.0663486890584012106323875154217685893787843122995787427999`50.04584645319781 THRSub[2,1]-180.6098098631332558793634181523893988364796684626270151627101`50.04584645319781 THRSub[2,2])/(1+8.98159984331830854948724886769378537333703047881910134552343480731042756995299`50. z),((258.2619521383917214530153157932529136064920497779507090831413`50.+ 906.1784615222893501410822629355426973846344990123601267156865`49.267182651440166 w+619.5411856798751069479134454716426056134078978506381836899125`49.267182651440166 w^2)/(1+1.94988118416131314786829965234086459689993357799489996588386513984048946258009`49.52287874528033 w-0.56955575078778788057144229399929147613105346067950872632930342259782569904669`49.52287874528033 w^2+0.46610537096448672887211854337063080852750944545669392968462849706370000711994`49.267182651440166 w^3)+530.849574704664003806369687197013518783295087041653753313508`50.10857276353444 THRSub[2,1]-81.80137656931396956887575038957374352828343901883385900714956625913018883357674`50.10857276353444 THRSub[2,2])/(1+3.52084307140481099366502055068455256301177261140248529171199487581321436458548`50. z),((94.3498283750836114695966050288392933074294892755742323087036242868224644434693`50.+ 43.2537305736402753024963299828566541612778881226536697085774`48.98790548005133 w+73.2915557038203390851010774290898975872323512489661263241823`48.98790548005133 w^2)/(1+0.08374638786904724017131582386784395023281511183754200517199525945124594434571`49.52287874528033 w+0.30261246293652881664787578084049357711069520405210804960764469394902217746236`48.98790548005133 w^2-0.01473416824612004638339968827161140891525493419821386090073006688025085667442`48.98790548005133 w^3)+131.34477816507193486220579877951371371290488881536401516539664493474142011480185`50.97470857097065 THRSub[2,1]-20.2396011432646229701118264952610308085776786831824993723283392598699407429486`50.97470857097064 THRSub[2,2])/(1+0.11856382415511874981361642306486134075061927995104255595967951648318298895014`50. z),((426.6922178897149396740277643018888389015469205330486538483405`50.+ 1577.4870262327428860531809812219685189355717317467793912901785`49.39923317297692 w+1186.0567920871647253854647303533402988873963408602241391867383`49.39923317297692 w^2)/(1+1.86907485466702571654236099515682678559558528009125571710366296685706219482702`49.52287874528033 w-0.44893334000946621098007986849673978406351664705092627884703299792012077786836`49.39923317297692 w^2+0.45318584784348847143097144144178797043508875805661066601118928037794039360364`49.39923317297692 w^3)+941.3664877016417540065198146121216969945023047157364378989932`50.05786114697205 THRSub[2,1]-145.0600663908526706172372474357981550404416310795955340148005`50.05786114697205 THRSub[2,2])/(1+7.01690415961306876544508458451161277263230108895028138791145263794501759136225`50. z),((93.46224937434628205873788667700129924559516350359438150821709386457032682754866`50.+ 45.07392064138344843083628446738290681469821445332347344154313118133230488253625`50. w+68.65344712482710758181378517615701952189596029447394448446831460558651858320915`50. w^2)/(1+0.12529415229368668515077527577208130744423430108133139895534210928030015543656`50. w+0.23932552317492995365162948755059486568013579431939181065458014576209917363417`50. w^2+0.00427669616085850085364680307961931215329868753345985505826991266809426721478`50. w^3)+129.18147224259838926466666259043501105675041639748341798845142638207068393605414`51.04083804685382 THRSub[2,1]-19.9062460633489286037636473225821557524982799867570161764495180097698227197177`51.04083804685382 THRSub[2,2])/(1+0.10014058891680370294232022408285443498012318583616149935159388574136726129671`50. z),((93.47333345824062307775165944763194049400208299238329822877473533036195323825232`50.+ 45.05509925493897454488143460561718108695892976872553562086350630083654452385495`50. w+68.71095413671294502308932774672986345680474370826510740251278470061895269151732`50. w^2)/(1+0.12481225964960496320855033316449793594061910591029801471398161049604973001825`50. w+0.24009473451447932280150496636986843475169327450062072684657580927586462183188`50. w^2+0.00404634952992595853430716049191007422791530187907266801456965125025499493919`50. w^3)+129.20848760045825565397508036136577762545217206295313429440191369987877362643875`51.039932229025304 THRSub[2,1]-19.91040900058529951290471555201852469523952060329631225489264648542500273693716`51.039932229025304 THRSub[2,2])/(1+0.10037065822310435547033646725175355594771909822645945755795035457350164429235`50. z),((216.7220216896445340960909741022465909001033532323662171029366`50.+ 745.5422716400826758541540360275216494604161141008209396874419`49.29958651354586 w+477.8089670262249109416992946757050178525763382001524300242067`49.29958651354586 w^2)/(1+2.01186009478130183605099805135674315120448793683469673287533362533027144270675`49.52287874528033 w-0.65420935822770938015559610496504759720843665049617385632710348608900196088027`49.52287874528033 w^2+0.47973986675752840713523764593451515472723406970986769053814601892854748708695`49.29958651354586 w^3)+429.6038518064628184925346704883005278292398388504038169186432`50.13866148024165 THRSub[2,1]-66.19989566121331187382561420028370928614418637072768011347314022671626234289093`50.13866148024165 THRSub[2,2])/(1+2.65861006476003277631548837545890831510698721057589738064381334121279554626529`50. z),((474.5896792185094734582872360270041317553379337551799419655443`50.+ 1770.0047051778381276808539493101102296037023108777137195036667`49.20157592134646 w+1346.335529068759750369497918947438790436976955626751553311693`49.20157592134646 w^2)/(1+1.85997056379778603768176102977069509431185801635590242801969558127570530662374`49.52287874528033 w-0.43447652699592695658876768423467418870248676987519872032399645844289553131166`49.52287874528033 w^2+0.45227139442571924217467327378590967942098788032807271159785100584690514568154`49.20157592134646 w^3)+1058.1074895481841596827487451200251781632478009296435544889646`50.05108566415337 THRSub[2,1]-163.0492955589100430215986589913407578033430173167339502196288`50.05108566415337 THRSub[2,2])/(1+8.0110987007698906696367167419839481931789405525425985981610995405025501259347`50. z),((95.8270264488569164044025127843678615341044053662601683045453177826846909129929`50.+ 38.6689413897467574974917830390926392318850119137869128420647`49.10723338631601 w+81.1854706061201875122254961213882892926567310804640408690092`49.10723338631601 w^2)/(1+0.0000730196657372214646112443773163462741164343123523839325071728108819823353`49.52287874528033 w+0.41684842366122628196075286786682958545412715316518413228856225561149213564976`49.52287874528033 w^2-0.04938616585574128407441334955255285770296333836704088639682059870014437026434`49.10723338631601 w^3)+134.94516904746733854720553483215705705561650264322775660102323592139495333643365`50.88656190305556 THRSub[2,1]-20.79440413153376553464384810317240349897021376033913950415021451955248518782569`50.88656190305556 THRSub[2,2])/(1+0.14922562167861087460047684468191116603922546968255009708839910037306418522249`50. z),((224.9947794298240611675096965693516935502633248510945495582556`50.+ 777.0849921387971375443547965819548434438446266158256258828241`49.291886904871475 w+506.1906934361114222722563825345289252236860114037056592964719`49.291886904871475 w^2)/(1+1.99569939743697902467896919647512074025641083447972663814126044127690190426949`49.52287874528033 w-0.63268944601802667918936048724042836098297075538383076686247153058896915032153`49.52287874528033 w^2+0.47597699481419281319089355392531259052235260365268024487661155052412312452024`49.291886904871475 w^3)+449.7671339477170114397993040773920182735497313418492527182834`50.131399299941044 THRSub[2,1]-69.30696085237916283584608289288047177442277470982951558353030538761390705130245`50.131399299941044 THRSub[2,2])/(1+2.83032544084521304865981164034425116006250280250537043260500222220705904830645`50. z),((93.78237117431863937221812430704385106159033130587603725540560770555564596682619`50.+ 44.4914362842007760520775415317551881608741441498588530134382`48.13341913419647 w+70.3183708192937664809613559015444461832827226376370377326851`48.13341913419647 w^2)/(1+0.1110075813122102601003877642927407492314351719399524723878584606709495689833`49.52287874528033 w+0.26174809756329700122804173629325096699110190685064636357488116636589988800843`48.13341913419647 w^2-0.00244490972306284805913200845428219100235222720617699589601883284884276432939`48.13341913419647 w^3)+129.96170857673630947799363792605160188050126413687538639150413465968538331488689`51.015552021186394 THRSub[2,1]-20.02647674492644618948465409245425261151149337731908732519475484931338783335508`51.015552021186394 THRSub[2,2])/(1+0.10678526980819957351626803535544573934850526587300434974833044057311282081434`50. z),((153.7138956097054507010032156247916599113055348537098578938531`50.+ 533.0185472632030446536726990224373913608056008743442904389701`49.34392321719006 w+254.4150682206091534627679615630636886356995752889775515121632`49.34392321719006 w^2)/(1+2.37233422811357047583359867291772543241235208483125561918746124035135297876118`49.52287874528033 w-1.07326869063721961138016480780240315943995714391546070246645104349238611995988`49.34392321719006 w^2+0.57904007949122055639506807646912457843643580662691489916985227634162668963188`49.34392321719006 w^3)+276.03346291774404432423199893050779381081228512962925656829`50.24062906456542 THRSub[2,1]-42.53543437126871399047182490178224919409644429696559039774323827648477470044185`50.24062906456542 THRSub[2,2])/(1+1.35076757667523096391348763091180681329552840236506735141097190956032248350848`50. z),((97.32681780926158959635914216218074486683413660429738748795098441750513047522046`50.+ 31.63095673204347293220633520370467522285865638660627646511955777339429934673357`49.48780571986654 w+89.4891606730670472486762349868365268820351320152984404699795`49.48780571986654 w^2)/(1-0.10676685938665067295555502291613342661323757976132899173815510182417196187656`49.52287874528033 w+0.54752562576768933259839196977835721500670796144867620855624780115194583272946`49.48780571986654 w^2-0.08958904846361638829940866924145737409588983219881284154977542532764991943614`49.48780571986654 w^3)+138.60062679234729731496593121148179692826812805652523888535634705667971427333428`50.81588163810489 THRSub[2,1]-21.35769265952872553798340058155691705610964695526503418614639554085478171197401`50.81588163810489 THRSub[2,2])/(1+0.18035638189057421823405865832830136071871989201339817822734441589255375868575`50. z),((439.5401039861345301271224261502262076952647145456170570376266`50.+ 1629.0970340362123459618068043990938059075567626660224039636849`49.2072330458887 w+1229.0674890639482754754510463094002510636215974172176208916803`49.2072330458887 w^2)/(1+1.86636880669982566778457180747668037890329497577891616621699919622287459117862`49.52287874528033 w-0.44465606240255537927160271316017202345678720210836000155010648019908664902389`49.52287874528033 w^2+0.4528993698336398837444401174797885696621317384264166450958841132125421862016`49.2072330458887 w^3)+972.6807797934567635810166604609732227431623864028113449363682`50.055873145733145 THRSub[2,1]-149.8854487994740944477883049994867539899072634847809739088182`50.055873145733145 THRSub[2,2])/(1+7.28358422715948918964919881018634819766650782593155798614198883925817854720657`50. z),((218.4835343539382590173802688859186097218840398594510868483342`50.+ 490.6148728332908476883943330043253927319710927223728410785225`48.83668738886759 w)/(1+0.81077189381299775144883982885666765528862640031213742454509544792400140878376`49.52287874528033 w-1.14596076906671056858795029276722792672210892732206958915100787461781650584506`48.83668738886759 w^2+1.17064914395669915659314800463278146188623361260255047274649481783237006804231`48.83668738886759 w^3-0.41729109119980407285112890562432417278718015789240516575682906521333897539559`48.83668738886759 w^4)+433.8972057231430841622452109727965483335813664853800687523022`50.13704811546253 THRSub[2,1]-66.86148093361197846480499001824787556012495294596020634956741897738830983734794`50.13704811546253 THRSub[2,2])/(1+2.69517330269445351601362960644765259536419070759480538428143005980302957676223`50. z),((441.2554654174992211725317013404665187933882212308348922334998`50.+ 1085.1758613938188418407495341005211662162175775767728019637393`49.308326203636554 w)/(1+0.61773623405016229602981174858915682129870827807061114853419149584116944649504`49.52287874528033 w-0.94371800021580279836150294205186664508659236042721402630807499911560126349826`49.308326203636554 w^2+1.1309059433445319216273698631876512508845299504238203965390222816564184204757`49.308326203636554 w^3-0.43829965167760221633664890849190804594211858241464681964076316175334114471525`49.52287874528033 w^4)+976.8616488097034941206292079744999619714511575144378463894387`50.05561802538433 THRSub[2,1]-150.5297006875447344642024562613884654415746205834816781323676`50.05561802538433 THRSub[2,2])/(1+7.31918951653937727477394124913126244802904693626248056321456740095667156473968`50. z),((130.436959151395624102790236584514020809218485723016583562233`50.+ 441.0424540452680922434158180041560524621701928743314462685558`50. w)/(1+2.49037355966213133741316566763609156977987170518845142855560208175268662864998`50. w-2.43741959692394666334284063507235810346835009363130181015651466043835711228206`50. w^2+1.45891307040215124535703671615483774824551803431435019142548725821036245376295`50. w^3-0.30745700015560685880853655802970534976955195159536471622368322183839938360618`50. w^4)+219.3003332972020534305171252687596551963574058654550574253309`50.33296042075512 THRSub[2,1]-33.79313086160202005504547269355769470132273788182824295410122078202045219792534`50.33296042075512 THRSub[2,2])/(1+0.86761455520614380813805104566435665530037798998548845364211130159163678201455`50. z),((277.8080950067283836900295436154044950145811352229417144049372`50.+ 642.3826117678436305922446218084613127592069641619094064109851`48.754713562198084 w)/(1+0.70549068935862426524811465413990449712754624898373568600451491931766843898603`49.52287874528033 w-1.04160999005672773940766796912672211058661141287086901624458142095064836719846`48.754713562198084 w^2+1.14984376545128451727793485229296574968192000453923832094938958990259552838187`48.754713562198084 w^3-0.42804529032152811717526221936174887445165534463336142354439217797026788091674`48.754713562198084 w^4)+578.4896006555487874071066646410300048662292772767762371556503`50.098531605008034 THRSub[2,1]-89.14247636156360454459535715221146616479292037186502865558398054795822638337855`50.09853160500803 THRSub[2,2])/(1+3.92655702787058531778802630041479073477058655575531823900606112097980859527752`50. z),((211.2528535657079311557300665053336183003775341562149428668382`50.+ 473.2247223609993227116278403210052039924286254347538947531542`48.84981638415298 w)/(1+0.8328907177319211666937274021886618676425352080385983442496601807055783985802`49.52287874528033 w-1.16669697070804354036491235401403743885498375601733293948873157494592307956375`48.84981638415298 w^2+1.17485423250990900983009232757820697285003148764135935116343507331690468452267`48.84981638415298 w^3-0.41518949885538832458568134861044067002406470692999134328675758091184046220494`48.84981638415298 w^4)+416.2737890360649877061711448303823064190373457427821934965284`50.14392421528248 THRSub[2,1]-64.14579684238962741086899443407535280500091194957119407523912598365306062261805`50.14392421528248 THRSub[2,2])/(1+2.54508803368282715678047292450500251878550252347250070271929115059574697691411`50. z),((235.2887936905596067061323284573168690422457636229129422488222`50.+ 532.2907529172918233190342799333327268345831759945538217746184`48.809246541180286 w)/(1+0.76996402936225798341030509451275973536974651846284401044550524532283435109869`49.52287874528033 w-1.10674202140991935454634562703175098404695803040284489098323014179179498859071`48.809246541180286 w^2+1.16275868925936167823317693970819801032690130143758270216706741830661422179224`48.809246541180286 w^3-0.42130041666879329889128362480063516671913161452275217104923987043419105122151`48.809246541180286 w^4)+474.8568465229097096470552362709219287421852746244563723565206`50.12336665803057 THRSub[2,1]-73.17316537466971831780227219137469688707441228405925452587476149080746928269386`50.12336665803057 THRSub[2,2])/(1+3.04399548724621567481615723918441348952510921986863727061831407858106685234092`50. z),((401.8617196971664068649986955289871520633740900249610225858141`50.+ 977.2702070656260742733897609273553994815297362252714445408642`49.3183703130079 w)/(1+0.6294099170973787762477644027687652708387156754655351812953775320368806637821`49.52287874528033 w-0.95757555128172325611247372288403221629703505124959491966098450499737956064659`49.3183703130079 w^2+1.13355066604338160807298271094931645246324003296121773435025480830556657029741`49.3183703130079 w^3-0.43684614499928241550383718579064355871054587795034286074776629457981408875725`49.52287874528033 w^4)+880.8468452210445361066261658563350420739739006897694901067749`50.06213450859842 THRSub[2,1]-135.7342793877269278522386190172320707697210882074445691364311`50.06213450859842 THRSub[2,2])/(1+6.5015042809477795680352098604620637212575725879697846212087255614826362852805`50. z),((494.4038573997177706906070156722321285977942608074487763247203`50.+ 1231.2648889238431944582863871250621213890858509869338430080105`49.46126720930256 w)/(1+0.60596055423735780786151444931101203890398286088259699054577604838937092582714`49.52287874528033 w-0.92940516295350653266988618040540911976054830620406943035622899448806385370548`49.46126720930256 w^2+1.12818727506336231846330234736038384312951449770140069964736782679532291022614`49.52287874528033 w^3-0.43979923396622798007697570555896305049144242792171292822381601344931146848982`49.52287874528033 w^4)+1106.4008008734249963597366977325501385904206119648734701250261`50.04872580399761 THRSub[2,1]-170.4910634979593729442763580122352906000592604112019181292034`50.0487258039976 THRSub[2,2])/(1+8.42237619312047901692460477409737494085431083441509967276021818187786670987531`50. z),((332.5121116087465046224036169482238445004285399420183863425667`50.+ 788.674716902442284097409565361167131776032194426152768840735`49.48461449553635 w)/(1+0.66078333498672245738471848514221988720518448555754184966420691754078789437196`49.52287874528033 w-0.99340955748346290950412476231139744913034554354042257423636985679977084144753`49.48461449553635 w^2+1.14044563223558594005746375470902422689631157574858259011485635439555561226914`49.52287874528033 w^3-0.43308648629642699795388929548117088294843679704163374405189778536504910081294`49.52287874528033 w^4)+711.8202934726707824178912602830383908416127845414237991437239`50.078293318781874 THRSub[2,1]-109.68809743971702119443390135635332371837994594365557983382660861121660973769537`50.078293318781874 THRSub[2,2])/(1+5.06203338040084063781984435139709730594006325934343049006691715909041127430231`50. z),((189.1097912087156850776541127893607450193562764012229688381957`50.+ 423.2505324712192151639588282053206116533943267594801321155563`48.89596449605787 w)/(1+0.92849772554924371349485493519713959490423775999659797028089217603882035162183`49.52287874528033 w-1.25299003108006645059420908101417910262295033741904441482565326667443075881399`48.89596449605787 w^2+1.19258715454291621184948644718304408795518905718116316403914853769484853937705`48.89596449605787 w^3-0.40659121423388612610623281917519602326317386614630423694849095645322134269224`48.89596449605787 w^4)+362.3042630572067283854173005303088668942318516874223436811923`50.17011734572085 THRSub[2,1]-55.82935141560351142483530742234079655189225270981869071313737915210127293240189`50.17011734572085 THRSub[2,2])/(1+2.08547052767980378507688306234945276746874138941861253446435914299295262120695`50. z),((132.5026888271292543046510551258615394768604786855296875552974`50.+ 421.3035610917489867900649762948742763055089288571467335544988`49.05083653755299 w)/(1+2.26764894070519640596865846720043036413859154248689892285293534988052005700875`49.52287874528033 w-2.27757516302447730993301559604438224655652573860583863206974657913390637812966`49.05083653755299 w^2+1.42149037036681313987088166005063044681855523087186494915214801344146263974155`49.05083653755299 w^3-0.31950777759805780291768291524798546069013336579367753604950568557739843138109`49.05083653755299 w^4)+224.3351586344752362167085384660566208363888333288539681491402`50.321869003670066 THRSub[2,1]-34.56897332809385259798310126643662197826836193474224569877908870647839120021517`50.321869003670066 THRSub[2,2])/(1+0.91049234267429467395962846300047583095721740649761431005194852038196972493157`50. z),((475.8992808111251341545408755163147693920052731613272928743441`50.+ 1180.3489162592912030104536090036642454571760697282453105739039`48.63125293422831 w)/(1+0.60965184445301498765476047527338601948551751538370180039349542269631723745043`49.52287874528033 w-0.93392999712862854637939212190471153931828030678300300896808845929548148971744`48.63125293422831 w^2+1.12904531669256785826341277563810752913162095958361887643488814990081890307121`48.63125293422831 w^3-0.43932540738924644044538964274137419909181558209394188556024257070020453944277`48.63125293422831 w^4)+1061.2993957098134456766615061138533697262488641314176814664887`50.05092265089898 THRSub[2,1]-163.5411530084457499559255821291740093581604755809805556642637`50.05092265089897 THRSub[2,2])/(1+8.03828174384457753072588595590526724380687799710232047775393136587535770213195`50. z),((248.2660040114717515827801839245816172727451157513539299567032`50.+ 565.3433691547687404750273018285600209599873554234882662433805`48.79059602992701 w)/(1+0.74573645063045348468379515522440315296271964737473572034615385109144969231964`49.52287874528033 w-1.08277623906411079083908786237313159638980919620151988617985215401553594672485`48.79059602992701 w^2+1.15797854603337347596661321166103085112026505040593906277062500614252125705437`48.79059602992701 w^3-0.42377089107496094355146178434982547558029136943758217944830780560581264268073`48.79059602992701 w^4)+506.4863419493367736499841682274298469548583119959185756544853`50.11454708455131 THRSub[2,1]-78.04711910725772722178413816361769430807118632205925148259896018658996809990624`50.11454708455131 THRSub[2,2])/(1+3.31335990244829237980368582360105945835935420601797766015453268243601750405764`50. z),((481.3062915916362050965773120312091952617689125091989788741954`50.+ 1195.2213380719097330420507481379247432643848957075857295211612`48.62934357396641 w)/(1+0.60853319835791962238418337299688452464509799891714949157587780375079322818238`49.52287874528033 w-0.93256253363212914820107371815106688170977377244205154206161573512176657674069`48.62934357396641 w^2+1.12878586515708431210256384161230081774165998878238071166463689528846208982728`48.62934357396641 w^3-0.43946863122659610918234720434148023021223812875024151877717958170335652820094`48.62934357396641 w^4)+1074.477961713111139514903493546256269619592395591481719400869`50.050260494453966 THRSub[2,1]-165.5719069011639806187038109642416783620736680175265212610669`50.050260494453966 THRSub[2,2])/(1+8.15051359189721179229998172409658797569450004312470528780409708621707909212037`50. z),((560.4582392659592166901571711379180267337174912905006126102403`50.+ 1413.3493382087124429286013046027058068766162513578298497613991`48.60571941308493 w)/(1+0.59536720912633949672956074755855395627969651516511657337260958164942563492554`49.52287874528033 w-0.91621223904573239139129453328646700204202988991380762364520070633107501954625`48.60571941308493 w^2+1.12569314415650499472921078709219877100898739550728006817162435739636882190138`48.60571941308493 w^3-0.44117902312007395104663994961998532473161018769919999040618235707876128822882`48.60571941308493 w^4)+1267.3958620205036227770571026273080000224609206360051518481041`50.04222457781078 THRSub[2,1]-195.2996312170138158628716190864557679440106385435302055815317`50.04222457781078 THRSub[2,2])/(1+9.79344898171994514381008297283218258067872766186292876500149003709082103484261`50. z),((359.2457820156347797790243817894309821533996252480815853404259`50.+ 861.1007065962451990554703497157740385833037753288279640396495`49.331711184401215 w)/(1+0.64648638682505848974359440989439492134483586214150941773114494290394036061064`49.52287874528033 w-0.97731570988460659427776444575853133429526480301102757641586438539918561748335`49.331711184401215 w^2+1.13733905855435439811847970266265696676488712084048742212527589280343447563539`49.331711184401215 w^3-0.43477467240165945093198293086196239500326363950296877603998478446251348516726`49.52287874528033 w^4)+776.9785582272831179979722475000223309020194981522490624546035`50.071157448249444 THRSub[2,1]-119.72867391519116169918043779181671264249420282095713986833646370238502285556897`50.071157448249444 THRSub[2,2])/(1+5.61693688564435986642913751303517334665613983835208844773068587206093035307517`50. z),((392.5396359872935879679869079851172420255021982019451305006963`50.+ 951.7997670473779596799867966052508663050940613075688086591466`48.667579514483386 w)/(1+0.63267877099863340671015038445347812305746900527004851362866856701006074965075`49.52287874528033 w-0.96140114258090344401937265740030773561003614865183636676863607612140775640429`48.667579514483386 w^2+1.13428293232321205389438838597054374358830483884050490033170314986514047208575`48.667579514483386 w^3-0.43644472728663396817324783943226206213623841610377702789954510620242233719531`48.667579514483386 w^4)+858.1260295160658186860256261760934269475608909564795162554523`50.063906775529375 THRSub[2,1]-132.2331105255705097929198986276234242342167761983479054853316`50.063906775529375 THRSub[2,2])/(1+6.30800833190484217902848601939175170852355095910760787739435496978413392144609`50. z),((568.9901338489112424932214289357328991906683894562982464950786`50.+ 1436.8983663263420218083875102894487231728328048182565985287825`48.60357564956265 w)/(1+0.59423126392002423711230320571910923932803431361149404762313804887058951378088`49.52287874528033 w-0.91477837183805041695702282599939149783516093452208101770138358406644167789024`48.60357564956265 w^2+1.12542276031745550876477652958399706441645389205565286949472544382515921545047`48.60357564956265 w^3-0.44132880194436699885165923051029531568255717048774980989950865070915789222677`48.60357564956265 w^4)+1288.1907411984555603138094586048620728266685827814447174681273`50.04150931245168 THRSub[2,1]-198.5040224860383877512618731579749350491043241301678722781318`50.041509312451666 THRSub[2,2])/(1+9.97054319057307737638083542862671537083576469693685469555947566523583116972727`50. z),((343.972560583400867655585377601921035023522802710635393587155`50.+ 819.6697807405852359454227008233037915128339474782150814536641`50. w)/(1+0.65422754322216534646015259261431035188855369337747899417003619326544067233441`50. w-0.9860757951389850755343422737910043170785657090721921689448670840040902504217`50. w^2+1.13902802314342411813944499371111152449205409542276942934456957060157578982043`50. w^3-0.43385561086757762378716330439238784917610522688237192823245836471502954266757`50. w^4)+739.7529700236933648195894175984099893455483335937910969636552`50.07506578811974 THRSub[2,1]-113.99238909222565639222977177400722541039497622743020536726546972701923961853964`50.07506578811974 THRSub[2,2])/(1+5.2999147940230273343687570110240348192009090530013283197095638248680548240976`50. z),((489.720641958741888633716686202961443341883087382103127315578`50.+ 1218.3742595257604324162687883624541111319784527991722091463147`48.626458551120294 w)/(1+0.6068589968164115482121878745082157710343584927892469434226056851115173025574`49.52287874528033 w-0.93050980586201828060699946816268176026161483712735481330545087819466697095173`48.626458551120294 w^2+1.1283966250416801969107062524359013533485708273581253116096314173217114736564`48.626458551120294 w^3-0.43968358359373465574891408196688295148223129433488859214801707282773623999814`48.626458551120294 w^4)+1094.9863490992545031807391755825340138791903976252248394537715`50.04926365864776 THRSub[2,1]-168.7321511574330297161542876999333911347539600007251183488876`50.04926365864775 THRSub[2,2])/(1+8.32516796752125514155213402468085750324417429163947955318715313752104990944606`50. z)} /. {w->w[z+10^(-10)*I],pi1->pi1full[z]};
(* and 20 each of [4/1] and [3/2] Pades for the Ls part *)
Ftri3LoopLsNl0Pade41[z_] = {(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 23.2501786876861735624435438824504575146380849520775832033616`48.579739558249265 w+82.6814594245209195302545988368506459350187122780228135818253`48.579739558249265 w^2-6.1660126690261033025665491792152734369813650691709506075404`48.579739558249265 w^3-32.0082333724755555760969807783335417032258706531135839633871`48.579739558249265 w^4)/((1+1.54381101821669475709997071381862101436389899646887761356798438429118207943039`49.52287874528033 w) (1+1.67479670685436443656891970844298033838891780666889488212869258029586661790625`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 19.8201904857653509751305633766417883474322347601739718007213`47.816296032401475 w+62.6957412594535930428765984063888555200566093697114745407499`47.816296032401475 w^2-0.7413202074734248402631631809441659535030618552951317281082`47.816296032401475 w^3-27.0571982506100407540225740444182927694155018569047114016378`47.816296032401475 w^4)/((1+1.61355482947195236762058317308914500146383474123903991803459590425042325345373`49.52287874528033 w) (1+1.11578366952673594120513809270819105205511541912316573466221440441383062438722`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 39.6409411176831284801176042047526255621988241330092428463089`48.880269804345076 w+178.6036396694883804056809477416831981497674866523279446040648`48.880269804345076 w^2-29.8323367480921389085121298314821457971381925855020220082044`48.880269804345076 w^3-57.0871861181610448767053713690080105584294095789444880276489`48.880269804345076 w^4)/((1+1.46556180949848499679941844055882944100659717407287744064535477568185916117335`49.52287874528033 w) (1+4.28237412955975186364522519606879687081678102767816931214591635865917071746452`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 16.5543436082445287980614965254290848803655970634557656321898`49.3353780755452 w+45.9836665541609666435897218371451359658742827227662766788206`49.3353780755452 w^2+16.9555967829696671207986562627092865680647023502067787021336`49.3353780755452 w^3-30.24196355451689980047046424966997532335369946813382122175`49.3353780755452 w^4)/((1+3.09485151464415884373555168521407230042258385448135020424134937273528988585011`49.52287874528033 w) (1+0.22979946494092292579706961974863762725227482027813616105547815495471297782727`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 42.0369553772170225847437409824891003498937908620704717049175`48.89141157628182 w+192.6379321285950430498836942552348868454910805005659980870544`48.89141157628182 w^2-33.2252831367493364204390231390350727278021512340784951808275`48.89141157628182 w^3-60.7951446958793964018630322031846012239582248125990375676737`48.89141157628182 w^4)/((1+1.46165356242449160284668793883519154960863014888003341544811014885490508625451`49.52287874528033 w) (1+4.6616692323072861233901662600896760469865306885650047386398473468541760992478`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 17.14115015542399081235372562250165569560130030205541280007702844476893427940056`49.37382867306508 w+50.1977111744757885171640427796524319400681604393276849294448`49.37382867306508 w^2+20.32559812112579920530241786946379118288373509170958538332320152688265076127691`49.37382867306508 w^3-33.801324991866597396847676256968795898515361887483133551904`49.37382867306508 w^4)/((1+3.56785603679438355652182664694661259551548170047305601577201400912240480688589`49.52287874528033 w) (1+0.20420199974749232880453705253748741904258244908541645901151628314625910147563`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 52.3219795497801294642846271356391630315497421208598606190191`48.896524615611874 w+252.8898375276436875944080085884876530544556455589996655713611`48.896524615611874 w^2-47.7414060256839654918370246973523772450247551599363033852785`48.896524615611874 w^3-76.7421279206100728425547955018360037883437785230550777547239`48.896524615611874 w^4)/((1+1.45033630501321354931004566654625479227796826813372085972926786351568267568367`49.52287874528033 w) (1+6.28844973180164882828078253655402539658066214698146252396984760410189774452571`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 60.349684536177184522243248318455438901140970604519678162867`48.88523628712419 w+299.9235007221746137481814204590300821124263171016339775474232`48.88523628712419 w^2-59.0411604616419473215656495733971807245395417011052580629868`48.88523628712419 w^3-89.2082566356821927421701622403009933058451686693267442645472`48.88523628712419 w^4)/((1+1.44494246884424801559676688426610341996674190179659319493150062360410051401568`49.52287874528033 w) (1+7.55733055711710943138677926098979100854129428861721323757479029067573558164155`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 16.3094603020450860984130957264314383087425958431862228386957`49.30852435347168 w+44.1751357216574547295528140363490985038433523068202066029494`49.30852435347168 w^2+15.27908884775456980294987400556880817760061648507399369453858162591858551842675`49.30852435347168 w^3-28.5865249609360231153291265071589275029733715202216094472515`49.30852435347168 w^4)/((1+2.86693577559040764266691720685333659116870234210487051640077660917415105326736`49.52287874528033 w) (1+0.24811261451497503664605969212866683273053447938232693622294303453315509949662`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 50.8475014678201277634009166424634005450691126263396782044708`48.899058437723845 w+244.2514016984601417629379322984022706266449256262250863618571`48.899058437723845 w^2-45.6637207796556320434115004267680112571185156289726438621959`48.899058437723845 w^3-74.4538227995379621223031521170465121179870126010136747296049`48.899058437723845 w^4)/((1+1.45157775187780412113705447647980504513727936755039149175348253521181636394101`49.52287874528033 w) (1+6.05532704135497460097397078251657007234257708351889672449188843113036324202417`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 17.1801945862436331216853512632365465023067931356219458657224`48.727894097361386 w+47.4930648590442300970385804367704435137941661495830338254677`48.727894097361386 w^2+4.4072915597675904255847190226418959909964627696973834151136`48.727894097361386 w^3-23.8591493515568812457812419214285547647287735565336512214822`48.727894097361386 w^4)/((1+1.7772126316081899434269655335254778349391495626552967350936472270271866443006`49.52287874528033 w) (1+0.65802776117345793881482480048249071024542750989246242042778401415208484478855`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 38.7653073348325035312929348974807810190650489692916108357417`48.875601883156314 w+173.4750477143693893924766907055324254233589292385777304982082`48.875601883156314 w^2-28.5907416377301666519116392554219807274957291635026396538461`48.875601883156314 w^3-55.7331204952864457622896582307698444599283349213047998216031`48.875601883156314 w^4)/((1+1.46717416179869443283303991748328779428725946687319406687123188733528997493452`49.52287874528033 w) (1+4.14371307577144293376976677832107524937022990231215928898513136662638874385984`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 23.7009044983715614803147451514336421892111659235285886891604`48.60843620600089 w+85.3136367274709191516674500615836907865742917619646185142349`48.60843620600089 w^2-6.8469093734570473810061676259100347448447485907986142275338`48.60843620600089 w^3-32.6789381742155262618328437708825222284897900378811657093415`48.60843620600089 w^4)/((1+1.53825677510627310162821086621426854017683150685775257200431065846632601201231`49.52287874528033 w) (1+1.74735250089808373220599671281509761607880272719554478713149352274752331746317`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 33.8104715267932518387897862397619960812425595347663376176713`48.84029052253519 w+144.4588096433428845869602516860807231190344132428068016046829`48.84029052253519 w^2-21.5420269508060420955384871185569493226053220228413019632595`48.84029052253519 w^3-48.0855467511503502492153375320737802584669797773240413422211`48.84029052253519 w^4)/((1+1.47890477419025559620591116002954362364659084488898695953659085237985573477345`49.52287874528033 w) (1+3.35843792666735500726815707436049261763737241025157856411216645370251759404966`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 31.4323851185369803490210512851763136862284883810837772822239`48.81496047991458 w+130.5361423554561217356323221230956102329997896496318294044647`48.81496047991458 w^2-18.1386806698668051341943369552160049334253213355284312464574`48.81496047991458 w^3-44.4278388531458618675830405871345252595334637736345132991868`48.81496047991458 w^4)/((1+1.48682944244586977820365420440005430651203924067484629524220725179140417843786`49.52287874528033 w) (1+2.98096943198404017391050000464907298981352539230259919748886190316013572095666`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 16.9085765948130705475461918518233532474026355825841664937742`49.36124290438683 w+48.5396488738565314299690101430940631384463994174681759602419`49.36124290438683 w^2+19.0555138405902453465533849798219538202772380765632137379518`49.36124290438683 w^3-32.4318729122762261244337316305068847186144915680420840489414`49.36124290438683 w^4)/((1+3.38779774498469218699825295108215916128194881014851146621957948517682347963056`49.52287874528033 w) (1+0.21249443155082249779476724955439512788538703175004033244235788527662906151629`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 40.3998429214272441187923532165726878496659435830812524174887`48.88403955833005 w+183.0486700114412633224852466176648721436545307440091637201881`48.88403955833005 w^2-30.9076652272430785496387343501792807143328456338690579196867`48.88403955833005 w^3-58.2612096195266871119365737320502288333127416320949695192355`48.88403955833005 w^4)/((1+1.46424894513073678722071848471902421669229087712703651813280886916915125291499`49.52287874528033 w) (1+4.40252894624286506951486055531612643281121856771548570361298596742968126551456`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 25.8679469714117293849338796024359053116448788165908646529217`48.70340337084914 w+97.9782665389829652519625468848335007983239379932311362955341`48.70340337084914 w^2-10.0697567971892206265464656106712960166127504977233454441741`48.70340337084914 w^3-35.9355958325881617464866807036930911758669762416482046493988`48.70340337084914 w^4)/((1+1.5172979662777488546660117494638144667160363443119659864143344801199055132979`49.52287874528033 w) (1+2.09475680411155709467588351058201583798616671147339506428733921135930735301144`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 65.5692489129842986384631643502496460874813253358971110072825`48.879586024601174 w+330.5059520062861544640460133852793825993695517431496968678373`48.879586024601174 w^2-66.380331271528053099813959267871889093389151243920757187514`48.879586024601174 w^3-97.3185990639587853489182667745674449291054080634970726260341`48.879586024601174 w^4)/((1+1.4423240713955981632874395522650328731598096565204571362018379235071047741373`49.52287874528033 w) (1+8.38212690018565833386725573058914399045466230752223002888571807734326552205383`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 25.7722347861662770149555029113771082179592843856499149782259`48.70023766499832 w+97.4186464540771955795606262978780846225851280904040414331232`48.70023766499832 w^2-9.92881329274028423049613747213839539911259739364201821227`48.70023766499832 w^3-35.7908772990024975808677187132066758628629338158154403038123`48.70023766499832 w^4)/((1+1.51806534685563208649951839894516759306888454035123012299386819099954423054075`49.52287874528033 w) (1+2.07945250866517275461565789699186748897391343652552016931231052358660021373007`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 12.72736680268766056124892438724545262954277142396703609697173294240080555922108`49.52499361229531 w+15.93708598312395779424047018861455150580141195001553821077979477104332281188558`49.52499361229531 w^2-19.03198218503296639250608317585575301203951581508293598126881870888185531553336`49.52499361229531 w^3)/((1+0.46982882472418589704325906963186677199520440122136731151367116095255015078902`49.52287874528033 w-0.6766918083796095242194556958728031866545670246517074060873716547114226234094`49.52499361229531 w^2) (1+0.28179564180667380928921033077308918028183142472649016544441586555581227658236`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 54.2859337995578419975219176519234411134375702330131269272081`49.131300143178116 w+240.4508318268964480609755999756301318332159502276550705180271`49.131300143178116 w^2-180.2435927183387050803741272826306500514334855179883217143223`49.131300143178116 w^3)/((1+0.91637857615266268416642115514918753554043558706987876628249925552886224857725`49.52287874528033 w-0.49219490933911575847475612647817284719922421211596504906569529425475374378442`49.131300143178116 w^2) (1+6.73203720345537273402520821960607296053680765074529489056934481620430898752234`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 50.4199182715309905726460224341711093198910723753231548181456`49.136123269433256 w+219.577003066286034628607468925826799913980068248432237035519`49.136123269433256 w^2-165.1791376162041905041538865249383456863088257967400300172349`49.136123269433256 w^3)/((1+0.91255369607220071159899489887659653213558697072728152108465099291161940472474`49.52287874528033 w-0.49597452120841551071193909554611111075732449162694291552762744663486083630438`49.136123269433256 w^2) (1+6.12256991905019589692350238087122095451225698519570931852061154572074700439476`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 25.633279055806835543850774833438075285677283401835087043886`49.2136801527079 w+85.7205347639515621927367181662722523898757037049707935869748`49.2136801527079 w^2-68.7400982284922070178687232739052722628938885528502961805553`49.2136801527079 w^3)/((1+0.8457735972716870042717542653175412618339195999871772192363511318437580697967`49.52287874528033 w-0.556305294692507351087265675840683258027868322970267585541002125463291592431`49.2136801527079 w^2) (1+2.22558506758335247710343133914524255615918083206683571167078551036234634031554`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 11.17163291055384113181878025634322316245902447719656871388131218924326248128033`49.69897000433602 w+7.61102266004610698779812977667504138335419950744167298811095527025735219966158`49.69897000433602 w^2-12.5594248444140636897159725816854748406289779763676016638251170787784645975237`49.69897000433602 w^3)/((1+0.18453600180916564209852199820300501505635554522911628984150461373306725826932`49.52287874528033 w-0.55051507233854952368442610248332004095251538790780905921016493946865199807959`49.69897000433602 w^2) (1+0.10747665404061527890484552532995259839805727870816311965681416877982207487147`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 12.23453500143927188016824338319452749476592491961809725352403693957619366040091`49.57277211859606 w+13.28279257506081097620467650922882044607343971264214721770572166422475700020967`49.57277211859606 w^2-17.07638084861061203548646236904317445257532131575716856627120483554553108729522`49.57277211859606 w^3)/((1+0.40195510121034336386665126809236401834609946999346275085426615218062366203831`49.52287874528033 w-0.66058617029862552617279050332182918281020506386324175152235754597399956979134`49.57277211859606 w^2) (1+0.22094852511959938767588633314992405793986873579416128615581033268054221202072`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 12.1681952785232708999713688477150493013547425718491664850516306497250643171009`49.58017138821837 w+12.92629193523108415567035807351612767875311126203710282990236397993529502127607`49.58017138821837 w^2-16.80866861823614738135060842404703418482850278281366704269277707720657941282134`49.58017138821837 w^3)/((1+0.39151737892281188976734854052609763255723345978378406984836308816308124913466`49.52287874528033 w-0.65724059166990733530220784298473182189573626382852286027037239443001951852683`49.58017138821837 w^2) (1+0.21308326259948210143278445680788883437479328869885263746711897400527067812123`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 11.7661507946960478242359105664038186671908958614890441755053901410065271042295`49.63181753179903 w+10.77149783003556438463414776517412529919457891358063569633420318919578276277114`49.63181753179903 w^2-15.15372695754996547757584764176988525596812851515626837777772085843465224186564`49.63181753179903 w^3)/((1+0.32029068188123396383776517630451499781458422345022227730084385429944315592206`49.52287874528033 w-0.62873109530842160145429864651651373144019931269403657306482250086283817671159`49.63181753179903 w^2) (1+0.16740922888715714990431846397203755082405874877801596796859924526938735586558`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 11.73983587514332259890752265348261645933851944039212363478921169853939644348179`49.635692390413304 w+10.63086839981942778684687457943909736853228069412036849829406198999603147748381`49.635692390413304 w^2-15.04309357478773779832854712607760342243520565365973873217870917819827234872243`49.635692390413304 w^3)/((1+0.31510528506547867476803483600095661552803316425273776336971084779141828324296`49.52287874528033 w-0.62628886341546922521412149794417339906530992548391532039017789026955491767426`49.635692390413304 w^2) (1+0.16455059079329725238305822069194785041900549971997766794951741328910771379933`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 12.77966935162386476947575648823531487374817091016375263850046546227722410226037`49.52054393031973 w+16.21925505733513824480842704951217464256860066202726313472203677007367638652775`49.52054393031973 w^2-19.23683182008275299072235628727978716308181683568922749782919215916544126944564`49.52054393031973 w^3)/((1+0.47614747905961260242648219713462591511574694266796508580177365365586712008527`49.52287874528033 w-0.6776705503989518073547223479406746379695897389490349059298935514736036355051`49.52054393031973 w^2) (1+0.28847427542327042897922014379053553832360097139590151620365310448661094940736`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 39.9616782691196240871393149905535229329561056466406401237221`49.15476897268966 w+163.1066319312746341569399279285630820880479850360908490797571`49.15476897268966 w^2-124.4444986581983083778248365173093945944107208601380500621729`49.15476897268966 w^3)/((1+0.89741699734301509592634390360469408950334724016989765990148312429145953206319`49.52287874528033 w-0.51059595947972648558372287089262118967051816595181644016310456470386954253321`49.15476897268966 w^2) (1+4.47505304072017127681429027017063029354900638172726265549230575491332673335689`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 28.0597538027130730414272067333879929729743285626512239108814`49.198140447833474 w+98.828719876476924345113789488426006991374361090778671726417`49.198140447833474 w^2-78.1560510303943302748801885520798378251951022855439606004724`49.198140447833474 w^3)/((1+0.85997735828487221952585652131116380332154290443274348020625140709952130065492`49.52287874528033 w-0.54439250359293206620590465779993989205371043025539050222451770550325949518163`49.198140447833474 w^2) (1+2.60516171894683051501250028566524497667628213661062274656147285992598302426905`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 25.5842505036333234444628236552811681799684907609671240147038`49.21403547059187 w+85.4556525736686122057578922829584779063580182690142673530245`49.21403547059187 w^2-68.5499709288409310103447072068110819626786393775012169232601`49.21403547059187 w^3)/((1+0.84544381819436137463104449575766672174034239455053947774100200710797612534408`49.52287874528033 w-0.55657582055562378667709686453426759643041286530580343571853817274675332624798`49.21403547059187 w^2) (1+2.21792616200949776355761649024727849028118682171001554413547063128330698765379`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 11.60218772158471675565567479035066086144021296643786900444916486807553350664741`49.657222441264786 w+9.89624272251108821936440105295099553316754156317734857722075896964255277741938`49.657222441264786 w^2-14.45883154182778220735965080505185105839631622177843114647799419725510972129998`49.657222441264786 w^3)/((1+0.28682313040526192477700849457529330511892058320205392793826490377288937578952`49.52287874528033 w-0.61215046095534335507126006319714190970950531895573164041666441784160389034235`49.657222441264786 w^2) (1+0.14988721047541367515683882765910753098470893856881873125270004013354159908362`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 12.01817932092306092968737345370005476172767486173213016943507430588772105488681`49.59796438983625 w+12.12102594249539720450902015395190316557584294826185845100796653563292226818578`49.59796438983625 w^2-16.19819351999267344920120026889595600136626034591779062502533426388564009016212`49.59796438983625 w^3)/((1+0.3666070226968514958039269188804623210167267244316862224197819843816389037956`49.52287874528033 w-0.64837251453838042953321946823462006510332686896821562658465529476848667111739`49.59796438983625 w^2) (1+0.19562412150857062566827216842745641916090928146576971775422761015306818342013`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 20.74436910594078324068449226553147930476658631532239446329`49.26144799469831 w+59.3011455808228127804645077998579779396308210991070543568422`49.26144799469831 w^2-49.8186880119951312300293354176157577618096851732710381364882`49.26144799469831 w^3)/((1+0.79937727269810663640421892350260666474270512797057521385481132142158180608051`49.52287874528033 w-0.59160604561849355894106100070556516420062721716467801092541784896921379089408`49.26144799469831 w^2) (1+1.46525099874789720541248108492951368213029543641108629324820760255720186078526`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 34.5639857802701355813694933429595845487269144865750569630199`49.16985159560537 w+133.9582175972861086746555055830322908530917449477540590724943`49.16985159560537 w^2-103.4376230212926021960912064544416142591880787601336212603156`49.16985159560537 w^3)/((1+0.88475722741265178970067535293772311046450997269323404187405196176504133149281`49.52287874528033 w-0.52240619482622307013953188288083261496614551715984605378414618784966987840388`49.16985159560537 w^2) (1+3.62595074812126391824915662137517224079884341016501140082835194228287246873154`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 16.9020512842519426137196529461926147194924336496170058354988`49.33204006194795 w+38.522088554301393380398029926002107362512619746103177207612`49.33204006194795 w^2-35.0365379540526836402204997341699164491292314809989553214553`49.33204006194795 w^3)/((1+0.72292485436149866434844832600460979985079220737205044426007595464825237390899`49.52287874528033 w-0.63727150613325050181531082842553649458501194351595681420016272195487604497106`49.33204006194795 w^2) (1+0.8776823420127585731161859470399816480468285088177611573875847449875967906363`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 63.7941536830561387847830036066170526934733925833646255975583`49.122209286400306 w+291.7871886332663380344367995672517193350540874508157722996748`49.122209286400306 w^2-217.3021536887856236668846305903009191327121719204267446930133`49.122209286400306 w^3)/((1+0.9234884974223909380463890874432211868638554496681743412989259728078697982002`49.52287874528033 w-0.48507930763568428865482843857258148483339023154369756670758656882525939852002`49.122209286400306 w^2) (1+8.23155759947977700538591401885260848139581937199345382853320342003693346501167`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 12.11960197679996559941558898813894411118017226880524750910833718798715997633069`49.58576725131477 w+12.6653071095758024583425485628452482996466555590799518269160551100076764275774`49.58576725131477 w^2-16.61172888826634494687907905399278341926622456845299713376544344419816283185229`49.58576725131477 w^3)/((1+0.38365134558000164021465624369240232960344711017169123654134565468314248709394`49.52287874528033 w-0.65457339690133596197341615687197401925272238735745681633963293765564559982936`49.58576725131477 w^2) (1+0.20737714434729435320688702687271710376988667035810095524665496700873745307213`50. z))} /. {w->w[z+10^(-10)*I],pi1->pi1full[z]};

(* Sample Pades for the nl^1-part of the 3-loop triangle form factor with LME to z^4 and THR to (1-z) *)
(* Mean and weighted standard deviation *)
Ftri3LoopNl141[z_] := Module[{const,ls},
const = Ftri3LoopConstNl1Pade41[z];
ls = Ftri3LoopLsNl1Pade41[z];
{Mean[const] + Mean[ls]*(Log[4*z]-I*Pi),
  Sqrt[(StandardDeviation[Re[const]]*80/Length[const])^2 + (StandardDeviation[Re[ls*(Log[4*z]-I*Pi)]]*80/Length[ls])^2] + 
I*Sqrt[(StandardDeviation[Im[const]]*80/Length[const])^2 + (StandardDeviation[Im[ls*(Log[4*z]-I*Pi)]]*80/Length[ls])^2]}
];
(* from 20 each of [4/1], [3/2], [2/3] and [1/4] Pades for the non-logarithmic part *)
Ftri3LoopConstNl1Pade41[zin_] = {((-28.11500702002329996843056089115866122736377385080535355753036434764248746015814`50.- 102.2224281331255234231689060181068022724872916310330815929741`48.10944256532317 w+41.7724842404894025802763836944084250932733463337029707831801`48.10944256532317 w^2-18.075114409033870841518952580996148366080200853248210375236`48.10944256532317 w^3+4.6503456020631926910016453577444003303224965013206224445182`48.10944256532317 w^4)/(1+1.13867387444207029170297576945059153339127899198599738192652623578869540980925`49.52287874528033 w)-52.34158144426361018767548380093190938093444199947020469902726232080762695478962`50.11014396286155 THRSub[2,1]+4.89541514137520086153840460148522869119619706041682079334856408211821985669427`50.11014396286155 THRSub[2,2])/(1+3.46408330890281885321534895837844222663200590426132164116311429553098844790459`50. z),((-45.10073198100283794705235818524673365124230281938540195990855746812600113212199`50.- 194.6325617650748385426875165820659989401911106185978650843757`48.1175068223751 w+83.1842287103270094088497201615082592666757267110652175420474`48.1175068223751 w^2-35.7491746442805188598461144956135405683666515063758002215068`48.1175068223751 w^3+9.5579200354082712785162802741773224592675037543391459668539`48.1175068223751 w^4)/(1+1.13830476533081542636363696717574752584854360544120081249524946045300511260733`49.52287874528033 w)-93.74107306705854555475050931100545477508051268784695069362888381341271819572642`50.05803119198019 THRSub[2,1]+8.76743605750435105546344493266664272065713596534488631693204901895995980226393`50.05803119198019 THRSub[2,2])/(1+6.99494298969366993536821110078501474836222476145066724066267081927946422653877`50. z),((-12.16748853348786110541945200525614975526311222139122772721789948065662167966845`50.- 15.6389674696821066351071019921844212281174839463318661129187`47.40482580845488 w+2.9162270627358718741381668544932180435777066579462017537505`47.40482580845488 w^2-1.4909225991749258706188990791132672789765498812053090534487`47.40482580845488 w^3+0.04103250059724491807681015487372988390450051065734887032668398442709222802943`47.40482580845488 w^4)/(1+1.15461662191622164991407974117452177022450644575083641991885189321174761928889`49.52287874528033 w)-13.4725217188541892592564263893604428063981588572644855388372532169611348665859`50.88703770344723 THRSub[2,1]+1.26006102595918500393862077657480889748788443379135632684134776850817334837572`50.88703770344723 THRSub[2,2])/(1+0.14903787150586813051548764622583945322751455262919793312819526757441513760196`50. z),((-39.92325468806220464795185775767597530671605895278673159731505590908394121914649`50.- 166.4641775289293918820839570209021803895914426985340336769082`48.116078326595755 w+70.5612996512354716539071179585322432083019383331461647222612`48.116078326595755 w^2-30.36185483281800524047759140725166263511325680935302988287`48.116078326595755 w^3+8.062030465418307299423717493044851200830629204069481800283`48.116078326595755 w^4)/(1+1.13837063896262374497902266620249677901176577981621880776498849915437482831081`49.52287874528033 w)-81.12195152183685493981648925104732002934189772356251188030400067077090003688799`50.06779828354366 THRSub[2,1]+7.58719203394318245217119939013148877981724706413737730507011561419420948865988`50.06779828354366 THRSub[2,2])/(1+5.91868949660755481094781152506106289354611414519760186982782728389168999433392`50. z),((-13.17889304750447884418358991308099998197993984455849016060857437971795253589932`50.- 21.0310881017208887699280475989651485822499827559595490582666`47.94375817449173 w+5.3670204759555652440244528037791520380773698200690990156115`47.94375817449173 w^2-2.5373787598140016280087570080981018388140635038123850327248`47.94375817449173 w^3+0.33430369134554330850079883808929143301955171546436128626925408856495531517604`47.94375817449173 w^4)/(1+1.14494209365719192845291666227287849461029288059787631632869519491881154036534`49.52287874528033 w)-15.93762890747743438395103787223121874811755779639680731349889596751195937338053`50.57787523302139 THRSub[2,1]+1.49061812269401537368109230433385539112240120253203463869675422275487792477974`50.57787523302139 THRSub[2,2])/(1+0.35928073295069396918019613396512764799034614242452479810217474299753646513053`50. z),((-11.95956818479994198254838438989027198341537956987527882531975195617497842564647`50.- 14.583416185347635946692025498142679461791287702904614107283`47.22789396406715 w+2.4196176808727198204607606644821989340883246467007123098399`47.22789396406715 w^2-1.2786427222154332506390558661424098244005914490073036330616`47.22789396406715 w^3-0.01976187253798971921040843423140321781236957601328574639852570267599150310748`47.22789396406715 w^4)/(1+1.16123470065411793711551125651763251500180586082797182504417363655149687090946`49.52287874528033 w)-12.96575519852677471446879943705678858557839675123455259041434976212437843883945`51.01912776060486 THRSub[2,1]+1.21266405345092052189183175042323956385708005379350324824426154822766731328343`51.01912776060486 THRSub[2,2])/(1+0.10581701530546182788741245417573723823394899843572963857214041011682454290606`50. z),((-12.00634505489214427877417473244034442283223383457242378738435784182081021602`50.- 14.8160805556721665181981480648953368770904135121158543403729`46.67788736194327 w+2.5306870776980869870373502748405340455016514831921871199`46.67788736194327 w^2-1.3261418639046706648508231047524543851439248035185703042282`46.67788736194327 w^3-0.00603880129998563088579265613971379130931473874807375184908064171374981632615`46.67788736194327 w^4)/(1+1.15932534152644651496368851600788451648921261399202297289625993700967925724866`49.52287874528033 w)-13.0797649712018539308849386400237243555737756179613307739268216315089411452748`50.98475067735229 THRSub[2,1]+1.22332718498072826929271844044235494937438053491216588458612953724186109207938`50.98475067735229 THRSub[2,2])/(1+0.11554062527686830374164664892337827179255916637571685596150593767180048493805`50. z),((-12.20943484195399030904057109226014036017381859487259539922633854129543866538343`50.- 15.8568474754224976023422057748621277415808220062660574649074`47.49426799715122 w+3.017086106315734358078862030935234526368354890770488728956`47.49426799715122 w^2-1.5340135105403673554747013207217429861523957703274032652406`47.49426799715122 w^3+0.05325026303609240387499146934692424281574899085756343134789975194131145130002`47.49426799715122 w^4)/(1+1.15371264896738072284135760771770462932719125090611437482390201497805722484631`49.52287874528033 w)-13.57475791130049294689774417258664928470976306440915823572566045137177577825671`50.86562796316729 THRSub[2,1]+1.26962299544287616195161017589477711139281477071566553765143861055298087723205`50.86562796316729 THRSub[2,2])/(1+0.15775734210022364406304883452495587591476718708095268697408654649788565571547`50. z),((-12.34418379657877334576182785948877616478813630730818394385055095620853874023419`50.- 16.5632274672338069462340901411444005761195824157719709294205`47.66524608870258 w+3.3419674627582268381717160705262599265786491272427231211876`47.66524608870258 w^2-1.6727866720606411595387884601281890541168127097561412488819`47.66524608870258 w^3+0.09243718583050326559645519786968319327590998986197837206212836250450241266681`47.66524608870258 w^4)/(1+1.15137351979516376635733720020549021518194028064292345964060702039542375077202`49.52287874528033 w)-13.90318299948391631401019149991899605049499351054476022607596138856225088118804`50.80502901554084 THRSub[2,1]+1.30034001057954473667056770973165867581349990875554138433467520611519811066519`50.80502901554084 THRSub[2,2])/(1+0.185767901084685435522747306789919132238936933091054706432745786363407336711`50. z),((-12.74000205094226927029304329779465723123701224698814348628821184332995817479713`50.- 18.6701464997940461893361550527079064311452249553342101533941`47.86087209812565 w+4.3006461017550780999481050438248821559337130705174747103505`47.86087209812565 w^2-2.0821443548870732931550640340757333937835447327019687406302`47.86087209812565 w^3+0.20724195322501926693808129985549477408320292631970693044776917629348899550339`47.86087209812565 w^4)/(1+1.14729750189562494597627919538788983624972439928578159691589976021172727973027`49.52287874528033 w)-14.86791512268237605438969810978531162414284867834813949454609377845133769802468`50.67492375523446 THRSub[2,1]+1.39056969246842427324152954508397363471804377322424265299563088792442849235733`50.67492375523446 THRSub[2,2])/(1+0.26804750460256137327483934197997356343673616427563585819284443588724303497052`50. z),((-34.64836526073077321688371033527898042123625505723889430712521948943488122504436`50.- 137.7661621621535906353639811657983022136603221870729514752663`48.113959163737256 w+57.7009224017142375265999781547453284371533843070110751819519`48.113959163737256 w^2-24.8731933661149429022506619571195667169109528601505693283296`48.113959163737256 w^3+6.5379930446140847217602491990030459626449979055168455862141`48.113959163737256 w^4)/(1+1.13846797212728010329762891087625290044511961397629112007818204990972747225273`49.52287874528033 w)-68.26540632522937995235946529448649810826579483276317993929427021933209293391152`50.08184210647469 THRSub[2,1]+6.3847421979888169061460253567892027979193217341811040096044618220194310303724`50.08184210647469 THRSub[2,2])/(1+4.82218673076267401960853680505145284623772390153592258271493238224516205826215`50. z),((-51.37991086673966583960016397893592623288155009806785945502248504428054353618381`50.- 228.7950834386165737066473552739780141230951843305113965704498`48.11873868694545 w+98.4931929091549488433083382042192712627010025592844220236983`48.11873868694545 w^2-42.2828619674849737495982160933474147442099824529935803385491`48.11873868694545 w^3+11.3721134609638092807234015122355360789538688059770331087392`48.11873868694545 w^4)/(1+1.13824778859761216870750961059181820734144841334523780697325039456064973769692`49.52287874528033 w)-109.0453838500998299673901286492420870600926786011950001951243428880027439445353`50.04940367696143 THRSub[2,1]+10.19882106094358211606822089671203290555599765372923427955358939350609290756517`50.04940367696143 THRSub[2,2])/(1+8.30020959486086145109170524949149398476799828721853506829250109844325890294549`50. z),((-12.06890706988196423265689045060040610219255933543933934565325092320005563854316`50.- 15.1323017110389001800332731895988147134917309134788047423356`46.941974346334476 w+2.6799247664633724391892391577064382903897259452851713595004`46.941974346334476 w^2-1.3899410073438684128924811720823750469125823837139250290208`46.941974346334476 w^3+0.01226710802232228915232168685534098004597723457921736045587498491806954674755`46.941974346334476 w^4)/(1+1.15721262246902866626250300574039167353853221901561745621732136831421312421866`49.52287874528033 w)-13.23224804869346423827959214914994795489530589959581447427415985052868282946961`50.9434621124847 THRSub[2,1]+1.2375886563722795564870716957819991751779776548865179369713063752323563804796`50.9434621124847 THRSub[2,2])/(1+0.12854552773372813311542552051178212937492741767632493224736127832813312244336`50. z),((-24.94495492578376362098363680193021765011454372888511526425269006642677040727847`50.- 84.9770662728813599049582450367399617052273186072920443708139`48.10564147749258 w+34.0439553255414923739684549002089662571016420815759649988279`48.10564147749258 w^2-14.7766612437523381873291506374883348923344753363310525292771`48.10564147749258 w^3+3.7344319730729386893532544472418816689174208162071921137363`48.10564147749258 w^4)/(1+1.13884554068297755799829725199648428286719287248374964688112146941568744830053`49.52287874528033 w)-44.61517910225106641042354209412497614016723626809477257650207126458264032777953`50.132417007654794 THRSub[2,1]+4.17277845425633380704667318685440930733472488439368046565492712195644528860133`50.132417007654794 THRSub[2,2])/(1+2.80511766856246705648021019712672291587908700726212849864354179258276839309999`50. z),((-12.80802080602644300825904979262953511429920264884969576726144955053558717709783`50.- 19.0349139877155995782359451669546825977596057058149288134954`47.8784708982492 w+4.4657576642801207160452977612777043007488390899383953475626`47.8784708982492 w^2-2.1526353335534470894672876771314412440166648692427404146724`47.8784708982492 w^3+0.22694457498917417941030112971886090776274712781616254669937843580509164411347`47.8784708982492 w^4)/(1+1.14683381081467662448926593893419747112324720164665332257797993556816949545973`49.52287874528033 w)-15.03369797197312546062949574143156250284865786869576393127525925305902030320506`50.657414713079 THRSub[2,1]+1.40607506789278876767821487905677530654429873787052414916225775415724319292479`50.657414713079 THRSub[2,2])/(1+0.28218671151990020632991910722595391499748156052178675366469446198946191900851`50. z),((-12.25281042513035281101342540288926541868405466244769861179156095742724116890737`50.- 16.0832677405199123596332868383602008846558244070206704821001`47.563391124682774 w+3.1215339347045694330006637213112508157158307438548078256324`47.563391124682774 w^2-1.5786327122003632258868917979155533812009852065679128850951`47.563391124682774 w^3+0.06587368637816428795079451076547467938254967069226449123537455386261370471486`47.563391124682774 w^4)/(1+1.15287548377816876063428466011629799737749710742400368175251728545664363264162`49.52287874528033 w)-13.6804776904956052522592112102048436133203347582715128210273127145317110800347`50.84485857810108 THRSub[2,1]+1.27951077860750417499590544435738842357272914450317468308534630569644980169114`50.84485857810109 THRSub[2,2])/(1+0.16677391914477365981472289698069250375688173667415894166300877651747218128669`50. z),((-48.86085924277984233635172857254671454878801816739143051483341534670406181682307`50.- 215.0898964750980009821368413640127384922987238966912031222428`48.11829453950393 w+92.3516106574291016469609771524676040162101230452574291863034`48.11829453950393 w^2-39.6617064266353688603754765381569016447332205956855520583934`48.11829453950393 w^3+10.6443040761004467518567591072742630219726527824650813591056`48.11829453950393 w^4)/(1+1.13826834973424670788051469071621040094624341735358224386638718831348584594128`49.52287874528033 w)-102.90567201306684589553817739343758656942436765193944156333814617610285498980725`50.05253674277945 THRSub[2,1]+9.62458471841545883908700908453304867188383739722283539868531759293127732021912`50.05253674277945 THRSub[2,2])/(1+7.7765688416222942674751574330035068394151521042059243694400898301600479946473`50. z),((-28.78849299235667000942018879762607957783948646970158657193555896481422746164009`50.- 105.8863433625735202635713789836408017955333996092672782512069`48.110068120962595 w+43.4144432891215477824472091937610066333972432246041398316061`48.110068120962595 w^2-18.7758844961969726044037835901944958102508405345622167577771`48.110068120962595 w^3+4.8449330000185540904879322210389449746103549847615710868868`48.110068120962595 w^4)/(1+1.13864548159162403723323693728877253408404127228695646098652316643046378367463`49.52287874528033 w)-53.98307610720776681185961973933288922322096507199150896127452377995899755644753`50.10634837843761 THRSub[2,1]+5.04894122151514458173898514538475861557774555650797124471130057231559168186871`50.10634837843761 THRSub[2,2])/(1+3.60408230634054638435309634239330029867931190288422039904160147246571699901541`50. z),((-48.60839831360583855548449913183160081783522332914087149155323109252795525528448`50.- 213.7163558233116489714367656796517790986242900814059219364001`48.11824668147215 w+91.7360976826436796668982844683568937894517747310288249496346`48.11824668147215 w^2-39.3990126735193112737699600166830828975857802832023892475364`48.11824668147215 w^3+10.5713625476214180660415412219486564162538491295637087298789`48.11824668147215 w^4)/(1+1.13827056402167361696641743163755045733949519098363399895604262157333680427335`49.52287874528033 w)-102.29034625296932338882885059494324519218423251781796326141116194569937844411271`50.052872816663054 THRSub[2,1]+9.56703439303854481824714836484148583230427121217448026460303207989179419882387`50.052872816663054 THRSub[2,2])/(1+7.72408923784657889241183150706712095921216207200463962651112320817274853908621`50. z),((-33.12480920355587609307842560320719159967686036812482981072792813448080794094666`50.- 129.4773621435975630129397208578124646074949878087989035939165`48.11315256906861 w+53.986449618190075362320892492796418503114717024991581752117`48.11315256906861 w^2-23.2878985540143544496764244736625113980177425445287739156952`48.11315256906861 w^3+6.0978015401722183758732626771604637375987352120590499158903`48.11315256906861 w^4)/(1+1.1385048970354905849404102288081708243779053436754699461083995559779438512337`49.52287874528033 w)-64.55202662723188932208454735220543700755709627771419100114096572805627252383812`50.08705409140049 THRSub[2,1]+6.03743639068129873087772088265923412990401405233854073866412323378592022831382`50.08705409140049 THRSub[2,2])/(1+4.50548181142237519832000537549407031570685996107707467870330964411984700431711`50. z),((-47.82937958843248805764783835509410685914786686332288525299983332002493373647164`50.- 237.0218825982608422731180234958158315433356292532272256020701`47.73919396405325 w-32.9297734265727973645008759135109618137732460991190834102955`47.73919396405325 w^2+6.2328838485874913658912386307651121522108368003004504192116`47.73919396405325 w^3)/(1+1.71415499834187559992811855411448040486228074736950908494778783535044103646647`49.52287874528033 w+0.70010273295237238954902221492456684106052261521507396540298699210093463231446`49.52287874528033 w^2)-100.39163546724171470134699839594838912591401623368883680670412259100749816409149`50.0539375247729 THRSub[2,1]+9.38945134581172042171389162600608304387898083294270958101471989225445797217766`50.0539375247729 THRSub[2,2])/(1+7.56215291698806374848471122487135040522582642274223644415632205450373409194202`50. z),((-13.56689252905148633545420309366939910324046322724905187704097912993650349271647`50.- 26.0117545841482346653098965317250841070152641147360882888942`48.56206012320754 w+1.23289785616208595647659580331809898719035534913058364441132261881804788399077`48.56206012320754 w^2-1.68914508675023759189316500435303487620741351369784140419565397613785240835351`48.56206012320754 w^3)/(1+1.35626233709323701396992927639402743071883934565912644851094357523922194632294`49.52287874528033 w+0.25502843087211529890737312556833923168752706134351503125057657255114470632353`49.52287874528033 w^2)-16.88330425091168894578737970078375276501335123087786458581176519762161407033736`50.514954352142496 THRSub[2,1]+1.57906545782092547807197457408114826629872823103100970864863032264345634763102`50.514954352142496 THRSub[2,2])/(1+0.43993503111631542860415985571833844603808235043105665119904104983649668635207`50. z),((-27.13074209583061890115629447097141506392961856612433187643184930014575044550209`50.- 110.98173337108583214701487769427704852282017072640567107113546192170482264138948`50. w-12.08676474025578862255224415852228668943017407199150764462933262755144201622039`50. w^2+0.83612294617965564207948233116788783462222565353188559524112266227366316648918`50. w^3)/(1+1.65893691822111775244711146407297847589447403749087389519350570061586152689978`50. w+0.63172056086166345285749750511096956094201098310483639363229987692387366235759`50. w^2)-49.94262187219151418765122111188011741123403041121343888487514201831078271910829`50.11620819984537 THRSub[2,1]+4.67104471372248828887051322856624191962688583145435369548087609860585509822809`50.11620819984537 THRSub[2,2])/(1+3.25948201316582568973300874904150150563638913025188342765482175625812835323552`50. z),((-28.07739345277356779602328082085659740881491842779171256540230671087473481870775`50.- 116.7693736596372476259354645404334095627683012673754390348092`48.00872661604698 w-13.0365025681614305320701745248683664404879256737230250414635`48.00872661604698 w^2+1.0730398595971351198615393676015240966307366530459520818312`48.00872661604698 w^3)/(1+1.66406514592372911187787511272525436902589785437353969538578519590683061613117`49.52287874528033 w+0.63807360233565182412588460369926480012179364213050966561790370523914727500274`48.00872661604698 w^2)-52.24990548896373578488961315138304744110873604337328048744759376437103837575408`50.11036398983611 THRSub[2,1]+4.88684085211432055793475431125370900183550639361017547813662695163440053346545`50.11036398983611 THRSub[2,2])/(1+3.45626449467158125267271847999561566967479566342472815389105089541604184217745`50. z),((-56.60580152468829904600960129837386710697058431635244318492084884495538907946491`50.- 290.3351695930231145842580774880361252462480714256203365841492`50. w-41.78712762761817153512155378634696760015932271458874113849280290795311593012064`50. w^2+8.57625365249148281786929755880587239245504917011483328567006430394569709260491`50. w^3)/(1+1.72309860607609843864471548779396592764902710468534642050589882120782843717193`50. w+0.71117396366298160380381621710006390935073881465912465159405739582013821639628`50. w^2)-121.78250381479930904690324555546137481898965998940946542940079144571691977920629`50.043965421217166 THRSub[2,1]+11.39010126708522977969779032343820539909792301426125075155905510487489414438574`50.04396542121717 THRSub[2,2])/(1+9.38652687968450036772899328297957533498703638908604431744557062497453666915965`50. z),((-30.86511650815852963849641804683047685274263283405588261432393322995869017221449`50.- 133.7900643438864021636957384516557746093580714836550130512935`47.4835311387938 w-15.8367657877619908408729630917643927594288071430858034038594`47.4835311387938 w^2+1.7804902129612867473146386358183948228292141684862994307087`47.4835311387938 w^3)/(1+1.67659778208582811681520655301595231087108373485222186677325540457940728829988`49.52287874528033 w+0.65359746150191418520237468396394432076859367197523596824586538083337508572471`49.52287874528033 w^2)-59.04445311900062954025726290249618693807187697576916938189091049777432336112604`50.096139808433286 THRSub[2,1]+5.52232282321786978988374450986792117098407585175456823317378945166635330368343`50.09613980843329 THRSub[2,2])/(1+4.03575456413177872379379480367260301144000099830439073024246859416026338262225`50. z),((-44.33935939160164954119502602302645015001674186760788733786140416212232199810342`50.- 215.8104191754381976522956264150658429129243319964508315966758`47.715024374483974 w-29.4092598364932020129784875526645328420820819089114045995039`47.715024374483974 w^2+5.3057135107625182718277263094977321271882823755816463932351`47.715024374483974 w^3)/(1+1.70936711224280619800779009213138623763682982515974813538786994569647310827744`49.52287874528033 w+0.69417536078969717634096321272421974996662579325841094069750328618844001367594`49.52287874528033 w^2)-91.88537139938462973128999278001231006926164608309714176743599286258804092094946`50.05928690275013 THRSub[2,1]+8.59387557669465803440291160048227610166456551435982669969140543543090455035438`50.05928690275013 THRSub[2,2])/(1+6.83667480955112781043569892374777645981063493792378959528541003570672166991695`50. z),((-14.31022111202270708846969777093369124269991025459937935222488303358020103016679`50.- 31.0192815794981875897076771766023587154145832133845626380242`47.81252997455592 w+0.5492804834736683407284716457780994326620420934285215084416`47.81252997455592 w^2-1.7000017682441251426479864905346111031031856197010819854859`47.81252997455592 w^3)/(1+1.41223703978753562114886240462656660483705182001409681310369261800051913668652`49.52287874528033 w+0.32511716727778078806955332095972773125100838599546619226681216800782709154762`47.81252997455592 w^2)-18.69502706606354998871823397386425801225308294980365071142972121442121860308318`50.42849449013178 THRSub[2,1]+1.74851267467114046165978577810188900107167011569817073098802493075181126772186`50.42849449013178 THRSub[2,2])/(1+0.59445236430178840091755725364472848765081254241643469429866952785491985264472`50. z),((-46.13101197274607256492845527901667964813127049391480906802304130966578989416057`50.- 226.7006316265684884025552812771290237037151846478366455373471`50. w-31.21641294678561988352098567475432592596191291812762392776802699100772503723753`50. w^2+5.78126266196804552189709119456245522490930651537796977196223630122712299704056`50. w^3)/(1+1.71193720092236887660256611006046754255191987985582108336402195199344910241445`50. w+0.69735715642563206575485785894545584771662052043776729019215971826589037055291`50. w^2)-96.25218566221077193260074668380235627724701831218488475696373658842206252976526`50.056414426288654 THRSub[2,1]+9.00229595819528502724842841147869936673886457096278189955411942387903140176652`50.056414426288654 THRSub[2,2])/(1+7.20910953784681592883560779609777590151237843990984311939280632919573074355336`50. z),((-58.06856906690957258466973626967811644058520461898314727553786102606218324139229`50.- 299.2181362805972767321932041556490733812018705633001468175658`48.46720733873127 w-43.2638111562088713475868116861617258084137311153379340724727`48.46720733873127 w^2+8.9680064410042003826060896429638339074059797026969505167676`48.46720733873127 w^3)/(1+1.72427875023688698829871398876938194632278751082940052480901820051330144426055`49.52287874528033 w+0.71263477063090933220382898633221581793509843184054299633893498436896401117993`48.46720733873127 w^2)-125.34772300617338644671706247144418550580815821795990287500614436780567175776588`50.042651431371745 THRSub[2,1]+11.72354988537658443778352707240776470203260357151023076925638294031311856946365`50.042651431371745 THRSub[2,2])/(1+9.69059555788713958267604570853316365433235892052897047104090680396594076758466`50. z),((-32.32403720323942320026010942213131198312022700363063694512470788240291100693612`50.- 142.6870296689102496883323215516418623268403774950442242748305`47.53272933516977 w-17.303853110678889265208933297903841794422652934398127552299`47.53272933516977 w^2+2.1552519385134366003281962119576599411379400930820187406756`47.53272933516977 w^3)/(1+1.68196683635771305135901689042539791765596364778017016848243364183387784523702`49.52287874528033 w+0.66024711885411840381329433399398301211783774836830206734387093125495213418054`49.52287874528033 w^2)-62.60029634812828013844706538556666153908679607934915051478801479565118934047028`50.09006982848928 THRSub[2,1]+5.85489452441425672713419800280372246177926008410328643995697743578410624454354`50.09006982848928 THRSub[2,2])/(1+4.33902358983225297059154194098418278863800953805112220450377546880748462610745`50. z),((-12.06157163151605672688543459011346744434260566067293215347412678120950540949211`50.- 15.18436561761099366537339828487837674293810958867101326555821423875616294348564`50. w+2.55014851567786770660828961777557161551730478126390424368289349517100426107112`50. w^2-1.36275044644013513276530354838045278883858863089448147442408877747515281126333`50. w^3)/(1+1.16484970636248803139716890631496385286230962892868643398154029965318424215739`50. w+0.00860885484340845669530035392337818808945709697721381810033827657094375334072`50. w^2)-13.21436930522643217544755814919707428747001969890395335306661349924757363296708`50.94805740873586 THRSub[2,1]+1.2359164892527118706486139194886790402086775046921286370999223224335166900709`50.94805740873586 THRSub[2,2])/(1+0.12702069416750656480631797536868011520712391695076648067642076155159076804979`50. z),((-12.67168067247037456128469070850361483619762397625660892352552459509246127412287`50.- 19.72369272276065882340157667969816127341502593929458680493607563330760157673459`50. w+2.02786518772434979483699568530559730664650531403881445290763837031366647014279`50. w^2-1.56506382475199063195622533798611596836897367272524355578172492658731329785351`50. w^3)/(1+1.25982416896320277913238541917740566716123196676133523803727999058123993371242`50. w+0.13304497349600610103713977785379508775620826332488295654360899864761883316756`50. w^2)-14.70139468612740347485549074375048663703192584603951643514254174794329293221827`50.693674705828634 THRSub[2,1]+1.37499533181736752417719740162399349521196697575328311090963378061692392413798`50.693674705828634 THRSub[2,2])/(1+0.2538453907018218921264815005503184873158334046336085647011850232766396932699`50. z),((-48.03916913201729104925056923008434057832594649379474704699563636196952154863291`50.- 238.296688072367072365490246429841158293582687950481699729878`50. w-33.14143327270118884132340629971494733868291835857568287391251831219354852446485`50. w^2+6.28872089680677807226858587060316971307460953758738932987475657152530308939487`50. w^3)/(1+1.71441559018736804925097166316617620008633514694008188125731891090443204409769`50. w+0.70042533423039533359645374635042857250037913023001989721567287599778898505696`50. w^2)-100.90295779655889474264753415722290554775412348144356197402134373958242991391874`50.05364659762717 THRSub[2,1]+9.43727441504259654976445830874294125797329226956335241036027208288758149838049`50.05364659762717 THRSub[2,2])/(1+7.60576232680700024668990333882409842051007679824750142117156684131201433385768`50. z),((-46.10748016149042627082385048068214798576285019143382841708212253846046707390511`50.- 226.557612378632022762006469004444773650200544360630990140831`50. w-31.19267535124936827980495782406371292213719421428816220044027156425374918750602`50. w^2+5.77501062223326962590406513002611310468628421386368084525775977722114822719356`50. w^3)/(1+1.71190504961683235963388213482772583247555630452060457546194760866882674387111`50. w+0.69731735339505630123011336324759284801084133048298007821486766247692295006783`50. w^2)-96.19483132348308658987429322436870643391348212886865098669141602539236323497669`50.05645034619422 THRSub[2,1]+8.99693170876904144312894401942341259607457362640453836036108800549157439253292`50.05645034619422 THRSub[2,2])/(1+7.20421792893583834793599053258023654554672074199665686916102598233231853500028`50. z),((-35.73149089631508413408236778515905045475396893120600858289646285074227771259341`50.- 163.4464923171234523711980842049421117783925072167695878946379`48.28898798918038 w-20.7334613503148893730318180924880683569685400936581207063086`48.28898798918038 w^2+3.039204322085542768869392687294814499511078826632780767912`48.28898798918038 w^3)/(1+1.69223135992634607902871374962735415879902842471890570343330920661832980448102`49.52287874528033 w+0.6729585280567502588354146573588620727444898134571456789268020440800395404155`48.28898798918038 w^2)-70.90532018111823828012244423455783200005587021434720217977212000343789549986458`50.078501848410575 THRSub[2,1]+6.63164865181475224556011117519190413939514935752499591945933704632394181952209`50.07850184841057 THRSub[2,2])/(1+5.0473384181178578933979740117780298881304797570352857198120409232665650657683`50. z),((-12.03980369449283748221840034576858679258974115677611935916807351395298119485992`50.- 15.017981907513051328547367322106493949584234989339424829461`46.96103969990766 w+2.5687852305985819647920304298459258225055036751062776945298`46.96103969990766 w^2-1.3529902483909786080522102623713364890671288650557607538059`46.96103969990766 w^3)/(1+1.16091567030598835980124882242258348257604200824142042855334532840956197246519`49.52287874528033 w+0.00321787891807864676430844585625472092163422823937579942134306513577946539895`46.96103969990766 w^2)-13.16131407629104482001946312215207000231872738660916739788542072261221759631443`50.962063698044986 THRSub[2,1]+1.2309543279290996695936494381355423025569998174633090580876204005216575243172`50.962063698044986 THRSub[2,2])/(1+0.12249574563891300559382568031693572047645760740548537259818224223424097909236`50. z),((-48.35699426000729859547136946608943089470397890393638367726101448904187805001734`50.- 240.2279346638860681875306371430922530679598374161395241315301`50. w-33.4620990994866004861031337787630889310944233435624842527239209124993146967424`50. w^2+6.37333253549932979721155063780818891971960558129580950134889664079161618539139`50. w^3)/(1+1.71480509875850966773920422299477747199956119733808416907053165553768255846832`50. w+0.70090752690112346669151905392934718452394792092798643548469255371742168827054`50. w^2)-101.67759642717152992956960845468624288193443347573821661865879888198582611962833`50.0532117891339 THRSub[2,1]+9.5097249902212120255279660173252476988191778930571040401273353654675466522905`50.0532117891339 THRSub[2,2])/(1+7.67182932910098972244863322808070856646780700726172480800085072580576767397669`50. z),((-12.38823629210363406073906120359662624290337462474781296860764369521536267519407`50.- 17.6455523948507038336470338149757636957433355598983689291909`48.35842772247651 w+2.2717678778448686352365773269105161294171596232158918704322`48.35842772247651 w^2-1.4867394098667330251616409165225976913339991573330323393031816575610835178403`48.35842772247651 w^3)/(1+1.21934578831016538223991438644959825482995839902071966876050601925206673305374`49.52287874528033 w+0.08091599599074012068047715252342723616153982142200868540206104635427014916672`48.35842772247651 w^2)-14.01055262448575137985231790581984678170906927911440165493182708171831203636721`50.78747275145964 THRSub[2,1]+1.31038210089195668719780161885646561137343765526709651890465200325151095305797`50.78747275145964 THRSub[2,2])/(1+0.19492518937495692642677439963730307283366012890696385878960566902684237677033`50. z),((-41.27419994294220793317201367229136362844861135391203420723494172808219604961287`50.- 197.1735620002668677112175060774713818029272466271211392062308`50. w-26.31848510661435274285486016212632432634585883944145097604331174951599032418391`50. w^2+4.49465715412573022727029707335253546705183406332467689074145161997193620599887`50. w^3)/(1+1.70431033980845437307178775775765129541315178871712952331999780284836025671459`50. w+0.68791473437832259301371587227336692476616699992368201716044110268582313557635`50. w^2)-84.41462503979036629950195279236529609410138850686521951265448355421936399338606`50.0649455410094 THRSub[2,1]+7.895149939505497772261953416697869205790099544879215065860804509431195392674`50.0649455410094 THRSub[2,2])/(1+6.19951343213985637982018214013048555644660254487941077523987036829928281943713`50. z),((-12.6116700777980469070272844981334539982318482005465581538570205878413584874899`50.- 18.5609744445581504719010863627864752455225747591601016387951`47.49040427978218 w+3.9681771301382027166269188831115581238114603277429777454243`47.49040427978218 w^2)/(1+1.19409901114354076479331346340701639081814190619727667080948585379391693280604`49.52287874528033 w-0.01103085502884209199472948951246233446037295218671921770779028738725172845539`47.49040427978218 w^2-0.12241906820810355164119391799998497822548064718657064587935270257183915745105`47.49040427978218 w^3)-14.55513021304054504408875620382569880450442950747296878312450429818018555860125`50.711216712251876 THRSub[2,1]+1.36131547545007113032486674605303918150138209064978609751387589312138623389471`50.711216712251876 THRSub[2,2])/(1+0.2413708575490971178219391045628739333158516714281873381278339235936982679069`50. z),((-44.09084077093730510445048371073583575315225811466311771263921207192094568467374`50.- 265.4479764820943493559010818564755423132024237357795204256581`49.251583758744104 w-271.4954916747567550906154858445254040671516198313929357020645`49.251583758744104 w^2)/(1+2.86905658839686557485722013140155097181510297205658824647972647385588575871376`49.52287874528033 w+2.53415721696887628689622892133764666814091779350585308792598923583572945017349`49.251583758744104 w^2+0.60419855872412355722507020196842651071080994215256260573944179222062374703141`49.251583758744104 w^3)-91.27965427056396166767093002995317065157118183411292394050647688031075196003786`50.0597086440289 THRSub[2,1]+8.53722392953385205473217994686334271527073280839840588100328315600653317332346`50.0597086440289 THRSub[2,2])/(1+6.78501470204053929751921274067413660179688656600316966251535529518109024517895`50. z),((-24.39039974268668683375677409024708272415462063520130463261716541794096438085763`50.- 94.6671496979195044910294502870307473654496633150866257804954`47.89010589744513 w-11.1561237958585071529562030178214798524333539063433027970167`47.89010589744513 w^2)/(1+1.65986023409305120192230749199284270832968785415753755665944824087909053462133`49.52287874528033 w+0.6404288677938571191346882639395917586074805368488134557640878368549988275339`47.89010589744513 w^2+0.01148915660103991536537136667216507822821228303384919989716064784042366797188`47.89010589744513 w^3)-43.26355574147335983564019430055933084210099062896589601607968269817677623843001`50.1372810399846 THRSub[2,1]+4.04636352212759152809747855316246887783997563652004152912630131132298297656052`50.1372810399846 THRSub[2,2])/(1+2.68984107358231740040572428810227575573725417387218486704587578260822906727074`50. z),((-13.67267485020553159007270079769379236113627864820535474326896465146040800507411`50.- 25.3945592463966489678743858432945712642330081450020970797443`48.27889437850736 w+4.5747037055389161765690234796770665987058105869999146713934`48.27889437850736 w^2)/(1+1.26733896422359189399179208723014902436454158894208398560151254322599479916242`49.52287874528033 w+0.07269867363544034730560493992535487456196850263761923282239763525815987485828`48.27889437850736 w^2-0.12282796987828051199749214197244896452751348354809181610860117936200437221611`48.27889437850736 w^3)-17.14112864925306837715980996704094988915747233173676721999211711484615103176405`50.50035411880707 THRSub[2,1]+1.60317931584029693099600604984713881579837898337443599032058824298757249631802`50.50035411880707 THRSub[2,2])/(1+0.46192423284666937773407958221522436277204563655316793711241181534193605567208`50. z),((-16.17990881379843198366737079105942087280020264889692695460363245589521941111658`50.- 41.1111778029640646673219291990579136079875601667671371105674`48.58646599569835 w+4.7697874498034578254508495579187185361148183288747925535282`48.58646599569835 w^2)/(1+1.37556362959698229852335965253393561637240134339318795142328446686757805057571`49.52287874528033 w+0.21478649060965768924045724791475116081107626727274148105910245194784770855225`48.58646599569835 w^2-0.10339215298601442223607228256969684043793886420439572706784717185938311195467`48.58646599569835 w^3)-23.25203717453542728979917641539339532687841371713597625637774577421645948352341`50.30474504205874 THRSub[2,1]+2.17472173578192155265068494708604702406585314114277213622462887860494241867961`50.30474504205874 THRSub[2,2])/(1+0.98310842325929271500440040181461548962256582636514202024142580946390854419874`50. z),((-45.52763005744068087989735219232484255808283257854101403327843865728628092137794`50.- 283.3096866200813033831617230578237233235430660393613798177064`49.27604535423054 w-318.303530247211066356034552634339803502226447462954151886341`49.27604535423054 w^2)/(1+3.03505060109423017479663616998263897039291479571824844835315904132655731560276`49.52287874528033 w+2.795033042824801103177555970416406459168606979059022008493532603940144218261`49.27604535423054 w^2+0.68667550894341487224843317330067543826054471500866108357645107759148962321651`49.27604535423054 w^3)-94.78155637759582847813840638405972392218055285518942586252962766965720548307177`50.057350154753934 THRSub[2,1]+8.86475061339289202215358465968962022491513886365990971731160494149193778367527`50.057350154753934 THRSub[2,2])/(1+7.08368322358796855199575442132645492566594143355206906209703730707487177711007`50. z),((-51.69178376567956956622061692333598658206397388719812519995441368264359793094063`50.- 382.812746642846059528336840519738249130035558671807235694717`49.36494592343658 w-636.3645908811127320451968159705524664332183067286747417454447`49.36494592343658 w^2)/(1+4.08495900145500351964944245330930754792994725887173155852336392012693117635998`49.52287874528033 w+4.44564234036978139783597082349234407302246226757419574347540884522918576606748`49.36494592343658 w^2+1.2089738888538588487628933063064964896808851411646608045975184978535419963137`49.36494592343658 w^3)-109.8055150483089135572923446489551884388083072132577848844833492281566051476766`50.04904161857241 THRSub[2,1]+10.26991478173814635951979877801835863681322699429565508957539752844065718036358`50.04904161857241 THRSub[2,2])/(1+8.36503929432484963274533420595656035658688777805599579381892591952638735565094`50. z),((-54.33937967682623497449409880439862027763586126979113006264214052125967194159251`50.- 446.1417770963009802718584548679654331570080426900712045087696`49.39726572978223 w-878.4360687675032919041890827575370436030365699220891010289938`49.39726572978223 w^2)/(1+4.84171639280503060146545985150107628734199913593666082290713677835546854135284`49.52287874528033 w+5.63561761038719810815365414247479552976395031540361281642669351716239630026678`49.39726572978223 w^2+1.58568552463893507549547108711909103190205052377181790958266109023559098092505`49.39726572978223 w^3)-116.25852927030191621000456647573215622683023842303229647759387194690246995529397`50.046169401735646 THRSub[2,1]+10.87345373983197353042776359688329511484849547626022002665089158036826611360168`50.046169401735646 THRSub[2,2])/(1+8.91540082879981840222472694517048537836873425299022563271467820107350194788597`50. z),((-14.80944539306333815560559104568050576970741404300643945651886541504930527225618`50.- 32.5343531390747648972103889692692765140553649037897770274292`48.54053959120379 w+4.9005674831898255840141032376965268565114223717534889349884`48.54053959120379 w^2)/(1+1.32188955615605181880618069107974006746765766881569548224279559419196430882204`49.52287874528033 w+0.1417926053878096927947817735474197641677207141619887257269653806673998773139`48.54053959120379 w^2-0.11600880806530502528070488087925645962692145281810523786210537745573495715358`48.54053959120379 w^3)-19.911791819308769323515178713894666149226134742253651114912815094519573473915`50.385999027990565 THRSub[2,1]+1.86231452077835468210002866797138626809200137259411466008134889312770592687125`50.385999027990565 THRSub[2,2])/(1+0.69822720403618342569477677297988493497307319264617758148784720637297091203897`50. z),((-12.02422791747679105416256617433374463646495405121379747671488092593722130048504`50.- 14.52753140324775255135130530442441129663034222427854557429724014013894397996791`50. w+3.54153831488924729587122763497165476932059038270610041624522406528111950800631`50. w^2)/(1+1.127204613068179176238009196847503907057078959180987186423971135635561846893`50. w-0.0779774714531802059713047725276155001209065886741606284669438475177347844316`50. w^2-0.11517661158553926110831052893852014097250614754794235299290121440926550215836`50. w^3)-13.12335106608243316570723410639072592508584263073760637435998911769555241687385`50.97244276706051 THRSub[2,1]+1.22740371501563015280681302106376974228172818602751145614721082333593911951491`50.97244276706051 THRSub[2,2])/(1+0.11925797491147649784141923387959553232767355957097060509220285624767136106372`50. z),((-12.17976423295693208248308593935740050093034143110372610923849309489893082037868`50.- 15.6316242653252550621636081414867248531798163542686993044312`49.05190644311665 w+3.65900555057846463008402850996262885068463280899854889962670618213607843099741`49.05190644311665 w^2)/(1+1.14851335282466934914045516010540421180604693591505538234993462151992873812976`49.52287874528033 w-0.0577763698755297063985080837799045161318694892658157001254467004633680939189`49.52287874528033 w^2-0.11796795596774646747106112935884193546352831478259257508738930355917634821745`49.05190644311665 w^3)-13.50244141427497538935042027903423601359656348844038049089000504371256756052352`50.88062820791499 THRSub[2,1]+1.26285936192739069958107170732375227060357385470921735076886076618663850782889`50.88062820791499 THRSub[2,2])/(1+0.15158964791861588575008378161556127366877714884753465084882701709724182056488`50. z),((-30.31042917601928325417393126224133856674276126845310051532748242689874875233873`50.- 137.3419648351224015517864849589800854298308059515177439237653`47.747572611666506 w-44.66240355702102284598317097548076676742125172330315692825`47.747572611666506 w^2)/(1+1.90320549951950919764662293025176456179450583087904337218325625024701911917079`49.52287874528033 w+1.01885073469456236005301697721807530303551564262310373218523798984535755575454`49.52287874528033 w^2+0.12744287776979095671490598969738400975423917945891587167255899792464445443877`47.747572611666506 w^3)-57.69250766992955729261452548619937375887612182865667838883060808866044250125944`50.09866889237901 THRSub[2,1]+5.39587776674315449071045396227082331004716107039907354018169076721855995108347`50.098668892379 THRSub[2,2])/(1+3.92045049904211512841528735878849190101346448289488407909369740409045186834423`50. z),((-11.96373071401764774488799033827260127842495755765516976086962817331741931965225`50.- 14.0866288439317971147331581074981346624726001401827551367735`48.37468693837023 w+3.4948998744680536769378798391208063238821323284019699658504`48.37468693837023 w^2)/(1+1.11780916631173946801292851815288081927862545823411269528353023589573295925492`49.52287874528033 w-0.08647540202848936647844377871963991301293078699371191522489267685523364752257`48.37468693837023 w^2-0.11384740585817626446439612812194327840197228519931185848974408011761008549807`48.37468693837023 w^3)-12.97590057612319324737951520963166525821093145815549104923587972188521821843444`51.01593063303538 THRSub[2,1]+1.21361293259690817466775115694266460106872019524353858793065731846682520904296`51.01593063303538 THRSub[2,2])/(1+0.10668228932930682427528647179879319693413598484563295374791367187541750289986`50. z),((-12.16518206799836795772344819676155474467704822692506578148511392692067740231976`50.- 15.5296025916352999170350859769280132358176696022790853555069`48.22192801648039 w+3.6481249620935429676391765306001843822322419294171357242988`48.22192801648039 w^2)/(1+1.14666132658301029698686527310250893793247030052037031617361941545807430772696`49.52287874528033 w-0.05957858307732846772149103262759167454220096715745148031373702374771470638605`48.22192801648039 w^2-0.11773981871832746121520611280567919681597221178423948027252997660901193195458`48.22192801648039 w^3)-13.46690014550775314438216245439065397540800011425306377535843269869735970204859`50.88825581433868 THRSub[2,1]+1.25953525018934512132886161494654939750097983081466136318207241235445297432053`50.88825581433868 THRSub[2,2])/(1+0.14855842149589238614956705321401218415999400386693629500010293206189901026659`50. z),((-12.23236485115413048558934252258704599585381042619358792240740987244190434166789`50.- 15.9974812845426419889181441487110123133471971904923128420626`48.159103168910725 w+3.6980332218409291244449337713728111166695231760149860072264`48.159103168910725 w^2)/(1+1.15498114702106127133634184171895288920500144213588339172995397818708570570666`49.52287874528033 w-0.05141846465507394140657842293191104567844437716446314266201986485221590989557`48.159103168910725 w^2-0.11873999129959543346403283902299607019389457047596198038802832846002088458015`48.159103168910725 w^3)-13.63064547135298246088862012996642264852407505118650117674626474316499594645035`50.85448476266832 THRSub[2,1]+1.27485005966497672403097131687375044514550651197177574816211679139535818530631`50.85448476266832 THRSub[2,2])/(1+0.16252385310584334436922412472368465681969887551983618460905979415881954569197`50. z),((-12.80029158101456971065180221363634128026299469567438524755962794595479147498012`50.- 19.801914713786614305658905829658549110744227955924963648288`47.244652453557244 w+4.093757069502494458701499597716470730595220367434571769558`47.244652453557244 w^2)/(1+1.21004501931258634673072400332669811029821783136569615221107139665493033884595`49.52287874528033 w+0.00631414552146285459445762657224227056205123029394716047672920166672261995221`47.244652453557244 w^2-0.1233218783809826515493972427458210877950756450395893016535623001506398503614`47.244652453557244 w^3)-15.01485944804407129446047673686014727504494165981493736780554373355801221993757`50.6593499788991 THRSub[2,1]+1.40431313421140669809420329187556699054638530648216019639696403413484389134313`50.65934997889911 THRSub[2,2])/(1+0.28058002066502781005377793956180974512587991959524579912084881388230754183528`50. z),((-44.50342886624167565949260137698945353607482762490794015369482488718987597194617`50.- 270.4363276259148388143979935603151692437663874062448528937122`49.25878902352934 w-284.2144195024499804779191010112276345364310628913481679411536`49.25878902352934 w^2)/(1+2.91465628866377088492635092193658796954347453806006083113137538286199650962421`49.52287874528033 w+2.60581707157714592361420022163132034528604007734203346655547867109278276193357`49.25878902352934 w^2+0.62685038422528901946736632752167959449091168511969643747904603415747053860694`49.25878902352934 w^3)-92.28525970892219459669751046116831324910120082286573678160566413591605371376165`50.05901172826462 THRSub[2,1]+8.63127641998888895422714613730861124514461265486843771000487061267575437689773`50.05901172826462 THRSub[2,2])/(1+6.87078028895726542426726775381200451815407698915413229202996049549816443772377`50. z),((-11.97521095771820487459975865057400190194903174209776448610362578341664762954078`50.- 14.17089799021256033784302548361212143831008059869534840095430843970823114306549`50. w+3.50379966514165380256829421513650915425481948022412464425485742195415020456368`50. w^2)/(1+1.11964960454900617835979289126537102954052737632656313070799883931092164198573`50. w-0.08483258496172101227448804181347060689034470417957459228144158141347445017332`50. w^2-0.11411167248608137791643608959835199952650088412490378344253944080088679857514`50. w^3)-13.00388149857429190474039656741518578116184370170714504089899943415652030594675`51.007258266791595 THRSub[2,1]+1.21622993857298125397971488043849364216624327163747845724246650006476730287034`51.007258266791595 THRSub[2,2])/(1+0.10906871261715998716709025321399447907348771693991412520528013316490353396336`50. z),((-28.14621037368044690095923246136685758834585873286003214301911499696857050409154`50.- 121.220619461724775909567417578212652076509824058113019153832`48.671235949179994 w-29.6872365368480577628238174508936987514298011374116535794397`48.671235949179994 w^2)/(1+1.80762361734709289019774941525710312944285280341664496450250458912819919013413`49.52287874528033 w+0.86973900617348932402943693946479859155402574282106617079962284928637351867018`48.671235949179994 w^2+0.08130495526236759019003415632297686776444264062778342721989478961850918288072`48.671235949179994 w^3)-52.41763371646863864199538970923334841936476821626832619384283877107553099124478`50.10996210175393 THRSub[2,1]+4.9025281753076000853117876977997377773007253392885305361965870452472772015742`50.10996210175393 THRSub[2,2])/(1+3.47056961805868806892343515733542270764901682016534934487622020996891866842046`50. z),((-12.24457977789783161576943401349637732313663199880773376412771515325050073963653`50.- 16.08198615147162447279788925617483797519445557814171526549298795570954251131131`50. w+3.70704647078072289366785524287212037798243197947384078070548951255797889902363`50. w^2)/(1+1.15643802837746352360174872436188146990668166111285044916799485495969588232689`50. w-0.04997291626035823763895015541725705286792860380962512639444279552114788142309`50. w^2-0.11890836689253153362633680699843518069408210360237829854463718319819366234518`50. w^3)-13.66041704475126892240509576469867208096140143120617116594717300880465219466503`50.848699683854505 THRSub[2,1]+1.27763454204351799303002485701412263652841882655219858290212789924420955757353`50.8486996838545 THRSub[2,2])/(1+0.16506299655966864492388466336473479108464809141006291638844460639964356848998`50. z),((-19.14291469682421167278420514949552882197703409506263270165111641720924753787424`50.- 60.6064000399762952219829388005771572232686282327466503703059`45.58245272099107 w)/(1+1.51505658223478615121804938444952947481680817498815269747032220213683120505097`49.52287874528033 w+0.4195310875264972168460190307516085626557504542169813561607`45.58245272099107 w^2-0.0523273143290277039844344489289912105957147125472069584309`45.58245272099107 w^3-0.00207720662045050305687052783918750583042083130015779587323939633876470349942`45.58245272099107 w^4)-30.47380354096456332299135811083806590575173449360978679954504056844344485788415`50.21095416695822 THRSub[2,1]+2.8501607164580765122473159633744222076575602601021938364473755194676967608127`50.21095416695822 THRSub[2,2])/(1+1.59903491626183188492785359422026007648145246549583556014018111349766626392868`50. z),((-28.80118319265762109983424528291835280284568003295382130512052745682649280079827`50.- 117.7513190727523460119058860410678781650735223748772279073666`45.74990412517464 w)/(1+1.54820931946852636650583483695900872482765408895017972626120279975276782133758`49.52287874528033 w+0.4680787003865650806777941909885999836315486325999776761915`45.74990412517464 w^2-0.0389567524833903511653119418147900396971030636618779109053`45.74990412517464 w^3+0.0077320656023137608990941436494432608034804644523628125229`45.74990412517464 w^4)-54.0140060700005069435725578286872913483614830166443414398335563653184355033724`50.1062793817692 THRSub[2,1]+5.05183404599617382284600670976368591470249224094545980940231510042595698132706`50.1062793817692 THRSub[2,2])/(1+3.60672024594493311212500081204449766995545736236185318519321559514035659966181`50. z),((-12.96971600620912229667402912816317144021744703946737896654699347412688465676263`50.- 23.28809216309617006888824187795393188493862266641958434832972017449943285724138`50. w)/(1+1.40682441010068133381201218275435704084745026868711180494299535389925495841863`50. w+0.27316927683983786026563732302659605156572713985708873430567574391648149426736`50. w^2-0.07111693704124051720159388149701841964413539312681686421077912828868425192642`50. w^3-0.01910590673128984691263177925242240959837318556705125832207654018304494073334`50. w^4)-15.42779943663165505167362393932463388081191659073384296165653363318282740686728`50.61977917225047 THRSub[2,1]+1.44293467786429738465742554018068717863655487988394814787904270614312792137742`50.61977917225047 THRSub[2,2])/(1+0.31579864531807372816167168438146454643638236304557990427974453742403779707511`50. z),((-13.4767988221900858755896464433232591416336167045661067315887772701026920033808`50.- 26.4610197574501921890812138448417908467942609123140984075459`39.04680506841598 w)/(1+1.4274296757174164141651229151095353635957680401958367786987`40.31864526296957 w+0.3000503120834860726431770412866972242631904750743858440715`39.04680506841598 w^2-0.0700763688002972963217958860060144253753775806523176545597`39.04680506841598 w^3-0.0169662494190538524513999436320046558946196146187703638861`40.31864526296957 w^4)-16.66371788229666353567155414939141628155385663427339968392655952727493746816078`50.52816171730524 THRSub[2,1]+1.55852793480201786298150168054228882330257861822822046813290295436464842207951`50.52816171730524 THRSub[2,2])/(1+0.4212070558440981293435991280643516577751994199868375961733046286246154522197`50. z),((-13.77489396033307104948778337288109960736005308876602806268454112704284170286985`50.- 28.30689927373928187846127711820794968570500477960626565504691552747906688176186`50. w)/(1+1.43742876556441012236534313095918653227362704777580030771839619502798745673702`50. w+0.31318791023379607468347670919327034810078668646886013893643714178490938856106`50. w^2-0.06917479375873695926217235720922719649984328713425156984532576866432977170272`50. w^3-0.01579981555449038046835511264906676504113999220060300783077624512372027836973`50. w^4)-17.39026839472381930262915005757420871419651818965659050787513364383485199878011`50.487089309504086 THRSub[2,1]+1.6264809137026890836296587279453610667175526152841366942076179844586048445737`50.487089309504086 THRSub[2,2])/(1+0.4831727421322474427449978440346132396320239374985925293222433584118892932459`50. z),((-12.11184763003254440173867694573162530289441613701859611498449055928229368076077`50.- 17.7948791556203019118319970747251853619880587300265120495107`37.54664219995019 w)/(1+1.3576876474035190010115121254656932189907433954311678944776`38.2618495269703 w+0.2072565660011774421456383627463720943882280155080628742286`37.54664219995019 w^2-0.069156142689003862189533396435288068739377897347484630892`37.54664219995019 w^3-0.0234089004693449879176139115539702945737603084997131120149`38.2618495269703 w^4)-13.33690754155090350004244796376531424238298337238341468166005579445313122026005`50.91772736484956 THRSub[2,1]+1.24737727283906591049752843680995455117751885993868968802952630498919051356409`50.91772736484955 THRSub[2,2])/(1+0.13747167559344917826594163477350629395914703238554897234562336234654867440694`50. z),((-31.7500489491860892019513417217530339348969255031897293209682977314462049261057`50.- 135.1485786089570901015569399336127505859720072973513837073113`45.769897689480324 w)/(1+1.55272970027155939934089398397973825520923554605834409538083635754653180541638`49.52287874528033 w+0.4748684763687893031909900333750221159002042740201268113232`45.769897689480324 w^2-0.036800376844913887794203746840827141081989569216682529104`45.769897689480324 w^3+0.0093335652013823469828028415435949114916914779885030714629`45.769897689480324 w^4)-61.20130855279703333540046192268237735104618413939281954954524385365139444240171`50.092363821071594 THRSub[2,1]+5.72404968085223108712104965130858495214189853653982711357784661711114873224227`50.092363821071594 THRSub[2,2])/(1+4.21970740002344435812237170325759676703635400740902083694255049455669917717613`50. z),((-12.69530006358964801184495031013374369590169983802543164565601161765148100850478`50.- 21.5492476566470616156006689312852619425772483727105167134531`47.72121658191223 w)/(1+1.39327276497094646863269279353846980279399781390282987391874695428239291574568`49.52287874528033 w+0.2555033411635770585062611168967004415273261983451323992908907017513542451689`47.72121658191223 w^2-0.07121548727450944950538918944506758663388657012192813738302458225843271360632`47.72121658191223 w^3-0.02036291554786167640702579446653609759017931217848121812414622161954966297524`47.72121658191223 w^4)-14.75896248420633153869375307251721425078461782790948981352842541747741284039091`50.687052184729644 THRSub[2,1]+1.38037954571757822547163204691985970664521320024242709902106540093886562762442`50.687052184729644 THRSub[2,2])/(1+0.25875520502999777758493374922919403748050461120381563986871757675014910991534`50. z),((-12.54161616664180220934901261956833993498247409049769408094639150319855129179837`50.- 20.5675834751532505055592949562657943597363673411753916125746`37.798351032213205 w)/(1+1.3847989821766956929309917429484552978309540861744330469203`38.750016469120304 w+0.2443829507366990945205346322602452382592545395326958626858`37.798351032213205 w^2-0.0710411736708705571857452328253927211861370852689657523422`37.798351032213205 w^3-0.0211059938179039115529727912640281818122175902231865205786`38.750016469120304 w^4)-14.38438705578823759715508460232608425716119355555535045537782319192130626934891`50.73311729653601 THRSub[2,1]+1.34534617123274968432505053864200505973786931861966603727255407957941814624611`50.73311729653601 THRSub[2,2])/(1+0.22680859830190485028001871072521320242411372178778271510373067418544788663242`50. z),((-12.08887038366694135264843493197875362815960658039690489636438168158314936969772`50.- 17.6461238726920045235733252272069880884905278940821972465159`48.162232510306545 w)/(1+1.35614129345142453452262651150532365684088056789629149849767618019440302951447`49.52287874528033 w+0.20497374773056569552583252413737650598387928465440487597294633409886391670554`48.162232510306545 w^2-0.06897591021326660599804941072744964786894739385454014846896430621666446693125`48.162232510306545 w^3-0.02354584434482275393505151846556182233808981316957240222406669648176030408478`48.162232510306545 w^4)-13.28090484984284101166161363123906672143490397549548493655351701936562652628603`50.93125742692924 THRSub[2,1]+1.24213944055772083158783530852576339942622918534522694545840133739490432781982`50.93125742692924 THRSub[2,2])/(1+0.13269534529525581059555143200010434519899200583434369233720152988922310486538`50. z),((-29.82564441731147742687351590995182043994424408531214493719744026974341149586809`50.- 123.7965660704404576399315331363608202782424996030384519591798`45.75912548405903 w)/(1+1.54992431629157050822323788802590948848321324924465191221929137250477490882982`49.52287874528033 w+0.4706496947188388525362901439652441065119676243353078128807`45.75912548405903 w^2-0.0381485365639591379460664680600920119650999942051945183405`45.75912548405903 w^3+0.0083313464390837053792591129923680751153803881991481671975`45.75912548405903 w^4)-56.51093652103317968232650989890026592262728622594084450807084482754215731070782`50.100991288999445 THRSub[2,1]+5.28536751593846947515356129617664548341142627318176549042234347389792821430326`50.100991288999445 THRSub[2,2])/(1+3.81967723429683446493563739968788068123309990714118924377129805295623510142281`50. z),((-31.42103616564094603140261274892464886894655258661830766628888057845849765009064`50.- 133.2080439082272168709039302936461295831810162704476205087869`45.76851626709869 w)/(1+1.55228407028169995730092249048491818766228232123685939352722581191503843241064`49.52287874528033 w+0.4741972349106135115470005374658841570965548563918947266968`45.76851626709869 w^2-0.0370167054793246090520152095446257839641477509444177162414`45.76851626709869 w^3+0.0091725235845661331374111532259121768977202709048373969534`45.76851626709869 w^4)-60.39940212799265452675020440410162454200130271425772260337152341298481328112806`50.093732423002535 THRSub[2,1]+5.64904879731695448403604875906193567799304857909030893086640814874695189424792`50.093732423002535 THRSub[2,2])/(1+4.15131479537730622573388431846953680174130566900510917637744072621204742738205`50. z),((-37.52549244646993025971475708884540826430057773625316999831934004023192990914897`50.- 169.1975923558525505111448147705142468744073625876718345921675`45.7780162953848 w)/(1+1.55888381296951491598478733690729978909019399906268069448087630342301396302446`49.52287874528033 w+0.4841809786012270037078506930222041828537411097587674437982`45.7780162953848 w^2-0.0337277233569152667058871464340320516755658220526370263574`45.7780162953848 w^3+0.0116306872589876195409430665989390905743176482526640347748`45.7780162953848 w^4)-75.27785961158324280863454210742429980775584850344527480723865344267894863442737`50.07353247874164 THRSub[2,1]+7.04060449807538162421471486158369790626214155720058385335594358187471064762791`50.07353247874164 THRSub[2,2])/(1+5.42026143172308583028051471180127843516142298617300469308147395286225529078632`50. z),((-28.62911438517533346305727526222625668116743005118750745887109745919332696152836`50.- 116.7358013909001271778035244438791036431201735737841928898311`38.764976980123286 w)/(1+1.5479037723839196889473742683047408242146421575538036540383`41.219673859481325 w+0.4676212847001689866580894723408269615372588946697369300396`38.764976980123286 w^2-0.0390994849234123280287134967777712375932615900427941050168`38.764976980123286 w^3+0.0076263473940821194542044810802377421739356551021033311096`41.219673859481325 w^4)-53.59462089979011647632407605438443997490449867950867869697660123270204351682346`50.107222650132115 THRSub[2,1]+5.01260969595427864262223398176040255268215103272756845418143227416518926553809`50.107222650132115 THRSub[2,2])/(1+3.57095192778031730479435278322727347519567736580612997528916770671466050051105`50. z),((-14.61215876019827485580322973447577806486299809516290273058821798425002693979685`50.- 33.4372614757865312198100951814324346077608286027055118309445`46.92733764877602 w)/(1+1.45962262412888264884586880332642966506585455118616913534140980945021497252394`49.52287874528033 w+0.3427128946527038815073318232070859430638258397354556727027`46.92733764877602 w^2-0.0662036711653845272974739283251228342599839193909772826264`46.92733764877602 w^3-0.01282707981320127419248297291180220554968214970904908940025156671137803233381`46.92733764877602 w^4)-19.43094296985727094316175171486305703800283513862722947588797339266980144274995`50.40167067020174 THRSub[2,1]+1.81734158199116234504479740172094614375006724631071637662693650855353635121718`50.40167067020174 THRSub[2,2])/(1+0.65721680152804885466141566132269435983083684775728539899608737391764684598366`50. z),((-13.24798839750990928390403624441297250240781528917553743080835832366214880694633`50.- 25.03504927662645272345417293890076819260464361915920724118059062317358450027406`50. w)/(1+1.41876102008491559524533288299795251714362460521032870906074106015805649936876`50. w+0.28871965421452905878083787691384431931323565181184605362092480550606146488831`50. w^2-0.07064646492194775031482534617892784063948234007224227831105443641179110726515`50. w^3-0.01790559002260727420178273609697360878130596160264824237745219889803881067573`50. w^4)-16.10603575324322974508366262644364857509035123839604200784269285613523727879458`50.565416405876405 THRSub[2,1]+1.50636891584784862366594131135326678761540313090195129449964049313598681246982`50.565416405876405 THRSub[2,2])/(1+0.37364373400156210639515370677420810684582712705968357739464465894819853932468`50. z),((-48.72303034309286483770503560166890884318767355188676440986420529911654994854483`50.- 235.1672919789850132529072336056545937187774405217991344265062`50. w)/(1+1.56573205569571504433483625181992669162433961684034940609100629045686527323397`50. w+0.49463876583688478130716153549085862670771339919200692679516644208474253151075`50. w^2-0.03011795168087944324856694958241650278282428530178872101184618976939736260133`50. w^3+0.01435421736481365367431797397866248158911853122621630587003892454559230202392`50. w^4)-102.56974014138763966293277144520468994051692620282610532384665240956079129524066`50.0527196874296 THRSub[2,1]+9.59316560715226391543815932402675548585318434448141221569640294624494574219254`50.0527196874296 THRSub[2,2])/(1+7.74791804774269932407596094555526898797897692076771454594263750143339837590999`50. z),((-12.22957582561144677544810420626665316069405154700300850437257188285029709271335`50.- 18.55726909562402641368285815075203464902546943989727607877519113106930459592964`50. w)/(1+1.3655370682282058434047205178436616331046056282979734517785611532017273423046`50. w+0.21843738999593726124433229884975232438976774611307057314431383164287009824242`50. w^2-0.0699324597080194617219980051730168290166664802587204730122330737860645024241`50. w^3-0.0227346618319162838022975086120593501079355880642351264129889159113614860091`50. w^4)-13.62384774915652952071502150050268704209804963997189525606932783691005742846745`50.8558201226 THRSub[2,1]+1.2742142807823150675297652156835095531213240460076535905494314439126040323007`50.8558201226 THRSub[2,2])/(1+0.16194409228550860622466782326919351853330662048307670102967122378201749931178`50. z),((-12.1894389256985409519310676944009734453207996687058064977030815818932563044046`50.- 18.2974131082957734182544558819418206469634727589416271653287`38.26857154608053 w)/(1+1.362883301902468824878238084554179960854262051210344037595`39.03477392052259 w+0.2147200025699558595494400814790252426538463327277330334066`38.26857154608053 w^2-0.0696940680665906597233150825863486663886330934095433033304`38.26857154608053 w^3-0.0229598264740569368440276618401638482705872404532555806924`39.03477392052259 w^4)-13.52602164779632716936061340867046780495883581917324718972629784708388876925706`50.87566219984997 THRSub[2,1]+1.26506477928453552670285783712551237183268679511516232097095663337484562772417`50.87566219984997 THRSub[2,2])/(1+0.153600747392077318059501011168196065978022187082121774027953703386784428367`50. z),((-42.44443508149227479921023380701017425018591757571783375925175495980736296969185`50.- 198.182272019110665304586677249589768067534979313896725073916`45.77460998105995 w)/(1+1.56245474958588574293534916287254672237761035057905484635692579885279013900238`49.52287874528033 w+0.4896214743366710372771127070509060048529044258214565776906`45.77460998105995 w^2-0.0318708637608137767002491361080608038902396378442884029779`45.77460998105995 w^3+0.0130281770726030732913605730407419116280359208578587796349`45.77460998105995 w^4)-87.26685183178181623530252890003938007096328338648695908702811832447014428722314`50.062661945638055 THRSub[2,1]+8.16191364512680012806121070665208742056957077857349317635125768579513669378549`50.062661945638055 THRSub[2,2])/(1+6.44277276179715495957067717455179230306656033820050509005479003669100206422671`50. z)} /. {w->w[z+10^(-10)*I],pi1->pi1full[z]} /. {z->zin};
(* and 20 each of [4/1] and [3/2] for the Ls part *)
Ftri3LoopLsNl1Pade41[z_] = {(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 16.2769403053206781395915293461852840318078634692765888980527`48.45820119232678 w-39.3222244703147397890270644602406682525232694686954761216079`48.45820119232678 w^2+13.6122856825609032891830761491635167092204186483252961087494`48.45820119232678 w^3+4.8422581591301944865884702998461248237493943206360162547569`48.45820119232678 w^4)/((1+1.08915406879467212034265100470895026119811377591498999617447918098532977138253`49.52287874528033 w) (1+9.23557373787754675676790583938531803592572809082271944424536604309585269652786`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 7.2979896429652606782968084229864749540834123593649632596897`48.54310552577357 w-18.4321498136425418115137440176285713655511278946421224505911`48.54310552577357 w^2+5.8553859893692856255177217227385275222609562533631097030927`48.54310552577357 w^3+2.72396768526087298051187166597641093499327132099806772490232585040217143913938`48.54310552577357 w^4)/((1+1.09760697255573927971822358001648035939614725747133785074102828647459338430147`49.52287874528033 w) (1+4.18280076436235764494573217625910540515621597110830176876918729111381019399054`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 0.35854775453664724566906920332565972431363071663510988322582428266253825110336`49.057046005990934 w-2.08688538853190953582226441991888912835084596855266178803119636706687086315852`49.057046005990934 w^2-0.62836385195610199930174346588673291030018913574741914122084087713719865308169`49.057046005990934 w^3+1.33804449521561502679188449735697639650600885094428755067611969211110315121262`49.057046005990934 w^4)/((1+1.53990992604540082394214415241247726681279350434952769465696105326348895968552`49.52287874528033 w) (1+0.16878896374884720303664872210089761155655223535319930379267277658768610517372`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 0.55114521376434428094292075196221522433421795009947580924319825301279558209025`48.41259443932078 w-2.6507472627079014391951717314436972114577006528819896528962`48.41259443932078 w^2-0.17935779161151616863920576635626794840383547240764109549761756224638578135541`48.41259443932078 w^3+1.23818764799419669735016146972369182224303800674905896869117198780235465614153`48.41259443932078 w^4)/((1+1.28779901707043914818342431399391332518360526537210301881359593826549412274441`49.52287874528033 w) (1+0.34015276180816720431787017781360106572542961392126061827099831702032907300845`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 0.38863708212841842857114940391426747258467003917540080087297621586706329338812`48.91747713748042 w-2.20779452832601940040298536021403849765342643753893118019345987420551408210466`48.91747713748042 w^2-0.47809846958481645660555283632319784161978921038002406767259616938232831633331`48.91747713748042 w^3+1.28124466068039202934866177279819993918842323893230722086913413273844134891928`48.91747713748042 w^4)/((1+1.42911814113922532589226108570818886707722710079808307229304540834525758943693`49.52287874528033 w) (1+0.21341215674576236793153960160806156989290345516997533460889339999547646353048`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 0.35776484045583231571034489202573898528053684584434057117336856598377074122471`49.06524352641515 w-2.08096757369657127028077206646648568675452137620579253420844769878977886331237`49.06524352641515 w^2-0.63904064292149439570219504648449915847631737642864398825830296395760790283486`49.06524352641515 w^3+1.34300256809865802226599531763608001834567703299461789244162661535373876737973`49.06524352641515 w^4)/((1+1.54882332491395489896635441665888038461925383404698478170649364006433223007778`49.52287874528033 w) (1+0.16612022486125028617881373093309141639882185060902924081958168586386182095818`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 0.35632871220022646205209863231732687748353131395416785326281558910385584674005`49.09393789414903 w-2.06191270626206238802004563636591096652093251052887029705266983195587915819053`49.09393789414903 w^2-0.67864366378290871534274069582449866675191103211028231381943937057209483933121`49.09393789414903 w^3+1.3623927231830341738104702479480753931046288632857563154141465449054756718006`49.09393789414903 w^4)/((1+1.58301326712465956580638974970716318264454011126916893334149293794663432795852`49.52287874528033 w) (1+0.15676491716479582678604137658503890625668466961525872800390367849318921181166`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 6.7551246823041913717929390957759417951883234191383331322332`48.55389093088407 w-17.1688142634025902878171922076661359665226865930275913242577`48.55389093088407 w^2+5.3856072530326625384954349595393862016764585106964389233908`48.55389093088407 w^3+2.59630660247694715565857413652731433102175500508964436821217338678752088493588`48.55389093088407 w^4)/((1+1.09883037358632469421188612396001716679457449940710966366787263872756224994413`49.52287874528033 w) (1+3.87713337373285980641389004371729630142812163174686606497697909746344730500984`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 0.42567939368405430029563426947932887243361542866723056468730765579624863683389`49.26351910181857 w-2.05109388388410430431339749158746392402010356498618036454636762505831924437266`49.26351910181857 w^2-1.03908010406357904334042981003059077699812163568484890069522318168383920718498`49.26351910181857 w^3+1.59501335035795687661594660296727727827640915631148527800945670715184423897619`49.26351910181857 w^4)/((1+1.95747288738087238445870080521875941263561023580935849454846366575198598140134`49.52287874528033 w) (1+0.10215977043539578113495240861076597091833945300631091462442357694226966639351`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 14.31663570129798497350037879302986461108187739218831030016`48.468743392243496 w-34.7618698864918240536039892260401233103898995637848365938078`48.468743392243496 w^2+11.9197906743619251713488867215747258890040747999531315079254`48.468743392243496 w^3+4.3792701770339336867872734772471896881339893035740713158439`48.468743392243496 w^4)/((1+1.09009983310715918814799375082136439843228291624103204370837549948797972276889`49.52287874528033 w) (1+8.13266595703666008389029796670729107745881863737910765972315798610205894870991`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 3.24770026863426173241168179580446766561211558837415704194237972459544858687735`48.68036003166521 w-9.0020234144140577839924653847569712206333827188075490254113`48.68036003166521 w^2+2.33955083296986989175234066907996317572754051137249421453345234656039679697204`48.68036003166521 w^3+1.77706154926271253856203816959154610176607448430032153641160788988944199210705`48.68036003166521 w^4)/((1+1.11640166936221302564242946658354836019402904087889130925794278319677284132953`49.52287874528033 w) (1+1.89981431709955230140429697682745930519164109157407657749948683682668285473272`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 0.36556733389523144604378187005662451927676556588209223314499978578925836670277`49.16896932250816 w-2.02894125467934617772957451160297360407924658681108899228456205487787205330846`49.16896932250816 w^2-0.80363548503310108488650156302119708411249218718414811486309960485777977927562`49.16896932250816 w^3+1.43296822644913100396446455016704713665578244012437474612039851641457722837781`49.16896932250816 w^4)/((1+1.70149878800005491343229360720800461322694246704434284178582412690236556659038`49.52287874528033 w) (1+0.13234026164938729337488723343818347211977834738092316265493924373799292382336`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 2.95386012586594658675940555594282808327293547557508099476310453840199363079326`48.69979527691614 w-8.3169828141891433382215530445472704319439356422995931121475`48.69979527691614 w^2+2.08227683225367869932151079839916952964333443980404026230013488682539109072519`48.69979527691614 w^3+1.70949930418806983800838559767783173502199431389358204857198262806367179778765`48.69979527691614 w^4)/((1+1.11973393306775809651109450641637951589065029665537444911683805568032140965697`49.52287874528033 w) (1+1.73369617086598876425772533194707925120169696418047403373602351362204953880671`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 0.64366740984368420707028688460405970137462779274465647696901571606111239116521`47.91406530185881 w-2.8813214675517058148477661391009191468974198462192958068198`47.91406530185881 w^2-0.06204212273319131485347185203147701205885364229867322410295813417712677370687`47.91406530185881 w^3+1.2408027521601844676688364078173031348867241086702937858061`47.91406530185881 w^4)/((1+1.25437800619514505815201532650607460735200951790006432025783584681811479407509`49.52287874528033 w) (1+0.40055174982161943527236587429659826351855908727718711021598651333345834642509`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 2.98309167149241315685988344536566324397631536551795264300103975703727501227114`48.69774752155412 w-8.3851447245786829225138809125148180465450832122874243697589`48.69774752155412 w^2+2.10790321560602545225185343073626666767301554387156759691837535370200207969348`48.69774752155412 w^3+1.71620378853196918065190179559054434979978168396525664690170229004745631258394`48.69774752155412 w^4)/((1+1.11937346958894277793089016186322668383811106810938538882933873093657765615668`49.52287874528033 w) (1+1.75022903115058003958429523088571223711048295940983591222466987482892211408203`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 0.3753739805652635835707941370768288559854337412577082824516868727685574814462`49.19577902565399 w-2.02569393727164298899160194929517017860711156835716185443831061798943670635939`49.19577902565399 w^2-0.85879609490254700693375126369356642556334367094482243150470749558079936973509`49.19577902565399 w^3+1.46801724784858061327504362443387609089352615120222435760552483514845987691568`49.19577902565399 w^4)/((1+1.75818753075246460957440441614299468361856472757915201613305084622790239448078`49.52287874528033 w) (1+0.1236843147131779466983039314033008939204986308960064232318566349884175101078`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 0.35770757308627252187836174834491380259579903415737586323782634438720474202914`49.06591454341148 w-2.08049178309597713654038292408457075999330343304775266992721147974890034140783`49.06591454341148 w^2-0.63992640392250220870159581416956658045557583218901309928442686817299508782913`49.06591454341148 w^3+1.34341912774166627726639269571180945428162600142670629740157639707175470070752`49.06591454341148 w^4)/((1+1.54956869668959557767414697494538187864653452405380716676625727637716983413228`49.52287874528033 w) (1+0.1659016690219627324713750730410018776318366590334052038658533536643229435728`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 6.0829875862409909594800345886305215816808864848360009227161`48.56930072535891 w-15.6045039404048967321181098878471782399503052953604736752464`48.56930072535891 w^2+4.8036250707585595810589556745867326355041637178378039670274`48.56930072535891 w^3+2.43841786900089445123572398807350208543872957767427144810014723620844664611641`48.56930072535891 w^4)/((1+1.10064415636997995455627359286970018142352522349831966708616551752000474611194`49.52287874528033 w) (1+3.49860281150139575940178439122057667767295067517900928639870944716122705451003`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 0.36131924379653833190255071186091609018601463404221362046801221354878478444739`49.035279534958015 w-2.10346694773094232513541606184267232764743126577295146326547951054614833823724`49.035279534958015 w^2-0.60123052387004610442238109225975866812961570771608832531229073041580161915791`49.035279534958015 w^3+1.32597658814678352623210462271362691036580599951092802924424251844969382595056`49.035279534958015 w^4)/((1+1.51785872596950379070656661276813958103991255970759216397179296067056931516782`49.52287874528033 w) (1+0.17586072647651019735187645556306373880298842505517963511662398388721344372241`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 2.47358302246325675097404252442139887014344330779038676623693377751956953693636`48.73781192325911 w-7.1965247170684401379960681401109395123560774220979732062849`48.73781192325911 w^2+1.65988711032343054949039709863628650333761968047324465213715616608010534089861`48.73781192325911 w^3+1.60003528610594805965407380605051505725590584435165531224265432703633602699916`48.73781192325911 w^4)/((1+1.12685661699042558578883987683347676792548742280545961569555294514497855100233`49.52287874528033 w) (1+1.46175962922130885930902228411200100580764833826407021138567607693513037326531`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.- 0.30516642846172631702690546760804448754590786713924574322963854409923999939206`49.64972507144309 w-1.57100949180820281954160437492265555643658467562677885679319563901819937502462`49.64972507144309 w^2+1.21314685782221540485873960180592249535330429875812961761485185098320405316049`49.64972507144309 w^3)/((1+0.27662226239984074560793713687009488539948940966295244298023687174810172876727`49.52287874528033 w-0.4860037073773035673604405557441837981605299137851293613806321774353456376102`49.64972507144309 w^2) (1+0.11127165172365209360371472358628458773888780565176966369194077300474742891726`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.- 0.2980739156723566055033254366637175458489571818635627214067182378051626409031`49.64539233578415 w-1.58901679258914288933104479249952899730862575379238032820046167536806783737006`49.64539233578415 w^2+1.22270034005336045600701795042389279068351552206025074423227136344737085810108`49.64539233578415 w^3)/((1+0.28162023842204270669773308318587022569405338148156210339314875238977950473119`49.52287874528033 w-0.48743651878660177711720696884906830015573753054563229736692610290808015531649`49.64539233578415 w^2) (1+0.11401169616212206606327950441352465736978157316468708252614686163780668755911`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 10.5600133112237579825186980627694965177493496624793806283635`48.96267901143493 w-28.8452677464205382999437269839534387790225068225222561526567`48.96267901143493 w^2+15.522411332592128559406544775636615078720212600082301082498`48.96267901143493 w^3)/((1+0.85011857378893266787331795739309867184404279444193780842632594147592384867049`49.52287874528033 w-0.22800091990073964105949261677820237489833839795480642470680013360397860906343`48.96267901143493 w^2) (1+6.0795611774494640315317715042929004566063318198675011557917532299286046389891`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 0.91788175991320531700842486732254276089461337849344384193550051695944800327192`49.30095274419428 w-4.62685188583264045300533254700898957029619403331824769461029879589960604725912`49.30095274419428 w^2+2.8005370153983204994114267303156514528548788336627110635996202005786894719331`49.30095274419428 w^3)/((1+0.64215134048984288407810261592151573663356130913417308814087472412109184870945`49.52287874528033 w-0.40853314082634911025367532658036493615037080226285581391938386567561158101042`49.30095274419428 w^2) (1+0.70785398816205060313104666722188470217816303145234739386200584678079938723947`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.- 0.3317286201375150132499642601006917637467420196938248096817756844515613750004`49.66669125665301 w-1.50342436994241691396012435659031783498143483653594102566408948214976619724203`49.66669125665301 w^2+1.17717221222275787910535181386119078283577067674345406074586216988948047055301`49.66669125665301 w^3)/((1+0.2572229327367823363591785757934221268727991848151434467020596280934460419556`49.52287874528033 w-0.47981999102395541141796563416981292599707421096515084572223271550879572406777`49.66669125665301 w^2) (1+0.10118025132178555429043379307833868450759115105177095800496207870476446453`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.- 0.19783052144191125447117331129031665800611647650061165102102929032914414285901`49.59116862041739 w-1.8421343533779384080007339289235301691282115820610143914801328375450996035105`49.59116862041739 w^2+1.3558819655286336863905620268257227916386407773778568203760801519493127405629`49.59116862041739 w^3)/((1+0.34494723690643243455954318195226048029651562244443671568240748090707702558554`49.52287874528033 w-0.49970113309722817108796091883064261780744056496605813976703774441800965255151`49.59116862041739 w^2) (1+0.15456685579565014405341255024446509313076390969063042807789528381147658283588`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.- 0.27753897792721961061222310436257214498780229085383173770522594141340053577035`49.63326993287374 w-1.64106904710389809420293648171619115068765023004550778782478704573295416828331`49.63326993287374 w^2+1.25024801503188830971509672403632637385065990461021872412539911849022273073664`49.63326993287374 w^3)/((1+0.295678130031121183028057411232486742212634291340221259385435112618135846842`49.52287874528033 w-0.49110841297781538840713888086524998181460663496500357107843674803239830963405`49.63326993287374 w^2) (1+0.12204812574149200660694348432126481622453597189299758247141948067549325091942`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.- 0.00386157213048289442251694988057859248177318900924885267155917159228357954829`47.99268506167832 w-2.3276269213198692802828837564432131419417227848885036682538`47.99268506167832 w^2+1.6081192732395189662564231448987252122773232146010085903188`47.99268506167832 w^3)/((1+0.43746173406061220017540650364114660201544164879693035893748578594450078911128`49.52287874528033 w-0.49723765672395962652232198377736367469982633945795160371865208565504233396663`47.99268506167832 w^2) (1+0.24054576549478365517681592311522122455847550231639802615556067259847064723397`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 8.8647223548055840974231394830045519644725089532339136699147`48.97933986664574 w-24.5829258426958807301059691737680508269839837540365514686631`48.97933986664574 w^2+13.2800228006649282280662485600179163211278461385120584075454`48.97933986664574 w^3)/((1+0.84271941910387545121714069108634483850484772642332722943831000436986564615013`49.52287874528033 w-0.2355239337324510181728503203969637550412640564031302953286869142021632706212`48.97933986664574 w^2) (1+5.12780980313550552532956411975180760372290768792152527809100828866117067005565`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 7.32158464993939257236221371581046556127311635419140357179613039511159384589609`48.99960389809265 w-20.7035470110944658247553910774599407337341764385843748275705`48.99960389809265 w^2+11.2394189895339848956523818790100203466123348299114715186607`48.99960389809265 w^3)/((1+0.83338364101866737716282115360354578086738780393778022715170663741082077308183`49.52287874528033 w-0.24492131992514325440142228347739607415055159069252764881052595215647008894171`48.99960389809265 w^2) (1+4.26212878866957481099637326007583376633261433158154852980171117686906100608521`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 14.3663678528338828704028291422827483460334307288048468140755`48.93758908202794 w-38.4162522277327436872481614645537036419676016478671295348564`48.93758908202794 w^2+20.5583464401020785815679941677191120567856833592419373042276`48.93758908202794 w^3)/((1+0.86080636523367888803050823383224244773107855151074941671561541780057431545894`49.52287874528033 w-0.21702039357150840407543622598453930767361712339124419314300959156379570003425`48.93758908202794 w^2) (1+8.21796365924397272592729766740931866604436848040832620168735671444267524422813`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 0.19615315923332086328061960160716567404133230334079973360341173389463398780495`49.44773483521256 w-2.82623541320996983320487350110226413935304517868060715183546247697071010715701`49.44773483521256 w^2+1.8659697054908964042001743256438812702474375642395193362164571881017108552254`49.44773483521256 w^3)/((1+0.50550197277522099064524674008192026159140649238022667841424776239053459526226`49.52287874528033 w-0.47988960298475972040360475689271310725146464175093182285161613657505933627147`49.44773483521256 w^2) (1+0.33604399220827107126737017421688395958373113086747719447754486350837569948517`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.- 0.30658678515848262549039969382506929534630023956742359243974926352889551945759`49.65060225672837 w-1.56740143517633801114743059404806905811950078073450970486001974531912517997679`49.65060225672837 w^2+1.21123113431198198848041664438966598050044916799198618547242353225580157030222`49.65060225672837 w^3)/((1+0.27561234135599512759963778631495224388328890537921995915333384120300797552991`49.52287874528033 w-0.48570614003081296222080102575853465612579913142521184509806824229085185365847`49.65060225672837 w^2) (1+0.1107251813426880745950740589779937937302172222318533346402308524854582980872`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.- 0.33372996093913990424742854502364856610538122009188860308128493025275724372929`49.66802045169417 w-1.498322224722693327019271856810978780367593625097450417023545767831286393822`49.66802045169417 w^2+1.17444833931144818676703480335500338816241566227094435293866825885978547308844`49.66802045169417 w^3)/((1+0.25571637229966254813132621853515203370699034544925840252022596184090829367478`49.52287874528033 w-0.47929884607135682083662904920863395369426151410886004224747895256879317142172`49.66802045169417 w^2) (1+0.1004311372301515001613232221237430064723088106693313132882779003144159818532`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 6.30202298161490930472051595920668053550457038461171380614753072653326056867448`49.01698807280169 w-18.1407546408186771486438068447593791780890132850058258116105`49.01698807280169 w^2+9.8916129837988969674890454616209636506403400666656323094743`49.01698807280169 w^3)/((1+0.82507127844285435892329814870334078604220815732050820870219518647282247283873`49.52287874528033 w-0.25319729733317692667270031634335497810119199712936058828804733841875160270828`49.01698807280169 w^2) (1+3.69070344088100622750779902321125593804410213534732145083196546714169316946574`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 17.2000232756991832085898178397574473432866532628062178242301`48.92524879056471 w-45.5418783558843683312695548254289834311765368907236415028147`48.92524879056471 w^2+24.3079594970593214329141371922160612665652808480038465973312`48.92524879056471 w^3)/((1+0.86586868264695799083384137028341661021860626124292050426749691793607628953806`49.52287874528033 w-0.21177360082823497499469096838016494769078156913890474946250609052059548781355`48.92524879056471 w^2) (1+9.81062925525238439045664552562604331137742422835115266325502688364099644210065`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 14.8433572401540603737128542685950438706603772461527851686917`48.93522764601223 w-39.61568873855035622714517279257773251933807013707618228141`48.93522764601223 w^2+21.1894931846440082661600718709693981959254695094973698480858`48.93522764601223 w^3)/((1+0.86178484983474383843922144896706254976768685357861333395047200820041253795759`49.52287874528033 w-0.2160085203974800004065393948707515929745558743838675356256248640066902499196`48.93522764601223 w^2) (1+8.486025568461306333937008497176279873137873820899623081803718594817262158998`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 0.00859223169054643388568778637075941509115642043616864072241145906958777660022`48.33008274019734 w-2.3587018671192151294282090670595346487220969453607882302181`48.33008274019734 w^2+1.62420066185926496219548401726561891920952357478233983119081085686505512981653`48.33008274019734 w^3)/((1+0.44237258952626476343066862976234848707680122558529418433511313750450483965461`49.52287874528033 w-0.49642135000398474739706115930134364426021026978042787292570854321453906938133`48.33008274019734 w^2) (1+0.24632331627769951153636555572629838255290851343235471684611181872921432120949`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 9.3172070161326934859010312956995998792059720919968368628327`48.974418197478784 w-25.7205358923906209835501155867272237854983546620846975887624`48.974418197478784 w^2+13.8784833432597505130194536654366219455464389835861771148162`48.974418197478784 w^3)/((1+0.84493076341613235307188779911263876321421415738698471650904277321207372410998`49.52287874528033 w-0.23328244019063508686084230198899193205638477170926744215547722720945557286214`48.974418197478784 w^2) (1+5.38177958905394033088469148738619857458313909573484047291566905266077758615451`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 1.09436983443617148555371926236622269505893466791228197510842900143211299875165`49.27609709433179 w-5.06808791742212727544892278503910267114354101103676276458259078168990133619889`49.27609709433179 w^2+3.03054545453111662636256104789226689222933432673928828939707087276602845759637`49.27609709433179 w^3)/((1+0.66220433445375524801315526531258414264981670551631131978975310523951305836463`49.52287874528033 w-0.39443659365776173507648488557106857387357958744312629699914372705087435617912`49.27609709433179 w^2) (1+0.80211528159024098195401160208618756364152990765491489696079844541442798623409`50. z))} /. {w->w[z+10^(-10)*I],pi1->pi1full[z]};

(* Sample Pades for the 3-loop triangle form factor with LME to z^6 and THR to (1-z) *)
(* Mean and weighted standard deviation *)
Ftri3Loop61[z_] := Module[{const,ls},
const = Ftri3LoopConstPade61[z];
ls = Ftri3LoopLsPade61[z];
{Mean[const] + Mean[ls]*(Log[4*z]-I*Pi),
  Sqrt[(StandardDeviation[Re[const]]*80/Length[const])^2 + (StandardDeviation[Re[ls*(Log[4*z]-I*Pi)]]*80/Length[ls])^2] + 
I*Sqrt[(StandardDeviation[Im[const]]*80/Length[const])^2 + (StandardDeviation[Im[ls*(Log[4*z]-I*Pi)]]*80/Length[ls])^2]}
];
(* from 20 each of [5/2], [4/3] and [3/4] Pades for the non-logarithmic part *)
Ftri3LoopConstPade61[z_] = {((35.90093366538015827573688574141686989801918916521596845982212092995008285475909`50.+ 177.8105763085713526671692195743768452243354073808435004986215`49.48242165423252 w+307.5511158981336717125139157267290580990920140349694168065354`49.48242165423252 w^2+325.1426055387548826241572722347326016923634145648709324559995`49.48242165423252 w^3+34.7483011309103919412707680640060275021437594273321017654341`49.48242165423252 w^4-62.3618562633208005042430296578035771102392331179464915502569`49.48242165423252 w^5)/(1+4.07799735775129455287445431910122891980790652386271567902126197250213900504679`49.52287874528033 w+3.1010663771896125814833409119872057494740142634086563797901170172179222131311`49.48242165423252 w^2)+68.8757442318535695219501917689493085960343608520939532682880937732746236502018`50.83467992856094 THRSub[2,1]-14.77279859147349148483238316520841632910910388158417996668434930565692760685134`50.83467992856094 THRSub[2,2])/(1+0.17140669138970344005044077257950399855776910970964012695372954119105048860923`50. z),((209.525213629427400125624010933489247829677420602596105696235`50.+ 626.157054995410787171938193340221411496820423310987392759981`48.736778700944924 w+1733.1455388071611888448152258809736131507436360097722908742957`48.736778700944924 w^2+1944.2860155640147391639059705913377423264475337524174776531886`48.736778700944924 w^3-647.2110874527900631264422929547774552928073081496575852759278`48.736778700944924 w^4-108.3654005948928759639420154614320736788739365903362438643181`48.736778700944924 w^5)/(1+2.63353319907243343226612234563182753839103072361573059023170836538141508202543`49.52287874528033 w+1.6152017175587468838956867558443046329238516911311338662152252017349098316208`48.736778700944924 w^2)+492.0520843879500941218571606437722628689987839801179060341993`50.05526787423307 THRSub[2,1]-105.53768122938340394219401257432888159031288279657817395794051374869931159978957`50.05526787423307 THRSub[2,2])/(1+7.36859348080519463565563572973974071016641187498667251811279911173803662445574`50. z),((85.01659682830929953754012498415843062547702963923935153116871707504559575103989`50.+ 274.3145178395710223698108588789628244112925075251148585185866`48.98028365215284 w+649.1546692024548994888315129174842547593344672475100261472408`48.98028365215284 w^2+713.3042769104587885951480822648254997797191284290548890797732`48.98028365215284 w^3-186.6396844477098574533561102169164983723601838597930625712678`48.98028365215284 w^4-55.258156814150796482750385557355091065199288520436348756183`48.98028365215284 w^5)/(1+2.71424024290403368841430400950928802209491061016705696109082604208254749887535`49.52287874528033 w+1.68101642286521535732795148409881616190726691292913320562293752434303848721025`48.98028365215284 w^2)+188.5858826176362011629071847496831910357262755029039055658075`50.16227324199449 THRSub[2,1]-40.44880083948570365137285533555624173403896041444715547016504094502693770454655`50.16227324199449 THRSub[2,2])/(1+2.20738116536772997819250126567436919311300917082007403992172442666202708546379`50. z),((34.55313126655320032081734851230165435764648642803281394882186126781912519392843`50.+ 187.6065597525578483449652594051087853364217910715361555863685`49.48908024898901 w+330.8531270596788287391167671811451810559083440309143148879479`49.48908024898901 w^2+346.3132077523683174975330970905965960998816956795300787546614`49.48908024898901 w^3+63.481644288293071737855047455082304097693383935909457278308`49.48908024898901 w^4-74.9674913598613266035547966021914381842267025314265816441501`49.48908024898901 w^5)/(1+4.53022255212882378632233328588773178893368769515435038478860854430918749851774`49.52287874528033 w+3.78311976220176924900837890140973571998366554189916282427398271605295449866023`49.48908024898901 w^2)+65.59073083103598269987372221280369502174133723314060241600427430725603202655692`50.984763876475014 THRSub[2,1]-14.0682132271802366782966588110566966531663982719624868797785197595585428931844`50.984763876475014 THRSub[2,2])/(1+0.11553670810402144374638418002306116383886141799855009826818956719024059570554`50. z),((36.64734785102189681004002406316306228568730169284966614126344407485376702793604`50.+ 173.8483977504334778220341437620035133489856203374919673596367`49.47833897518758 w+300.2479715018624917314977471018333827059352010469019922441818`49.47833897518758 w^2+317.9115069198519122048525021295931523691766737093079636163925`49.47833897518758 w^3+24.12184376682156938685549391356305900663880150560811412476023646691713127999942`49.47833897518758 w^4-57.8328908543882908382430620619244048058323866184904266673995`49.47833897518758 w^5)/(1+3.88178304165850262259653841393355795161475384381237822880859447678976402988246`49.52287874528033 w+2.85457326359269572424103964761836242469764404624546654265094759643900729030735`49.47833897518758 w^2)+70.69498761985132503183041678703389347004344809042493052665728914902729104460037`50.773932092763566 THRSub[2,1]-15.16299860251499021293468532734136652931050841859607739583973315116672096470531`50.77393209276357 THRSub[2,2])/(1+0.2023475385882948547119056836580950953986271229910382275860634990394595269885`50. z),((112.67928947069836343313223535410394976360386883841354009321199818507147323229371`50.+ 351.7808218478737786882841269087739251312026941774881517594478`48.87381794489183 w+888.7257516887620967223720013323924467623565370213297390335643`48.87381794489183 w^2+985.2469054113078426939691477016623398543289040354418696565458`48.87381794489183 w^3-289.3784963884041621713188910945085772854255859492248850283677`48.87381794489183 w^4-66.6846342670283934750965616568693850591792404209853372028344`48.87381794489183 w^5)/(1+2.67464734959812907524621626327658909007844771910171871663594918585164318716084`49.52287874528033 w+1.64848072867048199654734846178889452884858232040544956010985626257325419016602`48.87381794489183 w^2)+256.0084633401780647576139366445030354468882276008739326091735`50.11332319174361 THRSub[2,1]-54.90991798079183014230499025750901868063256807278457847807854675111336753696658`50.11332319174361 THRSub[2,2])/(1+3.35407312623109779776633641727428189658746251002214218526743766134378931048099`50. z),((86.48410996327744512759686814193926379648483917614859105569128524797906632222079`50.+ 278.3910470428266527043455040169159188048129636135194259914992`48.97255375702274 w+661.8041762938171828977612626742557184222531141924144972293685`48.97255375702274 w^2+727.6578982806987802322302443681123422098405653155062182077352`48.97255375702274 w^3-192.1099394493793554836746629185049438231481370416893998990586`48.97255375702274 w^4-55.846601801620413249707042597092206930819140109951002166392`48.97255375702274 w^5)/(1+2.71112115279153519476559525069947782776891626098380982232978069553716757110624`49.52287874528033 w+1.6784360592394968587363057670173888257942774914588564978799728749646387980699`48.97255375702274 w^2)+192.1626682936684639197391820903550413029277299621072383389415`50.15862649004372 THRSub[2,1]-41.21596691494794153693784556990473983504674170195191554110746281649025684944651`50.15862649004372 THRSub[2,2])/(1+2.26821347609335855686151164828644551601852643912214328426504825206001706839501`50. z),((40.79116813808582820390884555956979618411619655430911425822049341503539353895865`50.+ 167.4473464178225593482370997023079715145925658988731905452106`48.70792318141019 w+298.4268132178943400629260878077003697416434727821344661426094`48.70792318141019 w^2+316.697457712835730261099324774480196538052587712964959294545`48.70792318141019 w^3-9.7962435636260191832696445376434820836606019339497219125295`48.70792318141019 w^4-46.9858622140791539165957977762433464084396522126631728191103`48.70792318141019 w^5)/(1+3.30539007155387569053316112636739778024808642187203053475263518086394456695933`49.52287874528033 w+2.2216751616196614007516930834925319029308526154262482226162328769721024615503`48.70792318141019 w^2)+80.79476573675648748176350556850275056523817518044274290670584663298424086359558`50.56501383869287 THRSub[2,1]-17.32924725221899768110911049066975931098148028807345211481001858175984478110928`50.56501383869287 THRSub[2,2])/(1+0.37411987730695865462878183697948131115923423155012793342712558050808650163781`50. z),((50.5709627102382837255285327171529814399297035614732102921300862534695998637617`50.+ 183.2940879201674375682246116354446815774413907361561522358469`49.04241548350311 w+360.86520978242747946588712577661639261734385558146346790959`49.04241548350311 w^2+386.7699329396841578538832344139081337001378013419777113537067`49.04241548350311 w^3-55.149555576619493053747121379103744594924458019801469106771`49.04241548350311 w^4-44.0528511523267701628939053210973470159034933274142208845769`49.04241548350311 w^5)/(1+2.93167662725820507992714422917687542590643042363581651075667531719712812207375`49.52287874528033 w+1.86801457126777246548922262055952425077133559609583291537414900463777860142842`49.04241548350311 w^2)+104.63116508930624777310968798534427288265044963279087121079027052483046065641367`50.35847614504786 THRSub[2,1]-22.44179203425118866777778144204823585362259111734161878869660353210418095491302`50.35847614504785 THRSub[2,2])/(1+0.77951829458170945540610280284446515590275535672299036018466543073076762332762`50. z),((136.3430177085513148854464314255447637323436115478154473677678`50.+ 418.5925403826752636883681693171850090466395793614301360816037`48.82083937391475 w+1094.6429945417990741941826694014539851699941897065398230485883`48.82083937391475 w^2+1219.0758592806995428551338905505310779859909871773559088309329`48.82083937391475 w^3-376.9442833759697372692376271148341494747116435844331112696529`48.82083937391475 w^4-76.7483188618146470149714029542049512734198954189477791130832`48.82083937391475 w^5)/(1+2.65751864065575063423359790789434640859545060001051620499732768257846080919545`49.52287874528033 w+1.63455310271371064450788742277254123374680437250949190513443404918954980035401`48.82083937391475 w^2)+313.6843247589651922692880646028148366271759820028729282681643`50.090145370606955 THRSub[2,1]-67.28051221293997706706806416513776865185160403403427602170578815215194398445506`50.09014537060696 THRSub[2,2])/(1+4.33499740880874486504496332774325652628467641837482822606570344341606646293676`50. z),((86.2184942162826628273572889472701318013998070693968096263888547175568021731566`50.+ 277.6527971713831225113129263251803392612725430049267036699039`50. w+659.513908266681348757452403784977864866171967832924832526764`50. w^2+725.0590282505136007754399587325412333029537759047258706018574`50. w^3-191.1200890955563710250967850544845800799857477941660735824312`50. w^4-55.73987399950295440780037152674651922972002303956988476268254124442304294527858`50. w^5)/(1+2.71167307921881155398700841037408343277289811895211382750405614808121120317963`50. w+1.67889244358073143348608620991170754235646228486193495667249074068026412238893`50. w^2)+191.5152801534593004482981407445022026129965245471613722586862`50.15927420736678 THRSub[2,1]-41.07711201454026580943022137796591132997403308632974201096933851782507346602624`50.159274207366785 THRSub[2,2])/(1+2.25720299906948014743016578458075851329966149115153730668554045340440974578244`50. z),((130.3927198361589058846149029823430560945203475510044104825924`50.+ 401.7672249820893262962847547360566139301775432638182622861071`48.83217061755102 w+1042.8192284710446577141904924571541057858719905032437105710687`48.83217061755102 w^2+1160.2232604281918866641696263326005136450002777296325450900708`48.83217061755102 w^3-354.9403048654031508617025376550578881947952515067501002185834`48.83217061755102 w^4-74.2044330247983490899730624919572459870396929753455269521139`48.83217061755102 w^5)/(1+2.66104612004011724761906328730623551360232423060586670469640866782396117449728`49.52287874528033 w+1.63741400207448248979977972662280274621737705252731860630356212059832256755161`48.83217061755102 w^2)+299.1815992357892834262286054324489873487438388095599853727273`50.09502907966837 THRSub[2,1]-64.16989837390699618108584285248944980667012414111868762118332858949805024795051`50.09502907966837 THRSub[2,2])/(1+4.08834178409348211329371297352766708052678640978512570685061028559331409296663`50. z),((35.82979991850332042345204394371762730176042250645218022764504573852096025761104`50.+ 178.2546282522786225979009743307425133946970107216967029993223`50. w+308.4429626529558006739023048260052300407652919325593151328114`50. w^2+326.0108077747018956766054858746684069745117703896324638783451`50. w^3+35.91381773839361103781901255243077017710416048607832502673183166238869153277618`50. w^4-62.87178957808080539447019695193518248850391508155176610231315648807251393023495`50. w^5)/(1+4.09897808780478053576487551676628728954228209798181757904021063373762198185428`50. w+3.12866646419298899336048315314889699373203885943610833408658221603979455575786`50. w^2)+68.70236917929085355211777950839132248296848553009196403909740350129568067224663`50.84112144633202 THRSub[2,1]-14.73561228211510031497070040675805694011208241961354434625015617366803068206681`50.84112144633202 THRSub[2,2])/(1+0.16845800896228248192020757604053478395644148632614339850992920076098319949073`50. z),((85.66938387005992896432869997649523199355659583181017489774349549215108342100686`50.+ 276.1271720380285549210124549620169069775025446591733971410011`48.97680465367059 w+654.7802401987410535754081143617264704057660909684455571457073`48.97680465367059 w^2+719.6876083531792415264357103660942032332543054498635570573921`48.97680465367059 w^3-189.0734141783418941796585287799996699560781236160470427377642`48.97680465367059 w^4-55.5195401685190885255867152493330715738634767323238674920548`48.97680465367059 w^5)/(1+2.71283155139611202604479655119061608521894599654796620077971075705678804818177`49.52287874528033 w+1.67985067571047378533622395689556796967889137500620342928014043275822189932605`48.97680465367059 w^2)+190.1769275526335344609904708361463261025414894570364167634276`50.160630346681224 THRSub[2,1]-40.79005575639198734337552466074624185297777198250952284153480341409146276613524`50.160630346681224 THRSub[2,2])/(1+2.23444091918880915903115340864939020186033976196543504539492510908573042003345`50. z),((36.74242900404843003876720821504873914035506250085478001187589925252239527422714`50.+ 173.4316183748468661910739914419477692968680209091143384211348`49.47781757286735 w+299.5597309118799329102682814725504367832152740831074545205556`49.47781757286735 w^2+317.2200377105384681513506117538834042916223591060929225378115`49.47781757286735 w^3+22.94492633845538849238839615905505189117596567642072332100518077937291721432685`49.47781757286735 w^4-57.3499619511936445935676334982719999280713189999660200975175`49.47781757286735 w^5)/(1+3.85975430952418926073127487660044362060586608001563995416178894036619810996521`49.52287874528033 w+2.82807093537443592085344294781019433390508099698290691837247749264323153261189`49.47781757286735 w^2)+70.92672994508326763764427671501759318149670202063727241143295297088309251828436`50.766975463637095 THRSub[2,1]-15.21270380329288533474813884928274078590547635822762866477282166546811380114897`50.766975463637095 THRSub[2,2])/(1+0.2062889044999441970597498204880609906030132198266832141342220674497192753743`50. z),((42.35864644736295433270365440710351929274617048692941040275913446948809280958823`50.+ 168.5080687950307504401676008425878536052593419076776515120781`48.87417813810904 w+305.4433244809356932687745396012322045382693018351824570853253`48.87417813810904 w^2+324.5279569732170514278924349989700801764673829702485606000024`48.87417813810904 w^3-18.4283372454257370136707868610067745539652023264119381381055`48.87417813810904 w^4-45.5443015270306840557365842339868229405300733838739462429801`48.87417813810904 w^5)/(1+3.19895993895633313286717489389665563052782338775857410918184844414009688723841`49.52287874528033 w+2.11677510524123697924467743500143061112716586074600906666331041553874829347831`48.87417813810904 w^2)+84.6151976160496097383445561552794069637537371868931453659845166532706159348713`50.51553027861135 THRSub[2,1]-18.14867172907481749771334595792455193400317192540410588544408534873155963760659`50.515530278611365 THRSub[2,2])/(1+0.4390960095769426276070309152317525682298840821821618861454237937116260341906`50. z),((138.9726802962127277819293211049198543111517933558127177385989`50.+ 426.0323751744112815148333127901871669185200839931205874571569`48.81616770941393 w+1117.5531949980758956938947596939384927479338230386966505921861`48.81616770941393 w^2+1245.0940470081594629491490007440551300262700947859912035699802`48.81616770941393 w^3-386.6663351505855741359191615837161235512489099538586972817821`48.81616770941393 w^4-77.8747043646954968527863430746575985268303719869192924997793`48.81616770941393 w^5)/(1+2.65608538229807737961095970754694186999700570668247049609763127090291242100102`49.52287874528033 w+1.63339177559463514154907754735181961905950414330884297275019554670040375788615`48.81616770941393 w^2)+320.0936298971774242054619282386977167190870987082776130796329`50.08814399632625 THRSub[2,1]-68.65521059150670072417408860679331727214405804150299815307871313568104454229489`50.08814399632625 THRSub[2,2])/(1+4.44400389592250545673306708591599415261267235843489160192740873310225086923321`50. z),((192.4922632639239292378954150974468379097737522473100661195522`50.+ 577.7831766820376999905687914887496627431947816119055474450597`48.75035491468947 w+1584.42224726903760667250095694730090731789060557335407829244`48.75035491468947 w^2+1775.3552892565279053193364761319253506003065060530776723117588`48.75035491468947 w^3-584.3430876455142006732869399884193520394340566899527656182235`48.75035491468947 w^4-100.9733928930202244419743062774079357218985722495903378444942`48.75035491468947 w^5)/(1+2.63715578545321936717534636068099394109638604070003056225199551265091398240729`49.52287874528033 w+1.61811302263404893276041946405945995929352361484664703054636470024008821050709`48.75035491468947 w^2)+450.5374897746461852265376857387300955334388578027636481587974`50.06073298881717 THRSub[2,1]-96.63343269212582927330240338665915202320239145984890257056741369952472347456709`50.06073298881717 THRSub[2,2])/(1+6.66253252331263552028985603276691979529813758609873408551623453594698764609937`50. z),((36.38348202711076671860318263344675411137267906013537319206547401687139899992184`50.+ 175.106039531254140550855873734146041030170378253220539154256`49.47978716296244 w+302.4272106633866821504021617425861403884191199319656311903855`49.47978716296244 w^2+320.0904868451586468065567909947222283542122567258787262136359`49.47978716296244 w^3+27.57788477457227937174594575623484029955084206068157691202441632733106216007`49.47978716296244 w^4-59.2761006204031412300357410290004920697042018448995092671066`49.47978716296244 w^5)/(1+3.94629578822993888225436329833760044900834573341184113134769526547743374649914`49.52287874528033 w+2.93346875177974325036317466739071276874702890267552357608359184764556966859154`49.47978716296244 w^2)+70.05186458614827899286156495518608310228391385777843956981249961786156873173474`50.79409737851062 THRSub[2,1]-15.02505850252201427131060735201680241185915551590411350685500341958863096433576`50.79409737851062 THRSub[2,2])/(1+0.19140960051635774561076470700140822988095603064777372686484614596020126961943`50. z),((247.2787107974876656457494710785395898243163861260827119077458`50.+ 733.4444011554706233479554703576163133762661732296303241784301`48.71356697244513 w+2062.9088991842175608624371480161745129507047623636997698920653`48.71356697244513 w^2+2318.8669936500857296913949336864892774734241667140027204523565`48.71356697244513 w^3-786.5208702916124054726708668311635582034443364015623241313032`48.71356697244513 w^4-124.7843323983105302939513531247543730293503856513854188826963`48.71356697244513 w^5)/(1+2.62755267184352511536870415734316197869016197209442961777615793032514714500345`49.52287874528033 w+1.6104043426180860875178932279701609273083397999561497641104249743835076531755`48.71356697244513 w^2)+584.0690923950189383885499983974980063165957544717305709382531`50.0460802822091 THRSub[2,1]-125.27392860411248429267186600198314689140781069950788826382726422977302688488344`50.0460802822091 THRSub[2,2])/(1+8.93357604619561089032081689029536407979046625735170963858861321369453116016741`50. z),((84.72823657311805380453770302511342962828497043158884027102318262932916735225734`50.+ 269.8172280371062802307273834262825357375281590003897754649623`49.01672150524296 w+608.940151234178869570607989221252478249244587005664804196166`49.01672150524296 w^2+651.8990383457246790358071718685444569597570045734266095175182`49.01672150524296 w^3-342.9172205912771438853724994216272389848722997514089971306775`49.01672150524296 w^4)/(1+2.67124083986492476127695846534243703173199897430519787195346305913848752375898`49.52287874528033 w+1.25862798502261281169302828820691771503484513810576585563135259981590580515065`49.01672150524296 w^2-0.27554803177800151070777850283539119872938404174317965597117319966322121133408`49.01672150524296 w^3)+187.8830590409821879737707521606253218184800285345393227827006`50.163009845748235 THRSub[2,1]-40.29805588189514737354811416688612260363259126816198655935823744660604357689492`50.163009845748235 THRSub[2,2])/(1+2.19542786816940801764366688776567673151720000694499719606282150394418153716798`50. z),((43.78571526174762937380660904631050008820530670904201143436572213247091609117909`50.+ 203.1443284560207778743005384814961823039224728934568008484872`49.22487859342849 w+305.7851008406063047275006909461073548142931872514014044070896`49.22487859342849 w^2+366.147707913213724438322159800225201935588257554784705221591`49.22487859342849 w^3-220.7366455322048965069653791306927115174149001386061530661328`49.22487859342849 w^4)/(1+3.87767519294445026364491243674359148963762691039425908247777987811402236561432`49.52287874528033 w+1.30046713396654977673618148577678979266525541968831516963293297109586851536656`49.22487859342849 w^2-0.73506063709882523824648171727734904635084281135255740743599805419498922198288`49.22487859342849 w^3)+88.09340791098795518059955938507064751894280565316748568207335433862434073883067`50.47813593415276 THRSub[2,1]-18.89469488597814844487893191869497408256847537722096876350622096768887774872721`50.47813593415276 THRSub[2,2])/(1+0.49825179597158181389601074057562220197857291607075992549972175983994482471266`50. z),((188.736007518465735325811142427368231583301835636358528957081`50.+ 554.5167963958168771782767288848713318985435906123481509023626`48.8418683610265 w+1490.0875271237415675567545477761046873972382013727892582852773`48.8418683610265 w^2+1610.4337392844142253434654843355704303184998370797313756385123`48.8418683610265 w^3-825.5858483605016351804323463851432379880270039296962524596243`48.8418683610265 w^4)/(1+2.57129044434787760844055952630384872759759948813608997099258717762305717105258`49.52287874528033 w+1.31724985548581636829447512444433738658767446348157353263069091313352529406586`48.8418683610265 w^2-0.18962374996989857411997361552850458024762386137088967436174298720918917846922`48.8418683610265 w^3)+441.3823269173403870620518612624171652029603423513838672985417`50.06208715826848 THRSub[2,1]-94.66978963503101417001717343971542447904558308024013223666255406437889620433774`50.06208715826848 THRSub[2,2])/(1+6.50682576251584005666116811808488400171316867243182294335169192564897120733091`50. z),((267.9301267774406192165864368540185856212547255987765304370452`50.+ 774.2721792608676876992107581663096059435536304011507214951893`48.801994553564285 w+2162.9507446335465935301289662794672334311405495753550682320415`48.801994553564285 w^2+2347.1399308783472083134201368178312746569652660975829648082004`48.801994553564285 w^3-1199.227104926715385872412868115156150218407758320588939672308`48.801994553564285 w^4)/(1+2.55833851556011042403889669747460143229127767147083394807004582003709770656022`49.52287874528033 w+1.33053026588417767435609309788730719715766472876550317613947055023944857123208`48.801994553564285 w^2-0.17384909731261752526610593737484188641793202956228609209803140040212756232519`48.801994553564285 w^3)+634.4030124852693445102412530354728083000200254159272426775503`50.04224026590337 THRSub[2,1]-136.0697881930779681819383701459021501207844483880481379274962`50.04224026590337 THRSub[2,2])/(1+9.78963199818814868747085498670192960534624264426427850143538427916721262796992`50. z),((244.010926848405609053314196924364874228804138223843679204644`50.+ 707.8395997403810270823563765761370845313803942859912933793777`48.811281002983584 w+1959.694190991250276791388428486386900264700100940611966299317`48.811281002983584 w^2+2124.4859441949125016716022866392266497310689261324246926376741`48.811281002983584 w^3-1086.2367463284786295811735355857029179016511092036830254525594`48.811281002983584 w^4)/(1+2.56112122329426020152805676814483013218709007571350816622176646024529728320739`49.52287874528033 w+1.32746929481318241327735919790197245647305272760375116588735280177968125050783`48.811281002983584 w^2-0.17740926578874542111211194894633168594847990624436889477760510483692252539649`48.811281002983584 w^3)+576.1044871434969144387672281426964844266163143314065909172728`50.046752884323524 THRSub[2,1]-123.56564202872166762858360288472845817495199108129403990951898692013537559946637`50.046752884323524 THRSub[2,2])/(1+8.79811773659820054144341397369915993252406637066846290496506692581835908365196`50. z),((176.5028492970348478379962385542975403422354247899843257286563`50.+ 520.6462648107078585200957249781737557388448524024203838251337`48.851277744041155 w+1386.1900204817828840359979511652917532883445673999441233231384`48.851277744041155 w^2+1496.8159160318622310126888965892822064183414045187841541086098`48.851277744041155 w^3-768.0410026115438187735438483585898881866707589587895061281102`48.851277744041155 w^4)/(1+2.5747535395686311880783588912809702556508988653684839639704657345216244051885`49.52287874528033 w+1.31407059068562330465238849582443632306958646407204218448878426188513860814973`48.851277744041155 w^2-0.19353599532047770150805548176939114729183813506727028336868962097855658849588`48.851277744041155 w^3)+411.56631774070015114446741490653628900267107691248617458641`50.06694959284403 THRSub[2,1]-88.2747095777424942075607044326012571300949960324573660217391710595462658533748`50.06694959284404 THRSub[2,2])/(1+5.99972891660037581456795163908448607058983167661693172704117668619052735032078`50. z),((109.06718166133561794177827709237360950885008302086075749587169395523768212822655`50.+ 335.1314780111288732182340189659113967545388145537191392023817`48.9431784319177 w+814.1982996368216944622133361995122504642605476118963131618588`48.9431784319177 w^2+873.2804852926361267188672854081026570235927219533301046835354`48.9431784319177 w^3-453.34674531062848229213905754760818602078094463536096463857`48.9431784319177 w^4)/(1+2.61876887544212624784638753991392915207121811782002127263666748949705584423877`49.52287874528033 w+1.28272359659635478441486521924453828843318112657509628439149670331895174874382`48.9431784319177 w^2-0.23585218778948156681515500262651083139070577739588162064251803561616509133125`48.9431784319177 w^3)+247.2046338105068471215812985686290896638347826092564833594534`50.117959184364324 THRSub[2,1]-53.02163057386823278233354398796748780008319771291293274873249848407543463531324`50.117959184364324 THRSub[2,2])/(1+3.20434167961042158912012219945286726961005681101348936788430433967540053231283`50. z),((113.95796122528598791174892288449855706360032206842603697829623666090313950782346`50.+ 348.4489609277256593891214968833599204587278866927342769891705`48.93259430788051 w+855.5897784985892897111963075358228001107054075038472623071727`48.93259430788051 w^2+918.1903204955700734876838707508949949918021878165862202041186`48.93259430788051 w^3-475.8945404124420787498488090151605229915954003286726400255493`48.93259430788051 w^4)/(1+2.61262245258652088494171996464336157864011206696270214945573764194130304662094`49.52287874528033 w+1.28631632287768113820790872706872884205774276784047095767506682529924180517455`48.93259430788051 w^2-0.23058169481339037918562401784464001460419879772922370712757131804102646119344`48.93259430788051 w^3)+259.1249838722108706653397915673786481784276918309807393454768`50.1117686764495 THRSub[2,1]-55.57836418982197596282196127682673218849821753789445967526811355962793399140469`50.1117686764495 THRSub[2,2])/(1+3.40707746100514224549871623646804894565046719170090856439874080412402804915712`50. z),((152.5314660396167429644681226598295622801082454559267572191911`50.+ 454.3941949510222440910517888023499874910702029326353832031512`48.87422610445415 w+1182.6670941661266790678908007309249624481694888903771504179315`48.87422610445415 w^2+1274.458306884480338831112392882336709468436317467914550129389`48.87422610445415 w^3-655.5399037933553365811073967125123607856882133364147896190328`48.87422610445415 w^4)/(1+2.58392820785368047502031012335953385972428891085020554023517614497754393661742`49.52287874528033 w+1.30626632251720074373512548073675732937370726378923862813812568400157845631833`48.87422610445415 w^2-0.20339343032680487469887342603216388440885302150128490359203824012627980201297`48.87422610445415 w^3)+353.1406054068382823336158632551333174633424748463289669804414`50.07909373844102 THRSub[2,1]-75.74328373984440627218163511177421170411660198522337928132368909059153378657488`50.07909373844102 THRSub[2,2])/(1+5.00605151767880382856594441760659842293095181171546972379152584516604314164115`50. z),((94.45957799137386269233875592219924290998193670035703957262761185952040859087666`50.+ 295.6725710103291143093757648051625461493188837479329975204063`48.98210779317812 w+690.8061020517332560785688280283677279684461046890328368752988`48.98210779317812 w^2+739.8486567374508881488521141786756832233064504857833140061609`48.98210779317812 w^3-386.6004039668102193370171151858169301971315408822717259365237`48.98210779317812 w^4)/(1+2.64427502531850866160820582737168347158657865679151450493275763113904883449476`49.52287874528033 w+1.26972363638644678079754658276569495498879743594786934549398461716064809957509`48.98210779317812 w^2-0.25618153319223855218273947539628040166738093259831650765984059765987700832284`48.98210779317812 w^3)+211.6013629961644321264636504052741353053735077154085755195343`50.14138402837949 THRSub[2,1]-45.38527099904535071200154712255137419435252167387884540859071987336139476058329`50.14138402837949 THRSub[2,2])/(1+2.59881777373598832280338368409441887645867161884124343485013710045335726426126`50. z),((145.4470007131301612521885351204757251781853452443240848236658`50.+ 434.8566403749373852361809072690355426590663165557217909307845`48.882510861429566 w+1122.5438485217648754647406714966565637271408747358484817234267`48.882510861429566 w^2+1208.8427606956227910796117266520411206407675921764126687354304`48.882510861429566 w^3-622.3826991133667397913391044248910211838949809449364854023792`48.882510861429566 w^4)/(1+2.58751068666228758235673910441197562992060267873118537222682599445134893478621`49.52287874528033 w+1.30343627134697101888359401768015897761504812030548073286152551040245856785088`48.882510861429566 w^2-0.2070646025457239302297120361287385582708235232798917772099533436520397358997`48.882510861429566 w^3)+335.8735612500754437101127241326299306336866906928212914880779`50.08357675929831 THRSub[2,1]-72.03976563716862607269138434867328057016245473500827452016507664987721241213164`50.08357675929831 THRSub[2,2])/(1+4.71238164461485463565147636661320820649780681961267491506478875560178810628549`50. z),((65.21980607278063020571320305672519261149176320200291014243819251085975787177659`50.+ 220.7088631389937167196419383922638045403448897772472201780037`49.12738271623361 w+447.152749048576148104579087528415538021464536832045897508549`49.12738271623361 w^2+481.3296883653317449767895820815868517348233603276731362657286`49.12738271623361 w^3-259.8987701431047120043263157854957198824886683905421565819416`49.12738271623361 w^4)/(1+2.79129949282155064979065267277454723559456426652808370426316452240130580573111`49.52287874528033 w+1.22900069690255669081477658233210400846790180558779641252104265855370317974212`49.12738271623361 w^2-0.34615449877973368789597909352527896541370874822927707772461160566478351583665`49.12738271623361 w^3)+140.3349498535353426639263416443977129100048930980394363935415`50.235808534270454 THRSub[2,1]-30.09971032112676257587077606351192472009920901754085177355501973119068595095816`50.23580853427046 THRSub[2,2])/(1+1.3867516950654338202901137258102514079533931801464640422056886450433492856135`50. z),((217.6871308809078511999906057201629574613714306822650599493098`50.+ 634.7781417532692963242782571376719679717737068860897836209108`48.82388417365736 w+1736.0286986173584993584160022364212901490546865382941010838686`48.82388417365736 w^2+1879.5702049042849990396150239644202296727033827604278356029783`48.82388417365736 w^3-962.0045417535015735734580850078424650249266913730862775271823`48.82388417365736 w^4)/(1+2.56511828589787014161689470068150985290480119845098352114086929989214982613679`49.52287874528033 w+1.32328227486879753675499246297955058093067939764649750745916287939325923793305`48.82388417365736 w^2-0.1823502782433332143704397591074494395619928713044247716142813076039813002705`48.82388417365736 w^3)+511.9452138042599365873299077162370261194750417342824393890778`50.05298366055805 THRSub[2,1]-109.80445464139903711867895674922132708235711964908200302056905320577558698300294`50.05298366055805 THRSub[2,2])/(1+7.70692659314882253426351369851380914679394004935399069249758697801747113836392`50. z),((166.3096783527342277901376143672751121602918797933036204406614`50.+ 492.4517711449558233473655564649583341655761320789731667425069`48.860203125419694 w+1299.634171706564459092325937393119682840136868848733820197344`48.860203125419694 w^2+1402.2110757613602613895609667870354176091824763238159655111202`48.860203125419694 w^3-720.153835355439861028295591050656590358289705461363849911852`48.860203125419694 w^4)/(1+2.57819556863718451750548352701533272381717106653905696833363650756921206509475`49.52287874528033 w+1.31104269966712616361484908212485876274967562112785222542318012548829223013721`48.860203125419694 w^2-0.19731611005641431890340175733189489414171860865543783110329404942304725940398`48.860203125419694 w^3)+386.7223916740935309412705523100679250702121757258498082076537`50.07162488918173 THRSub[2,1]-82.94606565386745448284247453452904487492701478611871880999503136163707455379974`50.07162488918173 THRSub[2,2])/(1+5.57719495258471215477292822261976163270483105997732087864187047171684627882359`50. z),((46.75651030666412535131659734948571472909563601546938753917706940084268322724569`50.+ 194.4945639557680874968613297507779448212490614297421083647338`49.219932007631535 w+313.8479680593961584967520672701834767773608174602692073841504`49.219932007631535 w^2+360.4640677728166883274313029672098075804655383924874696624407`49.219932007631535 w^3-210.9724966383347685296102815358148115802993427984403476145248`49.219932007631535 w^4)/(1+3.43058048645686508798593265942470619463978994723483347741025246259605945338913`49.52287874528033 w+1.24153240034694354237968659656299953387377559846999544155508664645767386318865`49.219932007631535 w^2-0.5948067670382628593576857167960269773381578928460897460294433735100317716287`49.219932007631535 w^3)+95.33415888615084209844718953831151735085052599691386976127061307620765208492719`50.41651929563811 THRSub[2,1]-20.44772573885751420488006636405201274074687017947093557665664537779883586976175`50.4165192956381 THRSub[2,2])/(1+0.62139912799082181816002416053948380051571060638345603991346725784750828860492`50. z),((46.26401004362101061442657541499355402290094395984339709208103281908816962762864`50.+ 195.1846982317475127721427868140188663706723725867879828899118`49.220192836793615 w+311.7249895591471528100306803127668546709777881880801305630445`49.220192836793615 w^2+359.9622669478099733289720827782688767567355347880321935640645`49.220192836793615 w^3-211.5872799288098859780143180339289498621965134457741284668028`49.220192836793615 w^4)/(1+3.48465172605237908834082600655682486643677788818789960721069830017642813216252`49.52287874528033 w+1.24752183055099428851743722259447707524168711920515150313757305925848016957957`49.220192836793615 w^2-0.61246033240181726684255853257056034807842117604796738304790389046738527819536`49.220192836793615 w^3)+94.13378265487917334154978473241538068964368115209029077911758107672233507653544`50.42552422338873 THRSub[2,1]-20.19026331146254067886044938769648262322161564536604906751269139093714737129843`50.42552422338873 THRSub[2,2])/(1+0.60098368616614412165735719552671176396020974275928097299173916773461322467123`50. z),((42.90516969799697077582874281691338270130017795161811721559887952566479211313525`50.+ 208.9165516617160317906047754495892993907709318017307998268959`50. w+306.8055188572892839533665843380955260012631804094270371061509`50. w^2+374.0502077196004669635623584104199345926841728215019543872328`50. w^3-227.9436548354323563120950163912625490168074322487705029665792`50. w^4)/(1+4.09686931152938713541753249734376864410576488135158043323425332030142916232704`50. w+1.33498307835254827862849254708712183837676893244299936833162146516346717034451`50. w^2-0.80056283772010689052065061683980326831884830638169061198099534664262889478535`50. w^3)+85.94724466074524161184186651268735029900165315579379097131927056735165703538981`50.500465653096356 THRSub[2,1]-18.43437554142731431833221935581382584822304695774884957668475026923836402784016`50.500465653096356 THRSub[2,2])/(1+0.46175084748547741620662183378449653408260573315985175334752240936394397186676`50. z),((238.8479128486575048460466827785472937386158704638987103227589`50.+ 693.5050012389557104164845186901105479911233021265140822547445`48.813531681688595 w+1915.8232391468761190007879131133768144931486056312727972277399`48.813531681688595 w^2+2076.4379363811426485457311328701153881555019818267596831232829`48.813531681688595 w^3-1061.859455656610274965832329525582394691279290895805479248071`48.813531681688595 w^4)/(1+2.56181605437291194630306868353575763028354125075108623737749950212572118740902`49.52287874528033 w+1.32672425656069806254061938395246046498107953975361949013577703227724226228501`48.813531681688595 w^2-0.17828234192261609043582922016923222317933604079759084410686929215934516169095`48.813531681688595 w^3)+563.520617139598168036282255149730830869911583112632466883087`50.047856583422146 THRSub[2,1]-120.86659348642066712238396475359593952799259763685094764848031361032338136507519`50.047856583422146 THRSub[2,2])/(1+8.58409711597849848479384872363257540041826213120995835057718080697352505986259`50. z),((213.0494001196347984528424161305589488646096317772902743072521`50.+ 621.9132670941086073945880216693803511268153770163150129970206`48.826431341296185 w+1696.6268929420415497701931719093915178556833709701844715151251`48.826431341296185 w^2+1836.438225361612243055329505145710573783259782842066838259247`48.826431341296185 w^3-940.1338373103491914923843864306449865687520293650428059959951`48.826431341296185 w^4)/(1+2.5659581777337839726990285439328307511343024158897747477417870667663341720705`49.52287874528033 w+1.32243178812750232103122477799349437017370821187510146608412417487133097821834`48.826431341296185 w^2-0.18336438356697820731094777862636501474892746199215755516831514772547280534743`48.826431341296185 w^3)+500.6416223331173455486826123563997212526754770995163754099817`50.054257836853154 THRSub[2,1]-107.38000635374975886547325740550224551536331348287977062127953078668743232684133`50.05425783685316 THRSub[2,2])/(1+7.51468035561331167808743732934412947981114363089617592674450027411784734803601`50. z),((209.7527155566413784563490063879299736804396746365741571180825`50.+ 612.7699570548045119951284520957106122843535494667149348472489`48.8283114347881 w+1668.6193238395814998266364592411392985069591048365802721290919`48.8283114347881 w^2+1805.7820675838336231490071714936592205241144255101718870070034`48.8283114347881 w^3-924.5908583968524627967578693265676003366678388701847451782904`48.8283114347881 w^4)/(1+2.56658521615460546472249724713272129061987099435432272527290751721016507170736`49.52287874528033 w+1.3218031643040020967207734981072529632899663798400743372623846660392404920965`48.8283114347881 w^2-0.18411628138187738493337385595992961935055558477970905278984913988217342687628`48.8283114347881 w^3)+492.6065773019411877445121790817635556158141393024755892856608`50.05520153623847 THRSub[2,1]-105.6566115179798544980401907421294373241570953639801828862939950086362290899947`50.05520153623847 THRSub[2,2])/(1+7.3780240389359472241845117621617027492245876144235843006106460002637023435873`50. z),((38.29244975666034893437687282152516895028162928962186803253007191639807633695415`50.+ 124.1381377957018267201156434165878996613115327954046494872847`49.16210650389802 w+210.459457068237964928650810410236766041143793320856872802882`49.16210650389802 w^2+178.6935303975413913535578221707621777469789526457096191796381`49.16210650389802 w^3)/(1+2.4062121023431367096825507497884840885758602961003754957395447628808105142429`49.52287874528033 w+1.2991101014021723226435159089891766514545068614840575039075240301830129001619`49.16210650389802 w^2+0.09120905853608167016451728721869535870778825141210196873982489005202964549936`49.16210650389802 w^3+0.29253886635563314899664348653921200026445600362470512404142534364575884223798`49.16210650389802 w^4)+74.70461233222483230213627299979527424041478109011647433000036672191616161052658`50.671755119709076 THRSub[2,1]-16.02300206184450075557815384906074687535226708372554625577161071668778334560356`50.671755119709076 THRSub[2,2])/(1+0.27054137475542006379209499443283433279043177171679625300748946410440698715891`50. z),((35.95502732447908305075814169632618214004139977806382970467099585711064503842574`50.+ 132.8675127304433715743074315202419429892152023537897216010518`49.233454452465445 w+209.728799381311984878259299878060172944044025088610349107781`49.233454452465445 w^2+191.0551743030106575912660521337377332238264379789614386347163`49.233454452465445 w^3)/(1+2.82150988438969096922589437723552390397774157507795662736284912820243732456931`49.52287874528033 w+1.46240722377103749968451913980664497337932985002648437419637802623047012025558`49.233454452465445 w^2+0.06633807615275842249340643434473231950826290126512346071056668075210261682365`49.233454452465445 w^3+0.33826385072873672891310218114394954083996509376768795778644132632042155850777`49.233454452465445 w^4)+69.00758729371032502949648144832011859634534142326781965128591068747078839615313`50.82986591018639 THRSub[2,1]-14.8010769210975837996735935889667782836020835000293884499805265307387429302684`50.82986591018639 THRSub[2,2])/(1+0.17364901699496178447186104495082967508805293452725752637247086258341262917945`50. z),((34.38282521229718522392839767979561186090281501039391669631133971039301171229308`50.+ 162.7435647317294641935695556384024267858186166357180875436157`49.359273357414104 w+243.4686028387228173141280609593005601640633504444255436371669`49.359273357414104 w^2+244.8723464074485669873992816277574925074119762275240894991455`49.359273357414104 w^3)/(1+3.8307648209060025008679036795376950987788186969768711235178079444782391928959`49.52287874528033 w+1.92942351814884966652095981608854649776420793956545859968539032821139983350447`49.359273357414104 w^2+0.02196060171737038720029067041669358166981007636526449955167537662330750768228`49.359273357414104 w^3+0.46474539542188360670661943162752851823213143787627465174334389184497619894899`49.359273357414104 w^4)+65.17564203837743481793477984919651128759846380416827118911408292587380655803982`51.00938876540621 THRSub[2,1]-13.97918300035784979534599990727726166715814195059860024689467990400255257681092`51.00938876540622 THRSub[2,2])/(1+0.10847707056886401538357501044797686201233742735143355815229322008195887820149`50. z),((37.80191576057911717845208144655997308582129558341321932952806605731000616352024`50.+ 124.895277727958953038169886252510708474270067051587228723755`49.17232064146677 w+208.7966737755791873197845713871300100047467441297404751012133`49.17232064146677 w^2+179.2709784081958475975616320674641511551386104853709867904008`49.17232064146677 w^3)/(1+2.4606759709400107968521937707805973705821710024416488487958677527066714172897`49.52287874528033 w+1.31828864187616948000085444327094040157103402665753982907011389324706977173351`49.17232064146677 w^2+0.08711054096920676068116276576538932724201920459427554231658785035559379643191`49.17232064146677 w^3+0.29798127125264421570933741402267105569194518236521023517404522830761800483213`49.17232064146677 w^4)+73.50902850473949911401202189356491287170523419314505033127413022590805659551493`50.69868185975339 THRSub[2,1]-15.76656753210339835983128829792835137693055647580615114140406872031082809219987`50.69868185975339 THRSub[2,2])/(1+0.25020743991009720593580892938634560069914181799168684467824041674436167063062`50. z),((35.43475033775034678724750878787701916769100223755109890639969825025112233526632`50.+ 138.2122005222544686755985841505548168249570358715309773543498`49.2613357274154 w+214.3874888022040056786577702868839704047776348105338249997772`49.2613357274154 w^2+200.2293254878718589313606479252232305665999851329550686465555`49.2613357274154 w^3)/(1+3.01740186369212921105601034871772131349758232482936468945655996997005978597481`49.52287874528033 w+1.54823694905905831507657559915053145646288894849606876276285331807183645242545`49.2613357274154 w^2+0.05710428452528175851366212704417745385690517385789016289433912285606806062274`49.2613357274154 w^3+0.3618336166175251442724313856826823164370947561413690881233678141363587594174`49.2613357274154 w^4)+67.73951055261801080556623326501908608553196152330250769705064809948419290843349`50.87940518862445 THRSub[2,1]-14.52909376500088059286161591939401852416069357535052724984683179623126168002573`50.87940518862445 THRSub[2,2])/(1+0.15208215632031220438111223232141180483337424630150221982568051541297032070041`50. z),((40.1374800788908781992577524971250779889865188299038981292495672615899091380453`50.+ 123.4558890587203413095867193639895139360958384539659906046458`49.13584026747428 w+219.7039177988325377319570567715252154774223889042256089447553`49.13584026747428 w^2+180.5336049636630381494243813829844542478746452808507736571992`49.13584026747428 w^3)/(1+2.2672325875759318764125530896298890494318575461039221644840565301949794411789`49.52287874528033 w+1.25535733347058785928331224792634839253161102032092008844563532725018648575315`49.13584026747428 w^2+0.10428422491333230299724309099274765077868275794093759557713140327689956787469`49.13584026747428 w^3+0.28015642013018352916443642728982298726641871063262688659684965667739363869514`49.13584026747428 w^4)+79.20152474217242278863908385770874498724361664264624462593318227413611053256205`50.58901696134549 THRSub[2,1]-16.98752131396359506809181825193325894984593395625233675765938441069562493384728`50.58901696134549 THRSub[2,2])/(1+0.34702277392366018170341437050241424223050280408152788956079591865977579634112`50. z),((34.65639931090329933011308121315136762326296831770850497709552213694988258154537`50.+ 153.289638850189952286082516443404450686529866197183012196955`49.322145706062315 w+231.4901680196700907339674033669087311735613415254965629272948`49.322145706062315 w^2+227.4077831045018922150855394436222591937068705444263765198227`49.322145706062315 w^3)/(1+3.52578181986844069833822256743217947411479322673930208607736570700957321597144`49.52287874528033 w+1.78334235359289099517027148395916949481212824072756691807922654357501183476425`49.322145706062315 w^2+0.03491443370642718144915314624172316260161508500460579487103660184356186060013`49.322145706062315 w^3+0.42553382545488017266586456368124841816536690370101501980602701506829540026741`49.322145706062315 w^4)+65.84242715526092138522812813325377076445423526275520872835548366292934736236035`50.970627182941946 THRSub[2,1]-14.12219825696768416615799604985716912504288481160872233458956113717599407787148`50.970627182941946 THRSub[2,2])/(1+0.11981744236952399815589754381065114198785972291206680843985013610953065404963`50. z),((34.38732710260821120338214820994402496504056630465152357281647996971111726430534`50.+ 162.5581617971513906792649913374819790046055227920003245907795`49.35843471386928 w+243.2285627319753515489151636026353492198949692205550595252233`49.35843471386928 w^2+244.5280748601619046598192246066054236473994038728979753469925`49.35843471386928 w^3)/(1+3.82483930968594912031991768820506353886891961184264482771786974813282263961657`49.52287874528033 w+1.92656111458897449173477294213692526926819894116536237109850537796052880973319`49.35843471386928 w^2+0.02221173649596816078245044816603615967115947977965448614704717953516192163721`49.35843471386928 w^3+0.46397885141387822529777567562355489851217707452876220069800813154130065850353`49.35843471386928 w^4)+65.1866145444462787429827529187766819202154438706083793709263662758211350594346`51.00871539033445 THRSub[2,1]-13.98153643586706330670476815968793306695017672298536054345751033700969123920922`51.00871539033445 THRSub[2,2])/(1+0.10866368585954008390671543807163351649185898902879125198896283546159089214513`50. z),((35.74680603006804200785934457831922782173188449800022556468432473951638629858336`50.+ 134.7254459377218938560793495731049408476980079379529284651385`49.24379409231674 w+211.1925764328075621012868002457048745476935167888535520153381`49.24379409231674 w^2+194.1940738259276835449698109326036456762988445055652617724156`49.24379409231674 w^3)/(1+2.89136089588059034929550370295253399490098048412409787918500764668376806922888`49.52287874528033 w+1.49257958347628975596607581547008127158156743271440807056165542309517384619601`49.24379409231674 w^2+0.06296110156501069638149045143025024527373698803250098707736174479703078115587`49.24379409231674 w^3+0.34657702263701986249606687386125584380072459291260508669585808729583332932175`49.24379409231674 w^4)+68.50008727510880541508015837247725773223654834620724960959809750362978348647583`50.84880201151507 THRSub[2,1]-14.69222589315468709117525386216558011759611863336510927577523596376900961479688`50.848802011515076 THRSub[2,2])/(1+0.16501769221872393239006426949368437037137048600510179449893500723484191550133`50. z),((35.43283952658141450522007281846640136944594904608882185420190382622928549038447`50.+ 138.2366798761571019541874021600465546768169084974717342863593`49.26145177283319 w+214.4115193160095895096129547032310716856439251577427075958022`49.26145177283319 w^2+200.2722168900622417450182193879925438546649083816183706661721`49.26145177283319 w^3)/(1+3.01826879447505623128459990332690149439394499989460909388682464579596626803313`49.52287874528033 w+1.54862451830161476910041440991487616226192917791604579619603885871891373477879`49.26145177283319 w^2+0.05706482002059451958231417121642537689409781265232907244297532789869429804384`49.26145177283319 w^3+0.36193954174190962033165182995706074345580717595076638774419947135932437039117`49.26145177283319 w^4)+67.73485331183713847336536427444555074399406948613308983356734837249252819565612`50.879601579243165 THRSub[2,1]-14.52809485775399519468822246767940058176372520120254786927744431340896752725436`50.879601579243165 THRSub[2,2])/(1+0.15200294813062263593165310686238523238358800940402201203909480411792388855998`50. z),((35.84433134155704234970104266391040539468080567554704047497119394557352356789281`50.+ 133.8150194440672664534093741521645135627899550413246260152418`49.23882827798244 w+210.4497239932427033122398848415846594260515268247283724970756`49.23882827798244 w^2+192.6477358974462135551870131623791744217571597519870812387131`49.23882827798244 w^3)/(1+2.85742143023320620034160576882151810815248473504101091347562528376518466388041`49.52287874528033 w+1.47785280536554119066300860194429104027951599957879519238579617088065443594323`49.23882827798244 w^2+0.06458775254150441127523560633856741089573042987634665922551448652254336160984`49.23882827798244 w^3+0.34252358114199063573243093755514918578905319552384123754438639148415125369823`49.23882827798244 w^4)+68.73778677426321187084070247346238662397525114596556403794745216731545055790273`50.83979511253938 THRSub[2,1]-14.74320881704849791056115031156041393999280573206786951027679676956580400250966`50.83979511253938 THRSub[2,2])/(1+0.16906037497961203907060300459902914377139189410674855579943270401275452428233`50. z),((34.55974825774624133452314017704861154417220535469879245576679132850128399339993`50.+ 156.2523831453619122312463800608091450407414717526885411554288`49.333094703423214 w+235.1793947384046730738717335928918711063846576614531298838849`49.333094703423214 w^2+232.8587378096954530379408149136913734319857641362101587721556`49.333094703423214 w^3)/(1+3.62206228379621246655459909850560738600590867091070236752802051056593925593039`49.52287874528033 w+1.82916003400546070527376376390657836949380973792852450223485921354723062122617`49.333094703423214 w^2+0.03081571053899207709801786637299401588065569919813978068143950870350293529625`49.333094703423214 w^3+0.43785432690633282367051050646816837240549424850068041430652066905476908240692`49.333094703423214 w^4)+65.60685849541849909098860228115535084162161358329756845253397720544731229530631`50.983840827062856 THRSub[2,1]-14.07167236566695533695586956474902478009760247863105501727998394694100869217578`50.983840827062856 THRSub[2,2])/(1+0.11581099993469221733871386682924684922877235542594256316274504536453449729603`50. z),((35.20953845185151918723575053701191853241901345426006400908064814592249699797679`50.+ 141.4205695038294652411208484365209695812267109903435716735466`49.275863005691214 w+217.68187847580456851796482373567563579454449477433922819009`49.275863005691214 w^2+205.8982853775932827391848319637065565846819735714748260467497`49.275863005691214 w^3)/(1+3.12940692560673402977125077899924814567236466391643966057322787314118911047886`49.52287874528033 w+1.59877332119419361383638591195076738773736207180316336774555067864263259850378`49.275863005691214 w^2+0.05207454452415513821571391133144752383337606976168901962509805018751003291269`49.275863005691214 w^3+0.37561392066713421906490278344115480636508848977983159961083751864867409660123`49.275863005691214 w^4)+67.19059918115514199173783962179410705911796531105302427843205553105083083687089`50.90338436073671 THRSub[2,1]-14.41136063230479525089466078251917794927858453687372754386852801934249918109325`50.903384360736716 THRSub[2,2])/(1+0.14274652647438263398255110528345925214064329528004242563035025420069974261765`50. z),((36.2734901834891782375809803745473680167535094836638170214122959656141406865565`50.+ 130.5715266222747040483673428184891637360150451548275321344819`49.21938702408124 w+208.2658009804909349785843332941186006424763242555845918098859`49.21938702408124 w^2+187.2867427421190980792264075353468227109396331091865533004953`49.21938702408124 w^3)/(1+2.73126967044926825398541089099701826210976672881623184324590789772509674578637`49.52287874528033 w+1.42429185030486366808435069386608906498697716390857402207398448278218304185775`49.21938702408124 w^2+0.07089986733702221064859018724762908775057746136025729016567785735571553817227`49.21938702408124 w^3+0.32771104251647984120950178164954139758951908792498791870933249397067499024866`49.21938702408124 w^4)+69.78378027305310662767536353590179259172416232819893230028046040172379054083054`50.80290244417538 THRSub[2,1]-14.96755849860834446543697343531957765779928231532968629928511475895456005780378`50.80290244417538 THRSub[2,2])/(1+0.18685014694211872728295935689724790203656446900116360034082161384649916959597`50. z),((38.17467985945253100181498150342386373193564775095586664864459376534128125156507`50.+ 124.2896710392508398592209167914752842136808632092089240433086`49.16439952592134 w+210.0182147109728142122401572756816937323383157432818438251842`49.16439952592134 w^2+178.7758406354336690129072391689107444225673772543735417749937`49.16439952592134 w^3)/(1+2.41836810933030121023321368495820256752084831413781100311798013060460366636303`49.52287874528033 w+1.30330737611969662655239127206288936172760667767813372204437190032440540237589`49.16439952592134 w^2+0.09025654731769252232007148227900641272115307467915025024613884775301083841893`49.16439952592134 w^3+0.29373105547519071521037866151687426240427247132569566828318020036901977681782`49.16439952592134 w^4)+74.41757048478688163150175750567973312229493696435016323618371421335764268121075`50.67799153205422 THRSub[2,1]-15.96143595541883390599362714117632967760014468992683590847374237543176609025831`50.67799153205422 THRSub[2,2])/(1+0.26565950023562107933509136787220847739067947079050899435906402936868634528316`50. z),((35.76715734800116053166623780166933960497035943677421126044017338681818080559886`50.+ 134.5292269540267226454904991406844447177275901214640711791124`49.24273916989 w+211.0286805496145786994706073313747550610329920667167508252268`49.24273916989 w^2+193.8595798044725155237113295433621323168691532240442611395595`49.24273916989 w^3)/(1+2.88408893442320894946749012369257933633437678202626524391126085693096261823505`49.52287874528033 w+1.48941405007138785747006652538029842906353720678670977880590223242094441495033`49.24273916989 w^2+0.0633075540100057202718419712969076240819621344346388849975251840725972993351`49.24273916989 w^3+0.34570636882829674016206534919249091122840447973051559286203984279721502458241`49.24273916989 w^4)+68.54968976297555756484347922176146515410891797419531281121915168189509539036325`50.84690180274915 THRSub[2,1]-14.70286487166684446206754074280691777690707168781776183598827830622322796513491`50.84690180274915 THRSub[2,2])/(1+0.16586130831093042300225842825184731494438365469510035353895589092026454028956`50. z),((35.23769089743872422355076317607505966955219023911018506503583765320174252399079`50.+ 140.9808855502517464805665914203918429615682434307169194539271`49.27394680220713 w+217.2148092754454325669621646415048060473361858925963485768431`49.27394680220713 w^2+205.1162726668103588274515600462385672592436065212504273791192`49.27394680220713 w^3)/(1+3.11423141369886512883182654584372555462067594748731530556437409516437320446427`49.52287874528033 w+1.59187450413574738577926602876461651655754808687255288154857571121100771886816`49.27394680220713 w^2+0.05274878967860303002454450245949699292856537655089526041254725904540804451517`49.27394680220713 w^3+0.3737362871581068821074246858824599161285258394087677212657122711495395890044`49.27394680220713 w^4)+67.25921544204045147060381050227246425710400169374605787831463340835838972582921`50.90029159721793 THRSub[2,1]-14.42607777566874142148184440531563773191718686013305086247459042674613545745257`50.900291597217944 THRSub[2,2])/(1+0.14391351999344533168721846248151182160372024341903839110970973543025580276887`50. z),((39.36595617541861786876567632288298662596357153853146518516375474493999845587434`50.+ 123.4254076488574537060101633274316846562829633855754673374114`49.14494865516273 w+215.4052035076598597246729046789227437184904115534003224701429`49.14494865516273 w^2+179.1825462099187861678829648033430349618911154423936771053309`49.14494865516273 w^3)/(1+2.31574242487246106790796281845920934619503373015626762034406170489081433120675`49.52287874528033 w+1.26963544722063761076966673644954257650732620265790702764963579780318788464914`49.14494865516273 w^2+0.0991750847602968325449792065403707433514423993736141219883155160798193778561`49.14494865516273 w^3+0.28417179948242952921742098211328324063252516381577527258283655783925968949227`49.14494865516273 w^4)+77.32108116664287270930370198793537624676069686403307226488423956892025866646855`50.62057215067623 THRSub[2,1]-16.58419479439212415568932668720314510178785091607787415033605048875100497204018`50.62057215067624 THRSub[2,2])/(1+0.31504106233966596494131157937197510897172766474741673514134392457888763844606`50. z),((34.459086556002899740908435836364010572642393412053936817345877292600649755622`50.+ 159.7547428612587553677468824338639737192729116748339842152967`49.346580111517184 w+239.6209758662899393118479551976411179046166891296129343050423`49.346580111517184 w^2+239.3300813640237137316749815624680721411393318622485806229556`49.346580111517184 w^3)/(1+3.73500401157971778118054817990957741006495210144098201902276542800223438660965`49.52287874528033 w+1.88327202086219830824584179944017270850588335175255038458738073819340726478445`49.346580111517184 w^2+0.02602051759661600785287914392257854634806166775898927934821669719011948938482`49.346580111517184 w^3+0.45237822152015503857621800973780602068007661648445147921929458912293628068682`49.346580111517184 w^4)+65.36151463828945789285051792432275546419520736102460304388826135514303844198981`50.99815026767302 THRSub[2,1]-14.01904984336328550348172967151695350940963493833620312830829940020755042174868`50.99815026767302 THRSub[2,2])/(1+0.11163830548125932009873371107555639598223025777355089621604237439348654436506`50. z),((35.11406235590855461922458780997511870885170647344338388404278602835376757571344`50.+ 143.0057813939922808862275684939632452149628755636937824436612`49.28260226403372 w+219.4005869036761684254597758415813417493821037615518695344833`49.28260226403372 w^2+208.7291868967028006563170015760711645717090159530597878606287`49.28260226403372 w^3)/(1+3.18373326610531330216337278140144151859186837468023726732200779385435920903273`49.52287874528033 w+1.6235906566006573465496593254128367157210602515652247774953468295550590876527`49.28260226403372 w^2+0.04967594019629655740340945637572624755103613951459097600975975454623695057116`49.28260226403372 w^3+0.38236000624862365787569421122681954426661280739348143361996839112161363763919`49.28260226403372 w^4)+66.95789425727063421869786444303345020632694136604434973655988940758901249394663`50.91408879629958 THRSub[2,1]-14.36144896877027422815298093631526545980448422748377565040445887003308696414229`50.91408879629958 THRSub[2,2])/(1+0.13878878913161028591495102282389453172610787883017817284998472096008202142312`50. z)} /. {w->w[z+10^(-10)*I],pi1->pi1full[z]};
(* and 20 each of [5/2], [4/3] and [3/4] Pades for the Ls part *)
Ftri3LoopLsPade61[z_] = {(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 42.6964048183040407235293756110407098748154913553717325177458`49.180692545145774 w+41.6204161082153685345636057109623442576573725099787315212729`49.180692545145774 w^2-55.7897219328602260464400206224905690806940892716361227188962`49.180692545145774 w^3+15.33342982789052915881397340552753373598358386782246078446654628291535312022597`49.180692545145774 w^4-6.91945446258408942658587442390953246368149493865980813979098184695115870577606`49.180692545145774 w^5)/((1+1.29065874170472313069108238858918958590362522313110771911420332147143151070502`49.52287874528033 w-0.89669878650715645819417860522299058259539577165277440825535396045731503852073`49.180692545145774 w^2) (1+2.01781284116151370119250063115302498783881778163416924324721643401659800231081`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 158.8384913058027039058794517481550260967032046580101738874863`48.80480285129453 w+201.7969665830462740938481093738277345668417427777089240775271`48.80480285129453 w^2-167.6567031145910723566063323830809369315367500397661395964804`48.80480285129453 w^3+58.7541539239966568684696594968336882061380767968888631023179`48.80480285129453 w^4-44.6752173259076189509994617772984269910655917911715648781164`48.80480285129453 w^5)/((1+1.45748443267698323035289974643247869730248831835246657091790277273291657060288`49.52287874528033 w-0.37817120214805191067023929792033791011040907805601120009277848865578831902744`48.80480285129453 w^2) (1+9.60587852343660903132194180434934757128099558245474677066248797429232716619848`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 121.6848938228442312914547479593825300499491936962420638763505`48.86558935536638 w+150.4513645883446258135269905060332594709587775686809668318802`48.86558935536638 w^2-131.8582766929571445204788134975073990790586497835143302086836`48.86558935536638 w^3+45.3403463453416874610345374675199324680070601048071966584571`48.86558935536638 w^4-32.7778152426461807830436178269086526561299283337026489950358`48.86558935536638 w^5)/((1+1.43704424553780242841728702096077823071828211871405581526188970206943686280985`49.52287874528033 w-0.43412245231852461273429509718425572919612950058672496331512945914982106364105`48.86558935536638 w^2) (1+7.17024129031902281917940459083440798412568874801456748790426731040471377000543`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 107.0096573053498868913616429584189152888901138602224097476538`48.897893922989645 w+130.1826719390761816504500863265244088896029751398318154827468`48.897893922989645 w^2-117.7165620923649789224497385471116495891184083062515349328312`48.897893922989645 w^3+39.9931824865304336577044085306089028742477814664181818199922`48.897893922989645 w^4-28.0602721946187607190501635605941141128142231944812278702037`48.897893922989645 w^5)/((1+1.42520945062747639049852428088420024149938417133898971246213487529592327659825`49.52287874528033 w-0.46717630777013584952237708935326453461899500273846030690708099021344725113143`48.897893922989645 w^2) (1+6.2091333565104795140544387429435339934776269682585594173008302647653562582998`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 42.0011228064105866239207574475810231157595344654213645882353`49.186426653767946 w+40.6684397200950745981527346488073291907284541992802286822935`49.186426653767946 w^2-55.1244908168812546759076717389332374758401852174188541198955`49.186426653767946 w^3+15.03503982247402939700726757542552225492851399181329210840678548730657934328029`49.186426653767946 w^4-6.67849433407493492948330383562345999064846460760048154642832587007838163604855`49.186426653767946 w^5)/((1+1.28740055694624867904511687836200315628779771927521557239834954492302847775069`49.52287874528033 w-0.90904312765480437369502459064978920341948778071166252288360256948848339352452`49.186426653767946 w^2) (1+1.97295192671579591339977621694969618771355121227294854693734258636206306778431`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 161.4714308216549924408746921604741336472898547818527848550711`48.801325198250176 w+205.4367743839592872650752035392617169800292591736154577314752`48.801325198250176 w^2-170.193402103029285156633301630390630836317575687093268195341`48.801325198250176 w^3+59.7002939049123732523482609430206810804281227541342716008827`48.801325198250176 w^4-45.5166901590733062818770868986617856873244049094358204527587`48.801325198250176 w^5)/((1+1.45858438745837183611519497532725530875709563491722199435350456167686738977323`49.52287874528033 w-0.37519830817558881216322110597162738144522384061004881634286820958795338347294`48.801325198250176 w^2) (1+9.77857036424980638218032539647508384144858354247110561958915169067962789261666`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 83.7559027610885584263569845996697417375118242446384246680048`48.96477849017091 w+98.0917651341489700049854733363367816302153660935134249400777`48.96477849017091 w^2-95.3064685059369474332702923301943316896221352402853846574292`48.96477849017091 w^3+31.4123634580203994357550969465234870992288354259472240670796`48.96477849017091 w^4-20.5446150881606587674450899489592904086007896701739442198641`48.96477849017091 w^5)/((1+1.39844062918850190497536313223836675871833341660295111365954818981926914064608`49.52287874528033 w-0.54397299189826696252280702177731283249768630193059978622739977208057517241688`48.96477849017091 w^2) (1+4.68820665020342053554441205763241891919183413475085426020332934976816637482182`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 88.752620660747432088555581781713747785668373167704448371033`48.94834375996639 w+104.9837796626026668769284147155537922391307033436553274500258`48.94834375996639 w^2-100.1219706609429284195166512341773106157190078063086845040257`48.94834375996639 w^3+33.2715281179357007906424326359574046679618632148392112221108`48.94834375996639 w^4-22.165328426711934776461446634498855446336113982348138957902`48.94834375996639 w^5)/((1+1.40530795035206894809625861871059456704601975148187522700300307395951686515521`49.52287874528033 w-0.52398207512177824341524374571490999975981759864367671087244826262957813731657`48.94834375996639 w^2) (1+5.01474136076603142410570186950630397027348145838587111873213275825253751145867`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 26.7011358458451255628446804815029451029222873608681245692942`49.33666217374863 w+19.7325716835469232888879406831527664802200896498961025140509`49.33666217374863 w^2-40.812790096638340943287879868550311942051379953569393724062`49.33666217374863 w^3+7.76669787915841390703549753185720133652913637896646191860531894347462381562716`49.33666217374863 w^4-1.07775317946516903520738713533338771984731976785636525887618803527388464717699`49.33666217374863 w^5)/((1+1.19510747084125536496813656611320710253023847360133530395987260514365894507954`49.52287874528033 w-1.37552016123318430350684136989413855508657786818174341641708134060222970367844`49.33666217374863 w^2) (1+0.99091656579613804082643229724034263096655252777185506644271560976253642169669`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 33.1248025569943957128275662992691844145009183902503168466055`49.27086820066268 w+28.5307745376944568650930094874154302057331773573198353471163`49.27086820066268 w^2-46.6962336690005024123013876709128748986252259002429661355844`49.27086820066268 w^3+11.03067859759445329813397761005371888815208734159764690309623200878764225350833`49.27086820066268 w^4-3.5221919016825565215773315563151584625863786439918119214071849728769631440259`49.27086820066268 w^5)/((1+1.23836744221377859676392075635439980560103738286305402573675111667042784343416`49.52287874528033 w-1.11793251765907155831633969430462402122288432628231193014797222325750172524484`49.27086820066268 w^2) (1+1.40209427660514906754789480705154922749233951041584274461790923136050758683113`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 107.2925193717321701070122179559653208687576393296088002291084`48.897210906007736 w+130.5732514359018900019384168362651645468797313654031890096042`48.897210906007736 w^2-117.9891506341548789700708577434027996738391281443628489718275`48.897210906007736 w^3+40.0966361207142376542572186128988454920750644975856556408973`48.897210906007736 w^4-28.1513468885783334797746373917035728414014829939502702061203`48.897210906007736 w^5)/((1+1.42546689849118806442564220146107092033453301257613708030896089220736995260929`49.52287874528033 w-0.46645176821228420963926802557553561105216416888086032977794657621108592414704`48.897210906007736 w^2) (1+6.22765117408791326667379192687170793120539252601112234117513275724084916503089`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 32.7784602306322144061745354510970157729179574523058855665005`49.27465554488133 w+28.0574913780938494383688542642444416308138653559305742095518`49.27465554488133 w^2-46.3715504425201634272625117487325693295864122422278142743495`49.27465554488133 w^3+10.86482744944897489924638214535841906254903017742166102606473513680771914603646`49.27465554488133 w^4-3.39498686395981247459753007338533368890209567383087612266172844022720285959004`49.27465554488133 w^5)/((1+1.23616408633158013934162207530827433951723272054045994522140897134649859213522`49.52287874528033 w-1.12871707736031855059109480876962423934344277535981534200501265806843175306729`49.27465554488133 w^2) (1+1.37989269997526341358319737779812061025966550489065825056072652883512282652281`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 41.1913724899239495687921811906843698029441281558694576269741`49.193246854228384 w+39.559992136354711503188703049835101586850175100036108873003`49.193246854228384 w^2-54.3503116607221482175566374993654406619660691535948656257599`49.193246854228384 w^3+14.68528427364659833686511772954469643223824001727298555985076893130067036582261`49.193246854228384 w^4-6.39696090833198156698348041809621194062027358814083714118957477292631192428266`49.193246854228384 w^5)/((1+1.28350659771254627532845626980669305186661314944257891326390468774974678962975`49.52287874528033 w-0.92399131862120632786377181024630199912581979548876738354070935668488274847238`49.193246854228384 w^2) (1+1.92073014025867601435699110403691875166309073585543812194630968510667442816978`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 160.5520574588778004181405244264514407053954572994334562633497`48.80252947278604 w+204.1658083702805528201295197928665895204554153972253239990441`48.80252947278604 w^2-169.3076367695613768449529950004552666970000577508463616163904`48.80252947278604 w^3+59.3699700665264921827022432939234162093556104242270473007948`48.80252947278604 w^4-45.2228823096929482870208656046706707648122585474030244607078`48.80252947278604 w^5)/((1+1.45820431222283323617744007453745199806405703329475885365969596716811417654594`49.52287874528033 w-0.37622513324815808000020967582699495266663499413452109046729518878980270285113`48.80252947278604 w^2) (1+9.71826859280325505986835894206520447585870759184178199348261822779344611150918`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 126.0402624642055070334787359811033632163712980951975582610915`48.85708786415412 w+156.4684427635172128361711182947833304762942638454707735958872`48.85708786415412 w^2-136.0550995978635425033983310940251190399676391148656911163947`48.85708786415412 w^3+46.9205761525488053575919394834375393211815342868340787049699`48.85708786415412 w^4-34.1753964968415782875699124357431922969094777972790289756958`48.85708786415412 w^5)/((1+1.44004436861285611623028263450485465927513552516597283858710901984286376592672`49.52287874528033 w-0.42582287152899143055225969787242824482010968964265575674749142304064291300168`48.85708786415412 w^2) (1+7.45561036737691254816203811223296915799230707224537063712118428998909918825856`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 112.680606212628754022638624927791716770372705228866646266229`48.88468111598232 w+138.0139585355503186507185785196706497339288087532266351684272`48.88468111598232 w^2-123.1814688187148947815178601854746766647357664310061666471834`48.88468111598232 w^3+42.0641205983827425255449585606164801030283303437794901752755`48.88468111598232 w^4-29.8850025251687911466072838905635944515143749157243870794724`48.88468111598232 w^5)/((1+1.43013398307137763266497888658438037745817367495742616973026176739266838431803`49.52287874528033 w-0.45336020912961839006895145963033193661818565182138283988996195063187580147909`48.88468111598232 w^2) (1+6.58044631219884583987408668074735912980430420781238167227802623579737881024429`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 69.9510804889129999877902645013390133288392458469079365623634`49.01820658239178 w+79.0657745143815018861507659477914225571537380625444759303161`49.01820658239178 w^2-82.0034087953339361407214989424306270030192469060805663454462`49.01820658239178 w^3+26.2089751691460383420614352233370287613937668686832697046377`49.01820658239178 w^4-16.041640073337248374704706824985970531857925434563805897893`49.01820658239178 w^5)/((1+1.37478154726826358260809125003264538471590148561624312374931872490013198111083`49.52287874528033 w-0.61457886159114500994418412326421068686886478717285921485588065957232978361716`49.01820658239178 w^2) (1+3.78723528601501277345666447427891090007891506947143014715562017130767162603556`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 104.6898174032231412443843946696598296799386197857780178929436`48.90359599295201 w+126.9795707402698484042823839707856650054613221950639703469951`48.90359599295201 w^2-115.4809644795308575566685901897524494470073074863652355808683`48.90359599295201 w^3+39.1440571538028605107595682829486786979418305991085950989021`48.90359599295201 w^4-27.3130896287537652567522619564959474402137107069626422836639`48.90359599295201 w^5)/((1+1.42304785026951617818519052853042025202377644203427832004179424691593780897077`49.52287874528033 w-0.47326969499338373875398911794482547060487415047129239202881761049074213850848`48.90359599295201 w^2) (1+6.05727551485441693338974127155145511872562783000076107769539705023149212204754`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 85.3628593085450759523539482648955764058725480691628817619357`48.959347103222015 w+100.3079879921617514401070639019066538347494298761357090735281`48.959347103222015 w^2-96.8551397490083741734515676585796868113279928114287187852397`48.959347103222015 w^3+32.01142486927197936446819885481279752861577172114173347009`48.959347103222015 w^4-21.0662736675010904977129147601625539357801173911777022613201`48.959347103222015 w^5)/((1+1.40073133459234462900294918032400044291043155552404059926716629040112256546249`49.52287874528033 w-0.53728116868965702942896155851188377742700343155501653652063894067769790699326`48.959347103222015 w^2) (1+4.79320046237150115186578323164774416248867466878506743752131176905385470128686`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 31.1665959848475089310566822596041676350811174621456002737362`49.292858958808985 w+25.8543620263270119127599824927863557288195916202479453346953`49.292858958808985 w^2-44.8680637786339285601666228304860640597267238759814034229707`49.292858958808985 w^3+10.08004968127907336181898760101786005711544975077184299365120024809775986944123`49.292858958808985 w^4-2.79733053341331963064806566118871292858359243382618240274703825446481294910582`49.292858958808985 w^5)/((1+1.22564999825280187219796871186036331213830985690214597045449019240737639297536`49.52287874528033 w-1.18265731747272079993771437153960246126044513709759370930602425243841228651643`49.292858958808985 w^2) (1+1.27663232993610871558034664038684556972825344772400881318007752587940466444884`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 53.6325614997793722306093914516330029483459742263747317398568`48.8124565330022 w+70.8878094017107542231667697668746849121267502162402568821971`48.8124565330022 w^2-54.496263547609836264883177301083951264746105971153813013044`48.8124565330022 w^3-17.3331734371433611908966145283958198254039490139032569567784`48.8124565330022 w^4)/((1+1.63991486726300242198352671640267068974313672866284361667730914103722108645054`49.52287874528033 w-0.45410463098073047775710775677353577194994712395774332649138082927588940539166`48.8124565330022 w^2-0.59504848381307619592694158549102570648344683913418450233974255780299953697956`48.8124565330022 w^3) (1+2.64893246037981237153523000588090024225685483838282038747880775669421315869914`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 68.8735761432912545299377348375706653898710265422849777411818`48.66869320644519 w+96.8027921238773328116859245027444947155968834025366602468256`48.66869320644519 w^2-65.8976877640689115756454987006627674401526631251046559644779`48.66869320644519 w^3-26.0750699900550738802853282804779098394801594368536394786164`48.66869320644519 w^4)/((1+1.68613903139805974424262184466801088856365785009826536397426780260596389894131`49.52287874528033 w-0.33112665193253352795324947084207651461733732737881088658119757595916505967043`48.66869320644519 w^2-0.63378860922074049574972761852256906164019036410523379860510207545573421075384`48.66869320644519 w^3) (1+3.63861095797091622121830359953309776170300536709836712742657826961668177534389`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 49.0609907875999037933904263144951671271018082821657414348538`48.86598857022508 w+63.0393576055069188841568078898139499417559395463446690453556`48.86598857022508 w^2-51.1797756688367329930258001116113557331776061023488751672943`48.86598857022508 w^3-14.6019715656471999679419016601691824880686101173699154468414`48.86598857022508 w^4)/((1+1.61868720275758529726866758173789279538854636348566533246557823218963533513043`49.52287874528033 w-0.51002774583004648342995755836449674184515708860819292560989059637790770765577`48.86598857022508 w^2-0.5749568382279284407156106998107617694875843967167788114258990244093299938588`48.86598857022508 w^3) (1+2.35391721293233295975795437907818579328201707567800248933017016170559034237197`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 86.9928680687712288533603310364128510428335511873201301145561`48.53950528144673 w+127.392530670580862291705765333550123722479413490700562078319`48.53950528144673 w^2-79.7555828225783782045134400652737105430132836236520634551525`48.53950528144673 w^3-36.1530408400293981637866675803732823858623450187325637793876`48.53950528144673 w^4)/((1+1.71702602889036024506039739160712696177167056646845067362665992464257693106699`49.52287874528033 w-0.24837578774277769577296116783402665115584648265553142450709611095580870835065`48.53950528144673 w^2-0.65552785039948150084709783479064599733208405464465868574705697836256390602688`48.53950528144673 w^3) (1+4.8212076562571094822241032587076594067343067267307713200833747669886124237242`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 116.1791015174221580910984741469464955246166625957721378996933`48.38159660139478 w+176.4946874577690589484189086429218079508432269895383766301038`48.38159660139478 w^2-102.3166114305220924464137271662071446225970289457127743223602`48.38159660139478 w^3-52.1443873099357475332879696370971970392715723727668957229045`48.38159660139478 w^4)/((1+1.74467384750396665208559043148094333839407702817658572376648198236476690811942`49.52287874528033 w-0.17417192218464706750981404699301966570282519013218069206660671698371165316556`48.38159660139478 w^2-0.67201686337018828903524077493324636594117777176840446763223090534779816994006`48.38159660139478 w^3) (1+6.73163950479975432674257352424871480408270513083702904693243418941018732429457`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 88.1116272265798128401809517480389003864686751248108729395096`48.5325106233681 w+129.2774563433645466829503143841731664922739584364024541347457`48.5325106233681 w^2-80.6165287891858049617755453537565571441163538493108282687118`48.5325106233681 w^3-36.7698863815695716397438993230311958643530402673717138299472`48.5325106233681 w^4)/((1+1.71846345630038256949542303130136985532294161177154914197139773318128657963911`49.52287874528033 w-0.24451906153233626046362798319833873708725338712447913591412792858606216723865`48.5325106233681 w^2-0.65645497195135099052947356178418105166287119585099961414461706374955108498293`48.5325106233681 w^3) (1+4.89434342655991233820575258896391214387726353064156252810153353749211625659078`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 121.5994430508923215681038137501441446506783588151262681520846`48.35664214347398 w+185.6028996321366643957483499122881549991194479323217857345384`48.35664214347398 w^2-106.5217699274203754972703412865271927124792102572757078088242`48.35664214347398 w^3-55.0991185267184030049738163456216011885105598466303033668022`48.35664214347398 w^4)/((1+1.74823027457367638603941547252905146026941059156448480124934062073049502686802`49.52287874528033 w-0.16462832794366836910458011315985554488053227239099723866278618379797511279416`48.35664214347398 w^2-0.6739311868958562949631235659705258510747305518155336810245783791772865220125`48.35664214347398 w^3) (1+7.08683122869825004137855563207996399357412915586015349883017596065739907804328`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 56.910541391368242880283092669256276485818035338108252248383`48.7776029200617 w+76.4873236790156387215863092183510423070236743340287002979625`48.7776029200617 w^2-56.9128810368558078031909338989876920473715877190326017106199`48.7776029200617 w^3-19.2506726757322584293782551049597744339329994242364474967041`48.7776029200617 w^4)/((1+1.65247290566765805608108612605227396953325560074453325335045008935992221426866`49.52287874528033 w-0.42083766607398689673572617616233205827955476782104975815007271944522443132893`48.7776029200617 w^2-0.60627505907483993499884056951080929345286007858197762087720863795029607510999`48.7776029200617 w^3) (1+2.86113469548156697284341906557513782988048241967339540846752080193744196693954`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 103.4259045027980766676288329166118342409372420990208532121246`48.44504995281826 w+155.0539096808379557498318025810156445416336543006484448717289`48.44504995281826 w^2-92.4374968816037526198405916219317201514958076411298349318205`48.44504995281826 w^3-45.1776325751493493177877923134034912110158468496804897127539`48.44504995281826 w^4)/((1+1.73469893279430279479555111257679617394728911179596946424418459923452419169892`49.52287874528033 w-0.20094473982615979149675094269187618720333366023537017695163957969591687455001`48.44504995281826 w^2-0.66639571289756520787575572097501676184339040201170131540924269142899678562197`48.44504995281826 w^3) (1+5.89633196974274158441379305417174464955122850065660457107739341694502021533675`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 69.7363459354831067706454741558398486418116705312694543624629`48.66171794423987 w+98.2629944652219881847971489595579459811778548845257655865773`48.66171794423987 w^2-66.552495592970941398155818184920663697808251088073470666223`48.66171794423987 w^3-26.5601342783411680998450383835329590998717927534126223252652`48.66171794423987 w^4)/((1+1.68803692383004472952761112432746644980949012199100070540666641144942439116492`49.52287874528033 w-0.32605120305688100544666897521695992401090702286919955259725996358105965695799`48.66171794423987 w^2-0.63522319193811331242839934939423751167066316923022270432742533531863776834551`48.66171794423987 w^3) (1+3.69481479237917304180486397205927510692049471445994477525500416116361751797017`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 25.325727201890655777438435259275032011469353863089599627768`49.013447972050166 w+19.0080370830354339039355970647998237665005853350155382878546`49.013447972050166 w^2-38.439193217449713307568558810215903788182798999654585271751`49.013447972050166 w^3+4.3997724434990483967933771628871748431525215014496465590072502071007633958633`49.013447972050166 w^4)/((1+1.24402446843833256268730455234297615310200503589415910201187635535489255655162`49.52287874528033 w-1.39863512681353814037591725029143758273369205676734062905358463049332824633561`49.013447972050166 w^2-0.09339351619219602569841599310143865727951233509551847783104468808152620657238`49.013447972050166 w^3) (1+0.88833200402029773359623003060953381487049846763656706734042427532857686927843`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 101.7806309822383742562720446070488148756636633577860428454498`48.45379180508868 w+152.286500167811554146650302170185372391104607567556950152507`48.45379180508868 w^2-91.1649207546338256184065558187471855310409502605145842222552`48.45379180508868 w^3-44.2769603822359256733778047818215260317365964716573424161709`48.45379180508868 w^4)/((1+1.7332124250050251928296287385884134812816919297677252745376280978524620434924`49.52287874528033 w-0.20493484804072353470735453142721095728277197760901962708314156542409435282372`48.45379180508868 w^2-0.66552625922460331370352978485185867809808043282045321555384686563374140912698`48.45379180508868 w^3) (1+5.78861993475548199437818536455886094835658977666647591616609482900307328313798`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 146.6322859525933557063336753431591436961856273834588427278351`48.25331682080679 w+227.6450032788859394574095886909139131142327113597865783104706`48.25331682080679 w^2-125.9743246086952066700359744014027277528675448905024957634547`48.25331682080679 w^3-68.7139712100554570299077751538297203829213724262713219473739`48.25331682080679 w^4)/((1+1.76103364250305786880364978893889984533437423746814554055598147989255134712386`49.52287874528033 w-0.1302869946242402527924968882065274677658630776644085021804658633241182800035`48.25331682080679 w^2-0.68043178044351070201449303891436189261594761600925203234399358461250965563467`48.25331682080679 w^3) (1+8.72812371602473173086318139120476460832661391675628800015454899886510800729106`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 116.5173945982356747267557529753180423463226915530687195823621`48.380007042959875 w+177.0632145363585559251504118237066484354140205802194129817261`48.380007042959875 w^2-102.5789675664481540574814206432236783837638065048665586573719`48.380007042959875 w^3-52.3288908244510370318903690374952261557194773531281867322469`48.380007042959875 w^4)/((1+1.74490627204012586731529420767456785040490748977443578060457426882486767097319`49.52287874528033 w-0.17354817390467006312370813199079254825987445477669014010244964083882645740191`48.380007042959875 w^2-0.67214341370167264022475856692877296533313166715571528661842902669979274942439`48.380007042959875 w^3) (1+6.75380503171185795155496881710062927020667095058853557203867635072864253154849`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 119.5912983280532134953238178261025961270888974847283467784355`48.36576190647239 w+182.2287215217743811618165969109499849715540123648048991617181`48.36576190647239 w^2-104.9634626253112288680648396288542342318440440072477045182636`48.36576190647239 w^3-54.0048010990833707452479788253066303061499644957668653926455`48.36576190647239 w^4)/((1+1.74695321065606577881838706169872458616079756624884567072243562794799005552144`49.52287874528033 w-0.16805513373633839946401921612859460536832069268446779375101990458161585158008`48.36576190647239 w^2-0.67324921612791199854446839322283641436891199929799696066622067587361392118846`48.36576190647239 w^3) (1+6.9552285785787331847530100828432104076319017408489721268513528961980739120783`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 117.7770906484800430671160808868760883731805751086109193318217`48.37412655875547 w+179.1801466427520214327379198691543783477371353539893613238579`48.37412655875547 w^2-103.5560145891405817633912385604042222222028465209125691566077`48.37412655875547 w^3-53.0158092542005835728818722901258883130561660628965990128062`48.37412655875547 w^4)/((1+1.74575906557289228698385008514450147307813126908649134997854725332430917743222`49.52287874528033 w-0.17125961372272634634771143895513015511320295824228586673434994542576717020084`48.37412655875547 w^2-0.67260601383003164500196309808617339680518136188322826865176512241424094773931`48.37412655875547 w^3) (1+6.83634558845420879235493168133914888820056173568650328768553634921655696780804`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 55.5359908564061478952254981479130168703837139363151872756277`48.79189857110093 w+74.1416434878482611628998142625287855456180432358359644444652`48.79189857110093 w^2-55.8962863176610990071127995226284156137625802022831218862929`48.79189857110093 w^3-18.4500285887004189522653771665182223178147133581423103946819`48.79189857110093 w^4)/((1+1.64743616306775931347317602454467407033364004575990183265392802494356540759563`49.52287874528033 w-0.43419522358015418391961760504460460447650302761271507363043909612827156984592`48.79189857110093 w^2-0.60183303170722020377329688448601436561471695855719545046978203462166890337896`48.79189857110093 w^3) (1+2.77209494087855731641132103845503534819200023092947277487830734034706907478357`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 58.3605211399301565706790918835044248230445006533359546517658`48.76298530505651 w+78.9584794642315609790547191506925514449440292910749411303119`48.76298530505651 w^2-57.9897257307710697620016454122994238883345837696777261740903`48.76298530505651 w^3-20.0905519667630381265878759123740267464150346634398126851207`48.76298530505651 w^4)/((1+1.65746476398477637202156367766715943017433949127410935689845456154058943903859`49.52287874528033 w-0.4075806263328181980783424743189345620759033982280550779563922499614595571542`48.76298530505651 w^2-0.61059590934606549340544086266949303882433066304361927775909859052806192554435`48.76298530505651 w^3) (1+2.95514087496839851220548210780450650147231500789537907120326924388416761780675`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 75.1133596970117847966013619368730022199334433065759255572154`48.620347503064174 w+107.35336310995333619640356686500828757547680577224202186802`48.620347503064174 w^2-70.6473027241306907371178334416025229338831197255138377147522`48.620347503064174 w^3-29.5688752405280691788328930624014363991423845702861641527667`48.620347503064174 w^4)/((1+1.69872250294082419507508741799114905084127202280258010921337516574064089701322`49.52287874528033 w-0.29744871077170743476415333496246609242387722251317417537640332840860536352647`48.620347503064174 w^2-0.64306102191516556803994977174871308061277051776433877147020247610191683559091`48.620347503064174 w^3) (1+4.04537787828584388515232329301779520267054891062750358681149398580074653238318`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 106.1990135198972805824718107907879203803455920689281341369468`48.43062393634355 w+159.7175888885520015089162684651265928972136493659618967725789`48.43062393634355 w^2-94.5835345940841890484536810860187185545229976263143649515038`48.43062393634355 w^3-46.6946115509325543174352552439385393170031323385331165210656`48.43062393634355 w^4)/((1+1.73709047426276516196865380614295100702874175694197963551324725974201833776244`49.52287874528033 w-0.194525384346645428655646638280741220171773325943697416826909587644981525358`48.43062393634355 w^2-0.66777724080748251530823709471599884891361816939614823067083149377893764353666`48.43062393634355 w^3) (1+6.07790912929455179724523855499615320591353066586036951030421543049891756408545`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 153.3443151544132729802633155240035258115323036540554914975699`48.896889862589006 w+192.6825992104876288886368896005629140523026158610966574040093`48.896889862589006 w^2-192.2792662028618994396801386491087184120800301569471218522132`48.896889862589006 w^3)/((1+1.44955332956031093399064059412607441327342800142994368340272537301176488300281`49.52287874528033 w-0.57693520148415032624552025904766070207924732145763445567879565516148653977078`48.896889862589006 w^2-0.41590042949800895489430895771648655443613651267533325560158928071803335443807`48.896889862589006 w^3+0.14132214120151409052438732174595342756830788084638681328381075046989155308925`48.896889862589006 w^4) (1+9.24693001919749332197786990616782088632812847894389943558569585762243491430489`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 41.2392188710507067716201177177288524663534000287306507720637`48.993980982167315 w+43.4752968069154576537527960579382736305244333557377344364522`48.993980982167315 w^2-53.5918560639326045737293896364628905025014947550066756519583`48.993980982167315 w^3)/((1+1.39958703282082110676778014377657460916874239667826327868012153354105281740775`49.52287874528033 w-0.87249120864921647094525981822458716068645616560169323198086071539133527019789`48.993980982167315 w^2-0.35210323591506168444586707428580981348978884337237660079386590896353080878139`48.993980982167315 w^3+0.0619333796810097145473785118317049483487653946894291479837292378346365282511`48.993980982167315 w^4) (1+1.89485322440234318113549173221160415774400694124179432461143545440788157996828`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 47.8905754493848978948191330054996988011344050848103319695252`49.045160843089484 w+52.4108741951299848062157189038057744121374773467917312115898`49.045160843089484 w^2-61.6860172849838394219040696405858726036054170872812015200988`49.045160843089484 w^3)/((1+1.40833313106212082440725794119643495173587784896667758864392090520351562423672`49.52287874528033 w-0.80849197126615071927686746456128062538390848228033828966306521351810727059997`49.045160843089484 w^2-0.36899917645356856333488928236134521078874509929307827170699083868011273153887`49.045160843089484 w^3+0.07918946547636815032912880029493605310566348707439867009550290368093310491418`49.045160843089484 w^4) (1+2.32961713199535927441752839665180415978856647601432672318999774170531333245442`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 81.3533790229200656039297289206983364816169413394076476345094`48.95883947003062 w+97.0465825835794532836462825853513985317648720695902921891977`48.95883947003062 w^2-102.9263812691942408707565854220365763413707873905180254143213`48.95883947003062 w^3)/((1+1.43255172346403448467607531929918227276195198900679429804756430722795478153061`49.52287874528033 w-0.66316714601040165343327612841470480294295967150749419469319644666289446253909`48.95883947003062 w^2-0.40133298456710729943801961662761971109645036571264656827254199075924373745771`48.95883947003062 w^3+0.1182210180484261876009764384688531364177271589017301256802711027105545235004`48.95883947003062 w^4) (1+4.52184885003952691323350188597128330854184959276616419073697323806465367792767`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 72.3388771200185669949769639977089706583956266905969505870144`48.974702130167465 w+85.0483335805302603707637473159107002754331105692313696045519`48.974702130167465 w^2-91.7745702208374622685047995558433932391990651993498379866214`48.974702130167465 w^3)/((1+1.42810173317429203904817470902303633842051065396353250639730231143992926140994`49.52287874528033 w-0.68746086220889923951051961589024565252253056735146020527576468041247831863067`48.974702130167465 w^2-0.39657277897914549959887991224008819477727342875344677480311470751578484588478`48.974702130167465 w^3+0.11170916810909993677668897548591543414414513795905621886841658382384149383209`48.974702130167465 w^4) (1+3.93076779194690057222752167863590889863091918317444285381703754436170466301338`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 163.5601632740330271247356829308088057296660673488058076762869`48.89237281693049 w+206.2429878573224213435308616436625721339364664216165597289326`48.89237281693049 w^2-204.9760329822342398234971419096964153606001720007957865490986`48.89237281693049 w^3)/((1+1.45076079682007883641849230779542274205005386554007126022882717370461652013013`49.52287874528033 w-0.57113832772238594102995845424470779863719357846269542030476482609805098546379`48.89237281693049 w^2-0.41674304014536930703198092654582690779804852667048921600872423451896485553563`48.89237281693049 w^3+0.14287573076333330448277604387711968839160186274935374747211895566754701787717`48.89237281693049 w^4) (1+9.91774226243056439235814279279608613452232145271737953977443734083854075244607`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 52.7540400661867236568274474079798364767113068914827982455097`49.0263339239367 w+58.9222515589787821325857084716150615625530726999929797195364`49.0263339239367 w^2-67.6409212496105851029541793300181997036696466041918247236261`49.0263339239367 w^3)/((1+1.4135690898748435794279307628452479359498678095171534891789722243795347130406`49.52287874528033 w-0.77385546628471080899782014710901578866380033039701295680305057813280374197874`49.0263339239367 w^2-0.37750932485347492171325081169879673555164602383472834468300775428310447967668`49.0263339239367 w^3+0.08851120067982858452673606944560852903426509878624173286242274345056011816282`49.0263339239367 w^4) (1+2.6478058178485029057942932541762522938824566958041129503680749951573035059227`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 128.9210737120607219845810995264357556506354313860707738180378`48.91046679867311 w+160.2569271351436198500601023626221016462531869111635798827787`48.91046679867311 w^2-161.9352501456810689424064467335491152642632284739521339038387`48.91046679867311 w^3)/((1+1.44589416426021615615860817614977162659621389371396500245456888261319891815502`49.52287874528033 w-0.594739586202762286264972516739434776796650043919327248548528086054368224615`48.91046679867311 w^2-0.41320196838264436954088718345244347711698985808229183753477629865781969331709`48.91046679867311 w^3+0.13655171999235555692309131100662081853911910315786701810076983098179007053716`48.91046679867311 w^4) (1+7.64339829241176549117208279914284598848595864520226657261987903182505634846486`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 128.4564106713914248499272705828426663579195054207646209217519`48.91077304095957 w+159.6398981649899649512622207443821856440720437250578064808076`48.91077304095957 w^2-161.3581259706809964060222611521466001692945537935293857737723`48.91077304095957 w^3)/((1+1.44581113121034607383010910818507654771098165065790223723766008332258495342057`49.52287874528033 w-0.59514789936472869808515369387044903885629810215058365315100269186500596107846`48.91077304095957 w^2-0.41313814564517839373818185069326331815140211604149045717522315485023706873658`48.91077304095957 w^3+0.13644233536905706740151313533147572178042170448006393118483021725937787536614`48.91077304095957 w^4) (1+7.61289374143318429487913851144542265138651244547171789866616765033844006854299`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 153.6130039419155081042247561668102026593815492163809535871708`48.89676364551454 w+193.0392705479956965825603855794364630081651078395011830472329`48.89676364551454 w^2-192.6131788030877320859657620778835543118857787755146791460764`48.89676364551454 w^3)/((1+1.44958713835610881213768781155168619704022263697476665986536080381400549078115`49.52287874528033 w-0.57677237643827850999856311237924050411125911095185163363913061204447184706653`48.89676364551454 w^2-0.41592433988151676870607644020296617821242591325015632077493015591659675480344`48.89676364551454 w^3+0.14136577590029269123497233565270336589590226146557802868404295338374719218233`48.89676364551454 w^4) (1+9.2645726552286176927013487279811996311210517913051993502019897276381871251057`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 114.9156466882062429860901869838065953423177779959016343449525`48.92073474644159 w+141.6564378659411736433818554854818179720568466605356861512549`48.92073474644159 w^2-144.5442499482161887659390270395639390030182227839758242644179`48.92073474644159 w^3)/((1+1.44309889477595746772017436052340110434833666077698145284174400216817232647327`49.52287874528033 w-0.60859558923693971782942148516396635536395623692073217114845537558719887690148`48.92073474644159 w^2-0.41098817232304344393326500276808049816906408632702494141393757812678743634958`48.92073474644159 w^3+0.13284004415241537682849087968622847201245245421596970721671885452835500296123`48.92073474644159 w^4) (1+6.72403256077049212688447802032197553310005291320642767666794417533166471932304`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 91.5547949084133569767341987174866694541044868838908645381169`48.9444612489099 w+110.6138003502662122000052269816305366371603354622177279115497`48.9444612489099 w^2-115.5638304810262244273081642203085376110936489826158202776361`48.9444612489099 w^3)/((1+1.43655953335934268831719044509603372747366587203995770187158680110572057714851`49.52287874528033 w-0.64196951900524893896799751567560452363111373401802644222747398260149564541293`48.9444612489099 w^2-0.40525737788750549882718410903966807434006914187983965636599706036492484630025`48.9444612489099 w^3+0.12390044226046428580825784541004196688684877434821945182088702783446123177377`48.9444612489099 w^4) (1+5.19101290464190148535417367511400472772806644974764085896996438694998904323412`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 53.9007680157807248191045515854930903086538206166472589947429`49.02235467284405 w+60.4555895614161494111484954489260881312848105921300225066559`49.02235467284405 w^2-69.0481518699338065240593515735463363845754884102465314190664`49.02235467284405 w^3)/((1+1.41468366528751656353554319836023357521250889944271540299175679307249759412351`49.52287874528033 w-0.76676374575401526814625219834588520101358479526338466259501554951312046018431`49.02235467284405 w^2-0.37919320073387383751279394426705372926872720547175078045427371759531556676591`49.02235467284405 w^3+0.09041821815404734395063715812386305461601763095651120151232947658281641904993`49.02235467284405 w^4) (1+2.72285966703435663393157947082757365404842141256710406239370583968870623813092`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 131.968065501053768637441430773753320590857162076946849368792`48.908509897507514 w+164.3029205655650889242984572526727704396654134623975947485462`48.908509897507514 w^2-165.7198972868803943947919386977084797916742604113896821446196`48.908509897507514 w^3)/((1+1.44642424550042775799878842084339677760447563618973667134425143165235255951842`49.52287874528033 w-0.59213753014314824466096820501962460212487312362685984134316431483253962098588`48.908509897507514 w^2-0.41360666136562313120440395610267021269450487140224925731980178378392625690598`48.908509897507514 w^3+0.13724880951324128276267916571544443940093601498087410636775374416197938143992`48.908509897507514 w^4) (1+7.8434331159041755095130813965523454267338609192029383017875775242496559007146`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 143.9427266049443634776088984894974339062244513090495832143602`48.90159157263922 w+180.201775831806461653733674028800996009219629569880376814092`48.90159157263922 w^2-180.596518009300728791731753734861993211769388983250202014866`48.90159157263922 w^3)/((1+1.44829113231258530816799309649816346810772569438771571551604518562445226736143`49.52287874528033 w-0.58303559977812960026801753581098422807493100544472742985703500255407639261083`48.90159157263922 w^2-0.41499453525449943193380859798344607258382422710934894663710333000947182962203`48.90159157263922 w^3+0.13968744399417775142005057014398693275966887985578637498813422177231831645395`48.90159157263922 w^4) (1+8.62962296306986133044893504108169769453363674836824877469576146014894187838627`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 116.061870335614916494773749629496941363906561798808514816299`48.91980552194271 w+143.178952823164675677085874737414416219453587533761129058085`48.91980552194271 w^2-145.9671959451658876216479403443509983652176434870281095803643`48.91980552194271 w^3)/((1+1.44335279260750229677867818562326810724211845720495656859663577340220057054588`49.52287874528033 w-0.60732745574774662415362105123719700599358039117743524752547365047621356215305`48.91980552194271 w^2-0.41119487604282159413235835815452442088172522795549713522419039664942821591352`48.91980552194271 w^3+0.13317972773817495428437058440949438480380805745948746218551233371875109143241`48.91980552194271 w^4) (1+6.79926845001098593113921019405586363051017720297648952692867533825348036590511`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 115.8238784522943402005500548019570847171426223028386963686096`48.9199970134234 w+142.8628347980007882256842807047118177066023044663894109240867`48.9199970134234 w^2-145.6717419544443825999517250955284542072111747266620151299012`48.9199970134234 w^3)/((1+1.44330048496486947451415266107246226377642632705332683684375859649971775472091`49.52287874528033 w-0.60758855491728750461702766675918435719435034683165849756737296044534504886811`48.9199970134234 w^2-0.41115238436452466264849219832268483027264213052968814216656142205062396808251`48.9199970134234 w^3+0.13310978923215262516808951058384234128364291937818893217181398943880418837771`48.9199970134234 w^4) (1+6.78364702363781065752276308287342852334101296935578119651957524656165234585172`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 127.5183899781739803335927216957951710837399917137879741097249`48.91139777026265 w+158.3942785064894881404468553799519047712355921523916355668088`48.91139777026265 w^2-160.193104221589878519583464184908071852641511759354913030421`48.91139777026265 w^3)/((1+1.44564167948839876061360606961727870879567477769333435199635138508594404566834`49.52287874528033 w-0.59598178455580414019201220541901103054271968774320465522339674318594186788035`48.91139777026265 w^2-0.41300753441067237140511636392821445331468675791450932583559450507942348264618`48.91139777026265 w^3+0.13621894438218575800758830490763340153747536607144567297889781529684927215124`48.91139777026265 w^4) (1+7.55131430699902148342406032960250015879697694938592930009363274284398699016471`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 39.3631604314462448185979227746760749614186650031606202658984`48.95472804849969 w+40.9455933003590287128058289561855895223852572210029130171403`48.95472804849969 w^2-51.3242405878961672957563183597681080171845485325122744740779`48.95472804849969 w^3)/((1+1.39673719062478947778960721628444037529922036407709469878776794826807506747718`49.52287874528033 w-0.895558079632224139104403982790272344229956967260091677707850893006456096703`48.95472804849969 w^2-0.34566944793953163167478122272064565755588189360716930361141769049481791685388`48.95472804849969 w^3+0.05570518292405766545049168017471493031390677432345749712875212636724549470018`48.95472804849969 w^4) (1+1.77232096994083898927638712111036766114268222873417483973324825118754982816824`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 149.3507673746722243593183391706838374372853634926171519686913`48.89881738659819 w+187.3812374769745565266546291732026307660971583119894503347235`48.89881738659819 w^2-187.3164817100723135081215321921315169517671207830144083775649`48.89881738659819 w^3)/((1+1.44903652990756163255481072192013662302297804533439298548112841675700210325909`49.52287874528033 w-0.57942787117815022493104577414927776299053678340522991687921914609632784910734`48.89881738659819 w^2-0.41553264164505253854761428296206858880572936887550929812035247084798247994542`48.89881738659819 w^3+0.1406541640057729844012977052949376721130561773199764952414356079793729733445`48.89881738659819 w^4) (1+8.98470936496710811019445666487713602463364270918707002169611110694356662398805`50. z))} /. {w->w[z+10^(-10)*I],pi1->pi1full[z]};

(* Sample Pades for the nl^0-part of the 3-loop triangle form factor with LME to z^6 and THR to (1-z) *)
(* In order to obtain a suffiient number of Pade approximants we split the Ls part into the non-fermionic *)
(* (Nf0) part and the contribution involving a heavy quark loop (Nh1). *)
(* Mean and weighted standard deviation *)
Ftri3LoopNl061[z_] := Module[{const,lsNf0,lsNh1},
const = Ftri3LoopConstNl0Pade61[z];
lsNf0 = Ftri3LoopLsNf0Pade61[z];
lsNh1 = Ftri3LoopLsNh1Pade61[z];
{Mean[const] + (Mean[lsNf0] + Mean[lsNh1])*(Log[4*z]-I*Pi),
  Sqrt[(StandardDeviation[Re[const]]*80/Length[const])^2 + (StandardDeviation[Re[lsNf0*(Log[4*z]-I*Pi)]]*80/Length[lsNf0])^2 + (StandardDeviation[Re[lsNh1*(Log[4*z]-I*Pi)]]*80/Length[lsNh1])^2] + 
I*Sqrt[(StandardDeviation[Im[const]]*80/Length[const])^2 + (StandardDeviation[Im[lsNf0*(Log[4*z]-I*Pi)]]*80/Length[lsNf0])^2 + (StandardDeviation[Im[lsNh1*(Log[4*z]-I*Pi)]]*80/Length[lsNh1])^2]}
];
(* from 20 each of [5/2], [4/3] and [3/4] Pades for the non-logarithmic part *)
Ftri3LoopConstNl0Pade61[z_] = {((341.1264616952461260247362052717793680265183471307028570113362`50.+ 1179.8698718233146024175045433460426511961013197654328619661066`48.57747076140621 w+1069.9034793796433059181342591824066279096263897400647423733165`48.57747076140621 w^2+309.6466253641184040772930623923161980225091267012099132716532`48.57747076140621 w^3-342.5471225341000845229726495181568799304604065205790925703905`48.57747076140621 w^4+45.5736833647740853880604234560935868457002731331389436042471`48.57747076140621 w^5)/(1+1.73429265062392276400050884285381608829320175031184802131298127407246751975577`49.52287874528033 w+0.28872589123288565934265003199086106552227850937315921072861172237703703301661`48.57747076140621 w^2)+732.8161423434803372982502025384585936353404032434471535029258`50.075842159344425 THRSub[2,1]-112.9234571757194774061520858257536730173183482004209344756504612582096549117911`50.075842159344425 THRSub[2,2])/(1+5.24083909565203899250351389477118990895802926061055534331972711876795270204712`50. z),((253.2580590255793341320539434894451505845217426529901276011863`50.+ 822.6919933013485080398748944308592726001369159712322449429585`48.577434523972286 w+707.7903923788279378415047040353810914244078937678899226746598`48.577434523972286 w^2+201.0967749034950493237392850452380205180326278243716985394875`48.577434523972286 w^3-231.5006368978367734577792199366985642471494031664403433243841`48.577434523972286 w^4+33.1943556316544367510986900049069658197641939489580736236755`48.577434523972286 w^5)/(1+1.70302538895849560880598497611268570567529665691782991185472995695872771321705`49.52287874528033 w+0.22820504433643122311892650966586767371151204434649222836249231885403717958334`48.577434523972286 w^2)+518.6535317638338107033870743586413929344624338100393280161954`50.11148303547109 THRSub[2,1]-79.92202477400846474199324083341592795302662339819772401309479230812884628400233`50.11148303547109 THRSub[2,2])/(1+3.41697862683351668124999983931149131164628300591054802563692053035778562436987`50. z),((112.81268466443673300861562511620753643405662776699990083489353646744948197749395`50.+ 192.4662801454636981775568363818197336161939971306317788324171`47.70909274379031 w-2.8029544895843836989720418607908252588163990877808643440021`47.70909274379031 w^2-38.3837280527328014653863626081326936694714317235361408408129`47.70909274379031 w^3-94.9996344046960912881637423216417334237688959396950370818482`47.70909274379031 w^4+36.2902750288357145441231629656047462100434650819132818392064`47.70909274379031 w^5)/(1+1.02601822014912598237444131435486008291228974879236853486062183140392969021863`49.52287874528033 w-1.0328651559923948458760942289584022662218996719493850952498`47.70909274379031 w^2)+176.3444979909758158466876605213177462875497431656773045357150871881875219199597`50.47608588247981 THRSub[2,1]-27.17384240933386317625679172995563210648948748761976056222819058369452958321498`50.47608588247981 THRSub[2,2])/(1+0.50179229655857961841300154508381968481870563845279239833812221038885127087715`50. z),((472.8277161902481608827349414081823029290147973758627899687601`50.+ 1712.6650054041820712743848959185281359211898302259650859692263`48.55818631557528 w+1606.8057738400664038966372165838443596665193794600709252764014`48.55818631557528 w^2+469.4728434586739746825399824354740967108728723051088527288805`48.55818631557528 w^3-510.8488056946726503163014926732570587802431777056218331307598`48.55818631557528 w^4+65.1393881474280380151983625980982471416136656011087365647876`48.55818631557528 w^5)/(1+1.75398098181756383706825147708169144638500691164577819726675606112085185566104`49.52287874528033 w+0.32695261784685774678936124005196224561452432097964635169303750002358955591115`48.55818631557528 w^2)+1053.8130379545224177648695205832859432708355002606513321306443`50.051306641043304 THRSub[2,1]-162.3875411397466584564560649543114745240423082146659892396936`50.051306641043304 THRSub[2,2])/(1+7.97452611475342784057886100693033409482923489882672700020546622755386422760393`50. z),((200.4078722521058607397823172001669567105337565332977408818361`50.+ 605.5130636240950763868883565013091462304854254886184198206177`48.39505384796912 w+484.6500127088422333039730163163033643747781085185572633431045`48.39505384796912 w^2+133.1789140828211156013101051145903607579677348467667961819665`48.39505384796912 w^3-166.4034422046187204829442447579100588601264568131250924524405`48.39505384796912 w^4+26.6714576617260291880037333184307187663409468840945987394526`48.39505384796912 w^5)/(1+1.65930171356612068197847768492415171970376907996732305679400307266866232159818`49.52287874528033 w+0.14395067329038726758337965561352284494801216616632960589988968884148207222768`48.39505384796912 w^2)+389.8411984888114307573755615515568284923884773812981494499243`50.1556511298388 THRSub[2,1]-60.07266125730166612653494762981093918835771720568358309050360413779846034935831`50.1556511298388 THRSub[2,2])/(1+2.31998171443727903083442486080237369262916646449975575753078133216829511099833`50. z),((111.62455541796236483226229388952665200107591374309983384890739243510530064011882`50.+ 182.1479306832514805866010072123045792820904976700545675275485`48.574201419623755 w-19.6750989239994634319972321273350457829698708531391834391343`48.574201419623755 w^2-46.0244527576639183573951672531200897891128192715100924974545`48.574201419623755 w^3-97.1006210914169971229637703693881081759640599276429750846921`48.574201419623755 w^4+38.237436441042638469037751208591723586133797377136571731294`48.574201419623755 w^5)/(1+0.96834903891881548640488402851445750271587700915124444808548965506586960258095`49.52287874528033 w-1.13618804951251966981048230858769134094958601707293585039445272329344439147473`48.574201419623755 w^2)+173.44865769571551400060554868414398274859651824729561998900851682313140515439457`50.49078161132231 THRSub[2,1]-26.7276072915813989382379319371488408779611676712440396941133151312531973084618`50.49078161132231 THRSub[2,2])/(1+0.4771306218421481735920672922886231774427980036228055251808770051301043819909`50. z),((166.2111054053446538933615649770591856503712790272343876848319`50.+ 461.7635058081026070556579622665860039887437895506280056017053`47.64804957786972 w+332.9776342194485024376138763646720122045520784717403670770297`47.64804957786972 w^2+85.6343684363335360859061969942060166899564939619427614650112`47.64804957786972 w^3-126.585968627996471476113350208673627323276778084334434967362`47.64804957786972 w^4+23.7105378556837783124808291663947379286880073407257403341206`47.64804957786972 w^5)/(1+1.59679837584881579911988314608928830253479542084805030010257171430300084431731`49.52287874528033 w+0.02424812566237802882416987923157702789485938074496091256006283670587915365858`47.64804957786972 w^2)+306.493047859300738321813001399136396389449302398146538483648`50.20979719197721 THRSub[2,1]-47.22911050228096144583397147546880882965952248132549518831388207335112007873961`50.20979719197721 THRSub[2,2])/(1+1.61016875189047607238972571997931033022677699281097543161279068745712604548409`50. z),((225.7780487370040598256046809385666838517054211171953129156425`50.+ 710.1805231051503390697960341171928135103394654512732110063635`48.51155848165062 w+592.7036875574451082169465520763616836186791140939901263069055`48.51155848165062 w^2+166.2440690913971530081464015874660940060713106771737485515325`48.51155848165062 w^3-197.3556888807201749590173687064176723018719505033668153172565`48.51155848165062 w^4+29.640696812703697964323291929204128947986438765329896913671`48.51155848165062 w^5)/(1+1.68467465897382035036269805298919110553842620643523035491803468021156740910909`49.52287874528033 w+0.19279075075630096809470228410037733971433699407055329095167666666058203541614`48.51155848165062 w^2)+451.6762047230582801257884682037259560090264170068484427053744`50.130751234771054 THRSub[2,1]-69.60113951396713690077038426386444547785869532856999308553197791911819868529916`50.13075123477107 THRSub[2,2])/(1+2.84658354822398337050829062290024888770824349294826437168585051430126254361056`50. z),((154.0961871151669070664109538871402293227236001340915758582058`50.+ 409.2214300413005273734430542976658222341720958442752750601756`47.976280908762526 w+275.6137420826782543419072333705618121965400220592072346479626`47.976280908762526 w^2+66.9926412352368058480674818286054396904999227635400997152387`47.976280908762526 w^3-113.6228245846916906557740125726132046045203846042452862079714`47.976280908762526 w^4+23.2891861727674123773737866877528689794014372653899243230477`47.976280908762526 w^5)/(1+1.55751480176140968693532168252716415836830512031333035938754009451232524440013`49.52287874528033 w-0.05055386399594286694725211918893863910394386476647413395876742606930174654914`47.976280908762526 w^2)+276.9652261491736747266290953021758343208497556566609163615952`50.23954876613314 THRSub[2,1]-42.67901462186987620184981733392250736439245656878720540921707734165491278415757`50.23954876613313 THRSub[2,2])/(1+1.35870269718718000098233409790444175887910109889983562113638322811889664948557`50. z),((438.641035329955256386002331504604871736236017919552871532946`50.+ 1574.4996478544134071887906990778935946946105168546812107540802`48.56151475853222 w+1467.7501392196144430089304286074783302834905010039817376297678`48.56151475853222 w^2+428.138713778348416056367749798374082291646798797672306531001`48.56151475853222 w^3-467.0621120749867752387420552817823817081749074049957687542972`48.56151475853222 w^4+60.0066259235752852636831621083073388856140562906515723830777`48.56151475853222 w^5)/(1+1.75031713841017377985190438355429923660086876618369320079970141816797438383359`49.52287874528033 w+0.31983193665661146326678462844351675883812831887139814116353088186120875191686`48.56151475853222 w^2)+970.4894700091927852426343714781907967846337457853696230085137`50.056007799789306 THRSub[2,1]-149.5477784586014921599274551122854875555176927309038742183304`50.056007799789306 THRSub[2,2])/(1+7.26492250427687624583099681300867692100733013105686082897182521814991402392735`50. z),((152.8111160233068942900468605260852578466574000158015632228847`50.+ 403.5581071216326400263573234926844076064031004197681899440531`48.05340354236373 w+269.3275969383487728751365390339497373721832432255957227201403`48.05340354236373 w^2+64.9152858937770209361087531807174095771790423540264328114741`48.05340354236373 w^3-112.3109838422691782583057191133272711638715147383362649263204`48.05340354236373 w^4+23.2793089850429510833818896882772848699900781864608690212368`48.05340354236373 w^5)/(1+1.55239347006054482584253711240065929610132717705861460969003298068239574333425`49.52287874528033 w-0.06028167276539265244730703479851268458796939543631895654810833067761849386654`48.05340354236373 w^2)+273.8331084430191702947304545705937710074642716266739933670452`50.24322029089121 THRSub[2,1]-42.19637028692225428646228469836679267944382751071722569074440823232033546135495`50.243220290891216 THRSub[2,2])/(1+1.33202882702618255624739256265853761651703246181648827902481502068711292909142`50. z),((292.4942040444935748980614063867328085801427008455880419839047`50.+ 982.5062356606796860928857794134244702320326538007967393041958`48.59289324701502 w+870.2217157133302078938557442211554713938102964704233684772341`48.59289324701502 w^2+249.9295818421410909692547632435255798710298854242025616019681`48.59289324701502 w^3-280.8527795675183211577340721061361271288787233320716669355123`48.59289324701502 w^4+38.5949604036496575636754928456524462557468527207059173957807`48.59289324701502 w^5)/(1+1.72041130601026810363301855019681002563296199583560060680248241703310416250205`49.52287874528033 w+0.2618290276198637975610128090344290498528732900970603715195642743246129714309`48.59289324701502 w^2)+614.2842134540684474024002079634758136680575757606896650176548`50.09213399175187 THRSub[2,1]-94.65825472931213283755964051146772862287088678787647415997463144972795547212438`50.09213399175187 THRSub[2,2])/(1+4.23139258765008498197169564223309020723437030149212835413832237924346537893462`50. z),((521.9517710434262100662805048294791192513460458713586131180975`50.+ 1911.1031431715431780951404016246416934831569256308397411962571`48.554497891469225 w+1806.3983038629143921884479408676752769757678879671457920408286`48.554497891469225 w^2+528.7587091880120732164882392876730802961583332374007667766064`48.554497891469225 w^3-573.838003012624691845716847188715459204637817491331112620888`48.554497891469225 w^4+72.5531123671784394025508330842563265370938208568309717615024`48.554497891469225 w^5)/(1+1.75822035629981658011473173565323074175043419446382259981686666619414036507759`49.52287874528033 w+0.33519585585038277286337636604356456717242119398271733816829733745558551710851`48.554497891469225 w^2)+1173.5436294979394067919774068013983067253489209759084105505828`50.0457855887071 THRSub[2,1]-180.8374517592638626043642003947442892958106158804033231577138`50.0457855887071 THRSub[2,2])/(1+8.9941807231524208317414095644177313375193030824457527448922617397678017887161`50. z),((184.6446151704161285404783027258165002013877080120675365711618`50.+ 539.8042930711032570685060337591642907948130516088468348867312`48.2460793198735 w+415.9837451396572616981328669647484822120335529283094006463218`48.2460793198735 w^2+111.8799845480053657164103160967120462943625825704003218439322`48.2460793198735 w^3-147.6554678177503924030419737919775916032662534218510470132704`48.2460793198735 w^4+25.0908604150945923342277647184554445798116958458675375237322`48.2460793198735 w^5)/(1+1.63636521020241056109242203069132176180265237026967205144753122539434168676778`49.52287874528033 w+0.09992449225858824408438209296800405218035005962629373075422857729346866076233`48.2460793198735 w^2)+351.4212410833700087901038412937098233009538140145384306016262`50.17661484819204 THRSub[2,1]-54.15232986163651251684499400598648093269384187131747148853810944397083272435842`50.17661484819204 THRSub[2,2])/(1+1.99278808649344980691917374171141408689572467889370186961999565339360575785647`50. z),((178.3245506713500121193321876988163446200791832506483442413293`50.+ 513.2316643461214146362551464266182768320780046083163879997934`48.14164090014806 w+387.9392226870666394625321087699789139679392127721493493537422`48.14164090014806 w^2+103.0866656356721491588141499491450624976630211849102248493207`48.14164090014806 w^3-140.300912799545231610966087960828046958212688566848410887686`48.14164090014806 w^4+24.5459237164449802165152041544809916667098259955367971726307`48.14164090014806 w^5)/(1+1.62475405652997267247018056772835410731836967727268972353902367347705782429973`49.52287874528033 w+0.07768139878192595679426896376299029389717873479146749229291960674487360772708`48.14164090014806 w^2)+336.0172793516405088643996199148544803284634763112551681567041`50.18672221189675 THRSub[2,1]-51.7786531473290013328073874307148114320652338048881481057284388338841859073265`50.18672221189675 THRSub[2,2])/(1+1.86160423143278129614702579462724726036405093946137923952611327751157087406342`50. z),((121.10609471815133043546413175214031492989025170382703766612956401605358982695172`50.+ 249.0169903360955976135831198750232478967196072828200072932575`47.746352932301335 w+81.4780868356574929092330902083510043858138689491414955245364`47.746352932301335 w^2-2.7391218937537162838612977496334626766204798988738475147027`47.746352932301335 w^3-90.1253737968015246469705639972477403125892712227206736734617`47.746352932301335 w^4+28.7133477227589385087398934688883429237682429200800973125015`47.746352932301335 w^5)/(1+1.26927671961917336106338360328253698233222877612252094059262841968408563800516`49.52287874528033 w-0.5899175029641682727712585056601117845121856965618704528944`47.746352932301335 w^2)+196.5581162399410789906310157240159341880243865485386209409593`50.39512005994007 THRSub[2,1]-30.28866415357635094474821451013253042572767246492649993722863080765144123831559`50.39512005994007 THRSub[2,2])/(1+0.67393634708305595870840417888921596702053340830337823607125072923152516473645`50. z),((114.4917632047450354376593889119497039800733322315291753049614031605299621957092`50.+ 205.6598253533494717249368900548900458729625395232490746849116`48.46813900912428 w+18.0336781647767033573308356388398966599559772255043745236802`48.46813900912428 w^2-29.1954243058027523807495823733396531792550817859101355053313`48.46813900912428 w^3-92.8961420566176680557104749460204413425712858657398843914724`48.46813900912428 w^4+34.0847235220462630872346096465678701552897387398638619037103`48.46813900912428 w^5)/(1+1.09334878241308452449123680852900310249500975251208540607712580689579607491395`49.52287874528033 w-0.91138452790062702172795738413782691189628584741997847978920954959407052686834`48.46813900912428 w^2)+180.43693432343716625179216742750846812666432101008053169317979501863348363144636`50.45688673798241 THRSub[2,1]-27.80446724444625696031422738063157116364307958532555257801317807369566908429476`50.45688673798241 THRSub[2,2])/(1+0.53664447186467516061253148568108248588362344671007628952768805822254350654938`50. z),((111.75964315768609247656813907666930244377616827185177775762216311517072247246623`50.+ 183.3739256536700712695849862406741551275641233451848324050249`48.52456421025404 w-17.6420921201994512175695842802550800509196892655933305891037`48.52456421025404 w^2-45.093602457607908525836721234236232607341722018996794076365`48.52456421025404 w^3-96.829193579421147001225364895728933270988501569916099978519`48.52456421025404 w^4+37.9949948438630045908623182618868167835977200567490950518515`48.52456421025404 w^5)/(1+0.97544031084912721909494933754335792057149377019143926790879653746950242137619`49.52287874528033 w-1.12352078291905967763974426580613554946570412589704402954912671059525157032937`48.52456421025404 w^2)+173.77790850849402560741338691050891081262640584490948071106353943398255587664592`50.4890604623882 THRSub[2,1]-26.77834326464275418001710043369901121898369463547560129341260536345544889974509`50.4890604623882 THRSub[2,2])/(1+0.47993460121150577898220402259314467420037207529013419651581927476638859850805`50. z),((529.9138219469198767322212408462526389251192275176708512231658`50.+ 1943.2576156318756010869702902662639216126895367176825352081799`48.5539928774033 w+1838.7289088171681579919825239112496266333624713049833929655984`48.5539928774033 w^2+538.3582533835780264742410702188047639615916884158666925923988`48.5539928774033 w^3-584.0535203952217077861963257385795923644799391933369732302152`48.5539928774033 w^4+73.7580943656003717176703660440396229230809664010208788741347`48.5539928774033 w^5)/(1+1.75881745545963140208980054252782905913740779366953458634122820565607112158098`49.52287874528033 w+0.33635722991801246471966808116006433068646741399484168917696225028833485618121`48.5539928774033 w^2)+1192.9496224971598529217437635377105952084878287829920162189715`50.04500081576222 THRSub[2,1]-183.827822321233072803822399572944291738893260183413954582871`50.04500081576222 THRSub[2,2])/(1+9.15944684217128800422402118066156500800052653642553931806546009543322101121725`50. z),((525.4976808824517267482827316886603240944718909615685917446527`50.+ 1925.4234361839465132263960508324191629485936492268454723587111`48.55427023009785 w+1820.7973696893552310132673180152158052558238335478330043340959`48.55427023009785 w^2+533.0341673300542679178615123245938028763006927343136270339713`48.55427023009785 w^3-578.3873096086448936474265100989942683765575010366902091184818`48.55427023009785 w^4+73.089650979787287422231589704256018293192789251323887066979`48.55427023009785 w^5)/(1+1.75848899786852158499475131465221847495145457891272094536694192674926196040328`49.52287874528033 w+0.33571836039054779381286821204715327475148231147493957220675832776740469955691`48.55427023009785 w^2)+1182.186113996726285410083866871636026550246449446938149274429`50.045432731480396 THRSub[2,1]-182.1692172210202225637594867049767031175968420655478392780753`50.04543273148039 THRSub[2,2])/(1+9.06778220656286023591428504437431679821205805086972003902921620947140596726011`50. z),((350.5588373205106889306333446020560333263620127437665265650805`50.+ 1267.5373620965087325687659710678522497966726278484833358385066`47.152504161787434 w+1288.5842312318553760974591009607812215165475126602927000790254`47.152504161787434 w^2+508.3437698617988754645026287966613029940016346160268460762962`47.152504161787434 w^3-281.9014892533815090140424321002918400148697273350281325131739`47.152504161787434 w^4)/(1+1.87742325446164835786543687527844709277163424906740863561874353208173902209398`49.52287874528033 w+0.561278657357252063534620928027685028208808306558672673279`47.152504161787434 w^2+0.0882047062275923468508611242764808178590165082381350803943435806328530713494`47.152504161787434 w^3)+755.8057737297332909360258937377355730109764080457520202375887`50.073328837991156 THRSub[2,1]-116.4660492466707489663660912029178372722612120918852092960150399035388628558833`50.07332883799115 THRSub[2,2])/(1+5.43662434390153542840791548481359641500729062202135184603070291280973084383947`50. z),((409.1437890864995654666721086218548739902344530293953679149281`50.+ 1511.3079405517723446187266528480221657803621208459220586934532`50. w+1556.3805790402583035018595093801440718547442899402503456847102`50. w^2+612.3889649442845403308133275495174153905728967440130925294937`50. w^3-343.79291279267841698061950513699090127601121399443749101783`50. w^4)/(1+1.88358710770049665730399783047476085245483034265272209715161886173204180769421`50. w+0.57452905489565794852508679310093872182979067447521767773807075032395726713785`50. w^2+0.08794819613756586765387493276707786611383960114174172252018312476317452817084`50. w^3)+898.5955119027946942179333837681588626335134206421609929877612`50.060817122466865 THRSub[2,1]-138.4692639031516981957048408020603238933019241710436109194667`50.060817122466865 THRSub[2,2])/(1+6.65265620913667229745781684463397180953703160921634871162339646166969605144928`50. z),((122.04944621194258778763735165525821100172387194480787539686614299236654602330584`50.+ 314.8548604692217064440525482325572664060737598401344488530325`50. w+241.5871893387542624909510934964488807999300446725681289575182`50. w^2+117.14980684589112788142630055113929369330223538882540347402958113453108513355112`50. w^3-41.99194019531605256085554408697087154216368798471789769078903221214024090702535`50. w^4)/(1+1.78158475109678765242345878757881599790950694850651532834909541989951763716202`50. w+0.29843922398895701419408366774077288404557882522491825190308839386808015055524`50. w^2+0.14694961635821049354217661743810975390171770993133559869333576004776313944567`50. w^3)+198.8573570644734252111076552296624400716190175001932686107692`50.38773236174282 THRSub[2,1]-30.64296615073957469120841822929505015278254833048353608499346560661814822570354`50.38773236174282 THRSub[2,2])/(1+0.69351723674819524745075731418212989416446712724767612765209484462364913546929`50. z),((426.6550311986760294555549620746353173391225668347397447900709`50.+ 1584.1498401129211136552783134217998342235340446720134551224073`46.96815677619623 w+1636.3931367351412836756733083761376067707945447788105692199185`46.96815677619623 w^2+643.5121303029708253726008196696744147327923792139873415422111`46.96815677619623 w^3-362.2984042033900058247392893035632426976537725572017820628209`46.96815677619623 w^4)/(1+1.88504943621096575905616290396764340602489153000881065192756508417817386419841`49.52287874528033 w+0.57766513913193627578984463373302795484909101726582422503`46.96815677619623 w^2+0.08791436589793510416124168560059696511320741434962102713991120118557846110476`46.96815677619623 w^3)+941.2758521763591141925792734901081821580010814331635318964671`50.05786710665678 THRSub[2,1]-145.0460998905718187268516817540549540175579522035717450504441`50.05786710665677 THRSub[2,2])/(1+7.01613228560954315283767118765848208108051157458821904678874739557069837229791`50. z),((213.2998151777882975564196398651652802744671285753795766113901`50.+ 695.4627617439975781185599719341141866686543188419769767247826`47.58556750755517 w+659.8408901825213490899142606802655871235743416754062450352081`47.58556750755517 w^2+266.0516959770866679863823658343709596996999799140217899486076`47.58556750755517 w^3-137.1681882672940215507303159156520120465325908330197474069683`47.58556750755517 w^4)/(1+1.84530094636794624240178978076728461178694731236235664311394458816132650638127`49.52287874528033 w+0.49084783051604346352257349096990726101706514857337440171581439882984517184275`47.58556750755517 w^2+0.09286464694344653509382373396391351002930889374878582315443967542003998631313`47.58556750755517 w^3)+421.2628707682948583316848230493646760883108306754594291176161`50.14190798361261 THRSub[2,1]-64.91459043846677094727114129296002740163329438182924189370501899264104053076666`50.1419079836126 THRSub[2,2])/(1+2.58757625757256470636606610383991541453475565687738564907917491104639358660292`50. z),((194.6086513218186065925835216542031925207748819789827007908176`50.+ 617.3475189848054216294007231602045775095790960921439886844082`47.673136218712855 w+573.9496953996676790036814113240807042616094244376662527926952`47.673136218712855 w^2+233.5912732021728456901736557964613101556890894327528957134868`47.673136218712855 w^3-117.5309379654232076018174429193069641785100967300508865754224`47.673136218712855 w^4)/(1+1.83632519426828091006942334309733518216202055654509575466811061708678355745161`49.52287874528033 w+0.47046490439794770119353240503750629962768708073272888762681948262188374699296`47.673136218712855 w^2+0.09535132989345998163575787477313512285918164966221528994896363431998936735758`47.673136218712855 w^3)+375.7066944347484391234070636659649130057098513030927310610046`50.16275142992215 THRSub[2,1]-57.89460189012564257934668935687075257181906218378260794603711682792963838504595`50.16275142992215 THRSub[2,2])/(1+2.19960886727788491718645176737913652551254748032652362039695798902052571484698`50. z),((454.7655223167252242654609748085250991594962127938832512854706`50.+ 1701.0658045041159545979453644442797471412922081589906914478991`46.90228984625277 w+1764.8119616647778965451157141156577127770718118058145891539608`46.90228984625277 w^2+693.4892824481382493314265345368484836104411538975655717920897`46.90228984625277 w^3-392.0091940197513553535591409422374480476575126142008373528222`46.90228984625277 w^4)/(1+1.88712650662731710131556950096752039961370125481161371852588573995077430716652`49.52287874528033 w+0.5821152659172777089583920720691650358693660628905058695251`46.90228984625277 w^2+0.0878837816860939431624578001598234137624382133264389567225`46.90228984625277 w^3)+1009.7898569790847676121074759228730258252033936867367306928719`50.05368742337084 THRSub[2,1]-155.6037798326865128352819735009330161039545230287630524115284`50.053687423370825 THRSub[2,2])/(1+7.59961408283792257159311830305707108584637869950695664297465740542941447320443`50. z),((168.0993010319833102020898623690654515184285422148838596684881`50.+ 506.4232190160655714266908551489880077301511687810650897223008`47.82867890716418 w+451.9948103377230363636973810391815822199177722606066036109809`47.82867890716418 w^2+188.3191856000152112664475068083062197404595130881052752430985`47.82867890716418 w^3-89.7523854256730916482976140270245791981542907561124442089883`47.82867890716418 w^4)/(1+1.81936998666544675810259446705539692311564593931723909753184123887767538560934`49.52287874528033 w+0.43034070752592793943608051517118009064927870598712192536514714491535182363495`47.82867890716418 w^2+0.10197613276293961099148152575594146253870197956593201547853757103836699515219`47.82867890716418 w^3)+311.0951675337215782525007910121190920733431122555820665083274`50.20582536671256 THRSub[2,1]-47.93827509888780541342251575077873982285325542553537115883981895401068576222628`50.20582536671256 THRSub[2,2])/(1+1.64936151352253775780635638243954157407135148838558811627743187966786366727774`50. z),((101.41536244889718972350232076410501577488211147988268029474921417856965354598265`50.+ 242.9422565481004045283774722071794862837099619709457434218291`48.564231617096105 w+156.9671424832939698704548306793731241310243605263198828208224`48.564231617096105 w^2+102.6249347553285375262859173312925079207303951306106312235469`48.564231617096105 w^3-22.4536253601868949496158345925597584336332018466298291016948`48.564231617096105 w^4)/(1+1.89083397677417734744309305631351342158187951902571603307444348014626973925552`49.52287874528033 w+0.20709992054441752679818328271235359272341539624391266407029507586380254116189`48.564231617096105 w^2+0.23610651977830864654189632709865477330217593309452239927540211421488238033118`48.564231617096105 w^3)+148.56568097442419915949863669136859550721969775218320271250683896349165380224142`50.67855824033955 THRSub[2,1]-22.89325977406432237925503506366513495096306388466996428148448197698831510966488`50.67855824033955 THRSub[2,2])/(1+0.26522118785802654140969988293035439098671753702851118959683867498870515826123`50. z),((109.33560260921138177771960589481814474045599344472998447646367880809695531957033`50.+ 265.8178093351211313709076044971067374399654485703500986498772`48.55349438938335 w+186.7945550267793122391382359086060938441494247448729599964484`48.55349438938335 w^2+104.1940731781565581189615117626528320912296382620941621854317`48.55349438938335 w^3-29.3200639636641906521295551237820791451546150032572702646265`48.55349438938335 w^4)/(1+1.80078416363015383656638232129017241871713833284725604853970502387955786946249`49.52287874528033 w+0.24137646089453103894565706175016963126842853793081430701736174843651802425263`48.55349438938335 w^2+0.18864743406891976491132661899437123279646922251962828096240954710027476460702`48.55349438938335 w^3)+167.86976819594143272709817519409635189345521162134356017678894118792307236782765`50.52213651143694 THRSub[2,1]-25.86792714384179538472317144902915423952122017177850648500501300883828397935753`50.52213651143694 THRSub[2,2])/(1+0.42961945268425920727567383513389091920692457977581064877572838260219403248391`50. z),((368.0000534150613783732366068480258141960323282485071071539865`50.+ 1340.1237519419751307451573761246752905777460423103844504157947`50. w+1368.3299172250235450859512790387057692980842628197092083328669`50. w^2+539.303095169186603896239434955229009230123877039071892354683`50. w^3-300.3232884943653828742129792665652369472374308633904080961998`50. w^4)/(1+1.8795012405755542781641518488262207307479640605090942400325384927618749891464`50. w+0.56575179934525325855836568102095597128563735619875182663535979538615541553522`50. w^2+0.08809741169877735795538877794766479851202998706788843103378500798996821269659`50. w^3)+798.3154388312496665742138554429990584731447355212720512616493`50.06909582195284 THRSub[2,1]-123.01658500765195423962232629685321796209390674030893675151689465425390978188952`50.06909582195284 THRSub[2,2])/(1+5.7986469094255777019666051942395784191715818280386050732056880481957974275862`50. z),((418.578791329944378652591832188124622984732127889212071907448`50.+ 1550.5559595527256086840279573333571802216338679559075309367168`46.98717158826243 w+1599.4926454646544157181872192236154729540483060113694802912809`46.98717158826243 w^2+629.1569828404420980836412979889986938053046293419912491002896`46.98717158826243 w^3-353.7633363857416935231789040472768608585875231824941046754318`46.98717158826243 w^4)/(1+1.884392674025649302803557463869289089321357278118638434873837750793603864462`49.52287874528033 w+0.5762569812334699200069714500481908803708458369528894642239`46.98717158826243 w^2+0.08792829601643699569825209744857164454338992163887862322705787764764569965244`46.98717158826243 w^3)+921.5915451740186665702309620747895640307401555159746976066801`50.05919123501401 THRSub[2,1]-142.0128424739104888302604127319125981061078427563302094929323`50.05919123501401 THRSub[2,2])/(1+6.84849597738334733572326066419409886981702116078340562149505616453763812938778`50. z),((93.54367885478824316187460751950381732593740366437941763475400811302911645218959`50.+ 292.6201156138684741640757820761987847987908221278252292086101`48.62038695638245 w+151.7551369079995081784171639101114725760583219189968706799292`48.62038695638245 w^2+140.2328959814825807927961107600556985738107909056322834982343`48.62038695638245 w^3-27.5986848352274202472368242095663292183768994581188804107292`48.62038695638245 w^4)/(1+2.7695513820517005773311156484481704005218974136657179591401674885665286287914`49.52287874528033 w+0.17929728880031151749243058548987222623956617661093040187139552546791904787465`48.62038695638245 w^2+0.33428202264352574248752332636249544357526633356199628989862520317038864734586`48.62038695638245 w^3)+129.37994119821552442172150893396754154760214355636437969548701866159460368897219`51.03423575864008 THRSub[2,1]-19.93682917869716643332528782973981870647508515056627958346691769870522342095475`51.03423575864008 THRSub[2,2])/(1+0.10183079843310566876766712261839631070972281006095759228591126216140110289115`50. z),((170.2950926315577281316970772609202182092401508023737628874322`50.+ 515.6160164527639481112257704801040950170279033639086327007206`47.81385941740498 w+462.099891289946179680121824494763858203660716563120879484227`47.81385941740498 w^2+192.0166875559530503736786309603911221592966334216954078976972`47.81385941740498 w^3-92.048959955465293810717151650965933605125897153484786404812`47.81385941740498 w^4)/(1+1.82100336459465752612259657871665640234172064436789732486610094817071231310958`49.52287874528033 w+0.43433197352653689461887097244939323587501982256973959040345931826588429532085`47.81385941740498 w^2+0.10120624518449993357092155548739078317603389047073763620978647148742920233361`47.81385941740498 w^3)+316.4469942082271030823841231584099738738068494162366679075922`50.20139487030887 THRSub[2,1]-48.7629659529371594778510313459636975384368459407934658652703630933068568048176`50.20139487030887 THRSub[2,2])/(1+1.69493896087051465572306574592079134083077225713377595528952364026118340387885`50. z),((95.83064338464494379633503237111981299637140508968821825922322191496464854749971`50.+ 249.8225993130462053177122764582750775555099585323952552861781`48.589371282092664 w+144.5565440730448523518805663534290239123303136264218298439904`48.589371282092664 w^2+114.8092950291192418663466524360534518457357753647059448463861`48.589371282092664 w^3-21.2683011530649865412497588165990442594875587512439847259243`48.589371282092664 w^4)/(1+2.20339281838621137073931815679102174772337441844510636506054216246325971082385`49.52287874528033 w+0.18903413951461340035017415196245076691029405364499536313395325774255141964135`48.589371282092664 w^2+0.29242691689616946583690221481543811121855068994267570130184134087729740517831`48.589371282092664 w^3)+134.95398464428175864826616424854625217556440116112282285970887424860917558386565`50.886371833795664 THRSub[2,1]-20.79576257277411280236529868587003964698793672046295346065525802851731406216584`50.886371833795664 THRSub[2,2])/(1+0.14930069742827299311792259608063913538523235594590949187783666175329938227692`50. z),((99.00233933009759722780381787961595967683300762991339209786597568935586141530371`50.+ 240.5720055426254575806369949321721160082059564799988659309835`50. w+149.7983101638024535575203237942668151570855141718810205791263`50. w^2+105.01799121254667557717942523932448057150977685754076390831722117774514002210662`50. w^3-21.0607040992291353700197909922264264418259700989951175417451171889536868768976`50. w^4)/(1+1.9675873897385638261507005369234206006415475723959784354755714450684024747142`50. w+0.19855800305638050035298014973361430234924722539375747159392441460674491134553`50. w^2+0.2567413598686144693504339490915018680247560259177419542547665054311366686413`50. w^3)+142.68439356268023240340474719591940188842287316380156624431878925807821305877526`50.75191391599333 THRSub[2,1]-21.986981556646345350504698416858104571914429493387628616219308961114673895088`50.75191391599333 THRSub[2,2])/(1+0.2151347251136316131346794378327565025888920954385891278249446124334006026038`50. z),((112.12445645736242886494540280260614495398003865579115916018165816020179934757647`50.+ 275.9542257808961233082437503900437113336427282232862372450175`50. w+198.383772122521934578838246803034355243406240750810134680206`50. w^2+106.35277465718897568350087591150675071845746532987485454282740388419619763870554`50. w^3-32.02431136468391342846612181385491132338348761155031057409964505295131192216961`50. w^4)/(1+1.79066905840178138240551538877235773357773702728213389023146573712533529408762`50. w+0.25429068330504759795885991615146939440155538105772058469845333249255441419848`50. w^2+0.17680704487355557553073650443013006439690987881296980920566494086246036536284`50. w^3)+174.66707191944823767222123342880837160016526496998197443223399704552134052624055`50.48447820322118 THRSub[2,1]-26.91535908697168206013197185075737203289027868035131686993198000577823446452554`50.48447820322117 THRSub[2,2])/(1+0.48750693137301226583796857943055475568661178975181770520538139568008219635003`50. z),((101.76091603200027757892446540532489659495588228812226862936689053291519575834072`50.+ 243.5808330412001139293111473264389231259389913318439772303692`48.56412443588924 w+158.1077469354360559747428827996559018826873468933061510487943`48.56412443588924 w^2+102.4557898609975878329495843771209152027047820461501137013905`48.56412443588924 w^3-22.7002089106666459841828572824811884841065646453996700681385`48.56412443588924 w^4)/(1+1.88308028500963456829148097362059926372835017691582071010856660116433692240053`49.52287874528033 w+0.20842477943264432760620190362472924994948155101399375093284713322269616749168`48.56412443588924 w^2+0.23345882811737329627364011764828656627592967434243024557175784321613351288958`48.56412443588924 w^3)+149.40790246934225129170644036209420880154165002018482684742693365597649581643472`50.669424389430894 THRSub[2,1]-23.02304207199475119881270910594125104742994519404184231500852914247672880442868`50.669424389430894 THRSub[2,2])/(1+0.27239374933555394416626769845406130180548945549720416610164767321909752742877`50. z),((456.3028262150075223399004169749007927729139007616181808452992`50.+ 1707.4591936535257519758841290093538091239579123486411646278776`46.89869151083039 w+1771.8341599384874702451340157213674544624468447427936659924969`46.89869151083039 w^2+696.2229062663144793868918377920202418194117724559795299519572`46.89869151083039 w^3-393.6341484081948870141291863718228786394212595639680519724315`46.89869151083039 w^4)/(1+1.88723162077675759775191210520563995701418522271822170819342727645396533529646`49.52287874528033 w+0.5823403450008735859835665677305381560755606693108928983371`46.89869151083039 w^2+0.0878827751683512401839721935012698507084217623497635846536`46.89869151083039 w^3)+1013.5367444392805070581008266845465646815663563518047634353899`50.05347621150497 THRSub[2,1]-156.1811572418420771433522380533613887870515412679520963917824`50.05347621150497 THRSub[2,2])/(1+7.63152348056737063977781746446438806201576171976564234551418685570245161005222`50. z),((260.0165073469270162364028227400462298772726623506959609501217`50.+ 890.4092256020731004413060257320311162228117948367409207357279`47.410165857315505 w+874.1570973374658657741054095145799202790045095026744644671281`47.410165857315505 w^2+348.0586651317261673485688816610649648721726077694570505238616`47.410165857315505 w^3-186.3561576711812478855708134269601143698364497666270206661371`47.410165857315505 w^4)/(1+1.8609579788635179847971461877181667947463511809288088975595446908594939445162`49.52287874528033 w+0.5255438132069260520516936106912985300659654357628491950976`47.410165857315505 w^2+0.08984714481973456963824198748489138075179719577072610365844075884983127565446`47.410165857315505 w^3)+535.1259711389848892509813877417573801198388069312025031359566`50.107588146893896 THRSub[2,1]-82.46034877491133205557460298288012253690782071816414144898781256976291837664828`50.107588146893896 THRSub[2,2])/(1+3.55726189532764375374812088608760667132337756258207681318203581478292371735591`50. z),((95.98583283507995756627603811552008630436066592496111436347464707421869683854609`50.+ 256.9229937383284200260555172070674040072525135674363200210506`48.74846608707577 w+177.8377720697442753647400923241958028162708688827122123643206`48.74846608707577 w^2+133.7386369166617648885996852266911676926294526036950464232145`48.74846608707577 w^3)/(1+2.27018130214988172091313030459149659516334850574117205279375075702794417396048`49.52287874528033 w+0.50092173444267811056462979482507998751058318574631457996806288024043839487169`48.74846608707577 w^2+0.33279863243322096307640392254984102585210833047897442755725083665207937009971`48.74846608707577 w^3+0.07943785689284153095544164506668555187137999689336211594588360441532674572571`48.74846608707577 w^4)+135.3322295745387711892526477091399253638870408697052238237293469711389655049803`50.87831692413147 THRSub[2,1]-20.85404830464571062158187483805893092658845692651412223362836711621371602840585`50.87831692413147 THRSub[2,2])/(1+0.15252192252428584162371601593301401700123889210473073121123340739342592304855`50. z),((94.04387518039270393610877394115795651139914906876510192604096797993954821636841`50.+ 279.4387614259014052376022765258721864963507090106087364043803`49.01911794553611 w+183.5387259792749831822082730476185554574513526057615109242385`49.01911794553611 w^2+149.5660660771310482476309307838754531094331619802998757406668`49.01911794553611 w^3)/(1+2.60274236486411419572400565217172120300164248626442243589511537231423101835654`49.52287874528033 w+0.54674720643676119831169336571246296241251458572681667748368719335324588220177`49.01911794553611 w^2+0.36875801939092983929405434862106015589113434347570877985702795855548219055677`49.01911794553611 w^3+0.0912749065632359872931962485839455263792049848311056562250301468165263238541`49.01911794553611 w^4)+130.59907512621599839589423869239335713457621979547533854898840095722850322696059`50.996143968457815 THRSub[2,1]-20.1246918770675593886109863245717591785283931851687184328151474936436149252725`50.996143968457815 THRSub[2,2])/(1+0.11221323713917750153844076524373676584847537789773394269592283560428281779463`50. z),((135.0345670082622232889859846007408330344796616022499376732734`50.+ 408.1881074475814311552056762046338749198815041441767985134151`48.465945577855756 w+412.2382928721979545388161749695321078638759494020290446538938`48.465945577855756 w^2+223.9678136729686226196649233588289029317750410848783889719086`48.465945577855756 w^3)/(1+2.08599506597757168565581029507219858964837068426916554014950841004172630539797`49.52287874528033 w+0.89976611350010756986564550700475934009833654251258907632573983618890521460137`48.465945577855756 w^2+0.20612735778254168303236985920037610286999031296454275007523129374441966839328`48.465945577855756 w^3+0.16621055029832934928407340343767931527749803542876822174824623998242916410622`48.465945577855756 w^4)+230.506132778384070821270280455732217700198585799286515148738`50.3092834798106 THRSub[2,1]-35.51989088327175145688616415707033008644796960185278386049348256551245973348247`50.3092834798106 THRSub[2,2])/(1+0.96304584753078708362776059927832100697810451182066433874578323957648108958673`50. z),((94.11622847859660149782149522721812448687992072040113144900764396152709749570736`50.+ 277.9377303722554619171043925044838479520366995925187664230107`49.00581455816437 w+182.9768119477208710287227525791983762227812494611432468067162`49.00581455816437 w^2+148.572276379948114822224670620064358095682672991557106955014`49.00581455816437 w^3)/(1+2.58307034799998197301425407317801666106040633626853730684335328941122168290485`49.52287874528033 w+0.54343548141214158518572229289396297021786104475517922815009615514113279366332`49.00581455816437 w^2+0.36694513625103252313785411890708703987326891030130514777933326681519190380249`49.00581455816437 w^3+0.09042186632551206369677762838605723842896167409801481135435776012741892234138`49.00581455816437 w^4)+130.77542260445169342961229277536042953610466579280476811425055515500258186979528`50.99095612529714 THRSub[2,1]-20.15186617871832841933164530888395431710718513101423882551584780094352406230353`50.99095612529713 THRSub[2,2])/(1+0.11371505481621923867404761518312107934990015220592851949671563857678549061399`50. z),((352.204135354880240205091969334051380560611224147327158760362`50.+ 1488.5642053680397787666473845334314760897527302875234335495667`48.80960052074771 w+2039.0685608300375269986019341718120444943633270864631502721801`48.80960052074771 w^2+1165.2174366091562911414932602589751397263096945518659970735365`48.80960052074771 w^3)/(1+2.48573985598097409535480557336453279789396940661497963314200498173633619073571`49.52287874528033 w+1.61265611035053007299196011945808678328014559548593754991367704472791066584798`48.80960052074771 w^2+0.20687140718018565161332418431363314860458573123982851400403469590710556637053`48.80960052074771 w^3+0.35059635260103516425945500957069956516119461183929372425141938629201194687179`48.80960052074771 w^4)+759.8158764687897205713181613344851270070912859684685592130584`50.07290744102384 THRSub[2,1]-117.0839868694364667649917378805716604143957926415691041702931306898452256542765`50.07290744102384 THRSub[2,2])/(1+5.47077534645921993824404247124694465071704642084845381097750467672171506891155`50. z),((93.7153522734977872501319162067060261261540742811485371489745704044228969641323`50.+ 287.3828703744871196646056227319526416907798376826907240497877`49.084478155654914 w+186.6817523707334847720990564255945969251046472408778070117091`49.084478155654914 w^2+154.7629447785996299114131856488732501060213604855373414575416`49.084478155654914 w^3)/(1+2.70448905513067810633082934284544268145554875336880014377165297282574600423757`49.52287874528033 w+0.56451902845538787616493568306442745698130373594673403317868781610508665380627`49.084478155654914 w^2+0.37777268129045145315879883740448518806769713159701534831095442846437707498719`49.084478155654914 w^3+0.09585659660106675338010786034936760454919686655086621350338939859453905731906`49.084478155654914 w^4)+129.79836268308292557560596642059295827516356217911758972227165724321925520786062`51.02070055647227 THRSub[2,1]-20.001305925179203444635123281090707802513208597249147376052536820986034092776`51.02070055647227 THRSub[2,2])/(1+0.10539417676272399306635106251026657018616256545361931762357888544127936559283`50. z),((204.4875546769705115438379130256786759352966361575838675998346`50.+ 753.2571068479977103692108692576621485061104266149490079868718`48.6956369419968 w+917.4137588914886892514652203509857469815906607824259835410745`48.6956369419968 w^2+503.9369713001481979853398678018150243881658777327864758729099`48.6956369419968 w^3)/(1+2.30400631272045563417987451789689279657750590856410361608530774876884384023002`49.52287874528033 w+1.30111232262996916143419706768202434907655272463345283941788026316042275833373`48.6956369419968 w^2+0.19892372035439043501701189018151207362173914410988236003161273773197794334319`48.6956369419968 w^3+0.26456989743351510513409015891405489791865385757047095837628560503774506316548`48.6956369419968 w^4)+399.7846526987345289266931484724812349940044665084560755884764`50.15101993285939 THRSub[2,1]-61.60489991959724186217792544996854432815787165207437256136951921435310313506786`50.15101993285939 THRSub[2,2])/(1+2.40466256982982812003107917780492463392452983368872903408567113356557514830703`50. z),((266.5069271011134665681197326364845296730434177320786094836047`50.+ 1061.9690480111839033372869708713058171043445071002322906935235`48.7626861524414 w+1384.3373836705556414312217260146125286958362110483560039988623`48.7626861524414 w^2+776.3832964108029467524695745976642901454881100457495587344223`48.7626861524414 w^3)/(1+2.40480726010497017021470175167254061828595064714064005365597866411798298260174`49.52287874528033 w+1.47520214120092740125244260485790926997563948959740410476721766888411843637638`48.7626861524414 w^2+0.20264916285218003523056732043695162250179272294500233289832040121887978817794`48.7626861524414 w^3+0.31168203116213113400197980728822556986211080123141415560136447117650027108513`48.7626861524414 w^4)+550.94514158117302391068589093836494615334569551756423658063`50.10409676817981 THRSub[2,1]-84.89800716255442445903033882319394769922620552784812124929101816740551393339606`50.10409676817981 THRSub[2,2])/(1+3.69198176795582780485171699048102045859666671450553975551101265019101735858861`50. z),((567.000644343126183387856565711872344785283130276181104539346`50.+ 2557.9517659144938792533226363456300814810144493332005121394018`48.85900379833048 w+3698.493408086140157119145754470161483653889689822438928984548`48.85900379833048 w^2+2162.5162958478853822893474346380194522798558648037495509042162`48.85900379833048 w^3)/(1+2.58134202033364753608853350936921841487624712736019357829796915660578732332293`49.52287874528033 w+1.77311755854221561305153626986190789409889391933086978969645539839970422124919`48.85900379833048 w^2+0.21258861593765702252757524605241388051338015518625403000824894776853718481766`48.85900379833048 w^3+0.39770518275885606893993579519459283419845416895208341076903746509591120164856`48.85900379833048 w^4)+1283.3417368540665289125810307254500819662144037970358691157367`50.041673923147044 THRSub[2,1]-197.7568141444243173630105145058514612465070166301487505778618`50.041673923147044 THRSub[2,2])/(1+9.92924789951865962248653220335485946691969232665342979841268554679474535182167`50. z),((381.2077905105454513232696954326957816465748984686529598607805`50.+ 1632.9504098110788413421393495964961148403584667152308272524217`48.819987900141456 w+2262.0470327249207974564935232678658234299065281185199144374493`48.819987900141456 w^2+1298.5519434394813656194308486739520615061182649753238436184454`48.819987900141456 w^3)/(1+2.50490999065932284794800895694484077727319006155300561972179199018319128427795`49.52287874528033 w+1.64498007607133871547321645479921559771503014870219297943118005301261448666396`48.819987900141456 w^2+0.20797024441276256603650630514302155640207424414171085342723705899275447498182`48.819987900141456 w^3+0.35994814665935717849138515078851370236103065121875218308532182599282355915345`48.819987900141456 w^4)+830.5067996649316296516055791343868127069251111597233096231031`50.0662024364946 THRSub[2,1]-127.97711950803223154601751507817620308453168701958531914299624121650022107882294`50.0662024364946 THRSub[2,2])/(1+6.07279630601313169616483757321005554988330538922717667625330931382256341572525`50. z),((251.6307792093557857004921015775598811859616753902058288752406`50.+ 987.9192914531980467559495263969192327163512718188763914743666`48.75045656370647 w+1271.6103550735675845929098484126436630692448181950239745469273`48.75045656370647 w^2+710.0689950530545959628756701191569969458334037686117698720253`48.75045656370647 w^3)/(1+2.38515389260051571527472964453978696402078007007704778561430512130060581577619`49.52287874528033 w+1.44154568361377370415931975566240933206467918017810721725009510283976186581653`48.75045656370647 w^2+0.20175896960548984977028326755598066387627343410685707638488594490815145187854`48.75045656370647 w^3+0.30237658911206642780807900452011952951159930484874109052682049369085246264295`48.75045656370647 w^4)+514.6873450232353072935640102974606456479393090957006676314082`50.112463567740974 THRSub[2,1]-79.31085439623728771473673155665676405699080182704238650727611204781988650648478`50.112463567740974 THRSub[2,2])/(1+3.38320162351556556590412463386377031774828397855296772506349487731704610915443`50. z),((96.49017548658244191677098234593316845995189684117051507601900282346354311209677`50.+ 254.6433939209158201811136120170518437449709110669555471032467`48.69693717565535 w+178.2602264665045201846839722598426254443313882650854805391985`48.69693717565535 w^2+131.8267432347234205272058631919973400836984157795150031393822`48.69693717565535 w^3)/(1+2.22297927668377870371937855386600440797893058214340581928193770671735134281218`49.52287874528033 w+0.49765427305125445990241428826467304988747081262315041298880770718023483528945`48.69693717565535 w^2+0.32612231326548171962420766237025002023434681299907947792231807259532013013343`48.69693717565535 w^3+0.07855370793143699255348908253097394227152506574617177451359834904872069022078`48.69693717565535 w^4)+136.56146938760891048753839565366706933050259112069983416153591033462922803852149`50.853414046090414 THRSub[2,1]-21.04346827149580391072343467652031503749111718250294218278396939703315559006921`50.853414046090414 THRSub[2,2])/(1+0.16299042538614611530897765865705121761615028910372667912909514625124061058873`50. z),((94.20798194728979389504295270153848179739957049897473803466484067905936078389895`50.+ 276.1451837622496758229942812422426148645740806953324481127454`48.98944721671703 w+182.3224872920297785649065986921884216712716960672319026157961`48.98944721671703 w^2+147.3794109518128258759501798243981414939452497025110298811803`48.98944721671703 w^3)/(1+2.55934490129474418866971981313000536469572751556242751222103599708213783980437`49.52287874528033 w+0.5395046724371586723559995618694938584601111684836553404345878222811263065311`48.98944721671703 w^2+0.36472366890352921184210421268472787119136442503864509528732055709315925094017`48.98944721671703 w^3+0.08940961305856206314969046023987219451443745326431862921956283526763254487979`48.98944721671703 w^4)+130.99905432857606311135918019503732583210166892985365600301191682800745215667917`50.98448481943332 THRSub[2,1]-20.18632675615802957883604159088346139682508508539204131183327960062026680802373`50.98448481943332 THRSub[2,2])/(1+0.11561955654086776403554434098911717188652297147555164556427267420762925071084`50. z),((94.62494572710075846649863535188219026075479326809299467585448203667373402795701`50.+ 269.3313252940581960272423982886206442047966802117046908623472`48.921303598137534 w+180.0497363151118931625600585240399991107607475583400291395039`48.921303598137534 w^2+142.7690132947105262682836878172784149100528309545420888382563`48.921303598137534 w^3)/(1+2.46618529840555874854973806130612657414728583643722569923077861462471456623212`49.52287874528033 w+0.52487006305776431012548914405563412356774276289822381272350864319216275797788`48.921303598137534 w^2+0.35556646353297088304469289457642309954639348184182985849113140511087138105757`48.921303598137534 w^3+0.08564215816279396507257423427997233961391475511573806236782502853221293820296`48.921303598137534 w^4)+132.01532467022755446924613777861295337796160936172858708561834626249696650304944`50.956490771105024 THRSub[2,1]-20.34292914763570822477138928412852268927718901706744723635640257371078778338414`50.956490771105024 THRSub[2,2])/(1+0.12427435999490730020530524259645814830662449202836751618351564651842719687045`50. z),((228.66665697524898753780310223637186701625396010341692090188`50.+ 873.6106203657148080802141839477079015390076672143455988107676`48.72749706500014 w+1098.4077437791038414315408101051088990184537725067934018188247`48.72749706500014 w^2+608.7646180395881706666310551868601478526598734449442422685071`48.72749706500014 w^3)/(1+2.349799127075527571932965180844694285078683591422999543221277973120908312236`49.52287874528033 w+1.38067549711546683732609580860672096126270364821437696121134076188033916930139`48.72749706500014 w^2+0.20033702022695540998406515122574903881704302652749507700962419159580804544868`48.72749706500014 w^3+0.28578318643723820360131365785626630599592051231168647341587448932531196669596`48.72749706500014 w^4)+458.7166409031729584356905286988569773275461942890069383075443`50.128415910131956 THRSub[2,1]-70.68603700399939787362961595759536059542225951098616263766900410296317176718409`50.12841591013195 THRSub[2,2])/(1+2.90654160158071247555949563813099501242868329235113494495412546051055807442726`50. z),((276.5821694498275148173372576606659889858490097328871101705628`50.+ 1112.121425694421735326337385894337312852524530034717869537197`48.77004780927834 w+1460.8808415656277876883514299261335900393926457509173833527086`48.77004780927834 w^2+821.5498718201296461694498994589925301085957638516341694796474`48.77004780927834 w^3)/(1+2.41691839013615069853090621253381336234878684842698885376188722818094189080277`49.52287874528033 w+1.49588382608164081809324093961706547938257810342591029099282017450876144680835`48.77004780927834 w^2+0.20322824339080104285370386415539173470984574934692585926852475257473617932821`48.77004780927834 w^3+0.31744503832558823688464926520698174010669620088360931725840497029141679802839`48.77004780927834 w^4)+575.5016390030623977508331675002523860258658755788549742592545`50.099106234801745 THRSub[2,1]-88.68204578394528295552587570737997242922496052306083669471818810552471421522614`50.099106234801745 THRSub[2,2])/(1+3.9011108254472687994184277994459669455790493897738899708484165613284986726976`50. z),((477.5806046625623462400771045198379704679152569221554271033297`50.+ 2112.7424560704134519211190774869364803642819982346230438270138`48.84443063352774 w+3005.8452364578462679510357897384430939893559742909881701639943`48.84443063352774 w^2+1745.1265957280144383518705120308977758847672583884897418011219`48.84443063352774 w^3)/(1+2.5519449206247778314844384102575437290159546626486469514102392317670528792067`49.52287874528033 w+1.72396462421878334386666248418005579935751332760616398160777457156252585748034`48.84443063352774 w^2+0.21077535066793565256901326974668542896845854697264136127681355207384185482327`48.84443063352774 w^3+0.38309712082864561036120607874160098405794696636373158070529787671455139155232`48.84443063352774 w^4)+1065.3973045634350882604794643592378171352399933118960733723189`50.05071488804505 THRSub[2,1]-164.1726211328542982169089398681979702284224714206806667287202`50.05071488804505 THRSub[2,2])/(1+8.07318052446138541048180951854123588328216040304926469459112342216145196044676`50. z),((98.56005556546869861081829745243030609207648475790508422906862733653758893308738`50.+ 251.8594886876185394765642770514130472409614920855037484032183`48.52105233091047 w+183.6072938013286640831369331225857940636438706328925585481151`48.52105233091047 w^2+128.1522943725463370909090460198397968094200892756575199198953`48.52105233091047 w^3)/(1+2.10099492868663749912938009049278221931332369122041319365010193264174612725613`49.52287874528033 w+0.49999378454195880484817998861586639725116680758867764157776835015089371026921`48.52105233091047 w^2+0.30425508225023817151198559953223370317751340990559416852346802114999437277009`48.52105233091047 w^3+0.07879085855151223636475236188948677072630698238412263167396574525178534108777`48.52105233091047 w^4)+141.60641054748861176055662426024916170205891899842179481275085737565145074282161`50.767559878844686 THRSub[2,1]-21.82086953779416275182974854565259737670549156051519392266725957154907032904944`50.767559878844686 THRSub[2,2])/(1+0.20595436164054717657323499269009171237484666925562953950593747893224586197807`50. z),((95.72462499577850665794508821236184379785374165616804361023351294175009214153264`50.+ 258.4889854215858044294421090607428339388904487337101920587353`48.777289521164356 w+177.8270223360543561490042229281788434098068541805457766411126`48.777289521164356 w^2+134.9690549827259942118265180762792191064775137133782968101462`48.777289521164356 w^3)/(1+2.29884914514475054902445076606343907268342376813945104826042364133713824237126`49.52287874528033 w+0.50354424728087167070077121449263903352277302981875042021290059007008749680298`48.777289521164356 w^2+0.33655852069422051105448602804302637838027588672955388089615338799446742899178`48.777289521164356 w^3+0.08012843248174703143857339593180215280996676641238854071340081533520424656903`48.777289521164356 w^4)+134.69558487554529561728288516426015675362873430170226797776455705665903718383059`50.89198834284716 THRSub[2,1]-20.75594440620669152624881808889664298384698458776903239293559472458200510062122`50.89198834284716 THRSub[2,2])/(1+0.14710010264622996475534621607929244528011675710028077124917949277538772904401`50. z),((94.49263723722910039740889556208180221458683260155438323028355234772537658398054`50.+ 271.2803448458917071402693253898649684636499744621950441505717`48.94190778105654 w+180.6586530907187210010325030861286724475633234542278305521408`48.94190778105654 w^2+144.1021458279771017985263337724216895227898113833331866149087`48.94190778105654 w^3)/(1+2.4934017548529153343143463320324655459853520903124887897765550159219847218985`49.52287874528033 w+0.5289973449095840113807742325369671891901598986633552570454949469486616650151`48.94190778105654 w^2+0.35832123346594912910043910837879138557619226509086743881361198753872804062686`48.94190778105654 w^3+0.08670466038770661018212456521808142540004170129915187618708231529498935128006`48.94190778105654 w^4)+131.69284775324876462799799269787305973284574725534941757664612558396096295989688`50.965133550810144 THRSub[2,1]-20.29323699946855698308414756568231835250385193803547329550904675518006300789472`50.965133550810144 THRSub[2,2])/(1+0.12152806875671119697278675078953406787008941017254382475961259327306530194619`50. z)} /. {w->w[z+10^(-10)*I],pi1->pi1full[z]};
(* 20 each of [5/2], [4/3] and [3/4] Pades for the non-fermionic Ls part *)
Ftri3LoopLsNf0Pade61[z_] = {(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 71.6761173053651030481111835432449417605572589833896316621142`49.69897000433602 w+291.7929455007749828720082160812934815862347029567624889264793`49.69897000433602 w^2-392.9858565304533531384712608737920566682133204618835156713703`49.69897000433602 w^3+123.5666216771320395398055933028336245139766717010071385351437`49.69897000433602 w^4-18.46373611344163380252645407053833525873105156526114365033966566867830386180041`49.69897000433602 w^5)/((1+0.3121079297491043192570997424347927941735577590638507678388160398877419653225`49.52287874528033 w-0.6658468061416197234879062587102870401991441822097547555294353664987039698554`49.69897000433602 w^2) (1+9.64997594492056670166137002930911911647637269991152710903383917325340745317419`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 51.81864683452599357463610677173561817046388747108918108237151107289772813109469`49.69897000433602 w+198.8544583338258032027108438503604536860554823327402585950018`49.69897000433602 w^2-269.4546237880954160922946994325521548204277981120850498309474`49.69897000433602 w^3+82.7608696171870604773816604910542681382860840475554007596631`49.69897000433602 w^4-11.86497926551344617434130607892315241769411084427353769958457512505312695587248`49.69897000433602 w^5)/((1+0.30727296964631213815447321855049523805075301068041788401573922587807495047929`49.52287874528033 w-0.67032234476029818174454459926903248201045271723235772359026386002736742765882`49.69897000433602 w^2) (1+6.51579461060324746165148822267345820180812049032839147312981679710029719515066`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 48.38650277638354714901488714830843868289616427465544438299069453757728968809861`49.69897000433602 w+182.7915893539476159207348037697235677265340066393939747607764`49.69897000433602 w^2-248.1014625797223073116628596692972032474854497011194085004369`49.69897000433602 w^3+75.7032766427148441732246879839542406582190318545540632283109`49.69897000433602 w^4-10.72279657273610043860685387467778107424737324153164679025688388930849885458287`49.69897000433602 w^5)/((1+0.30598611715279348979448255127411112102605704321467080187773932155509948914714`49.52287874528033 w-0.6715087145022772520515644685958146619000256347380036045943747385413203447261`49.69897000433602 w^2) (1+5.97419884086203031969603015947773641723781187223159559598342099167041363715069`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 68.8596080934933390670433167108242820710344830678059727520882`49.69897000433602 w+278.6106853461924834323440418104760863731727909175377820191335`49.69897000433602 w^2-375.4655337058463939819975262650149383942208081550402480446773`49.69897000433602 w^3+117.7808385845707193060096910018644966021368206044016123699227`49.69897000433602 w^4-17.5284721316906863044293570082856588640349264446856627533594651259968624833256`49.69897000433602 w^5)/((1+0.31160585978534191866049575072416476439881224707197339921106325019908704865371`49.52287874528033 w-0.66631283105726401332540593235346324860312786408374297846733860204767296734292`49.69897000433602 w^2) (1+9.20538948158964983111559468527561933083751551229100620447711000480639853063672`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 12.04021261967712895040284913027041835182432253574913611116534152523515028344298`49.203306503924395 w+12.75602832576399860583812229385945737339805485505107879707385658954007812532543`49.203306503924395 w^2-21.6920773234583442933448437137638592012709283632609066018579`49.203306503924395 w^3+0.27910396343517427882194868797680630567945229602738176121936886852277936541526`49.203306503924395 w^4+1.61644229913098197994914014062589514199404063747120323107675259875856939284667`49.203306503924395 w^5)/((1+0.20600407831757165735297904389107156631006637349777437168151823188489380244933`49.52287874528033 w-0.74485563334460243633440510421104254810745892534606805038528133867400344890672`49.203306503924395 w^2) (1+0.26030643109087500960450529663328256943178189667561403776241325494670800897709`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 73.761864424032518029725438631357555884798878722333733025135`49.69897000433602 w+301.5550114612020420940888639097937278452823693636465279362945`49.69897000433602 w^2-405.9602857936056493507307089765873371819132240824189851834569`49.69897000433602 w^3+127.8509608995601324810331080123061453919138004983077466845934`49.69897000433602 w^4-19.15624094240299676936963855904305505392767930080666585872854102201021767523169`49.69897000433602 w^5)/((1+0.3124531342239902842787527301759024014431577938948151069893641872318118817002`49.52287874528033 w-0.66552621940558445126246664212393307479068238634921383575578876314943018113934`49.69897000433602 w^2) (1+9.97921813622301599697662863839162289217080738682654634171836862461209795977961`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 48.81875744602792849157321692318498694619508003237312581601137022876951155492565`49.69897000433602 w+184.8145831996675035456025115772476256820728499256664575122719`49.69897000433602 w^2-250.7907975176827386933350263713742213472823439593688456361654`49.69897000433602 w^3+76.5922487414991841952899566455020215321111285596041419007529`49.69897000433602 w^4-10.86668742494154136641500733115582975689407286998944995893898268781644846734867`49.69897000433602 w^5)/((1+0.30615934808253421147422749465978258499423336573078220319183852363676850655615`49.52287874528033 w-0.67134913340428876456086512360590772160097551613901490157577048991877054381746`49.69897000433602 w^2) (1+6.04240627044186587757477757229603669808243870071591090306290123697744480133645`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 56.94088758852939205119090789844260930848039235117460730932012225055824170651656`49.69897000433602 w+222.8275588836778192801915608784631422093728249366959715937607`49.69897000433602 w^2-301.3212489596180271248213094517695000633574700142686435951523`49.69897000433602 w^3+93.2904946452180559439048601557440457819076661950770052251514`49.69897000433602 w^4-13.56844200497489391768736560827921383198659270489095794541324176042763866326755`49.69897000433602 w^5)/((1+0.30887565639337994843580477116862088470508167798531572715158617839087628637158`49.52287874528033 w-0.66884190204088307601694120775423172844537244689662043846768837630739683856951`49.69897000433602 w^2) (1+7.32416879481175395274770288084108328562082856772617225257852626401507573048584`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 11.8836251796045029145512365889731255423701327324439022896922`48.59202744733252 w+12.0238042209586754817250379753079924771439638098115652167872`48.59202744733252 w^2-20.7159326845823913760146346422691987829084730422957618679359`48.59202744733252 w^3-0.05215217257573791296324129424679866875555176826457120167452493371697118501991`48.59202744733252 w^4+1.67218654343978408198242661859274434033210465852798033281915663555047032260782`48.59202744733252 w^5)/((1+0.20228096663700398709540618068169764837010256890547899570361238069268805310732`49.52287874528033 w-0.74583116322145721627006189871482974620303722385565168660409351324422614004017`48.59202744733252 w^2) (1+0.23651287636797071098180179538868507900295340519654479237014557753192311818697`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 12.22852157883351330923273513594165199529495843448937703615109530579823691674468`49.45614840502905 w+13.63631939180555778898773749910948847716719032811833120593523767982084730321375`49.45614840502905 w^2-22.86717069585244526221742755771254388158198774357227255983438221706307106788765`49.45614840502905 w^3+0.67940610951305010729825718317194078456417102673960701476991135294732369699279`49.45614840502905 w^4+1.54878909691443447891622599025604543251584658698642517712382303183458805310196`49.45614840502905 w^5)/((1+0.21005437608491357561238049774262755269223790897085480374596778619611281742605`49.52287874528033 w-0.74353188704830237074329239093885688005456283711730629151956473702252238476785`49.45614840502905 w^2) (1+0.28902685020004758669700535511848309548949731260843841823144330846431185780383`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 60.97568137433665158857395480293336007395729477942454198925423727013901745173904`49.69897000433602 w+241.711431807988427833184513809113212595142561162049990992581`49.69897000433602 w^2-326.4216274504253348997962440476720621489844308118619110015284`49.69897000433602 w^3+101.5824952615184659328896772976024732443207895937104106372588`49.69897000433602 w^4-14.90949722761401861143652306745796536263497691226267138972481987765165828602398`49.69897000433602 w^5)/((1+0.30993064887948122836355499419326911861838394222032091801654854228869664170784`49.52287874528033 w-0.66786567238975473457665540406466929406379254928014202316043637759066617063527`49.69897000433602 w^2) (1+7.96097774971242750708940431000451345327043496402271944447208216444441632952104`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 18.54637193885272509148968703816576972309701847666593199865429909165603595371023`49.5072785003738 w+43.1660187085593883866914631336960233691699335471711629551144`49.5072785003738 w^2-62.3271972992690011232893701759819894185873914971741402826337`49.5072785003738 w^3+14.06107720888660787320018163203455451048021427246757121712374674756094056609855`49.5072785003738 w^4-0.69369033100642140373235144710897624883039695837905301533678441481946858268903`49.5072785003738 w^5)/((1+0.26662037753998996201504601152818451226789063589999603330761785988909299541746`49.52287874528033 w-0.70636953912514740285391557504773305980811106911333565259465315401833540809871`49.5072785003738 w^2) (1+1.27244066983931192940006822439169139156433045332508188410131138253715841439492`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 17.4021313327168984813183751884828379694086632098765089481434`49.21389827314711 w+37.8156900715382260451405816511379348612187629423216781626618`49.21389827314711 w^2-55.1885089770640503895591713642084006321811467326409344529897`49.21389827314711 w^3+11.66158416744424264591965067545650890403604856223248439669984622557484085984425`49.21389827314711 w^4-0.2964589654844490600909698291124065163259128901680113790145823986156079665877`49.21389827314711 w^5)/((1+0.26118478084223406234336451076585935409313100518604294003654835141364688179559`49.52287874528033 w-0.71086213437856607705051299663018210995579540086194793470350050329276948645427`49.21389827314711 w^2) (1+1.09312999962388354481725514963233608842038531887892221388757223317396009551185`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 53.47728250581757839522268746555019916126050065513032378632917176033492173992985`49.69897000433602 w+206.6171586626913065139319149350185019951354652711844171815559`49.69897000433602 w^2-279.7735513043351730132700574235883664267765626812343222871362`49.69897000433602 w^3+86.1708670392371445678337037086882799914795357412901483027074`49.69897000433602 w^4-12.41671553901214560203374357321608529662105696377114152871303598837746645255703`49.69897000433602 w^5)/((1+0.30782920896345992367618201604505537070970120309576617739031426363298082925104`49.52287874528033 w-0.6698088919213857375508253297619896487937890564929414492768922991881574905175`49.69897000433602 w^2) (1+6.77754539360947390799525797495475200929548026075733913939346266658456186861317`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 58.50066336568546847151389696421001932157014207350851582541853285915552794414141`49.69897000433602 w+230.1276888605812479120256794623272482272863397273912235639467`49.69897000433602 w^2-311.0246764791711529598290182818609982706180189823331604791618`49.69897000433602 w^3+96.4962278266737222146134655313518205289764877995274529361003`49.69897000433602 w^4-14.08693877177568185608674489485231456350236076345769036854529396883853529915495`49.69897000433602 w^5)/((1+0.30930245163742850689944227771450256302919722613094796056674192393409633998334`49.52287874528033 w-0.66844713090122602896976078816688159473260191053394977677636005163218426530284`49.69897000433602 w^2) (1+7.57034248186749072160384440932578286810660226842670899864997746157281517820722`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 40.61069950793228249260447334409897081844740668780938930162382334064790511882118`49.69897000433602 w+146.4008964308039561261407252171918866434385076552905669533397`49.69897000433602 w^2-199.7197812731617191240098737171492760664419765882696953232729`49.69897000433602 w^3+59.70404042371619889543622948949396039263630101982279161976234652508533306485609`49.69897000433602 w^4-8.13171317972036404020075995592921939742827160304008115442166902677688050356004`49.69897000433602 w^5)/((1+0.30214626831182214654845408952433869530978959159208491512880122328877984945773`49.52287874528033 w-0.67503577209103019760206825564572216614114241245979504851516109360448370589289`49.69897000433602 w^2) (1+4.74740039226417873607431404267157933454339069510895597844544308217294181302561`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 44.16348846379352148429907047448847289894103551573439190901923174565757067471094`49.69897000433602 w+163.0277027547360189465885010818590304173339529702937009939331`49.69897000433602 w^2-221.8264146640613254697199137254929868869585961255802557443053`49.69897000433602 w^3+67.0161303532694252763572476537894179901985347835018208888447`49.69897000433602 w^4-9.31628086703799832836838770833916464744922270564634607465947200318986678106077`49.69897000433602 w^5)/((1+0.30409117815029165317982004764451177802364133247859518379132611595857630226119`49.52287874528033 w-0.67325177723988259861280266041348440150669292898740500717643636514450818949857`49.69897000433602 w^2) (1+5.30788084204580962126298788951882586604813231166496673183810234783772427728338`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 27.46503336676284014955487471708110239549997079735425029878469033847816197644358`49.69897000433602 w+84.8860659051697980896439335806105025940586657477926451392854`49.69897000433602 w^2-117.8984599569496891689348037263322481270793043101933115670033`49.69897000433602 w^3+32.59306396243487134213311895837966740709488728503324775635583086369855606466082`49.69897000433602 w^4-3.72928258921118191274088961009231810970838900305183095434600390805428632365198`49.69897000433602 w^5)/((1+0.28953062756156117430032073239595265361731811636840656669718585553762423749658`49.52287874528033 w-0.68646688280486823470347970020400828899765269619166170298079278383292716491589`49.69897000433602 w^2) (1+2.6749228064776215039179897040034860939748081601587540520504938639219720040393`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 72.6459714926058665460799067597939490051700443180858914406989`49.69897000433602 w+296.3322177737961357488829560553240028711408402277293143855762`49.69897000433602 w^2-399.018865679680023779470864906733954799673431682726850448992`49.69897000433602 w^3+125.558830357640471933816291914034900321725785183966544684919`49.69897000433602 w^4-18.78575467080040792829429708538933338700515187512900713576500839316140371672496`49.69897000433602 w^5)/((1+0.31227110413185490955079516536365066912380732029514864363635524311475215609315`49.52287874528033 w-0.66569528502081866619059903097172084117447452400089049540205671179993929856371`49.69897000433602 w^2) (1+9.80307002299447329060932352355832684425661852034524168817352986367400165067205`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 12.17422776285148176716163291433714418439872057734173396037449047689362828525387`49.40976480022525 w+13.38253496154816728841997153598925750184979012365717339300421701417670205595852`49.40976480022525 w^2-22.52825623122269172019255721539325605492117684598704675971252023937503666454202`49.40976480022525 w^3+0.5638224326142220770093203537117518834789314173710048773231391665055383701632`49.40976480022525 w^4+1.56834744106075256950141698617890346625105885626440991839942474665557702905435`49.40976480022525 w^5)/((1+0.20892887964859614691894230895618186765359374388083536467093311318587364317786`49.52287874528033 w-0.74392631142704261407633387179654899338829152411319177623932352888092811940828`49.40976480022525 w^2) (1+0.28073551652249038459598034100911959923922606064710304109429118746716867341713`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 16.666487438613356590050714221675079294019050640105723092103`48.47721753092132 w+34.4105441342242143490443781691030923281444375792083597205361`48.47721753092132 w^2-50.4339693511301768793260373979955554330838700177045741640095`48.47721753092132 w^3+9.9148306088432001891210061388628726880396348249187032429176`48.47721753092132 w^4)/((1+0.26074536283173873677738417793838706766806176635909318256292291373929361871086`49.52287874528033 w-0.71325765815118253354930805917352490304312034563338166371210824561031260881192`48.47721753092132 w^2-0.00264738181844424644284457395437716425768961143614144449677350728481026374938`48.47721753092132 w^3) (1+0.97708555505752707758754060650113700075460853862185994632622981570020318951093`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 32.9073810901272649439239508594705884241455875415260818815072`49.52813989149614 w+113.0995466062510368533999028367731683898054425586743579886974`49.52813989149614 w^2-139.3443514719259088380999939860345169185688217702225034304379`49.52813989149614 w^3+24.22053561337380830040253968840387839090926339194130158738160989475767910601261`49.52813989149614 w^4)/((1+0.4057559155174481605642679628616128714679289723660252698972445317770796190434`49.52287874528033 w-0.66757665586620084767435667633577337289068972436309108630260175320447185061488`49.52813989149614 w^2-0.09800123980810704555355621297406161346005702202872992630644692185287649997244`49.52813989149614 w^3) (1+3.50518454607250630383133070834330567561409493208123406157620177324239501687065`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 47.8579421343577932363810069709175118707000048327148397417478`49.527515920000866 w+184.9715198041051493011930316779283890714088835677307232710975`49.527515920000866 w^2-224.0771441365499272753215323851708159417366320737473306137191`49.527515920000866 w^3+39.7097937714268289107106327925267045374892490400428905182853`49.527515920000866 w^4)/((1+0.42235446511088578260824414783448756008730131025917939685646485493078914137952`49.52287874528033 w-0.66360948268371999683396099419072083281429819448202048878279199696376988936775`49.527515920000866 w^2-0.11087502207085912895893027326915745308351087370597869545873973599253075194283`49.527515920000866 w^3) (1+5.86164981039475662870829289022328544238889668305879272910021553295893968654464`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 51.4509269298070858755736533234587352431581134069616962840948`49.527806762885234 w+202.2333392775635009238477261933949971613411384725267063206793`49.527806762885234 w^2-244.4954963123595235230441370831605561633025632254568781673275`49.527806762885234 w^3+43.4764794113492394154475683426436360114191829435084925739397`49.527806762885234 w^4)/((1+0.42440424733528097615480214142649307388623924854692141060996977510489949725082`49.52287874528033 w-0.66317733302025242627773123673402297597841712053779552145341450505107294219241`49.527806762885234 w^2-0.11253951623606896773835753822410976352754838819772581484487458465793223812318`49.527806762885234 w^3) (1+6.4284507535938092996678607106475824911693898681047311837177622832423863540226`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 18.56410775640160880066826095738744615242748951746806515302423978395723508631138`49.5020830115704 w+43.7689165062076386682817092518849639152948277974237598082073`49.5020830115704 w^2-59.9839435660547713087136130745614659428203438432679749432885`49.5020830115704 w^3+10.91295802976227041587662118501442829973859409318853779447276183306062342826441`49.5020830115704 w^4)/((1+0.31352319933839221307688567275480078071034240879643931958245482083624344772086`49.52287874528033 w-0.69573521158182817799437675529063107715760447659800737095798864093866573212801`49.5020830115704 w^2-0.03550544053393022109739160956673240799659907091811387074061788865155913649207`49.5020830115704 w^3) (1+1.26351535663427195229438313843582833961116030601708742460636582267651718464245`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 61.8874508332182195253159577993528737169376572879829907575475`49.528698061066905 w+252.3635579459948379135261293528804165400577421030839069446142`49.528698061066905 w^2-303.8561319744226013662265134309763851617512590780378491024357`49.528698061066905 w^3+54.4590203512128009011047871978403730148040082164839500974567`49.528698061066905 w^4)/((1+0.4286261295870862505033174688088738677459156842774545375409457207292610404573`49.52287874528033 w-0.66234042826598764508066870428629563525752408181918425774169417450084843000697`49.528698061066905 w^2-0.11603462659098563597143185761794524009396628713164881303669620195957730276906`49.528698061066905 w^3) (1+8.07526747830630013630320100657474599909071452985971925079445153031914255346308`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 62.1465201469874211704705003680524997848494880541902944304282`49.52871934263575 w+253.607819700888679810782828082447633985084526158569605008056`49.52871934263575 w^2-305.3303623335764884996313317575134166367917140230685587042631`49.52871934263575 w^3+54.7322078494803566281615855935017285426953039417140113491911`49.52871934263575 w^4)/((1+0.42870775251533459536736113796588591382967715379985124496839416082686875712863`49.52287874528033 w-0.66232501951310456808449918355853168858420585247549368535704948787635491247928`49.52871934263575 w^2-0.11610315969321123877466035537956905301781404812808580352517062915277591907145`49.52871934263575 w^3) (1+8.11615275369569094142738102118543394566111586240666220994635285026130947235897`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 21.36539823742480623101646584752909205725949965140855553444237638434495761625738`49.55467865439114 w+57.4152129472407996886270514704371071556190168153521413071211`49.55467865439114 w^2-74.9431000379426805407399511334630841358253485579619901635947`49.55467865439114 w^3+13.07774525121093493059024577777987469262584278234631611071017907827629485472393`49.55467865439114 w^4)/((1+0.3539332518269587005011261150410433924924711521385764539331095460682164906957`49.52287874528033 w-0.68273082264642951480318665442417206128096630443810760093732083099135664630013`49.55467865439114 w^2-0.06172952801318960893215045506099292731732075460497435715414734700391094007127`49.55467865439114 w^3) (1+1.69572186683158255628277643157084335584962972027744994386582764759841033756436`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 23.26389956944207184370020050127279013037027585074939007289528153704838097905792`49.543347339851486 w+66.6109924494287028856861508831521807622017846241930764944663`49.543347339851486 w^2-85.3500996125366879032995111693011401526203925135153650966772`49.543347339851486 w^3+14.76089381170507155313235775952467354941156887357503605510370841847208697934872`49.543347339851486 w^4)/((1+0.36996605033730761247512288098500726824026836803257758969080258255005640442641`49.52287874528033 w-0.6777757199357579467747798052160038445668187770853339842062850528982622744091`49.543347339851486 w^2-0.07253063834202182021244734877302642556829681264575123321925311741073338428915`49.543347339851486 w^3) (1+1.9914770354172477934498669222549099774038556056735322265120812130946238829823`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 47.2053590307188655096790683140386145119456111829429859918016`49.52746736213245 w+181.8360378378269831776737464130125430218865624625555371292445`49.52746736213245 w^2-220.3699944460526661911530257014897550328325373412826117098775`49.52746736213245 w^3+39.0267676641008805314589152129857824617983657016876981134957`49.52746736213245 w^4)/((1+0.42193521755236175151309140995245414898740688694820528354753358879516887505169`49.52287874528033 w-0.6636997659157694215677274652915754187829498342774078151419706089578432414737`49.52746736213245 w^2-0.1105369793893937168868619240276530342777727898684754038082814504183212493069`49.52746736213245 w^3) (1+5.75871518486771483752914339202870473851843971260679506449288974306973895490542`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 16.3572695390965809188909931078320336377616245748816891787189`48.73242024216143 w+32.8689432752603330745733578523758256242810956187114020314959`48.73242024216143 w^2-48.9628562754315365255359720859801445765299410250620513440572`48.73242024216143 w^3+9.8203547194526419040871671063749142729188189971009996267016`48.73242024216143 w^4)/((1+0.24836678605618761437181295398634062956608226585605307589048591844196716117497`49.52287874528033 w-0.71740792409342134981528515833518718517152646367790968182343535481768445125117`48.73242024216143 w^2+0.004900339803306665790853752997067738975820537688303165483954411340437545367`48.73242024216143 w^3) (1+0.93135632038034501537424060504024666455524666660697940297839032047397747797521`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 34.7418611842017052377352464533097444883067304607355920997093`49.527631948110724 w+121.9251311318173993565790078263842949326763478124627124796299`49.527631948110724 w^2-149.7072645684876316458337999233712857412067463823967195608361`49.527631948110724 w^3+26.09371319705491096805821694671631738739621098155086480746603014471150585044825`49.527631948110724 w^4)/((1+0.40902741033077333622618799163856923766885458871633467810644654342980591614933`49.52287874528033 w-0.6667400990625542240467929560831681255244301544295509116070453524780335930423`49.527631948110724 w^2-0.10046632140438529442323338451411465200374007382262304349767914119731500530519`49.527631948110724 w^3) (1+3.79402142406513926683342368964998596261562293628990454911270840954184926980336`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 70.7920902716738672928588818464411875832927683231655092604864`49.52938443691427 w+295.1283092195532255094149018155236018913207827149644189477474`49.52938443691427 w^2-354.5410168239374492817421334552317431973800405180485049616381`49.52938443691427 w^3+63.8595065277342655582322818553847046938734175375788393666655`49.52938443691427 w^4)/((1+0.43100509174658823265649957270160698946637683869069645074634282957179151352238`49.52287874528033 w-0.6619045476119632092481328214532500603561494356874799860626304528757180777441`49.52938443691427 w^2-0.11804841216348818061093373924641297250648589398820586211585855719377486671203`49.52938443691427 w^3) (1+9.48066843857521113037694611961550701334824835207469359061576787094740870319113`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 61.5168302130549411791252600702822991472551182652416837593345`49.52866749439925 w+250.5835267506628655590447150079235423015251503345521408949854`49.52866749439925 w^2-301.7471676884174657859372678994849128758107111468400046253269`49.52866749439925 w^3+54.0682404687168758072738678649909846266110363820912453352983`49.52866749439925 w^4)/((1+0.42850781781782130932950170359153386695374386759201131124408507463402440980646`49.52287874528033 w-0.66236281821758070860188692403726431125444240598053680641426438111636868750581`49.52866749439925 w^2-0.11593535671202459855160431666673941224232217501973311978067117596793787105469`49.52866749439925 w^3) (1+8.0167780109596776853560184643416218567073039541245583520102719451754059134751`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 38.4439686085154524444817798601573631371337926616329730690897`49.52719789221293 w+139.7281094712411956356709240223679542450429731961272354414242`49.52719789221293 w^2-170.6594519526652639884731088466198145924643510825746607621354`49.52719789221293 w^3+29.90538081333785166437369760683226613035086648666962569700671201122521175049249`49.52719789221293 w^4)/((1+0.41419225950731626888612846411751811708408048070749809308643081110288231218499`49.52287874528033 w-0.66546878790081898924608738799343093146832809316097836227226336598697769466463`49.52719789221293 w^2-0.10442427770843510581882154123903331097269748820362243004961407802231364368405`49.52719789221293 w^3) (1+4.37727348929422677683894384629566221362924733711798729890056055098772447835134`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 50.7616902551695150506660969247288432897247740856364606673572`49.52774878226691 w+198.9222082813896168377813620473361032744680396797573304448818`49.52774878226691 w^2-240.5777721770608196875859812393204163313140434284121782102284`49.52774878226691 w^3+42.753195259452316418930344466669802918641879765328156401434`49.52774878226691 w^4)/((1+0.42404174632560189619467258431729616608208615148918648835952340033916428693024`49.52287874528033 w-0.66325260660525101528871181072902776790435777477965125557275206284237708054048`49.52774878226691 w^2-0.11224369767690301227227680520361683879719131677749416851644728362407578991943`49.52774878226691 w^3) (1+6.31971453548240209730406840538858298863095351268628485312913896722733409146206`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 31.68281356483251241615858027648077463959379632220896841245685707070532079204172`49.52865208056845 w+107.2063517777108839603886838682771424212155478144326953491324`49.52865208056845 w^2-132.4363442595500572810291066602744173834183173583545066246471`49.52865208056845 w^3+22.97780416371239510030468261952969090795893197835331891580661538192618380366725`49.52865208056845 w^4)/((1+0.40321642479792781700109897393395320695523473238161361934330702670877588203191`49.52287874528033 w-0.66824086902689842885676040916414458266492558077272106285729428474259637598918`49.52865208056845 w^2-0.09610796358812197605041246290461450031168868326371673500183786960583771930995`49.52865208056845 w^3) (1+3.31246665160058335902232760036630262576040672060617907858659019224122389335092`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 65.2483687222152823161341940014578048236331632252035385752201`49.52896834736167 w+268.5050370540038751118391919892783902914797085045053353376159`49.52896834736167 w^2-322.9833534667985301808015154860759974066762151358120141463285`49.52896834736167 w^3+58.0046741213743638433708325773138557149842326251020842579171`49.52896834736167 w^4)/((1+0.42962106574871365096270525636753544524722899729574538510575301456472842871138`49.52287874528033 w-0.66215475632729853366023830472446616129137059880727354954940324227745403344088`49.52896834736167 w^2-0.11687266924902556841908099263811133273071385936751002901686780140468316013755`49.52896834736167 w^3) (1+8.60568998989700846368597030212270130577257134958739139704196117493819774681256`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 48.7902366757800036628369044748647194947057536924516229907067`49.52758810457735 w+189.4507843672221549047351123173205581917941569200718218338666`49.52758810457735 w^2-229.3740447230873453751421951174982795533687503095073952499484`49.52758810457735 w^3+40.6862114590755970031940642480770432269215850947227712167765`49.52758810457735 w^4)/((1+0.42292650084201735803948857262702061023523566377409911654848869794587274227397`49.52287874528033 w-0.66348731444271984810722271555073112282072527643190376471669382286204951054857`49.52758810457735 w^2-0.11133755087585549267015086153132036060373982986926881245795396801074888366564`49.52758810457735 w^3) (1+6.00871120273916485481720244254313233101071554621747486018264748231852124948095`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 44.442216768287983095564644918758977570516231614002078331037`49.52728745878891 w+168.5587894863419149939567984209396530031758687776397628545963`49.52728745878891 w^2-204.6789981977118182954713209569380387482881171921975833180928`49.52728745878891 w^3+36.1392892429451143372258291976630384742766281871424994862563`49.52728745878891 w^4)/((1+0.41996429974771633389045644967229328916612059739951646693984003446056737330293`49.52287874528033 w-0.66413232538145807148442518273416907359234634052692229514059721441281765553581`49.52728745878891 w^2-0.10895817764573950996122874924177708534223353997420893806308979960582663431012`49.52728745878891 w^3) (1+5.3229222939350526528641037012651180679849118793717034637550040341710883710209`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 67.8089916097258558182163668056839692306897151332524995204813`49.10496285726993 w+295.4562150113499131120159985771410013339019574220558845054426`49.10496285726993 w^2-262.8241032668144797059940961779223298879981291601988190037493`49.10496285726993 w^3)/((1+0.67332575074376239507294663943208102388136980888571196393309674376586883478486`49.52287874528033 w-0.48807017256490086215980436387424676459502723746672865278489782903270354384232`49.10496285726993 w^2-0.2209010780445460125848932299394935172423511038190323453118923449187885236995`49.10496285726993 w^3-0.04949243821868459649057137806569002073745545908883781647041043851464048447938`49.10496285726993 w^4) (1+8.94907269562359998851348987281332771222822855322387742041990978370807183554014`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 52.9219395483400726185595491215282761716132606224959729176291`49.104208375355725 w+220.1469024843798069668091349348092477567494185955128669882929`49.104208375355725 w^2-197.5527664761467154004546725644162010031196804393230652050598`49.104208375355725 w^3)/((1+0.66397163248927135051280094844471230321083107653885292125325464528282850600744`49.52287874528033 w-0.49449908666243493368376249625731447980791701733337501910910836825732325783238`49.104208375355725 w^2-0.21672973723701115177088984247876942614933515832975136424325716611578300807899`49.104208375355725 w^3-0.0479467729149656838430928046191160870190271890765854896423324729044478008883`49.104208375355725 w^4) (1+6.6008240575999938233919235033250604620153704188227408231135231825760587108348`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 16.1723782895129396102087405602180859994520600105672448573363`49.15886120001863 w+34.2577605481999399501250926850790183123489972402251594327583`49.15886120001863 w^2-36.3318997211746771182879668249704010419148417332558705336745`49.15886120001863 w^3)/((1+0.49811732677404698871891445519526234474774628007370307533064674426229578458823`49.52287874528033 w-0.57882107229592925503350299704814418223190889438408225163323490876374947459281`49.15886120001863 w^2-0.12608763868752917131512210415671403459017852631472860150713403943941941361432`49.15886120001863 w^3-0.03454982631163835066442189785545184489439053805566463552211900377718167211049`49.15886120001863 w^4) (1+0.83972533000346312304816219590423502971095204763448441090337874088154399558227`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 31.3170180923344106211966498001650844304486176454069797270839`49.10216954835731 w+110.8588278868688335847274131126065322722815560933962104398166`49.10216954835731 w^2-102.7982825291055043517331305472843145774423284570610399325981`49.10216954835731 w^3)/((1+0.62942300341451860412879465251368857308092454973286174347994168169029748416381`49.52287874528033 w-0.51662088622382756460222485784201486064990304621616406757901127354849222578`49.10216954835731 w^2-0.20014437613887716751444942883422522708284916087179638199688080857496186648915`49.10216954835731 w^3-0.04283609341390247813640231625057601605317758386153340435436538023405289388429`49.10216954835731 w^4) (1+3.19815782707831432619378307919783875120606131729967258239440064626912862359807`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 62.493545548946571551692186408359209504764757825622060360399`49.10474062846889 w+268.5667462821122875550472487333066538138322891158068131635138`49.10474062846889 w^2-239.5197765734086192548118474583352748818417747188882950825301`49.10474062846889 w^3)/((1+0.67056888625468586949462826427958029737123367077000420408348459210155115469058`49.52287874528033 w-0.48998453732890423694376688170934944419246423428176749836543604972567267166812`49.10474062846889 w^2-0.21968689394610007039181264184413238066375144151151250950310826891395279334043`49.10474062846889 w^3-0.04903047500438994258412245714552188574084208285293215309839577496647966118285`49.10474062846889 w^4) (1+8.11048095478071897256214624597122767397287459181121244498791420804921864853208`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 51.9042136540745224171215261282679927147710818358450011226136`49.10413892929522 w+214.9985806809343851839481616617890213327349451169356734299647`49.10413892929522 w^2-193.0902595845364514175723489332581724551234687794527320130662`49.10413892929522 w^3)/((1+0.66310223148764512361375058162040780726328523204356299636931944111111028162938`49.52287874528033 w-0.49508703244793437333760609194130057195910491525736414715447003233790826494315`49.10413892929522 w^2-0.21633470231242336429411395605070080807323768215180341433397741977049711994108`49.10413892929522 w^3-0.04780632205180977681329140993612128564992310633758769136295544818672878420822`49.10413892929522 w^4) (1+6.44034784559794508515278772767424972439559707152799931486538352751518668140521`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 10.90199828443930413236637708152339521865781848290490534907011052075701132544331`49.69897000433602 w+7.50955736551994342231273219080617192309709787580598627688159333150512807095002`49.69897000433602 w^2-13.72882847220556604620788464247164743818852667712848734366562784754733148320261`49.69897000433602 w^3)/((1+0.12112065478036362801815824845705241788348214546402462933215858524837499325175`49.52287874528033 w-0.59126854761709704470511545984569139850520399530114831472065859289927783408406`49.69897000433602 w^2+0.04927817096444513646149942713913241810603719572768883372868510897504880681905`49.69897000433602 w^3-0.07726529914329722182117485262718306216683344883661128019143447550607954426808`49.69897000433602 w^4) (1+0.10180923404288888777455701411067844077529573481391054930309316964707217712008`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 11.1242136324842316169990206634812682011403537131967726084229516138920632567499`49.6740488617801 w+8.64317510761066280127791048868013004971448557296972035948874514255590354769311`49.6740488617801 w^2-14.64796729142787417766700120784761415289286041731804883860699850647251526942793`49.6740488617801 w^3)/((1+0.16277180809654191058410647408402560857558401337430164665883430343752493892906`49.52287874528033 w-0.60313446473303146381759718316811186801087307352848751140109895283962091010486`49.6740488617801 w^2+0.03879481754976963017526200286044645713975255073421906139254065515259683277017`49.6740488617801 w^3-0.07277097527954259026418530158978761109191675591366601376745778560011074598514`49.6740488617801 w^4) (1+0.12648307961567497260138210222359929823109161998768850277750418356367713697636`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 10.99470677842493450811922061765854088615858748333935821750138574392897476712314`49.69897000433602 w+7.98239900036581848934278467075405476820959052104350907121854595512747346438443`49.69897000433602 w^2-14.11290380678477615449984611265765843573956183077549254576971333206914298251259`49.69897000433602 w^3)/((1+0.13920518116861087840414531107776482979143092162533313346000836538696847753443`49.52287874528033 w-0.59691984154891797431647401908778894787052018992895034962008159972431211864397`49.69897000433602 w^2+0.04510949610979985043358411313591752534361977903846725567250963301627417996216`49.69897000433602 w^3-0.07545440335687356672153587155271769818390784465989779659510155005309865801328`49.69897000433602 w^4) (1+0.11192628570671608187587764889789175898264048821060159692331622272422619056167`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 69.4349819632334542827625934222892849556699763150467264515459`49.10502289132272 w+303.6817063201393371045388829330857554707822855946080136176986`49.10502289132272 w^2-269.9527252009650502868824502443270134158101643099259369896408`49.10502289132272 w^3)/((1+0.67407431900822898884374435050672989987052869943490391057812920495594170381187`49.52287874528033 w-0.4875475318864074185193688074527560093331318339705598426632550859972823860724`49.10502289132272 w^2-0.22122853460126199318471219204606639330741184714152458898225382222111227776379`49.10502289132272 w^3-0.04961877276475046017688327082500331182580137872936672207141578508343784414136`49.10502289132272 w^4) (1+9.20562087253236730815703675292971534454361164876465124726549423945491763108528`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 68.3819464998235141392742096892898321773088805696317613339762`49.10498439768449 w+298.3546537369527784797723555419354688033462135668737344719842`49.10498439768449 w^2-265.3360436091884168314908635008480821885365335318127279750491`49.10498439768449 w^3)/((1+0.67359409974985622748375198640585440816849097536143320220995776804195051745629`49.52287874528033 w-0.48788295406552793392251521189228388598464146315548374326040702492484862217428`49.10498439768449 w^2-0.22101857567239060979818370672292769376829224218225958494693480366469244105545`49.10498439768449 w^3-0.04953768331766855832876661030634147762742180703006576014121508414971099846824`49.10498439768449 w^4) (1+9.03947216996644363373571109663923114720157964629640775238379674777556442842823`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 54.9199171543885149733074174924539796611735397773715278699311`49.104336655490116 w+230.2540053799509464786965986550534710857985017964289282212687`49.104336655490116 w^2-206.3133005555832857388476118130862100182696287088149866054138`49.104336655490116 w^3)/((1+0.66556947511239121070859790782639525381759092350613661625449744312452891024629`49.52287874528033 w-0.49341427869252288240282801854554999916813604186605090022483137214088244603129`49.104336655490116 w^2-0.2174525465702302763276458139746517467106898257769051887366964558975951993641`49.104336655490116 w^3-0.04820635766955997109557749862949124865741519182815259696109319915443996308888`49.104336655490116 w^4) (1+6.91589474526765212488211137467843501218898769206133628584804907392321075266544`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 17.5318098853490012865759314368975348024819456092301489690576`49.13269256605389 w+41.1348976814055666387245731155352738236793874941864448472798`49.13269256605389 w^2-42.2912884262387394548424698500020839747822233064432809386736`49.13269256605389 w^3)/((1+0.52692673989953670546827596132653535435608412058057347933205058965488334678252`49.52287874528033 w-0.56795386838362710695561752760830944532529696710738707700252739338361897252989`49.13269256605389 w^2-0.14319282857478302091637951962745773362626715659115032233276385850818336068902`49.13269256605389 w^3-0.03471713227522420302645130375040393376843089579907574264941464011482843977771`49.13269256605389 w^4) (1+1.04717007080146885328722037884711921989253373466507607329243338271997664688237`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 23.393945083645834035703284029348356794124317317662514437151`49.104239526003404 w+70.7841805419849467724515343722112071464203251252546215826467`49.104239526003404 w^2-68.0258101369746676763832063934307644130919726882984381048341`49.104239526003404 w^3)/((1+0.59280660812733085029587611507938733882954907651756846703639764723716400081278`49.52287874528033 w-0.53734205779280170423389573662971895455862889658900938434500115297690482184303`49.104239526003404 w^2-0.18085712034721039621700241356368913011748353685620214460746514468076087506606`49.104239526003404 w^3-0.03862929713568620596050829793049441385948325165794296315388654579751591262252`49.104239526003404 w^4) (1+1.95630039821244127746884969711166759087559460753858047480071708342890094692503`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 67.7267927548618133332601124693880489638512304954032653691845`49.10495973159099 w+295.0403912148971977379639614256515451027238812183187520849726`49.10495973159099 w^2-262.4637275903740965456925653970102687837138209957226354627502`49.10495973159099 w^3)/((1+0.67328683224453418762890621022465048369962331639241488016436703580737539701187`49.52287874528033 w-0.48809731182857227062892461724528604639421032605561987991416583325824000746079`49.10495973159099 w^2-0.22088402723601623802724495504028102533005508620098345647930167675976657693963`49.10495973159099 w^3-0.04948588041292371711829605014499995029712025994263414515707277107496673306608`49.10495973159099 w^4) (1+8.93610365869092664801298613754214530514127286510788625517729229883945745831288`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 41.8790926609099326121689945228365089743653582646803634431905`49.10327946370745 w+164.2856632475252777881912963763851954415886267135809868707855`49.10327946370745 w^2-149.1282893202481414140844286580672308471726320151254716051855`49.10327946370745 w^3)/((1+0.65177234761519911856935758577414274957162597117302434849619147452634765043377`49.52287874528033 w-0.50260070309960721949643401614131083678292112789222761399228747129338996600794`49.10327946370745 w^2-0.21107676552357668185691320538326945511772464946217021527277602402339765439382`49.10327946370745 w^3-0.04602893457443986210526526715744109348876706653062568659870293745812311976818`49.10327946370745 w^4) (1+4.86026647554006872247401256525189750349129237550906487474314959884521997105828`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 16.2923570570354913597189176647780748116218231509363476700393`49.15579965909742 w+34.8647897503198792585530805857728950476655266145993967323567`49.15579965909742 w^2-36.8574095402813432688984343117654484642997959450202747356373`49.15579965909742 w^3)/((1+0.50104399225900539644071118472354160782324016114364793737009660107680734879959`49.52287874528033 w-0.57778369716431020724005691893008603384951018920691065682849620444240865439515`49.15579965909742 w^2-0.12783252859841314356976329637270045380766365502503642708175297893462779850334`49.15579965909742 w^3-0.0345246873874127920517125344378949249407108779809288161498633659296195238903`49.15579965909742 w^4) (1+0.85793767955683695525089887213690028954783065216213121026678184267455953036511`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 18.4397845787681128738285075355366772026238023234925341792784`49.12255041861984 w+45.7275173106665117771190051284057575658743999197044840832692`49.12255041861984 w^2-46.2755156928477015261186231924094100162599795566120676866808`49.12255041861984 w^3)/((1+0.54196574901044842336326015108831997776086774979023546277009648104974492741178`49.52287874528033 w-0.56168857805133767445899914438996341021545254803917339796526891774803158587126`49.12255041861984 w^2-0.15201988752307714632560864359819231008681330306105121389227977031525220588651`49.12255041861984 w^3-0.03517704433889350938946760122440455762152667877628586881867375275241628385895`49.12255041861984 w^4) (1+1.18677474380044275337967055750759028511636783487778013475660067639324249755926`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 11.22674068660634918626636760058203897911734356229595026058784122679780811650074`49.60050039823494 w+9.16635924222214992286444481623224166958822256856828439204378181397323403315529`49.60050039823494 w^2-15.07118132826220740037120383241248371726761399009970491243189795751450537754343`49.60050039823494 w^3)/((1+0.18014605638844112927595648554968391111686531655825489762997350507796469506961`49.52287874528033 w-0.60691664827092368264249114608140910499263517273288540728143168622486219390983`49.60050039823494 w^2+0.033526733985981114067821437410112405827731668565274675007266579592266231738`49.60050039823494 w^3-0.07059194445918781327779910995724634071440520063649268892538255572912120892222`49.60050039823494 w^4) (1+0.1383279997725082051811585894257274770131907440494658411773819501398755923907`50. z)),(1.58333333333333333333333333333333333333333333333333333333333333333333333333333`50.+ 11.41901286838020261360493749713541425837591309718865818221920642881780765737553`49.423247351878175 w+10.1473561175743884210120670325585013913795070236110296790237361818693636604305`49.423247351878175 w^2-15.86570009385039079041151925025100323016274361972123311106869381468370840466298`49.423247351878175 w^3)/((1+0.2100022133140034799787986097475805462844465426989241786502971237251571685904`49.52287874528033 w-0.61191006298714146970653846349880499707189401351977613841566710054794994955875`49.423247351878175 w^2+0.02332640063955936719045625732801893552454592192900240877395908831150898416512`49.423247351878175 w^3-0.06653357835325159281108616275124114477994804282614751684211449818447132059052`49.423247351878175 w^4) (1+0.16122272608435763234838014730573362547264852197104062288566701587605669529125`50. z))} /. {w->w[z+10^(-10)*I],pi1->pi1full[z]};
(* and 20 each of [5/2] and [4/3] Pades for the Ls part with one heavy-quark loop *)
Ftri3LoopLsNh1Pade61[z_] = {(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`47.74459091315667 w+0.7489731855175040203156211205268642503641738684744524499052`47.74459091315667 w^2-8.1514745097155685172316799674162053296782527699713307649974`47.74459091315667 w^3+4.5746544104651180222791726621847785073099835668134234623712`47.74459091315667 w^4+0.33610165629526055872529185615691557857300193176903919096761474041625060871496`47.74459091315667 w^5)/((1+2.88868976273468455589236750670877440791247398262260445804707676729090904613462`49.52287874528033 w+2.2676043528318234701773555010427119135633841489963729398409`47.74459091315667 w^2) (1+2.34564434565371239118218978780274035951819957122601041871122349397673763572047`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`48.07199233597768 w+1.326306757200234005201937847128361277361479149173847532882`48.07199233597768 w^2-11.278976709003178870785653315019283227763480892337248597535`48.07199233597768 w^3+5.4038814246912647001823624601026352658693179483614332472501`48.07199233597768 w^4+1.0566348843695826984004737071817637260702542475960732961096`48.07199233597768 w^5)/((1+2.98556813464585997503180223130353904142829128099495384188653440170985717969668`49.52287874528033 w+2.5420319229225057687994788152491464962524426984782092748607`48.07199233597768 w^2) (1+3.40392519958103725805917496903185612675919264794424742796922270190007154755342`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`48.529359895953384 w-0.04059465812033382133462296893709903815680373520100376484266609289530127453732`48.529359895953384 w^2-3.92424530256078586450241821414478797732920897739260948799250446919528301663997`48.529359895953384 w^3+3.72868299355069832492524731927081411030813903074085752011395300789885065271168`48.529359895953384 w^4-0.82552407775849350332856217107069825725767657288204228592830037714654681843222`48.529359895953384 w^5)/((1+2.4872489645083912129560170391168438280697032551129714742744706051728823273877`49.52287874528033 w+1.02494675940225581637141779174208767347877281092258843515517897315313960902135`48.529359895953384 w^2) (1+0.96556483838933977382206973695579183850205924621194512741739663810749948131654`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`47.932012283406436 w+0.00582433792113711615083332430585795943882533063285331073094234507485900621114`47.932012283406436 w^2-4.1682310986415200542358249128553052958113539828696557683755`47.932012283406436 w^3+3.7522395338743777316091089697430352974385074470421964150383`47.932012283406436 w^4-0.74102196458844682585224798236995554036721935387153283328327049178138291827171`47.932012283406436 w^5)/((1+2.53242135750989263995960322173926186482650038713602382423011988483151702197738`49.52287874528033 w+1.1758069968658066132263445129463149574476622771463227621799`47.932012283406436 w^2) (1+1.04130735771672242485640374113073169980466446164465718314012082911521470457471`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`48.1975147365316 w+2.218209020016278312798174533042811093565355109609706250342`48.1975147365316 w^2-16.1233652409821272290458327363516371858634830691563247726606`48.1975147365316 w^3+6.7587258601156558574767647599729525745085037597541573306949`48.1975147365316 w^4+2.1251316196404271297040073691656278741682434565495871361208`48.1975147365316 w^5)/((1+3.05754645706896375202466207733126788989875282537269000967016650343892277327746`49.52287874528033 w+2.7411625333227495401091870236885120192923087532671629885116`48.1975147365316 w^2) (1+5.05824736175534439055390379361451732002384468766709089077919079587338850903137`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`48.605571420284306 w-0.17417899897301996863352615637092580256906723625490927663092100137647286195916`48.605571420284306 w^2-3.23005263782232481723362083174215841881213826699348470961488258230877982068239`48.605571420284306 w^3+3.70691870194449806370616476030656433767848285215963766901697076635679807230262`48.605571420284306 w^4-1.09790728960671566713562632872341324907569823159915189787873481235737483200736`48.605571420284306 w^5)/((1+2.32752466603609792757321993142026132543754200930293178998044179739985544343923`49.52287874528033 w+0.45762128842357914023326562935328734995497274557262550165293781913518733835764`48.605571420284306 w^2) (1+0.75502527390862656898232553744151228088710549318838150630207820346408853917346`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`47.53469042726966 w+0.6351844602497829892091576454205487972033948159483078008883`47.53469042726966 w^2-7.5368228589778088980039128805073343216983681952457034159467`47.53469042726966 w^3+4.421347483911790096595553297000563212328064505370349658827`47.53469042726966 w^4+0.18794587603511391111961551171848116023061247211631112160956632522823879738907`47.53469042726966 w^5)/((1+2.85929650771212955327397584677548391018504283854049946953465955845641713669943`49.52287874528033 w+2.182756366614676370428181831166298720102623449761302814075`47.53469042726966 w^2) (1+2.13963879953237420851216868696172150927359663376002556124692275337247537346669`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`48.16935973374056 w+1.91144424375450696439396548541649979414729140140804482039129280736346473091508`48.16935973374056 w^2-14.4562311150170161940159293295211685802990027186260413121654`48.16935973374056 w^3+6.2873602687184898441459595218479875715477378194469135371919`48.16935973374056 w^4+1.76087155146378741067106622606296681025362732052239599305678815490980114617343`48.16935973374056 w^5)/((1+3.03858673794211451294029057608530155849360348760734280595635919403479795740742`49.52287874528033 w+2.6890795543210212217382857207765483219102191371255509065787`48.16935973374056 w^2) (1+4.48780333604623542206710470462667521646626256923034643085785621969188198686408`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`48.204455271369945 w+2.3117803564322558117455034457585174847832460794335866968307`48.204455271369945 w^2-16.6320127758627595146226724529549628138287539669288980184949`48.204455271369945 w^3+6.9032396984935028030130494043382069402025902390559575413959`48.204455271369945 w^4+2.2357974514565084245850914590018454383246162313091862305489`48.204455271369945 w^5)/((1+3.06252765133200210597608011113661246600763835944550191512821878792230947505847`49.52287874528033 w+2.7548034999957686865423696048504810131889858478607291892477`48.204455271369945 w^2) (1+5.23244831896954261259229099650513065953016887256863223659690510580749796408071`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`48.532400042534825 w-0.18842776054746703962125337935366180994973963685662623833333610293615128932705`48.532400042534825 w^2-3.15691671502802148002474769543470385430535855150186820559170179412352841465117`48.532400042534825 w^3+3.70987723198019583009280729732325484719839053786754364260702017950261225108019`48.532400042534825 w^4-1.13036128195975295501444522483485748815885328184074904042043257406888729017346`48.532400042534825 w^5)/((1+2.3075582229401899075134220345884155143759582594134626104623326092643672863722`49.52287874528033 w+0.38208691690023018945080535869115373858232852712436574768047607720908723150821`48.532400042534825 w^2) (1+0.7333004567305153158952864685568437198137406795325232878995450295734757523723`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`47.996165016859926 w+1.093824618660361036548491739384402448022215414672838027546`47.996165016859926 w^2-10.0182758375689260687078237455807235272838624834491438606305`47.996165016859926 w^3+5.0624217246837054195065795376106615198513927475741621832254`47.996165016859926 w^4+0.77105784072215604125330759196783274840394927123808920761642852639485895503816`47.996165016859926 w^5)/((1+2.95436215776584245579929031550052069884328003175888301053488139680091563602539`49.52287874528033 w+2.4544732939664849530098743380250722931989524073745356011882`47.996165016859926 w^2) (1+2.97582268403877982164209149596268790739432595806391221328151531648168183671219`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`48.792818030101714 w-0.33682763078886897076671315327586704716024335089899810461710336026343720482235`48.792818030101714 w^2-2.4123954577467183615226414798007352352440070308822895510055177733883772520918`48.792818030101714 w^3+3.84098521714323204167990641697963100820345903615475670739683869663973769899214`48.792818030101714 w^4-1.53592454233836192747747901049118774056836663283721483516212764980482823525959`48.792818030101714 w^5)/((1+2.06643617776082761121202775191264975359636162589786879722406610417512755266304`49.52287874528033 w-0.67468004701621102725029875424573163178635890403668465650911497135985584322597`48.792818030101714 w^2) (1+0.51533121132272726907289796312165034023894537408197448744549676162280666457566`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`48.12184669558267 w+0.18321615884900274052218963129259738271335588483992721292907345552230520995421`48.12184669558267 w^2-5.1090090529989005423759172493602749100055840623263232970024`48.12184669558267 w^3+3.8906694342719016916220444522076660078306312920628315215511`48.12184669558267 w^4-0.44828522531512234074678973997061025675408293574919950212804943505546809424584`48.12184669558267 w^5)/((1+2.66804657613564052662331545151389908707201057999179606886099536629424496824324`49.52287874528033 w+1.6095677476556494871337722121673887001729619265135303505131`48.12184669558267 w^2) (1+1.34001071730003349888676875928720881288303170256898766263954778191188608344871`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`47.52866766624568 w+0.6329317712764608100317765421369055855446382323557121510818`47.52866766624568 w^2-7.524663601281117339021961259176024063844914627762072601594`47.52866766624568 w^3+4.4183647163154507561386742891096938625021274079841540846687`47.52866766624568 w^4+0.18498104746785824413586660196825822873673662990140647317291613331524316044429`47.52866766624568 w^5)/((1+2.8586627211516093082613937337268155304305662385941039098957081254700578540974`49.52287874528033 w+2.1809182311781545492899736775779087862671542831582739964765`47.52866766624568 w^2) (1+2.1355734543475251838077246465670575823520471895105024653425073165562011699555`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`49.203343751855805 w-0.43790677455852850678900158839093990051527707501086872719656762265074652271686`49.203343751855805 w^2-1.94441725204932380397571817201078212110545331830474017898843651458513195826637`49.203343751855805 w^3+4.16215374363950458584393511468750499250907792214427056427387414302485892302486`49.203343751855805 w^4-1.98546343725762052338254638524402433631172047599411858119301072712348593261953`49.203343751855805 w^5)/((1+1.90365792169811375221024576374649019865136155537863127330904495086628170372269`49.52287874528033 w-1.93098915953925376842817624374890761843298135144253619755835179790359903800735`49.203343751855805 w^2) (1+0.36650238077029410378155264432242862893450715900202328140518615607583834871063`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`47.97998586898279 w+1.056739678553371729987103004317131088034605437106008123299`47.97998586898279 w^2-9.817305148823970971633394615754565492355418263424532527483`47.97998586898279 w^3+5.0087186350640111042559342753147458582141424245033298772241`47.97998586898279 w^4+0.72504006236285888480455572359606372558139360719085931217850205939484346731571`47.97998586898279 w^5)/((1+2.94858378627267401581469383540958517635778292666759751154223926241726373094947`49.52287874528033 w+2.4381750163700807281945349007684045901225235062854162220911`47.97998586898279 w^2) (1+2.9077330142114669818356367377342879880389315263989148437899022640726324188835`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`47.415184475908475 w+0.4112526288964643985502068050671951487548753879456616281077`47.415184475908475 w^2-6.3303855968997159205379932833960512748999063721437162465968`47.415184475908475 w^3+4.1379278769164286149181889037165719855309736180823659021683`47.415184475908475 w^4-0.11474797729262275393568157499382697892494703775498064858722384380933603809108`47.415184475908475 w^5)/((1+2.78358327747514572784969781753404688690775419515716548467584208672680987378188`49.52287874528033 w+1.9604586323016371729879428620976335383150237622059532904193`47.415184475908475 w^2) (1+1.73869492330414780738270536860954267425194486710088816356152474987613171419246`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`48.16354148685613 w+1.8594637706783347663152589831234072266885567637349633113962`48.16354148685613 w^2-14.1738152450926937301099151155605485663782689666256193245473`48.16354148685613 w^3+6.2079234413933169964804087166043313101847170095191166052094`48.16354148685613 w^4+1.6988864160876832661163537357245332929023923428231557725275`48.16354148685613 w^5)/((1+3.03490150579149853235448846174754663636344986418073263759404585170338976898819`49.52287874528033 w+2.678926006384010687854319758995894283660431671589771324392`48.16354148685613 w^2) (1+4.39126125706606654581598054141156538301367352944996237347850857422539192941092`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`48.14875863530286 w+1.7407735758220424316430294026493142383887104069249950340004`48.14875863530286 w^2-13.5290570301628048836914632590126515052148195067511065215081`48.14875863530286 w^3+6.0271114721113023653523282808711407086165430577704070093756`48.14875863530286 w^4+1.5570074566577102812197161419558278348366783829779102270077`48.14875863530286 w^5)/((1+3.02586919722491949478888103579690165436661106626889835083097529711034808009737`49.52287874528033 w+2.6539982550356697654220584512149349148681784030963169747185`48.14875863530286 w^2) (1+4.17097521885216317769695193451030227545067130990919522114334588753948523248275`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`49.02349500930246 w-0.38640264134704450806023633819599588291262038701319517738388237725848635715869`49.02349500930246 w^2-2.26394558633366841402616427043043768651235953872876093100843375340012451960997`49.02349500930246 w^3+4.46748365914203465865174219371134365210240568690377335559575571501784969724568`49.02349500930246 w^4-2.05150654631736333960598037908028936519186342419650990558123007590037752314016`49.02349500930246 w^5)/((1+2.97140816395349382260769494917587910092576011725059802616154816380584747774518`49.52287874528033 w-2.66049739876239135060046572297746176385577618397003457043678634769898123000869`49.02349500930246 w^2) (1+0.19613506997798158379862519208060143637088880852967141617170319138741698193162`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`48.29254788594381 w+2.1084151917589439737897769424211998659494679575896116326808`48.29254788594381 w^2-16.1224005468320692890063410724298909782524648883329182176668`48.29254788594381 w^3+10.0038487222996689435775728422477488559208038421177526434973`48.29254788594381 w^4)/((1+2.84290646517704502585622554654357625403433168806276488836497643166350958619012`49.52287874528033 w+2.1251445932201324012082729514809427154126931181871436107234`48.29254788594381 w^2-0.47411520410161968656182781996079498363321980889772762361646096342967197629729`48.29254788594381 w^3) (1+4.90604393174582218645526744389591917721016156195689413149093164338043314870382`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`48.04397803512086 w+1.0516800394330150846168388687417260097068975374392974882988`48.04397803512086 w^2-10.0046080676580828902481795111525673292806818214271753717876`48.04397803512086 w^3+6.2315910548299087991276283707961416979336952433831405743822`48.04397803512086 w^4)/((1+2.82945769766857805932536837003027638550915695861187224087579763178546252507581`49.52287874528033 w+2.0991161056735851080339830094283096796285494685222656297304`48.04397803512086 w^2-0.26188541815916445224405536478081956269110570309820007344298591254150219337022`48.04397803512086 w^3) (1+2.92802771301182226088872284987523066388663570653778140911468504610153781327306`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`48.5681735868648 w-0.10682643618771623139219159590645500509063518807260985226979217392985164969039`48.5681735868648 w^2-3.29365656755624769507064390416738176041879552809341430396450417736573451400793`48.5681735868648 w^3+2.07802433295373311607791641677052149752764083884632675803987237554297460726173`48.5681735868648 w^4)/((1+2.82640949276737841372338815193921454125775840104937614234493870370219737721172`49.52287874528033 w+1.82994999033714180553103910990413600020190709490807755005830877902281397177999`48.5681735868648 w^2+0.84214406503456767970467813701616675268677688764623919687246978888585819763803`48.5681735868648 w^3) (1+0.75659012244825095477228578318265672220411148559357338205188900322864763736824`50. z)),(0.1333333333333333333333333333333333333333333333333333333333`47.167048137696725 w+0.4474013726252668840412146042863626400828477496349459208727`47.167048137696725 w^2-6.5054712340462059096773033347156609005775732669892775934567`47.167048137696725 w^3+4.0710227444604460690385799982631989438143430988699957709871`47.167048137696725 w^4)/((1+2.81354213052974450304382815688766911663303923968573459253055683845668580008262`49.52287874528033 w+2.0467624240129099046034694835850890953590083991849283486088`47.167048137696725 w^2+0.03380438114777837087398117443417772451089551784228542876963591582616050011023`47.167048137696725 w^3) (1+1.79898410453200277387981240730707616306057178413615429470219733230060605120248`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`47.440439334669485 w-0.0020700968336363299508083101055979728690677879393810930992748532359088829988`47.440439334669485 w^2-3.9012285723649695892624858378606317862580661612807712012259`47.440439334669485 w^3+2.4569986617855624511239884920210294778541198478202576127997`47.440439334669485 w^4)/((1+2.80791258630697483681577875784125327470503767969726505437868044117406517224517`49.52287874528033 w+1.9072798131625404131355935540693168866905011457188574934593`47.440439334669485 w^2+0.586793082519212727847324202498629932967715797269875367126`47.440439334669485 w^3) (1+0.95763248535225166420178179258375397425773054118140152439536354914181945554162`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`47.8630995371521 w+0.29240282400202727018620606369341706274825659898820869094359868701666803100962`47.8630995371521 w^2-5.6076748755342562690776575116214366727952447882107371585101`47.8630995371521 w^3+3.5156477226245565179478423658389151049699031625447006593633`47.8630995371521 w^4)/((1+2.80842569378926055367255612065192162962826432071153832762989228509236458609753`49.52287874528033 w+2.0175368118293720813229387021994162113619364120838621221388`47.8630995371521 w^2+0.16744741284413572994620746028730020779350244134765245047541919260607613752197`47.8630995371521 w^3) (1+1.50964093504854948524448940275424007730940710641705911569041731732533724530163`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`48.864111865042005 w-0.26574012304381946343188736664086329517661315173996336283157359581392409217872`48.864111865042005 w^2-2.36775796610101008679580253543138507999894275241090867293056930426707868554979`48.864111865042005 w^3+1.48320596320348244737294304612414751697634502418589894425941843322972886828995`48.864111865042005 w^4)/((1+3.57146865106981548178452068640798696205751265299701381877655852645374971489211`49.52287874528033 w+1.63261838491170404479315220854280892690787541536858413832632096407903787184799`48.864111865042005 w^2+1.87485863080793152763646778055852305280821812204021887024121673563385641712665`48.864111865042005 w^3) (1+0.27236217001744812768257307943844807309296424073037949382218808363465612370498`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`48.810294725993295 w-0.25498289193362967651642908344726496481199561499441778464073781592831090174888`48.810294725993295 w^2-2.43267605073384001696871435387644791660536585788870276648204950968630605901469`48.810294725993295 w^3+1.5341612382331570539988866465124033340739096425466000882712347472360735193634`48.810294725993295 w^4)/((1+3.03108074961786698979730322762738972069573542034711315607713211869821360556935`49.52287874528033 w+1.63092432654620433246437953853901667360600373210288211998001979087994515610738`48.810294725993295 w^2+1.50309617368228924356849977515963521079916547844895265939695456943758998850356`48.810294725993295 w^3) (1+0.4276289537120411011458617251215942528670664302907516855851010682315105738626`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`48.215740745062476 w+1.5889683733411366950298555017603262337028845756341566840278605266629755492407`48.215740745062476 w^2-13.1152540319161335545355886270231497407710097182412177695982`48.215740745062476 w^3+8.1500345977318826498853724878681304684871076399793639307322`48.215740745062476 w^4)/((1+2.83774736501398132263980277298487280450571875035087060022462244628082386141317`49.52287874528033 w+2.1165337508466131259587328950619627913848712883239777344576`48.215740745062476 w^2-0.39415418787240362523816957853428521455939734930674010519109974153851023313881`48.215740745062476 w^3) (1+3.93337092225319946458452043604645697912997095521835684541080263076265816882091`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`48.29385130582278 w+2.120361483133244611683725590056686480724346075392141302018`48.29385130582278 w^2-16.191557754593566649273847849175757995848993744253387626286`48.29385130582278 w^3+10.0464763887971998816987041935816398750236490537599924862749`48.29385130582278 w^4)/((1+2.84300338231722637344843092124763880000439455769518451595078342257763626000678`49.52287874528033 w+2.1252914139152692823099115147830147174373435827876322726409`48.29385130582278 w^2-0.47560929199444987687655782534747392582026477818039303416350921702543720826118`48.29385130582278 w^3) (1+4.928418998787590545608369814536440943420542315428575194176322400445233664701`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`48.26273490277027 w+1.86889903898420879882894062259001979451993515304640359387202745889240521430507`48.26273490277027 w^2-14.7358267109045955601095900688550879859426936230260973172327`48.26273490277027 w^3+9.1491338446396697453459488953809980106206344800465309874472`48.26273490277027 w^4)/((1+2.84077787656199721182467239871794520740117019400023698851521212462558966142361`49.52287874528033 w+2.1217830304165750384410166010866253956958165266876159445982`48.26273490277027 w^2-0.44124275551423853691947870112866262057683321026924954629739034726201458114362`48.26273490277027 w^3) (1+4.45748329244695568691158763116886430493807792695400512625989244871619953450416`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`48.67848982667216 w-0.17871569635935062726950143715184336624005973325834777761410843852455321090706`48.67848982667216 w^2-2.87633678516384701704050250821563603978737492093329778247238823925960676108865`48.67848982667216 w^3+1.81623427748716388636662796018619546228485976433267966514776907593864903842622`48.67848982667216 w^4)/((1+2.86692337609288647203855343115097206021101696030726686364616197823083522955551`49.52287874528033 w+1.75216336362812975958820674357830043018994668075941224974953584300236829417741`48.67848982667216 w^2+1.08821957337609125320907514859310138616180356689118758170232706824479810103946`48.67848982667216 w^3) (1+0.61166928879505944792353851104461416531062582355585143069464311778314888547321`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`48.813399499106644 w-0.25648066431747453383740620426538761036944501569358611631024588248903269930849`48.813399499106644 w^2-2.42393451948059783678057985358304623058618034730358994737522191021957936589855`48.813399499106644 w^3+1.52848596996335932426875902173448711523485655125650819920186951903241059592447`48.813399499106644 w^4)/((1+3.03919694005351261984311388873782099025222601187491488839851924078438013386007`49.52287874528033 w+1.62796488849775041589695222126673031967447738044843267610889752316440457509473`48.813399499106644 w^2+1.51551166778510783218985021586630697228416943708334161482411882574202205582806`48.813399499106644 w^3) (1+0.42279158288342058615757695831000647505772615609786321799724653734348475752967`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`48.287748861536784 w+2.065609641936839081435773095040508897728616290313313627823`48.287748861536784 w^2-15.8745983207674676207482518002984834385218681331625481918791`48.287748861536784 w^3+9.8511047126349828915252977272271857137176983920237639984955`48.287748861536784 w^4)/((1+2.84255245964225996586921875423137776196283502364518603690750976299578989913891`49.52287874528033 w+2.1246037248861168927541571301550529541231476865024034758935`48.287748861536784 w^2-0.46865617700686726291976963890763044400839820376839783232058234791930505333985`48.287748861536784 w^3) (1+4.8258720272130717782882619281351732348139388519182731670345975736888693903241`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`48.78174594599954 w-0.24022473005864333305652951614145206969342325889843479249682088738758288397473`48.78174594599954 w^2-2.51869902671635248194567285102859382401605788759088007544717064126914066674984`48.78174594599954 w^3+1.58955571189161000044659602579640776997402032154025016069108240295236297013631`48.78174594599954 w^4)/((1+2.97152684395537333811755139305671062497676864203448463649380989194802551071813`49.52287874528033 w+1.65872961244125140901433425228688771458875155942434881091380550340865705275382`48.78174594599954 w^2+1.39662519302369067363781696051361137546484842263391600009279251963336483305276`48.78174594599954 w^3) (1+0.47018898364326390805311137246266320514413129254887760240252097742178123585381`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`48.13449337479274 w+1.2713782212516043516373436464684817874340277660083079092876`48.13449337479274 w^2-11.2765944128281162958615382285486191448410561863821985819519`48.13449337479274 w^3+7.0162151676453598331888501701769988947348606628188947250247`48.13449337479274 w^4)/((1+2.83333843031500970340326284796291951658437381418118196552351414446213092964261`49.52287874528033 w+2.1078643293257701770237330088710300596377532342451885916324`48.13449337479274 w^2-0.32463598897352201981095316999629442460171442331414963030856823142516380824819`48.13449337479274 w^3) (1+3.33899162076006922553269568862973696435620067121231957476880350289070906633395`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`48.56195014114313 w-0.10268863327041745480466094703899113514691992570696764122424998925013332566968`48.56195014114313 w^2-3.31766494225816498774177806922035480276064265968266814391564125325774793220005`48.56195014114313 w^3+2.09303818821375239745272671856490782759713316149676798813896847354162836035374`48.56195014114313 w^4)/((1+2.82508628085767770866130981660173235969119315109341664235658212906247769710387`49.52287874528033 w+1.83369066856949626826541068142987124986852541883903110881534113633142210156766`48.56195014114313 w^2+0.83015732361565195359515059959459648460859202266284724353345933047100090813007`48.56195014114313 w^3) (1+0.76467930589561133713942533364352202374021891501815163896523156631714950711543`50. z)),(0.1333333333333333333333333333333333333333333333333333333333`46.98565997715192 w+0.5279316226465748862126139940701713471055336792187706968468`46.98565997715192 w^2-6.9718649406702346635546822043771653947266619854340837566476`46.98565997715192 w^3+4.3592948241484880986896872335718410675804948048373167075729`46.98565997715192 w^4)/((1+2.81615417908335418860800393993345853361318352029534084948162491798986658765577`49.52287874528033 w+2.0580500260757918091911267697112105347424985035608941307792`46.98565997715192 w^2-0.02233118332891166155479935259020055979543672356832574918379201037890301859596`46.98565997715192 w^3) (1+1.94932531118355285656014231739027013448307183195344097602693060868135823007862`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`48.86213373382242 w-0.25508004802888192026955182611654725036285902756614832705317728166161977033281`48.86213373382242 w^2-2.4290893607704477113072571001304263190380117542161340850839833409375229436072`48.86213373382242 w^3+1.51936646588882242776203106624921081417863070832125646194698721157120364619397`48.86213373382242 w^4)/((1+3.74300219739118405661514395701003211518392829486515144534079828106687465076339`49.52287874528033 w+1.67737377661979095674339482223953683187550713154129156184829603919813544913408`48.86213373382242 w^2+1.90057018830156120376071055266742604454682993609285908162246770318092544509632`48.86213373382242 w^3) (1+0.24946642409011387740429640027102936883714931308924787534876427040058607614808`50. z)),(0.13333333333333333333333333333333333333333333333333333333333333333333333333333`48.26340479856585 w+1.87365510503754006320391312989552405958456371056056710810718754165639759700201`48.26340479856585 w^2-14.7633601217657723830550655590574350685532188922196811776928`48.26340479856585 w^3+9.1661070182106675857843880224829567289133884018410733175027`48.26340479856585 w^4)/((1+2.84082388829137409972482965737570505022309907051426651487039253938239331229064`49.52287874528033 w+2.1218584900144571349020902770776851844462995978634548392905`48.26340479856585 w^2-0.44195473745639887983834915319860600968176059686393225199935641789362785269031`48.26340479856585 w^3) (1+4.4663894133646075856396217677022448412287742531645610519717871673156237399538`50. z))} /. {w->w[z+10^(-10)*I],pi1->pi1full[z]};

(* Sample Pades for the nl^1-part of the 3-loop triangle form factor with LME to z^6 and THR to (1-z) *)
(* In order to obtain a suffiient number of Pade approximants we split the non-logarithmic part into *)
(* the CF and CA part. *)
(* Mean and weighted standard deviation *)
Ftri3LoopNl161[z_] := Module[{constCF,constCA,ls},
constCF = 4/3*Ftri3LoopConstNl1CFPade61[z];
constCA = 3*Ftri3LoopConstNl1CAPade61[z];
ls = Ftri3LoopLsNl1Pade61[z];
{Mean[constCF] + Mean[constCA] + Mean[ls]*(Log[4*z]-I*Pi),
  Sqrt[(StandardDeviation[Re[constCF]]*80/Length[constCF])^2 + (StandardDeviation[Re[constCA]]*80/Length[constCA])^2 + (StandardDeviation[Re[ls*(Log[4*z]-I*Pi)]]*80/Length[ls])^2] + 
I*Sqrt[(StandardDeviation[Im[constCF]]*80/Length[constCF])^2 + (StandardDeviation[Im[constCA]]*80/Length[constCA])^2 + (StandardDeviation[Im[ls*(Log[4*z]-I*Pi)]]*80/Length[ls])^2]}
];
(* from 20 each of [5/2], [4/3] and [3/4] Pades for the non-logarithmic CF part *)
Ftri3LoopConstNl1CFPade61[zin_] = {((-13.90391737223414554868408917465629019432846477235274099180984626672245132490026`50.- 3.8741758720677788604658291788813292754758693439059863279014`48.317125073709654 w+9.5984607453327177616133450328874512923912837921153838565748`48.317125073709654 w^2-16.8915650043011090059149242852718531647249198986128795052148`48.317125073709654 w^3+9.0089490745187929580363986480735175271446698649126592069829`48.317125073709654 w^4-2.2335049882446367153624584747372274138625976730208007732947`48.317125073709654 w^5)/(1+1.14643568616379357470551938819622099310251395248961324981666423934303679189589`49.52287874528033 w+0.05851256537836487000990854331899080873513564156425598511775943396423548084518`48.317125073709654 w^2)-33.06553321565856268193297153585604373613483604467870268373195970463646748916585`50.13427446120067 THRSub[2,1]+3.09256058940343109652496382387619715970001994981643609276018485354284335587533`50.13427446120067 THRSub[2,2])/(1+2.76010279284801656013760169995069959576289827675601936038734070819763627500081`50. z),((-29.48813329012395343258381380272882116683148156522337705567362484853008880610626`50.- 9.8228563499388474836992109011263654619337580252458297649251`48.56023042781179 w+21.1066204806484469261557011688814364185059864672604502518511`48.56023042781179 w^2-38.8865266393437431620837328561551248731305279652181812027857`48.56023042781179 w^3+21.4157636393403093275484449541157120406923678260510152465693`48.56023042781179 w^4-5.2924861209983474096465238309081948584801250341784618861032`48.56023042781179 w^5)/(1+1.1883449956871535116000089887489497253371838831703836142563872110635097363885`49.52287874528033 w+0.10858766697565738812566474164235364903334698193108011086772724422580159172903`48.56023042781179 w^2)-71.04911165123569380771287913039582060147525104467046454373592624630618111888709`50.05738213168202 THRSub[2,1]+6.64509721260696227361132058013461947870611454438146137939981240956216854985267`50.05738213168202 THRSub[2,2])/(1+7.07946937999684239407072135591011423291149480148774425840915135108481208550615`50. z),((-9.60881799903527988360730580616118665358498477078137455655081279398741543224063`50.- 2.0545117529198101003569078646372001653654446672865805746737`47.30916077702411 w+6.467035307961440637366119122963934642908823552288214158972`47.30916077702411 w^2-10.9338698449589205285369503573788719066397639417501590109446`47.30916077702411 w^3+5.7115149169708372721618308618987132940894648943922440503921`47.30916077702411 w^4-1.4109924090603919386969132912712635367943046576038292076412`47.30916077702411 w^5)/(1+1.09223810127990569220691499790249685689440841775144631240722538589465534534062`49.52287874528033 w-0.00532691409436731263648096078351695712752523382627412903244329600620252492122`47.30916077702411 w^2)-22.59704094180486364753163100429346652057162425898081557603445788743104900914`50.21407001223625 THRSub[2,1]+2.11346110156384079466719258285000117876723716895146891271588577687826028825821`50.21407001223625 THRSub[2,2])/(1+1.56966056470984872021420959966453744457499726052983586566030069481469590841649`50. z),((-10.12416908635493416250026306563164211150591386013619113000516323305203205511768`50.- 2.2904012095641293270892780416074832683906802981125869455817`47.432210632031214 w+6.8390688546046148805719785273118578241659078275508721804243`47.432210632031214 w^2-11.6387724964583853644900637356856585404347898461552612749394`47.432210632031214 w^3+6.0954177635819296012739869084060185109502651641381251199889`47.432210632031214 w^4-1.507698260862221857122829083398168799500840900255271309924`47.432210632031214 w^5)/(1+1.10290286904488219041953706677537920284620033789881638872922426900543615347733`49.52287874528033 w+0.00715685198105056321836647525328854712483363008910460236363208808923615707691`47.432210632031214 w^2)-23.85311173485613177044989361986731832810106903201160560245629378390934463188474`50.19973946865986 THRSub[2,1]+2.23093917175723259954777843647784535822102641440104838927418255584120066711637`50.199739468659864 THRSub[2,2])/(1+1.71249677019799389926889439209243237872371404258753918190595216417178450728506`50. z),((-6.5733895643567304747277091516967012725711829668115126642375397399778855858956`50.- 0.26909054932845372645350249014400867615832572566005542407584331248212271918443`48.33075202074736 w+4.3475166636440460984031584045870726685823607889998494677104`48.33075202074736 w^2-6.9951895740908718178576824024098460731519243298716542788014`48.33075202074736 w^3+3.7083278640981625534837750007753285708469670228515008438095`48.33075202074736 w^4-0.88526586638338729353460349290593440001142896925087904503135432843836781246739`48.33075202074736 w^5)/(1+0.93524386832787352840894059298665666992464365426626411149646637116464039037957`49.52287874528033 w-0.18507876160539969219929465258304947738451922046484781057667762663716769031171`48.33075202074736 w^2)-15.19875830495818465164109937595837470758245506709433870805379428385570088760279`50.37529074289055 THRSub[2,1]+1.42151286765044298557261400274252193555613398821088747167860235884213651043952`50.37529074289055 THRSub[2,2])/(1+0.72835239575788065509183727576721814757916386591676997820023488497526865112673`50. z),((-28.03680699555052917078414530217468533446632256054139807407455795531824505472672`50.- 9.2786752963415661725493330368737223679804981961501062397094`48.55348059045442 w+20.032546423462985330233219369654270126105627566979870777586`48.55348059045442 w^2-36.8323644538237743955832652554404721677191903820529409339357`48.55348059045442 w^3+20.2536133125874634377120395666362112466069653257046130346727`48.55348059045442 w^4-5.0064776075993529420076280959671074631602791748153884843168`48.55348059045442 w^5)/(1+1.1867592747652011707301376562766357551712984456899355290905307116555050799757`49.52287874528033 w+0.10668112996641268059604951032095193465183905742964703302182727664962437972373`48.55348059045442 w^2)-67.51177833681061788993905271548768594254642375057203974473079675342360239038387`50.06060833805323 THRSub[2,1]+6.31425671085469298009685611780449189736627634201674558861391952244086048674796`50.06060833805323 THRSub[2,2])/(1+6.67721556518446421384207347452922336414562967085569380212803848711303410240467`50. z),((-30.65121643886671454721946249915851834136359320311689764732303046230742788917109`50.- 10.2584265828972554891524513106896273823015499849046682821862`48.56502403563673 w+21.9675073673657757575379146704498854899507373321621994152979`48.56502403563673 w^2-40.5330380891959285018680936977797772975908904917124382843324`48.56502403563673 w^3+22.3474710323400198926688785016146855913257280753035750943188`48.56502403563673 w^4-5.5217532485312449028387865854505333409355864781642169333789`48.56502403563673 w^5)/(1+1.18949000651471669901595946847960508498994161708580036242511039522250182543706`49.52287874528033 w+0.10996492448875775168728201729208413045808060085290848804107670466700808492275`48.56502403563673 w^2)-73.88390682092111564195233040470473665719674086881902542079673308840296875078314`50.055034763448866 THRSub[2,1]+6.91023056955669204017290217371227529317861210425963973366762959354689245883997`50.055034763448866 THRSub[2,2])/(1+7.40183288658739912747300918246614348411315366974262785711641877615947876506645`50. z),((-22.38780688556521954866959568497194604093177243005440170442116013488810059619332`50.- 7.1503337585182502106033457011669618013273780711800245165976`48.514485103751724 w+15.8544227291215930052044406312964840845754501382927237810721`48.514485103751724 w^2-28.8430604888952677516360477818397242138186163392957579216018`48.514485103751724 w^3+15.7372216867257504005931088602951783871783441601101728293285`48.514485103751724 w^4-3.89443080835880018349930204149166707890380542216079682475703211940848162986564`48.514485103751724 w^5)/(1+1.17817297480751227709553254413370622668750686325740650941919234563294337068356`49.52287874528033 w+0.09637415176758330202102057955300768432681276395949896465982506807453884290474`48.514485103751724 w^2)-53.74340911690669135978393061625059428492045785103349105633426893800565525004859`50.07759914132023 THRSub[2,1]+5.02652559361790432826505013901895129879290659049406022311626772996728593633047`50.07759914132023 THRSub[2,2])/(1+5.11152227304644677316939830224574584285484070164799677904899509901371250449682`50. z),((-29.90559572031526497338065729889554313106055508194768838537865453289801354938321`50.- 9.9792450213628555482444942345562698229436901679814000363422`48.56200868857963 w+21.4156039213109672960472752659809360786432311467705495808377`48.56200868857963 w^2-39.4774743824482514991894446157838818783165238171780432824056`48.56200868857963 w^3+21.7501440342288128682865392319399073037464147476529489912563`48.56200868857963 w^4-5.3747705090612317215473734483908753450222176126875908829128`48.56200868857963 w^5)/(1+1.18876790919471492205857686036029866165231791211452117389956587054387155866006`49.52287874528033 w+0.10909630356341585054947245943159582702216024154531585208995364046746808297131`48.56200868857963 w^2)-72.06659735886604694556718422161626103192564362992787842249329758288750904891863`50.05651687451859 THRSub[2,1]+6.74026084354483465574872671743495161570644109658675964487871484727344406151821`50.05651687451859 THRSub[2,2])/(1+7.19517448071277628063469125861159233700175303332892708732594334727036006944676`50. z),((-8.17959277809591043406035078772202689663448564469036843338772198575859579070964`50.- 1.33927620885683764126724665754785757696762337915899434925550715736957929911934`48.346724203140774 w+5.447244515066727032273677164231671793878392334658698532133`48.346724203140774 w^2-9.0126851880304137800013398383181247654511700219276715703885`48.346724203140774 w^3+4.6871435384945379072892650462068778662372972056281962530932`48.346724203140774 w^4-1.14962688723532800100494243620543480472280026154630037501444536545759534490216`48.346724203140774 w^5)/(1+1.04816728765216597054095382947010404860163508029968658205143178610492848620327`49.52287874528033 w-0.05652690053851997846855255614015949796141447951868123763279939862990240553395`48.346724203140774 w^2)-19.11357481378894887656220692668880213358761300138419549117373287077972542405955`50.26767104282033 THRSub[2,1]+1.78765870207547603268890074613574794489707464565853715932172553007104903261239`50.26767104282033 THRSub[2,2])/(1+1.17353234771374992456326513898594833230764132005710123886707000656836547589134`50. z),((-34.55831174861183707698513064849008531723400737726576318557442951974298269460218`50.- 11.7188940374544549339888425862361831781602136988589552883447`48.57809180737066 w+24.8601212751951273474115447740383996359139633788110795448219`48.57809180737066 w^2-46.0657308665085897879571519256568500110639942095515355360819`48.57809180737066 w^3+25.4791990632873870276301897162338906156228702029152801197026`48.57809180737066 w^4-6.2922369067636768632091989536985950932966968206098563209382`48.57809180737066 w^5)/(1+1.19269322427794906797401078483383821273636886723574904093439613448335618193289`49.52287874528033 w+0.11382051343293425447899419045470118045031600611795167431352186466854637979302`48.57809180737066 w^2)-83.40671258380959193474512229280732914712878546824192078003267185853816095537133`50.04838691981382 THRSub[2,1]+7.80088167779003697683532552707074245900029318068615539946819569002416518325705`50.04838691981382 THRSub[2,2])/(1+8.48473478057014789178891009601114703322293541363989455107792024312325436716337`50. z),((-25.75723244282428154019236237430691103616525706772209037122420624099033989004732`50.- 8.4221101242892659169149481751771466560598866748614093456385`48.540687902641665 w+18.3459641900704985948412865026343500903890724718948303880897`48.540687902641665 w^2-33.6070209448912575566004775262310148998450263898953671194488`48.540687902641665 w^3+18.4295045445539070902989674890433741808462984007777119572595`48.540687902641665 w^4-4.5574607558250776401155799282302998754610288981076077261122`48.540687902641665 w^5)/(1+1.1838368352854874480127653619708552996794520496449656937101309749337752108385`49.52287874528033 w+0.10316992673268043731703595486357307208060629120303406600071593655472392276935`48.540687902641665 w^2)-61.95574656213360367185986186150986357942232354054245126152533515553649996010583`50.06648059241623 THRSub[2,1]+5.79461092780400767314077329586623943988564255024974093345521639278705378483598`50.06648059241623 THRSub[2,2])/(1+6.04540205542312543200412973176378449623420854929982189256265713846475517708045`50. z),((-15.81643702230134886540405891568514910443924540194659743862153739192790266205796`50.- 4.6298780831592774017199048173402047991154912726227919706455`48.399373295978634 w+11.0047532253396622901475889747447722695516451578268638327605`48.399373295978634 w^2-19.5757160470900695174390540529114837301576809369095375374072`48.399373295978634 w^3+10.5139957352666951559307195622628585427736871976465131805873`48.399373295978634 w^4-2.6059561705633318149956027442672917434579773547147572680547`48.399373295978634 w^5)/(1+1.15764765559849510221107806991577342685094524903011448192171574002789531419563`49.52287874528033 w+0.07184635547938138031815035557339219043765526062519704547471590577896647281492`48.399373295978634 w^2)-37.72693809612601738652348435679750296383446394367128297795805355486679610151942`50.11525578512969 THRSub[2,1]+3.52853350810899586036965231497568592051692428430551257680900811062069988771334`50.11525578512969 THRSub[2,2])/(1+3.29018229875904684294250850416463656604490551104185823501246640899243570328318`50. z),((-33.38018449428938270839888507229075222475984913094495520245805328197501366154595`50.- 11.2788947316339522852270781293926211906095771379458908727155`48.57456927022101 w+23.9878010461492209202141216953848823575874027769930980745642`48.57456927022101 w^2-44.3971980379212083159694596079668621656904815961850224790766`48.57456927022101 w^3+24.5346074241965281080283643756771871847864440877331470424004`48.57456927022101 w^4-6.0598643441509702933956670562693232744175402447416327646736`48.57456927022101 w^5)/(1+1.19181778647055207992511777650322343997410679168281102991869756171898739328084`49.52287874528033 w+0.11276639429937096604796123985813611074371444881867974032122146720447628925968`48.57456927022101 w^2)-80.53525025247226987248957686227418109117189999359841648173010962329297125033543`50.05021576630359 THRSub[2,1]+7.532318906340611443884331689006337915081452990303998466981324407804560821639`50.05021576630359 THRSub[2,2])/(1+8.15820160594387871049351675688660176199175362391761688741895495053617209718704`50. z),((-24.00917592097523023275986091214590928968743739442304619937862919386304772370278`50.- 7.76333323858474139872217954066024380847452962735027784201593577195167982241731`50. w+17.05310621160047767874583199126350906586470970213174963114019662611024955913047`50. w^2-31.13487184309195984579421109333023679847613465643735895754066504541384221936311`50. w^3+17.03204720316505186088151590669358379315357441506266435896537233048485906761603`50. w^4-4.21336305953675190677770342908605216384163568477010735780648350788212472640106`50. w^5)/(1+1.1811393509382876202844432883669086763447655462322562647444172596566405960243`50. w+0.09993185402569904633947720920423778746810304895670748640584269012472244456577`50. w^2)-57.69518944733804689748863701897228689903969445918117223646105690260707883752267`50.07181826601804 THRSub[2,1]+5.39612858862069554026349506760877900862436060217191951162293285580396784077524`50.07181826601805 THRSub[2,2])/(1+5.56090562822367706953854781313880239941305945997001338839829432222771145632206`50. z),((-10.83667853851036105444619328338198725692854453066262639863238580525262019776261`50.- 2.6050064632421652805755575503599902235361206761612862315936`47.89731878229227 w+7.3558025248465749813892170804985709994428365032560633695361`47.89731878229227 w^2-12.6198240272324698948292342450344844930724753824192899450517`47.89731878229227 w^3+6.6338692485403478025531463649763434286885647302302036590559`47.89731878229227 w^4-1.6426994274095560511592474134589354756541351537346887219765`47.89731878229227 w^5)/(1+1.11491313786440220181010243094336537576622286999852807422991469770411778119312`49.52287874528033 w+0.02126080771035393782514492137163665827104325556752084649991693394459648386336`47.89731878229227 w^2)-25.58971874830030400519406765367693769230591253971181521153100883204127774899172`50.182861343803346 THRSub[2,1]+2.39336094109727003830419259243915398803791948782864848670138554800712823119136`50.182861343803346 THRSub[2,2])/(1+1.90997796122377821820019129259867706351935748602691979515078156020957350940964`50. z),((-4.90579747496552045892305562092929885366056370409638561421684243597360389406188`50.+ 3.16553556384688669528510626936996861407455994829737543162062057624916986127161`49.69897000433602 w+3.43746051278900724251180886792559845273007990844433194626583485241570124988176`49.69897000433602 w^2-5.97595830383535636252696115917463428404063773473336367301514597186565351941255`49.69897000433602 w^3+4.11114473506459351914756058508861259352366370238150987857367786523914157281978`49.69897000433602 w^4-0.87014223637975816328187444095198414684048642881825525782232468603520441491502`49.69897000433602 w^5)/(1+0.26613590901183543926723102805192804294418630342356450899547745430471823675574`49.52287874528033 w-0.89177863438772209959606366285322878036833787218800127056113275763859447880492`49.69897000433602 w^2)-11.13431802386409890104462078029047601804003370115875797314308569580951007829619`50.67734873386172 THRSub[2,1]+1.0413729875730538554149036882647618083351599345565884580225091780976743178897`50.67734873386172 THRSub[2,2])/(1+0.26615772456871183559455032081502298537030540936478472667084263206687480029671`50. z),((-39.93850036943227982656373334707680514335203696141232025090835744688820880157024`50.- 13.72513968425931189844913909178943984127210170412512065301182841112375734718994`50. w+28.84454654810738216976492741491500017461289461145114733051150204797531948048194`50. w^2-53.68734452035098977854147553271449142247496186507013662835969786704104815787853`50. w^3+29.79504799458055211989257891315174426736699386321458353703557766311669706479721`50. w^4-7.35378144967716872508047644872116405417549075616316846765158487842071762499286`50. w^5)/(1+1.19595669227968620399919096312708887598261167993942859474540186282082033589509`50. w+0.11775265709313235769822176713082084028922083665254526102561213979015491470297`50. w^2)-96.51990464646192908570561408174152719292068431872223466826362153196122791046973`50.041487961319326 THRSub[2,1]+9.02733523925965834576662242051005098146073200441646475640433645773827359302931`50.041487961319326 THRSub[2,2])/(1+9.97592349893570032918095893382220076037635357213750285465339722465308595260851`50. z),((-38.44566693931120661162964123074994369900013699983811569533571575226329264653329`50.- 13.1689055973934341898573445471813892331592178605506560464505`48.587804474242596 w+27.7388848253781125978081413585530945892522893464487530648733`48.587804474242596 w^2-51.5723229878257125326566287040440197571379086623826069021875`48.587804474242596 w^3+28.5972333875172498277862565625131895807211087733000160148861`48.587804474242596 w^4-7.0591854363031962156050651936583813326463888215756593699899`48.587804474242596 w^5)/(1+1.19515408426916919636115566279520146493332693889452822191364019667131227137717`49.52287874528033 w+0.11678521816682335290982483735618822115031180324144235506462383447287622486864`48.587804474242596 w^2)-92.88140554050669224554644625776176880157377503613723739989554793614352606643814`50.04319671235328 THRSub[2,1]+8.68703288072009792754670931208665818976263245066973197570952599888644441140334`50.04319671235328 THRSub[2,2])/(1+9.56216544577361065947599533902920216910653978518167597978447809203899833533774`50. z),((-5.21624704801812315297132706840476650557625434728404689135527466894586888768273`50.+ 1.78727996527841065642430672889367412656095178806947729406452951148893563730915`49.366884383742004 w+3.55441877498945222107279438911635419919460579379703034190189273676315793305477`49.366884383742004 w^2-5.84247252561702829742871615155645720244672318189033343438006994399971296325843`49.366884383742004 w^3+3.59104926841786589903891947027623983680021442367490378986240229462148615246619`49.366884383742004 w^4-0.78623145798622487462079472712958696244185643936006619911403576597278265192195`49.366884383742004 w^5)/(1+0.5647530206042991980500853317041048035697149986689083686178797682522498916803`49.52287874528033 w-0.58534851839682491397630722348190265760072975421502689694722439234328624206403`49.366884383742004 w^2)-11.89098013445500948579666396488352628569576508945805020234265116552609143256795`50.58424899861378 THRSub[2,1]+1.11214225076461568564610089311030656897469240369827357901944455501629474441789`50.58424899861378 THRSub[2,2])/(1+0.35220283071349388833690942758922246288856872897204455036352751980252298812112`50. z),((-18.98701566869857248814039880248127458532342536543878892595006221325807784523906`50.- 22.1544864430903848131514923652473246901858142782739000300171`48.539951764758605 w+2.57302894907245814375248370954195236077052252686167908326711971446874848975508`48.539951764758605 w^2-15.5380165114097221854422351182935444356763411422593686062691`48.539951764758605 w^3-2.06292956149104028841417823676485310653738339791691488491062091980708681580808`48.539951764758605 w^4)/(1+2.02825519796964081605262507794677708821777656846371584746386507345200669357552`49.52287874528033 w+1.39305623730609158384288889571035592513656957202777022019150026338914276538916`48.539951764758605 w^2+0.49007533452277920066080782604772821389684795511447504970105340560927213171774`48.539951764758605 w^3)-45.45462380942187210231897920017293390601445362461806572834830615830822066385693`50.093375662990574 THRSub[2,1]+4.25129022666441812498826491517039682691884160628687248223054757659089861133208`50.093375662990574 THRSub[2,2])/(1+4.16894909327289534064664467399980799896419148242254419097639930042164764115531`50. z),((-4.39494349515326977388322052136232397164860112349867295145868370255957557269646`50.- 13.6455203782442227526794255601860179065476339942200874952257`48.695103311098705 w-0.35101374596362833403647748872448002115038102025388119133030681408607936497908`48.695103311098705 w^2+0.8685289709967400357250488913497193288063926718288209334187824825519373008916`48.695103311098705 w^3-5.1658253770722936995115907540067569092528155137618060762153`48.695103311098705 w^4)/(1+4.02405445005323971088364202398828716300643266112365904216154708229526551340044`49.52287874528033 w+3.31156590415471748225352112886892620472956477297331652632282784106500193751233`48.695103311098705 w^2+0.80049114298398855298658077863118019032541488827134260138753941502872265431628`48.695103311098705 w^3)-9.88920807970254615290873569103668196911961327780403801880593698815209038556839`50.955579383196266 THRSub[2,1]+0.92492006610724064488635671988741094225104252926541387032884530579134844449712`50.955579383196266 THRSub[2,2])/(1+0.12456795047041905239143026405781768091883148771068106791255830882089823827181`50. z),((-37.3592268455963537946091087718776758984217223771895880130509887000769525940894`50.- 41.7276601822594589742110158908255085721966043629617981385412`47.98780418251883 w+7.0889852469342614660658162703496831533303801403132135636083`47.98780418251883 w^2-34.424247580432776238284458042053585885018440199367731026999`47.98780418251883 w^3-1.1386237829594259594911652126693693091747254746972292797783`47.98780418251883 w^4)/(1+1.96980171806776211770393129539735928436097592296350025888288613001956353718572`49.52287874528033 w+1.3084396888760733852350224283276680762611108079364852712231`47.98780418251883 w^2+0.45822606251871557977484655826728263041118279531589270565212743849852289966179`47.98780418251883 w^3)-90.23341331987775391127674078438905953610309178612496674827581560109405968992849`50.04453159980093 THRSub[2,1]+8.43937087178912146291033782336235924952940177413854141612853347511248104457556`50.04453159980093 THRSub[2,2])/(1+9.26104455111610149591416631349245509751017955190143449640022906223935530009327`50. z),((-4.58361096271147561400118320891128492951409897572743496610703417313098041337824`50.- 13.4075353934170812629669996900081622762130767282239688850617`48.9215542322587 w-1.20079556085911003089417834299088168724910296168912027967181374962916830194659`48.9215542322587 w^2+1.11204840031412160188956142606175578141846316936946593190197712448785401113362`48.9215542322587 w^3-5.3525115466818967762987166211464445315138535113751908853081909518833617387156`48.9215542322587 w^4)/(1+3.84123934341196238968341568248289202655920609239261860100136424281912106676618`49.52287874528033 w+3.32705394911429375000345871948103527733239273880574291548833708301372203987044`48.9215542322587 w^2+0.84679297758306036787989061715319750921086976483414876458406629950096228964772`48.9215542322587 w^3)-10.34904934409444561619100427119998915648451012100366240933949949108999622857014`50.82309606967675 THRSub[2,1]+0.96792820277827990073060960989306582466246034469051164565575837897509453090387`50.82309606967675 THRSub[2,2])/(1+0.17685957423555261124913239651657121767024224805934943388303617558601000197764`50. z),((-23.09750537697052580373669204655309607916102046757517311664518117369801181321231`50.- 26.4785014880936099942160591760414031089613895879045109109596`48.402557053372306 w+3.6098812342079501778026295494355030062105444316341843900299`48.402557053372306 w^2-19.7854855430290991745895622374697958984861665831309417451869`48.402557053372306 w^3-1.82637871825437758813501945910133633648346948216160279073272828865814808574944`48.402557053372306 w^4)/(1+2.00471342604917890477904145157809971890303077731943787951219025497905218022368`49.52287874528033 w+1.35912299263070712514434489784906809043070741703522556883508645281923559827566`48.402557053372306 w^2+0.47747852203522440485491736556852878387970249906246824742772340315359800643617`48.402557053372306 w^3)-55.47316494523548223266886772227225504630618640694214309725674823169638785414368`50.074957860352924 THRSub[2,1]+5.18830658378343560428263582549402576270701494813305767562648922894228526342257`50.074957860352924 THRSub[2,2])/(1+5.30822437001925919790355250821763752698511256601373217041358901718010574035995`50. z),((-24.55691212901313549802221059095134021763885529131710381174348961977744882223108`50.- 28.0263311863425264903200719372015001067777360900378284488503`48.35722143064017 w+3.9720167271473694488822283893342489739026603457116130350891`48.35722143064017 w^2-21.2884956440215120250410516215409547786817564743304010440244`48.35722143064017 w^3-1.74917790858497147803791204867961064720909755822499511661642416979269000450814`48.35722143064017 w^4)/(1+1.9987644420773323834116307132671499706400809845987495522047598076482626864622`49.52287874528033 w+1.35051777341593581461903647274584940897689846567175364807055562975373380971147`48.35722143064017 w^2+0.47424786257743134549692113825211343320783409709738292267757719903118792735575`48.35722143064017 w^3)-59.03019284626621583920544087134212931949868888538420557130054894344056394408729`50.07005561906649 THRSub[2,1]+5.52098908523865862465711723810147610116853837215108774140704418325770235552872`50.07005561906649 THRSub[2,2])/(1+5.71271778791370265233913692162576297249633972081301612984627539470552313190464`50. z),((-5.65068832048179003353098665084922614939297691450024553937617760494482945288575`50.- 12.6998390086118055110503571522649752436861159896259226914681`46.77738710476896 w-2.2274462800637480554021244599801905257453914197245205647554`46.77738710476896 w^2+0.00860612927806685651696794957311959280285391752135422176474173664364414070481`46.77738710476896 w^3-5.0674386195406407586286182700195293664954914658099826294674`46.77738710476896 w^4)/(1+3.1500036784121703034688654532296142536359343314735920602450307795266701402649`49.52287874528033 w+2.8417026110661562173453594182054559448796751040303010434719`46.77738710476896 w^2+0.8863213637293838789947050266284523718001562571310291635251`46.77738710476896 w^3)-12.94984855845654513870023219358566597333001435468693873160510826687684227912314`50.49358244448188 THRSub[2,1]+1.21117633365913074794568747222524609863738519264156687998214345075773561298318`50.49358244448188 THRSub[2,2])/(1+0.47261383671116183746047792444893877622341184312757791722670335351218362955725`50. z),((-17.15470570237229219693951714134418121929441432961395517603977661769470178445252`50.- 20.2539708064775500892050415657519537563957567730372295343702`48.56520432945546 w+2.09820877956934890078840409913226134744909410881829485218582369433548621977293`48.56520432945546 w^2-13.6338682514579638376314025420048668119721043976947546758831`48.56520432945546 w^3-2.18283707106921126185047230133825351579461699276432960852764203626717763797265`48.56520432945546 w^4)/(1+2.04395721487164789969281510773536696616821780320237933718282967337638320079643`49.52287874528033 w+1.41558630200246054429947765829845161183513159359744539453138080812728529228525`48.56520432945546 w^2+0.49831863150214015880691581784138535477504338621239070790595187184312397454897`48.56520432945546 w^3)-40.98871486084591543585271956801582456951705725634062012699218879124083730635116`50.10487681026624 THRSub[2,1]+3.83360169522135898954192205846083227398202547283949998593656424621736130858632`50.10487681026624 THRSub[2,2])/(1+3.66110073647720851040045982349971125238218545177623535110879764145826219344423`50. z),((-38.51625209611457378919039664080890795057111397864223294966288289299996262999335`50.- 42.97184500260906181636361984395881704764647110011707191147`47.95418164856812 w+7.3677847584725747583600166880600229459263709244310050833989`47.95418164856812 w^2-35.6090614938496381460066139771376031894446543198734771485297`47.95418164856812 w^3-1.0866482976287704473460674296387823479863792412607013438505`47.95418164856812 w^4)/(1+1.96828628674856224588597383447982489151345407472182797455838262330953716426683`49.52287874528033 w+1.306229360274937471763498328905957096326033721808359107506`47.95418164856812 w^2+0.45737371611820685302201619812232996684900542370138329400881139599885075586489`47.95418164856812 w^3)-93.05344350853500233557990460365160398352146962599121664188933857359984847733758`50.04311275128964 THRSub[2,1]+8.70312328628940677699872289040334573006194978416243807609173481277752635718893`50.04311275128964 THRSub[2,2])/(1+9.58172903302442229596237474432867250183215179589188110332628178131663430498939`50. z),((-4.60156604248987689640694013003796857265902515169909215087530338118723507081262`50.- 13.4098374496556481163776620472954525462959449467698086411579`48.92216638833377 w-1.2636986850117643012697400075676163325698191923002117341186562815101693085154`48.92216638833377 w^2+1.12461510276414107216963612688855758597688561477719928423962367670699472445031`48.92216638833377 w^3-5.37129317500552803512115118591118028864754306326773680513867024796900261886491`48.92216638833377 w^4)/(1+3.83004463520136145034179882391807974235332607990187446788287669839724015940067`49.52287874528033 w+3.32957885465397287764837681633447013503299717591939065511122513690005486197875`48.92216638833377 w^2+0.8516286683300432210208675100883679911760876497349039285931094744460742652831`48.92216638833377 w^3)-10.39281145472441027246900133375684230362003352715278995974220846546643600136223`50.81287723178117 THRSub[2,1]+0.97202119525357593725467375481249324584929736136375515073811673092328781246809`50.81287723178117 THRSub[2,2])/(1+0.18183605634238672758050372971630284741523463430734456685646088195640231495218`50. z),((-39.85296112957310518564501710297836304641774310080121292691055685316398657431532`50.- 44.409935060255237385959704186417713526251722667028175357229`47.91473841851456 w+7.6895410192121713779331493293336179712345207615265010923157`47.91473841851456 w^2-36.9776030259342095502698885844260482316304349961430247136213`47.91473841851456 w^3-1.026973874055472335060762734148804774464400113686195187159`47.91473841851456 w^4)/(1+1.96666227056637912646570654445578628100850101995974348378833185937542677517781`49.52287874528033 w+1.3038596710991221507647465013261071468382598270052907073228`47.91473841851456 w^2+0.45645868153341452237692940891427887500807573207843517576380140140756111347535`47.91473841851456 w^3)-96.31141892965529550555292233295847932223344226170537272076000411809011245427948`50.041582210341005 THRSub[2,1]+9.00783594048698987499175185350534448062175389589603985475685578306898097058905`50.041582210341005 THRSub[2,2])/(1+9.9522151945535920854521783094323829943855347499922696715621297785296628602779`50. z),((-31.52231363350332165055295107103771483731541734392552644014870592091801631566955`50.- 35.4620773109597275137759621216752737638453143391535022921346`48.153868262190834 w+5.6770604225012064724142437837696889478399709999193215446244`48.153868262190834 w^2-28.4427738400036368959421567357927369747313228637852976403382`48.153868262190834 w^3-1.4068165058876460841869388540071580124558367937249977775393`48.153868262190834 w^4)/(1+1.97949280630888821059493884901727768124547175717051548397836312421201734719138`49.52287874528033 w+1.3225538885932237395845439222608007170304265985664848517855`48.153868262190834 w^2+0.46364294775595181806064939901173228001539662953039277920585562641567189730736`48.153868262190834 w^3)-76.00704145867393923799215477452221989950824780000259829446653852803577963356092`50.05339888681913 THRSub[2,1]+7.10880358103325714103190724903912275772113280342278018268420707852038144071438`50.05339888681913 THRSub[2,2])/(1+7.64326871733414830894867443605943074449808001839596771035703507415246991159359`50. z),((-21.73476281703325732178165571617708052003935596972564253438895929242342861481695`50.- 25.0381926684225764673303665786924453452963287035902973452856`48.446301722246034 w+3.2693424318487845647127941422164267595252025603362096262448`48.446301722246034 w^2-18.3800348075924242956560869175875739286123140159310186707231`48.446301722246034 w^3-1.90115974088614545148104735541590233875870074076488839356738535847455783248599`48.446301722246034 w^4)/(1+2.01121970472214376120583782430464434057037819546948283010390078862467368201809`49.52287874528033 w+1.36852014709050467027652824239981747692839174529942761051959235353267919551935`48.446301722246034 w^2+0.48098948008607434634435297702250544234122242822305452292218523740416999936372`48.446301722246034 w^3)-52.15173772774828658937983092064348333844970651528668057160107121235527956136267`50.080200010240716 THRSub[2,1]+4.87765939577714900317667691006141028783584757794217178711134613717967291113836`50.080200010240716 THRSub[2,2])/(1+4.93052268061172969017910240346836737117956432819418740533320730785144875909899`50. z),((-35.81809261740196312645384151449968484296665979387955066623917617740696213240406`50.- 40.0713983808328267870909735494402389947271415247975287803426`48.03203712974998 w+6.7171508866007617993874724629094767185212684316971415050039`48.03203712974998 w^2-32.8457160730700472225826204554209540916225950224968743948063`48.03203712974998 w^3-1.2083795992209281763517814105922150696641334416833042485912`48.03203712974998 w^4)/(1+1.97199929975869903592530657869324976293133524762792854999817174239386988695966`49.52287874528033 w+1.3116433988981491427362442161172134803680029895970643343929`48.03203712974998 w^2+0.45945951455262493126255637775012353453199328506959002308946635969266230218052`48.03203712974998 w^3)-86.47719015505518801527462532535802814952725484610330035571289599763359171604357`50.04657331241051 THRSub[2,1]+8.08805799112964850648356355959052730016636620776480468554573560930038254332915`50.04657331241051 THRSub[2,2])/(1+8.83389930834949566058612235711973121866423029856780193284496107113732450778637`50. z),((-4.45303541858371474626754541312722034051342048672113210884587313106080231051346`50.- 13.4888335935178748623546835827218776725702208033560869124688`48.888400124270746 w-0.65723595949357032421693603650439028405547034189068410180188897950419070839407`48.888400124270746 w^2+0.96699877038352927449811130369366401880578905413074739309339558746167665896928`48.888400124270746 w^3-5.21322803953106889262210484551443436494213379151031419400607974242706475546384`48.888400124270746 w^4)/(1+3.94738295442204248969607628924192102290154061586822674374741914765218858115915`49.52287874528033 w+3.30916103081942090722953350124082074249496381510968354747829480781611031570165`48.888400124270746 w^2+0.81238760621689251735638785647737693314167227315096410051805102590261700435177`48.888400124270746 w^3)-10.03079615456750384864331812618447694716853736709029099882509284593364727866275`50.90896157209465 THRSub[2,1]+0.93816254725523896230524546917661149917665795849965505013930925511027391169943`50.908961572094654 THRSub[2,2])/(1+0.14066887684173745357403994849193903730967355239130162897801359161304917071449`50. z),((-4.36334360721945439430005757532852201896699810543419149774686114088028503364168`50.- 13.7931820099446061533579551819836640082258999685800174058503`48.40936081406463 w-0.15952946472347115060012821986652198583616680395885120151202948299139227992103`48.40936081406463 w^2+0.80425575130542777333993944064589606869456193860828394835629354551741905385237`48.40936081406463 w^3-5.1512908103171932697275073220187219716839641233791912080081`48.40936081406463 w^4)/(1+4.08092603027243560125031319342518793557240402897965203284175915695885250715783`49.52287874528033 w+3.3204168003327248394364397809706522726480111843762507345284`48.40936081406463 w^2+0.79625659761995439171658809686863921701884860922667971087258121254853753292992`48.40936081406463 w^3)-9.81218933020539158601507276176615837183949779306176552150219945483896328116168`50.98384541884859 THRSub[2,1]+0.9177166392704025736003936793554037117731028213314588707783571532352229385087`50.98384541884859 THRSub[2,2])/(1+0.1158096336697460783522417777016086280807912308182189927732796398190288197461`50. z),((-6.50654098031710090993855883225565753886259457725071817978650296338047295617397`50.- 11.9665918208577446945790379898094397698042035003924790578039`48.88391964316722 w-1.68283930612240413945325218971074279991614272319504367912695095394031670596725`48.88391964316722 w^2-1.47497478137359972898812909633575018475722963573364177455902412235720813407609`48.88391964316722 w^3-4.2784396826425173297886047666490051174285335547489148080732888276009972901848`48.88391964316722 w^4)/(1+2.73398750858296969098152195237486826724801618680218815362468959683198093523611`49.52287874528033 w+2.34276000627434024991443605317542127566068915862723875189813895905681834004845`48.88391964316722 w^2+0.77882433773332749075037440765263051096369021573916789810395933687626697059203`48.88391964316722 w^3)-15.03582752624241116242257388369826424968715851520765234166827715810334900035102`50.381800569234336 THRSub[2,1]+1.40627424132099980929995498674285570505629434012389942396051221807751697646257`50.381800569234336 THRSub[2,2])/(1+0.70982444787649094756131051356711194814537767449729793525401029745563470909007`50. z),((-9.30237198060703944756289129788204389466534747971820782844074359742070971346526`50.- 12.8444809190436256362321957962004103029256333743219202139056`47.94028868876533 w-0.25406789427905497783812019620836429049687925322018977227392942877104858516432`47.94028868876533 w^2-5.1789238227545362761241902117063141472024544965055835630308`47.94028868876533 w^3-3.0832753070722379051581917179747129420362882555076884643878`47.94028868876533 w^4)/(1+2.26033087306102783245866875118709681715342010396856738822363282228370421242597`49.52287874528033 w+1.718781264109245155044312731288051099452764239967324140607`47.94028868876533 w^2+0.60149874159198030616674086557587155218031547590054263838668912034036399310984`47.94028868876533 w^3)-21.85013673831026159643053554897736663521662885470665290184360473918628653717792`50.22363229711969 THRSub[2,1]+2.04360447809063116132351189867230564936745430001687427418513171651872821093055`50.22363229711969 THRSub[2,2])/(1+1.48472509540309611981716583420326177456371565111185329162829239334061661107335`50. z),((-8.92060007710223612479057877768673532305026729371982437833544746082205311698642`50.- 12.58144179136746540259376703803986000599904419988433322583343102501599302552556`50. w-0.40686161884513693645738513677535458563812041181944652535708716929040301132485`50. w^2-4.72893004289492082437987442159428410419647781333864997269909723864257867704221`50. w^3-3.17713451688692143443488318540259199315463633404122365798260550364617063908379`50. w^4)/(1+2.29145738279026827930710236219192611925939100490324941544100034408097341171152`50. w+1.76139705600342075504457578813106209701808527838974826797010694922062436196177`50. w^2+0.61500635316523805406978011881001928424820019281504829842247446802672238838206`50. w^3)-20.91963993836360070150528103528346254635873787622394798577683031897571280047446`50.23684181474599 THRSub[2,1]+1.95657676517540972366163560342403329540131675944987696067092353110897853954933`50.23684181474599 THRSub[2,2])/(1+1.37891208481602649655296833460482884094026356285524965537928821315107041647911`50. z),((-9.83435726456235032678244815556291771250628486391866641192124800939298687288438`50.- 13.2455729436272880226489289919379496890800265047216527802503`47.24499454237712 w-0.05391845089059801883198233422318993934302258003305802028102761736113839545213`47.24499454237712 w^2-5.79217768278423028880180908091581047279366850278945123176`47.24499454237712 w^3-2.9700227431155173092467083064519027596401178441613042065872`47.24499454237712 w^4)/(1+2.22450112618970786188700319842432969836586794259185562321856512486414030019619`49.52287874528033 w+1.6694324533430614553414653799076448037327297033140820270736`47.24499454237712 w^2+0.585576191696892696588537194665105483139089847553840881943`47.24499454237712 w^3)-23.14675023918541031989921283664998069008567212887211740004768612130877609604691`50.207548373749184 THRSub[2,1]+2.16487443573329161371739826231189382722197147219223426178206966326093134042181`50.207548373749184 THRSub[2,2])/(1+1.63217168318642239148689289261081021512705226579017672354950803608214042008801`50. z),((-4.38862948780231117752974888694959506616175839371166900030723491268045210965949`50.- 2.94541940885744174447820680894755787603620537546987359189562181826035940644998`48.71288068829934 w+2.48766175147589120800094699444419125464209214833284886129761622250120049973227`48.71288068829934 w^2-2.63603795286756922922414898971290323345990199499454706732631562663236585664999`48.71288068829934 w^3)/(1+1.59048782936958155618819694928924711431563662035710574340651803451873433171521`49.52287874528033 w+0.42755058772582481581244661900615365492967427382251730433086716145702614571654`48.71288068829934 w^2+0.08601531975593949249184421334169599223974334929010748264109143335389210300251`48.71288068829934 w^3-0.08246753419378029277295159273853191588689933579608822241356461071284682376753`48.71288068829934 w^4)-9.87381888112357647749918967602267149539871857044165570373906540036490869122052`50.961047528461734 THRSub[2,1]+0.92348074169902916163135743255422309800502864838670249851210351282957755776038`50.961047528461734 THRSub[2,2])/(1+0.12281794183819551442739150502089192340088988113207888085488657000945191689533`50. z),((-9.6869246656713800292571582614967422200556646481046997412145176014131060099382`50.- 9.027285541878264646212423053495765853091390598050016750672`48.03036562998023 w+3.2650159403339392919164898682919932285215879538814563490038`48.03036562998023 w^2-7.0326122102443548214997696544442035132454578264910050754715`48.03036562998023 w^3)/(1+1.81004967017658117532252238453299881687293455959733261784360172229609138039729`49.52287874528033 w+0.96188399382144454671300472574005021299154572239651932869366120059137858697363`48.03036562998023 w^2+0.22577579987646892564390183444718974103199282865358523580074503141089781687307`48.03036562998023 w^3-0.07302936531999064901535370115841610780977001387104396165231296759869353297895`48.03036562998023 w^4)-22.78741116730386347287805268368956909773510963839194036924644590869216352363402`50.21176470170409 THRSub[2,1]+2.13126609061193061801661156380978299867913504434193713059390226273561946090603`50.21176470170409 THRSub[2,2])/(1+1.59130883549094458154729181685658106939151262609235678860356644612076925677767`50. z),((-4.91666238502875493913972642397025083724065188524687999583000635162190036696913`50.- 3.2620672531077607109901799021564234489717232550096705410901`48.4350034832835 w+2.3877875730378108119335953728048857665356816134832465236259`48.4350034832835 w^2-2.8682525737934783053986215587032560870400347499588067390987`48.4350034832835 w^3)/(1+1.57472311967354090894039461598205719949839989034985435851210990999606624551312`49.52287874528033 w+0.51631550419132823039832981385068901584647992803343213864354928063444609435277`48.4350034832835 w^2+0.07967487354443241459354048045856640253395560383608832399543355766013455153962`48.4350034832835 w^3-0.07852548694507794282757222575111331191087846337255568726195192909773487575267`48.4350034832835 w^4)-11.16079918696891800499422891480732870298356547862754599931418530022628778223998`50.673494319808505 THRSub[2,1]+1.04384972372139897368724458831160915436649502037435593581933207923751172685829`50.673494319808505 THRSub[2,2])/(1+0.26916907462615294023788228594131553741643272444022498541901590529690801199094`50. z),((-4.44835297640327613719222252837727411906376201715203220934790611619214683275299`50.- 2.93194850854242276555785330421067044210492589037718440552577162780028032661824`48.663801338612295 w+2.44116133394637530893323031636476923104327086440212719873770319771814000487604`48.663801338612295 w^2-2.63955597643149036467069737091183386136225852862841109613735396674331043110781`48.663801338612295 w^3)/(1+1.57743752950197144266682647871402922254876385179757610717037555818395212212917`49.52287874528033 w+0.43637274327069952002232753848993585225429152375021825565333664500089651736889`48.663801338612295 w^2+0.08329371827865816598436919306905782557227975291270329400197009806625894631789`48.663801338612295 w^3-0.08126589750220177877225131356307085314302040045986922047346209623437613304974`48.663801338612295 w^4)-10.01938358746962527774911851376321145074641197916732251243454316432047982338904`50.91249253305563 THRSub[2,1]+0.93709515012600991804295733561819061453054353364462428361872918145356565890428`50.91249253305563 THRSub[2,2])/(1+0.13937107755513841194385224988809709533265668936371218370360130569690399561589`50. z),((-17.42388314932859570719375712204816728584671522309674249629467373753928381918973`50.- 17.9652085652531700736913264469186203206159300266805094430856`47.74066152803534 w+4.6630964634690409290371069376371889798236156260343807675246`47.74066152803534 w^2-14.6331276861545206477745203032843502815766435287846485090087`47.74066152803534 w^3)/(1+1.89406196764237864790926874521602984258181981064926251843703200586044969117925`49.52287874528033 w+1.1415842954147609284315875512188127074599905357187675912107`47.74066152803534 w^2+0.3381691901407452311111798887984787742976455942211721723792300161234896947641`47.74066152803534 w^3-0.04421654196274862166379075281296020022117540685411729375819573043805211864409`47.74066152803534 w^4)-41.64478397099063607870226477618121018249056360408245573942157330337152878722519`50.10301202476959 THRSub[2,1]+3.89496267375830020234376649938568737537953824063046064637056126439178618795449`50.10301202476959 THRSub[2,2])/(1+3.73570674017498811547532575958756453478288988459918788394547456935432994406976`50. z),((-4.60182235342857820927998229998209951125020422552669621669090615803466944691262`50.- 2.98589483990030823987422858188305386862299944022472099945016687670706488384691`48.56494036433585 w+2.38622700535375865975449396231988677744752075436253644792516592367168843545273`48.56494036433585 w^2-2.6889245624939216392588911235582658076846480144958940216265022843644786098869`48.56494036433585 w^3)/(1+1.56470122145379909113111410528816196086973696855442751166370457801427665259581`49.52287874528033 w+0.46170121240348666426877378854521954117253254131759071840692676851944165922041`48.56494036433585 w^2+0.07951476152099856530921076318158626114364771014849295685715907253066052520093`48.56494036433585 w^3-0.07944786524676809218857503509298320131022436978941519227057345738311021301389`48.56494036433585 w^4)-10.3934361641544741737195076982429689167174625986341826460014345739124510886726`50.81273369888509 THRSub[2,1]+0.97207962321693717535630564787083132517190413876500443588620293452255733628324`50.81273369888509 THRSub[2,2])/(1+0.18190709622725358904343348921489518176987694386960092636114385007722549026906`50. z),((-6.17212659522655612248820436974519324126574031360764545651706318876181576899281`50.- 4.7658335116619610419327631338260995666706381692266836575142`48.232192325973216 w+2.6199891050707735059040838563643456005449488888883455861391`48.232192325973216 w^2-3.8362731423732366733584931970355314973086708856475207527739`48.232192325973216 w^3)/(1+1.66973078376828716456066432336383965920922770547023930298281051239578968269724`49.52287874528033 w+0.7000643356435031817073051206859605651905454427976492346370246747900363949988`48.232192325973216 w^2+0.11529187072636483862851195907128990273241180433156152861892653445045706664651`48.232192325973216 w^3-0.0813914116866175379228979546974420036435274743859343127961659016096285786896`48.232192325973216 w^4)-14.22075571942211900861923828320133407142465879039017548001182325548836998117072`50.418365148453574 THRSub[2,1]+1.33004202299062686179880077485318776121678214354515238944039475237309270548544`50.418365148453574 THRSub[2,2])/(1+0.61713718476151688628248424801761664864683970855643797107949288125219757499348`50. z),((-27.55970408170371950698470014560519298649825855820427773877760823611932335656194`50.- 29.4531937857812369975325461723199494294607828387690634188995`47.44686657444983 w+6.5491845515175817313835678576209921260251424632614136809763`47.44686657444983 w^2-24.8115312815180156898626442709118069032170252399774889155743`47.44686657444983 w^3)/(1+1.92472215545318561036491203947143890942562431837107487408013044702034317483289`49.52287874528033 w+1.2146266192123909106003330201744934164894167700495645238193`47.44686657444983 w^2+0.3930668728341907900791927258550301006263589248655115014347`47.44686657444983 w^3-0.0238493622301101843967687358198784665054983543151213651589644470845134906454`47.44686657444983 w^4)-66.34893023168782090774248166279465221587601841358138902204785378425725911133917`50.061749766173996 THRSub[2,1]+6.20549759307756883634386538353026899432753577561404787486059061406086539865258`50.061749766173996 THRSub[2,2])/(1+6.54498033464356855880116846943295177966882827874219829769951134924810778745907`50. z),((-18.94159554883502961585197949250594591328791453630047603312922088437667169850779`50.- 19.6931792380677048686965599821511768321233933865007592614158`47.692838840790934 w+4.9427310913546789208108460506424461603006268889186526003331`47.692838840790934 w^2-16.1497717219037065070938257074608271169549577053470882362382`47.692838840790934 w^3)/(1+1.90115295551411426161259881067843494148859725244182130627266873880723062854727`49.52287874528033 w+1.1580353303189620926323175564273328683701366714641906936876`47.692838840790934 w^2+0.35003964852369702636879453690035402330085018977915593608556358832856934603599`47.692838840790934 w^3-0.0401486262346964644289405889932231064631950098644634799967655852045506533932`47.692838840790934 w^4)-45.34392085879028203095181560840312594258031257902467290067285110937621376342915`50.0936300676384 THRSub[2,1]+4.24093637632663489180084100378137614977133119153714551254741464356197794591943`50.0936300676384 THRSub[2,2])/(1+4.15636032081513754941524716950426886972833041574043245321592652256545086082873`50. z),((-33.25300400048438947683820151196753364649623345497551988544300294422278722577739`50.- 35.8763996034576625391823150169004244946684992255615548440383`47.29420648830838 w+7.6205398090810810746275666199000669907650143168874933724497`47.29420648830838 w^2-30.5566236566116894617685731575704365177339024881818101011046`47.29420648830838 w^3)/(1+1.93285572370213754848985110502980002796237482143285511519210676816099996141996`49.52287874528033 w+1.2349236127646639012179359776699799154369062015915164478194`47.29420648830838 w^2+0.4093596835851600646397313842725523343123073919468814229776`47.29420648830838 w^3-0.01705060615026053211544007970200126946576595216692164019552450739150118352374`47.29420648830838 w^4)-80.22527185590937716612461765108109545328725186776578554655442316137675949059443`50.050421503573446 THRSub[2,1]+7.50332717750549617755189631126800806399043316092338686257911031219743292832738`50.050421503573446 THRSub[2,2])/(1+8.12295189056693983189652927512179843446584974569571124198562345850081023795082`50. z),((-5.35662397918305623454585246661251664804094897327181885554905227593300382394761`50.- 3.7630190973457169828884717817679344325059050505970088210163`48.3324028709016 w+2.4588826028148967469270350211150744274743872989830032504855`48.3324028709016 w^2-3.1819797904269295106569284898060786879054640707679520803746`48.3324028709016 w^3)/(1+1.60822783793921124299684807829463404894482446146560555651411863221406767053595`49.52287874528033 w+0.58834223630745646264188928033513815798954942382890902151176858319634273920425`48.3324028709016 w^2+0.08857832221331930506727213504003099485029988105023004186702379098568521558319`48.3324028709016 w^3-0.07942001731598398972821549861695391130849537485081696410786514050395054005312`48.3324028709016 w^4)-12.23312235088361973117638228182518489992706791253818779312139087879597299562509`50.55106246527734 THRSub[2,1]+1.14414220454117193075800636970980038772235392638956358165861590323774908516562`50.55106246527734 THRSub[2,2])/(1+0.39111010903118319332790770502471554055041154257356525472063739592525533999599`50. z),((-29.84886308166118650238160923055689976638876055200293697945509196718361593372742`50.- 32.037273917008693232775600410388597828541097723638903388958`47.38531676359201 w+6.9793028516892381157965081675135475837501600170494219142336`47.38531676359201 w^2-27.1201794635193147493501147292377578799762461905193511438824`47.38531676359201 w^3)/(1+1.92841374032789487341607503745181408249988039390626791610755329549380340456964`49.52287874528033 w+1.2237855944892794107167939049159817138514493276195418806366`47.38531676359201 w^2+0.4003610452375788315413483956141008755073177485645963817098`47.38531676359201 w^3-0.02084781512997813489391886627624101560105258156219189191341591610391858445615`47.38531676359201 w^4)-71.92832228352518683373618985684623006360621915530188282520032440867611150386749`50.0566329244741 THRSub[2,1]+6.72732822135764948393006374527080267609620635498296816068558455385871971369652`50.0566329244741 THRSub[2,2])/(1+7.17945029766151915147428261170085315675074892117963249206591062434217279541779`50. z),((-8.11302705256599446592507293165236665318008594776255707718472629453679787145026`50.- 7.1471535395774355088560740731476793277291677007744267082011`48.106396225339566 w+2.9835402398769034338387684777840392863303235501874866273724`48.106396225339566 w^2-5.5557743326530628647599125925393318047510850569331155451145`48.106396225339566 w^3)/(1+1.76571281743069294265230503253275120550000624952163573178507158036469944607814`49.52287874528033 w+0.87546174007769090996184361501949882009423771506087708415300062921615877628374`48.106396225339566 w^2+0.18237756900593604658762198814804930644297870437445480087420352255045781194559`48.106396225339566 w^3-0.07902367462420852833994456540913852176099266977384779922786546146660735343059`48.106396225339566 w^4)-18.95133344918592156460300619765595156186290864988790067642808568155111830171503`50.27085084420516 THRSub[2,1]+1.77248455542343445060477146754024691917516947935908841748144869075473538576075`50.27085084420516 THRSub[2,2])/(1+1.15508279771918268449137819652947096088815468181149307421555238307007164237563`50. z),((-4.3554174042229880881952564666098281462321551782624192691152441299109048406714`50.- 2.96719183213991190341900710742882065905187931643956597067636982366529347313592`48.743647712028185 w+2.52414272236241553572412679024937711970867478951291991024852950707229640505098`48.743647712028185 w^2-2.64053651867120441162648116736872438175634698075130548219174758971321966395056`48.743647712028185 w^3)/(1+1.60117889452243608332500270884871339673075606040049699190328271991073326529345`49.52287874528033 w+0.42312920134234443816396811195755041813117887031562292767926943224699074364006`48.743647712028185 w^2+0.08798468165776122252272697395463922831611282079819200170887685423001997645938`48.743647712028185 w^3-0.08332057231424316922135927154385377811915106704810577357632643012576819712842`48.743647712028185 w^4)-9.79287070969866605901710184086694137590831820864473100176851739109711725344807`50.99130700513583 THRSub[2,1]+0.91590980300887669421032638515471086753365754312375400937316909588707397311996`50.99130700513583 THRSub[2,2])/(1+0.11361278420575769440212825009207404285520677064570593055936282751349743513904`50. z),((-5.23073889788048810082405738095354870181959197205833170578442636802800914343904`50.- 3.6136913968468078893861540923780466229371019829483606004977`48.35606578611266 w+2.4356104200300660458624286149723161194304466226342565901234`48.35606578611266 w^2-3.0880137210537960623815230562003196499609755906030245975313`48.35606578611266 w^3)/(1+1.59807137521609789976046777315658201519578672349576930453915818953731690495149`49.52287874528033 w+0.56852818654997773918197232740285925434936640532231162552218800551724974327824`48.35606578611266 w^2+0.08537697449760467685717395815616218850992207142547946332224781460221196117027`48.35606578611266 w^3-0.07906712981381363504175373661158157298505483412806140353297076692223302170107`48.35606578611266 w^4)-11.92630127725898322886972349829606681792408664553581823246185598960044123802263`50.58061235411504 THRSub[2,1]+1.115445774512314735728737332323324945925982302196856066068780500488158865832`50.58061235411504 THRSub[2,2])/(1+0.35621943394918316070920437562959737320303288478133090306650632182823553890062`50. z),((-4.31179588916941998134665884713454459991024958116008748012367991226469814989942`50.- 3.01822941104469804754105090729210269471739714454246026141279837156955845197061`48.78865124141837 w+2.58891568631105051862850709540785932794083477802117570562468732886714345390475`48.78865124141837 w^2-2.65656514045248730902987984141693132642999378515641886242177051273180901091373`48.78865124141837 w^3)/(1+1.6206756045562780956124173886662836029288948296586501690789852287783308531616`49.52287874528033 w+0.41811979088718643228531509210745778773106766674895035903848718813319975688972`48.78865124141837 w^2+0.09123892185202706887559255385811802643413765765767901967801337568397573254979`48.78865124141837 w^3-0.08471336582327021119644806398212561757110413320646977827815931056558501310904`48.78865124141837 w^4)-9.68655151807261300654189519185939720175532031437513853124490968663888239863984`51.035430997825976 THRSub[2,1]+0.9059659578642819401396057736565687977889443756386267455009846668439731344167`51.035430997825976 THRSub[2,2])/(1+0.10152251828568024798851008578113340227027053764352012287720995455231058299287`50. z),((-4.4559424651187185747706140161173245415728124409506591186523496086890424561971`50.- 2.93207093415411340197274522820935664273030314322808896187343105547358086912298`48.65806632359466 w+2.43660462593712806847920840782595129713848674739395572171432969645883665424666`48.65806632359466 w^2-2.6408342696051809385910182906599865331109322699125718087351059691029119542904`48.65806632359466 w^3)/(1+1.57621583282110217288956137881173962170205597291641178817893829057416981042866`49.52287874528033 w+0.43755322212755990487751570053231752140626142098169056105464161170113337296976`48.65806632359466 w^2+0.08300990445698784400458176504696777067410428612735075810186152201501249889263`48.65806632359466 w^3-0.08113813106697005537249995320756100334455695098787931781886748147535298290398`48.65806632359466 w^4)-10.03788153060823456156017252722052517579535889128095024896056239139737379067426`50.90678777113442 THRSub[2,1]+0.93882522989101422525982638428818415452072914488994832667372146326404179320248`50.90678777113442 THRSub[2,2])/(1+0.14147460231016913979963177326183298357360467348041573096838065560240419406042`50. z),((-4.35176277774362136534604438935065855461527878049265248755965216956269726486509`50.- 2.97038549461849232387605929165790453012629253682889331179611748046084782246436`48.747206690544076 w+2.52875459072288949451006247309568190124002961586422151030890114424823064313374`48.747206690544076 w^2-2.64139153251618427357646543655504063215430718844186215195849358012022059569877`48.747206690544076 w^3)/(1+1.60254863411645872531487583376795734193525056734459285182237635277296271688442`49.52287874528033 w+0.42267066969889312542501854910975080325991244325170653515569795328546797695442`48.747206690544076 w^2+0.08822565323605499311607947225451621310017574176749555330086249108151745661325`48.747206690544076 w^3-0.08342432858401221705770343766999478267726212217602298871998241508701614376979`48.747206690544076 w^4)-9.78396324895356625173689843045308655394316309791194187990712157039597103900319`50.994801159753884 THRSub[2,1]+0.91507670402715790998408554171580043901888714593962063092706450220476789898716`50.994801159753884 THRSub[2,2])/(1+0.11259985730673001198892179764006283597165479622736512699878841213174777270049`50. z),((-4.78520426996473582929863522777378015866952910566288203008416316105322274549706`50.- 3.13170090777695968854949828646184807567920067712352730422070766688467398693459`48.480729389513115 w+2.37738726335717993455776079625101006377646145601422520878753911565225577283063`48.480729389513115 w^2-2.78589479624328201269520483185335131298997302993408160522345485774535833222244`48.480729389513115 w^3)/(1+1.56755310573912898315147931835575725427229251093059845645533881796344206166066`49.52287874528033 w+0.49356166036171444135815205472332835831825174992148066468346756241472245223204`48.480729389513115 w^2+0.07869451258337891443433035717227922997541831246853724048054089739221985392628`48.480729389513115 w^3-0.07862505907052554159525005827679913255060330139137627000017941987136196758642`48.480729389513115 w^4)-10.84039489772935977381914404798252150807465007779278401458761393393901253271346`50.72400990193697 THRSub[2,1]+1.01388287966310210299969483840453508308048876267807399066686799181165031770125`50.72400990193697 THRSub[2,2])/(1+0.23273376130600899144340344601722041881594903727716412743612027116362081879057`50. z),((-5.30498089245545187923774790854053285813626369765152661628857779325158556505368`50.- 3.7013888541576638000213715824426641017828852318864982436956`48.34169159394801 w+2.4491824593253765635177739999201865713779254889449160547995`48.34169159394801 w^2-3.1431147851642895454870760128898682122087970101679354758336`48.34169159394801 w^3)/(1+1.60404980511042923505385920131495228344675173670897658545813259606941930035844`49.52287874528033 w+0.58029672335581813413109173495612717800229387697807157553278333844423450377004`48.34169159394801 w^2+0.08721605235200548645575657707649525678867313394293757887654682347818337166556`48.34169159394801 w^3-0.07927133555374379013704687025200296428282321163649706188601025168569424848555`48.34169159394801 w^4)-12.10725209563892194322737262847469941301181531388512770918099608814941645653832`50.56276284218018 THRSub[2,1]+1.13236978314366778565778810691348846860902896839283171173717241981541069338931`50.56276284218018 THRSub[2,2])/(1+0.37679656098720514348076184627753753457982417463544908669782264008339784188618`50. z)} /. {w->w[z+10^(-10)*I],pi1->pi1full[z]} /. {z->zin};
(* 20 each of [5/2], [4/3], [3/4] and [2/5] Pades for the non-logarithmic CA part *)
Ftri3LoopConstNl1CAPade61[zin_] = {(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 63.4158150330062963972449388521640879905067513389052895450848`48.55091193641438 w-7.0761084621708361484912417950639140298904127741664139895513`48.55091193641438 w^2+9.3933626972624188851723460313889124069972655485927923267541`48.55091193641438 w^3+1.12710591333514832984689533036582131997307711620995732412188667969130819490123`48.55091193641438 w^4-1.80351637587483611869554058166394131846746805995666978008515246169663605509311`48.55091193641438 w^5)/((1+1.53714702246935061911029938527097494477496414109005835758009216054261187190105`49.52287874528033 w+0.52339931477076271809941810259038952770343732692270877112453415661756965550298`48.55091193641438 w^2) (1+7.16280384319923554821287998915641482769419341545144989556613976583825212780886`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 5.3634660332968123296334717369806097533857105260802112569243`48.078732113833716 w+0.23952399920087291188418995226821952882597960729218717523680614861698882848823`48.078732113833716 w^2+0.62400463723176959374631653727799689148367720770334154391984339181885451759539`48.078732113833716 w^3+0.02497578227520263454869606926071926692358101676484855924731791895403620199625`48.078732113833716 w^4-0.13250206516726672531507728867655182661160614768674738230701161121341216352856`48.078732113833716 w^5)/((1+1.06666430232528732091559354952707169678268741566276841371255484452034134000206`49.52287874528033 w+0.02794265260511374925456363755803259884410811629049894906407733522094203676031`48.078732113833716 w^2) (1+0.2464450173541703463232881798002919538946361052410161260413156534424992360761`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 19.3210946097621137560401559893227682365598638159237462807876`48.227011538698456 w-0.8963975744531120722223505129928500739057525668624610649980491898199465751727`48.227011538698456 w^2+2.0290162482939870759507679119708645644537651337983816693116`48.227011538698456 w^3+0.4827367467192961130452907521400261712064048584639446327582172146943099455452`48.227011538698456 w^4-0.54234231181423852286567373548087012126472349887941750152264652822152693850558`48.227011538698456 w^5)/((1+1.40322230036531592117458679658830676026143616801505240255691626002788903712673`49.52287874528033 w+0.38234069737463776582452278293593294487987103457101597586061263733060608404382`48.227011538698456 w^2) (1+1.85349760652344085195303737241770359695591511068565743531343160027419670439366`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 60.9009448152209793507653100996257352629241184562060986747826`48.5465177460735 w-6.7094833826008153883138784428767138614542667118809588664723`48.5465177460735 w^2+8.95742152907542916831187651420487731249986574598641908227`48.5465177460735 w^3+1.09471101373744583931841921452488634988432339959848805565319459655394121136891`48.5465177460735 w^4-1.7317694462126404749362102334080017010172561701588213382920566380141643830696`48.5465177460735 w^5)/((1+1.53455368012216177620295368839777261727256352218858238790008986890068988534154`49.52287874528033 w+0.52066776295279631549110461063815152520367867741135013890418647122593308331753`48.5465177460735 w^2) (1+6.85873504198350412722451897691347010684599297640339601202275023515220358523728`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 68.7456648475540142509171324492031215449482156761839121934298`48.5590608496094 w-7.854830256914330070781216112181972929809843396738573983979`48.5590608496094 w^2+10.3191991588346724216751233303953914071769274889836272494042`48.5590608496094 w^3+1.19523355929103093519771981802075484423835219067928855320146463139992877364499`48.5590608496094 w^4-1.95555001996132824528198832657193404592613886424441761947983258616485362192856`48.5590608496094 w^5)/((1+1.5420317535158256621072669108717743487773854243043733497460799530606091047284`49.52287874528033 w+0.52854437846686569345270731300788354425159875966188013352231633816723570585359`48.5590608496094 w^2) (1+7.80738003144736425173918836761132587863674353871275075077918899411150908663234`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 84.015296687428712797309368857557222127373708624449203800886`48.57624614367442 w-10.0952750588724850837759060405647726101749146240821755331257`48.57624614367442 w^2+12.9822743502705480634748393855937181752541057292318915814732`48.57624614367442 w^3+1.38751131772840385786042569515413479769904962824296878915314837149260977267204`48.57624614367442 w^4-2.39099406082922310444951008455219551822650050480449933697965344591128373207586`48.57624614367442 w^5)/((1+1.55266429422106094417032196837818747554260998799347756437709132148542308794007`49.52287874528033 w+0.53974360898666450162519890083604097163416607690204977285782012468120186045704`48.57624614367442 w^2) (1+9.65488436643338005848832690185456237214703132642184801724630016485529389699625`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 20.1377583338111443325563966762748895486488253491242669740587`48.25240072026337 w-0.9974321056004186691466843825067345242162829591398004054007628026498385274032`48.25240072026337 w^2+2.1503171400748580905411262706803356790376550072760862129662`48.25240072026337 w^3+0.49879976530563921439994709963245607788178611898941521155109612624599041726612`48.25240072026337 w^4-0.56587276580857655916483503040709970983050439417094278288892317820527156559145`48.25240072026337 w^5)/((1+1.4104854557072426337232492270026882958274949057228790582643227633274926138943`49.52287874528033 w+0.38999053037528347342204245726505375047097671904731018761785888564293031753323`48.25240072026337 w^2) (1+1.95063381527527731548856062377545869202158251764158867818827432550442314790492`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 6.7151666051295392444193503278481001283007618790496264900736`48.19258655958059 w+0.23704159044353345087742195953847002384563148415775444372017195491944632736337`48.19258655958059 w^2+0.6379684709800805613194578523870208214478780074180393673993897709460448072721`48.19258655958059 w^3+0.10285303534786653195303149457761090365024676906017652352552503774560487664222`48.19258655958059 w^4-0.17360102389445834519505020093639450581769611496676199351018745083649550567536`48.19258655958059 w^5)/((1+1.13818264975058421696696883879284267092877630209536754177802834077446659869277`49.52287874528033 w+0.10322755891384481517588247078083827075143436217698243344689074056671261329859`48.19258655958059 w^2) (1+0.39234578192525726695913343296562324206306656026683663640614292482097717633692`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 47.4782782255799917908397000466956044988363696941206991524382`48.51405084582157 w-4.7652776376514055636946579175881490593924729422266609041249`48.51405084582157 w^2+6.6447978687927620825065800151877446442951521956224182687717`48.51405084582157 w^3+0.91794547852800004689337303909603847898111705733517795826203353805163064027946`48.51405084582157 w^4-1.34867169807018540409085506504638287029898236061872953975924707839896329134998`48.51405084582157 w^5)/((1+1.51623771522465121294152089222162536094885812433797781891824076754549285925678`49.52287874528033 w+0.50137573287623855135550532409672770591455477602489914068948769961110002045665`48.51405084582157 w^2) (1+5.23694122775461930190256652009292582293115688569798914305720964888886501246507`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 71.2372665446616417895046005030361220794058302261523087435205`48.56241384197975 w-8.219556396035934416961852555247989316519092862380704561454`48.56241384197975 w^2+10.752782853150357108477140145165253601641343649542431089199`48.56241384197975 w^3+1.22687061678362115774527828389817441149571121659173712970834582265720250682549`48.56241384197975 w^4-2.02661397971406561467975745168404309721226610446728752373423565271256523107551`48.56241384197975 w^5)/((1+1.54407057026243822003652512809358128479746975200863774528211527488919230416988`49.52287874528033 w+0.53069185662836131154643618108029984655394449395014653568241892290190856811498`48.56241384197975 w^2) (1+8.10876810704497581068175271422321624050744067047082238356860630802077710764952`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 38.5540780358812892412345107301527504771190335710342186622036`48.4776127315376 w-3.49156861872678423944592009330697597670978830328676568933393032042514513109075`48.4776127315376 w^2+5.128468652147564987556141988062192106465264116307139319829`48.4776127315376 w^3+0.794613416002649370222919072718733921685112659451076858128278318274307030616`48.4776127315376 w^4-1.093722452613472861544144808452445605750412219770886687479211115841608289615`48.4776127315376 w^5)/((1+1.49733403232771077819828774410368212411032527350014449137666712946333214312571`49.52287874528033 w+0.48146479057937238330387570653811040557262557038255200366363649617130598230848`48.4776127315376 w^2) (1+4.16035618824475832975435348339650801133400271859724506829428185055683843706447`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 5.3928943780113949831934814249080896144910950990975094292706`48.10570563260722 w+0.24003351925851938936316936514286272852531992176586355044886894772369267050806`48.10570563260722 w^2+0.62366409533170000500840126054380451873645852268956442437452459296162391760287`48.10570563260722 w^3+0.02684890880281024905254570868466279987738440556656801464582238963885237388599`48.10570563260722 w^4-0.13340432722992878972849292696060851553745342631104436808474737103017454877069`48.10570563260722 w^5)/((1+1.06842793897648885462817181727924055880850857078734952108416462583844329705556`49.52287874528033 w+0.02979875990629448683435617823798321384083429123365864483363808016213323443433`48.10570563260722 w^2) (1+0.24956982736003640418188720181268389511140265129056030501632668039189832455902`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 75.3941528392421484329750654317961198872360740723937747447651`48.56747226109931 w-8.8288759771807492224862643710409328940673950746719345392063`48.56747226109931 w^2+11.4770825167979353743828107664056422990760869208050033243497`48.56747226109931 w^3+1.27939939078715217522081381014406292379717394772278626136932396808381358361066`48.56747226109931 w^4-2.14516360322782325506308425464512819836014984582660921822267448079766241611341`48.56747226109931 w^5)/((1+1.54717882873615879541995353949191591915326933541092337956736707638099262527784`49.52287874528033 w+0.53396577639048386466531512800244285567178548076913310193732498017848349340961`48.56747226109931 w^2) (1+8.61166494207363066659153850561008699526854492947292652342277098281691870847035`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 4.1341353117985281673276943634625425548214392322377153143275`48.33574383346012 w+0.19052531835645526586832933121458492541374238631574910692010647135098499903744`48.33574383346012 w^2+0.67007490982812214568254429882646788341067356569067400602131693118055605663854`48.33574383346012 w^3-0.06206533537962210086523476947780174325003768155970104918994293133084493350371`48.33574383346012 w^4-0.09444010954826570013015564822159202142816272189241213192687671673794774348436`48.33574383346012 w^5)/((1+0.98272204326602921069606194805587486334479457070255130338183992685460573275849`49.52287874528033 w-0.06034349610431591064122177868786870934857139076344684046616870140260016600125`48.33574383346012 w^2) (1+0.11847731407788963823487239915398445638857326619922778158017042083842510408519`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 48.7037928423338221371741699496829626168706060387056530294897`48.51786254474827 w-4.9416525412349489228017303732966904082985646190060478091201`48.51786254474827 w^2+6.8546706657387746587499547108319714282721761361010775181757`48.51786254474827 w^3+0.93443280468815928852116621564171915615822433334528591646606944836781541173914`48.51786254474827 w^4-1.38366379511981667341156291432570977303752099806803066274104248053198965019778`48.51786254474827 w^5)/((1+1.51831337480684708388213981328940184885112159646217787719749488873357019367992`49.52287874528033 w+0.50356199934036422388294541558662271253432436505694271505249968429145274209844`48.51786254474827 w^2) (1+5.38491319818822883093747148494689492595530844705071662839035172953490942349908`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 17.2957739719568879793397369542946081145365414194543665495182`48.146009019221395 w-0.65302617462032811980402354385043138532135492918032722378827510153580372676692`48.146009019221395 w^2+1.7362931189675616807028290152391757924557508875616719169935`48.146009019221395 w^3+0.44068253534511378678369352920808936882363996590780606635675759839630486173566`48.146009019221395 w^4-0.48389412794982775180497552406650526369303836059452193566773981702288354506036`48.146009019221395 w^5)/((1+1.38263995251224912757533310338701465546761395869455221381412110750979357989625`49.52287874528033 w+0.36066274892283599026992372351982865311362492381137995850936745977289502717984`48.146009019221395 w^2) (1+1.61324289350519860954168664729301291177311703181645286566343644479322301390337`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 5.3056166165829270731216747402107617183757051398442546779468`48.01929646939769 w+0.23844052612767766359749156699251394536115071587291991921310660396774366607845`48.01929646939769 w^2+0.6247678993526763052560882170007769039448740686081666031808907616017303831739`48.01929646939769 w^3+0.02126775922608766991464099170949883197670999091965251176553476697685569628559`48.01929646939769 w^4-0.13072733242580370651732934742214430720589153345048248813882600295530956852789`48.01929646939769 w^5)/((1+1.06316725641123073543266871332949795067500134427412967142610549304974448429196`49.52287874528033 w+0.02426233555808495268109983079362700242429976413279707844892569603614440293298`48.01929646939769 w^2) (1+0.24030988785016491012829865546343036397715027218129655647975256391007630973767`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 3.9804102430255612375687933226004038898442771786284552333336`48.32855328372259 w+0.18012341929027561819608043022745098535511699808200951625275799794829911457119`48.32855328372259 w^2+0.68076476762319179315775746451819487104359431007094136780232963497451672549411`48.32855328372259 w^3-0.07431273537735519728968032579253303385014825870614433081715969310351651587383`48.32855328372259 w^4-0.08962293431224795626706865198301281030822147258992838456029275771561461358727`48.32855328372259 w^5)/((1+0.97062287820523434067347870257126951748994776122296777588684227977793669853149`49.52287874528033 w-0.07305029941663876586546001932381344187593370583186693837683897831493775443888`48.32855328372259 w^2) (1+0.10287583092145176782516632647982943673303790520259865781596827349103435875808`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 55.5524369091263081080345394479350235207942110578302767701672`48.535689634076675 w-5.9318903573229099146472027302844885108545811368307139312851`48.535689634076675 w^2+8.0326711147226598599375405954563003121160040960362027774375`48.535689634076675 w^3+1.02516208734422279822051744229597758623254315069281099854079807972630291479992`48.535689634076675 w^4-1.57915416118324146747073273590838353935618887667313044143756866178254985316706`48.535689634076675 w^5)/((1+1.52828207263910125450446715665813205515992653038807000427541939514903191392325`49.52287874528033 w+0.51406192600469992327594350190337655858658799732680461797849889574548596869794`48.535689634076675 w^2) (1+6.21224484376427768555813371613816301801768335807513498105117988160046948217348`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 4.2462599027276159336726699591755840021064386687762198265327`48.33887837708982 w+0.19745839523450774879775710300049565230938423041138899147929564493154554727515`48.33887837708982 w^2+0.66303410208093560338308273210387531019607011495395986247965558871054317176004`48.33887837708982 w^3-0.0533416743786444507189402853431387589523375065889846192598453209467957292018`48.33887837708982 w^4-0.09794481852285216729205572581966719616318535328488606181757499812777168849871`48.33887837708982 w^5)/((1+0.99129871554614935312023866044708321024951802034515515314584076716706188879045`49.52287874528033 w-0.05133147723586476674525940256998763780099983691450865661936188946559325610744`48.33887837708982 w^2) (1+0.12991885077760888478397232631647974277232864221713779596731373909210930031234`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 3.71518418049421042104176488848327345367697238631341844508204473916622491945608`48.96603129339176 w+0.97941444268111550573059871577495840245070092210702264461240099019090696094104`48.96603129339176 w^2+0.23722831236722421540019153891765502962438281880536204881760731082447163361499`48.96603129339176 w^3-0.24023935241073990266446775490888722387502978473865925375246164598785244549915`48.96603129339176 w^4)/((1+0.75800090168116762672181486384052121670956684695558832511935347911432889473804`49.52287874528033 w-0.19820168974825206312484422301033716522662375080979983068177376515995731787287`48.96603129339176 w^2+0.11224994308355686409390586204237651796736223802274579595485957282996250929571`48.96603129339176 w^3) (1+0.12389490472810927426745847877582248603596918677766330503290036710644491688587`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 9.8479679963481184172891892102824536961525954576126203141647`48.858230358392056 w+7.20370033034256741559769514988766392615900037146511609071886164249357886396455`48.858230358392056 w^2-5.35427786561020215794155345260577605190437441015449302675101738456074947323957`48.858230358392056 w^3+0.87055955465321476490035002980857811564276314095050386347398387566291903268899`48.858230358392056 w^4)/((1+0.54741303880319498933793014929797839397039643943010553089981638226444808814373`49.52287874528033 w-0.11302928479390754311136264608658030885272375760856294914709660171932924412244`48.858230358392056 w^2+0.43737157713777293800458076359182948699901012427313045655662184327058861094974`48.858230358392056 w^3) (1+0.91962766142793710776361577377980288316375195165111580758259870689125573765162`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 7.0581393373449163517305076438031396672863405096561198560615`48.76017258494109 w+3.57265975925571458344857093471032977509797519325361758343935118778973467254973`48.76017258494109 w^2-1.97351956727011109866965850827350179238567472937974419622154608145453817682942`48.76017258494109 w^3+0.16730987927200189747133039940161450342951287186171658300240363915120216086977`48.76017258494109 w^4)/((1+0.69370251601331113953701120516108691998851024448432089345435556555317957168728`49.52287874528033 w-0.10903627840623233688802046992280837972672856231375332761059251508861490801944`48.76017258494109 w^2+0.27721754566697592825528227585800885050884955878715624500608896653023365459649`48.76017258494109 w^3) (1+0.54502250016299452397285307662175440596076710074640215580575248055871626744363`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 6.2481586968126706377366396200516674127670464438721341156991`48.37624913378603 w+2.7995499487149380674394844123094347173895252404306819099826`48.37624913378603 w^2-1.28622858685323992498864252015522918422900179459955375336556573573860746827566`48.37624913378603 w^3+0.03270299412781788476770280650566798544767332569572910155762251405101271168956`48.37624913378603 w^4)/((1+0.72193553333529648167046758658404993867492175334454240521114696210218311889489`49.52287874528033 w-0.11894986174627747006256116137940023145611344551788011735292011961184362365038`48.37624913378603 w^2+0.23502615745853375906390045928080467759071270874522653801211741864861842570358`48.37624913378603 w^3) (1+0.43982201173112256450635767534081358587340451847567602444052428158875377936966`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 3.97673851587878786171416444866757804723399331746332862083669568999007728009547`48.89543682672063 w+1.13327805233692336664901758408170089589796254148399652544063464606983413863634`48.89543682672063 w^2+0.11549934137350065195785345964835204381226492346880872783676500794611440917579`48.89543682672063 w^3-0.22045845590255893080522761402431290940954701018690546699954005228248029031621`48.89543682672063 w^4)/((1+0.7585117344581137805604570674631603536094185502910309295559010960805513063225`49.52287874528033 w-0.18562847760759857379111809904553244720290297328383298075255045944761232337256`48.89543682672063 w^2+0.12440841450525748130240393064951539794109122529431045893667292621792416154192`48.89543682672063 w^3) (1+0.15545872782365175005279437067764481313152660896121477178378036175304646190527`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 6.8329880373211201969752658904486943623856344972600695903816`48.76402551971801 w+3.34677899442096361865383440580757070237021940687924212099857841003684983208065`48.76402551971801 w^2-1.77096461865147950832602320072777004132352653132383246184297929620767679134441`48.76402551971801 w^3+0.12717069197214645817692535746076543200625190352616859277004241924778560813742`48.76402551971801 w^4)/((1+0.70224972114165121542286851060585388413600509779181416789004523542399515404993`49.52287874528033 w-0.11120558948400314781985588426562988288996404470829557127368628176269095388338`48.76402551971801 w^2+0.26532089516356382255122821826253610745144232944941905422373662138684284666015`48.76402551971801 w^3) (1+0.51560498315831591648114762478546911725289303437983382526188135799927300424025`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 3.55630791601837404971084555368314951398991674481772575060372014875771938225717`48.98041603797339 w+0.88885950771111625764404284264095195478288011260731985437402375903030970079064`48.98041603797339 w^2+0.30816397677206001591848993308178841233446632625713584316737643014848986130867`48.98041603797339 w^3-0.25154780220762659330104818968842894058444566244595071187800379497095366257777`48.98041603797339 w^4)/((1+0.75720119717350765861965793391128373949216672793428331437948544123401166249782`49.52287874528033 w-0.20649751746462547304891054116876657169261610021807790411963987408076368741922`48.98041603797339 w^2+0.10490796849354557881836471200247274489631267681117200320525322554759589713466`48.98041603797339 w^3) (1+0.10484440589289968420221873223408061242006426013234709830746118990932706477076`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 5.14434868670508977274712764380685956303668780953026709624067525339320883557013`48.844845060943626 w+1.90760567002252700505946153482939195753582406673385144596476597134163429044368`48.844845060943626 w^2-0.51902237643534568351571991408845296101714987390688854332958361973692568922444`48.844845060943626 w^3-0.11065881891727099900761432691295556732017186570853466973146556587635451011199`48.844845060943626 w^4)/((1+0.74832142079656125245587430581305483183675637352975619855059573594159097174215`49.52287874528033 w-0.14307018296791404216931269347534998721416224139037527247586064128946543003627`48.844845060943626 w^2+0.18001213656814573494179789981318177520349461242755821190925867743955868289493`48.844845060943626 w^3) (1+0.29948113290783870047160817696221594253809076323603618759281892240393661255118`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 6.2175087059435249314966769212359807925733738057773430083236`48.31273963034815 w+2.7723786261913476510812270768696006736829550857998549644843`48.31273963034815 w^2-1.26240529353734127653549450645033238716888377725475382307949837157676627810952`48.31273963034815 w^3+0.02812610544555747618323930364836090698710183110112884579510767700503894818399`48.31273963034815 w^4)/((1+0.72286361622300536006352363561681640186106865934254709995895870091688569142518`49.52287874528033 w-0.11944452793606553674657561681730498676648800577066102564141355557281764772101`48.31273963034815 w^2+0.23346163055241162470710712730882616070573906062760409767293954152241458917883`48.31273963034815 w^3) (1+0.43587624968186176774327783751923057032939969300128281675959118598718689174592`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 6.8488715916195526813523496299298585634104094544165657488394`48.76369582373997 w+3.3624286810352249696219885229342455919935750495442822191167321624030985106856`48.76369582373997 w^2-1.78495503292828980866047634444214028364946440208182359135338385489674888099689`48.76369582373997 w^3+0.12993161397379159657357657701536562338621101866167039037373969152761308859645`48.76369582373997 w^4)/((1+0.70166399635787731786951382069855462687373872080753004683035033230168445049242`49.52287874528033 w-0.11103831857234342117485429530771325530205340098306731219760760522593706966439`48.76369582373997 w^2+0.26615577540562675831421708033686608539642535586408775134604048552308425504082`48.76369582373997 w^3) (1+0.51767596344384545670176776402192293903099320426474412458421056031106774896149`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 4.60151063857648507575105989051327470953792385275621196257386601883780322486052`48.887025501974925 w+1.528373849164638259180205473681044568554075030230765486483484422433019287479`48.887025501974925 w^2-0.20393865108914602781963186359408693211898811506484189898467487989139756555544`48.887025501974925 w^3-0.16644988026911876950025147133387927268319496296921970767123378814380250326506`48.887025501974925 w^4)/((1+0.75552190644224140455801949810598291800514759514566340182572815927034371407366`49.52287874528033 w-0.16034908014231139884975034958606146519935022548248555927753295891482312654126`48.887025501974925 w^2+0.15386797782752523764126141052582080013886231916949787478811235507650587965126`48.887025501974925 w^3) (1+0.23190741626139722300529712303589848511822547328680876996130245759787326077527`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 3.7861596386617695478440996984572745103438483844582417347195099290586285782296`48.959519355838005 w+1.02055599395552168390751730211410418465754246238319757756377262148741024951681`48.959519355838005 w^2+0.20482882014550237550689577089287455104666096152962548799195091563051822769387`48.959519355838005 w^3-0.2350205715031921593579843698282109553568634800698051615617902503106621839316`48.959519355838005 w^4)/((1+0.75824137973856193007829668775625158513748817600699873232278644794468677494997`49.52287874528033 w-0.19466142731980458139220765008507556927153010409006583140062797655831544577504`48.959519355838005 w^2+0.11554010399358085778148252311053298214609571286975926657366249290891552348291`48.959519355838005 w^3) (1+0.13243460807663278081203109456565664689740610969503090168659022923299374974507`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 3.95446337236521795915527710262506607032648675408875066462335313159768113112999`48.928489654424 w+1.11992792782698360881676595339853062512604611666856626334444419792544359219178`48.928489654424 w^2+0.12612185979637924624368212364093247982776012447215860094341525257703524850292`48.928489654424 w^3-0.22220325624696548330724868809340524608652575925568897368452000057742677618363`48.928489654424 w^4)/((1+0.7585087418089127190717033362453077576926537532717799928120023688559323753675`49.52287874528033 w-0.1866498707436997656470830047056658104770454477181374506188080260054508553188`48.928489654424 w^2+0.12336924021468305801245667781993001034743768566225553851947751900033854870704`48.928489654424 w^3) (1+0.1527604826520940747090963072202838669581342228281011100864424452267178341951`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 4.2113666252557971242716983572547323893603902974268656871608`46.61889698033 w+1.2768569873100804640904191735860101970868372618890795848891`46.61889698033 w^2+0.0005338166485210976556512540469099498677434161661050510695850215074542709825`46.61889698033 w^3-0.2013549503746361002733949261577058963888349298366496540766`46.61889698033 w^4)/((1+0.75808086866569105298483820181483858322660094843586054932361835111957842963582`49.52287874528033 w-0.1753939830568231643077544306015879939525661173301128359661`46.61889698033 w^2+0.1353989340035157444015104352848343653885978544426921381562`46.61889698033 w^3) (1+0.18399542847823229688833350595654546904484600822037495532352249974051630561543`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 3.75094867118987270514059414337973877760961364171371824645093999159596023498593`48.96275317941672 w+1.00009067194772194339124313004566400541348643611451915778610823346084984789414`48.96275317941672 w^2+0.22095909519663248626055373626914128069313754348391589070189695951140811497516`48.96275317941672 w^3-0.23762298793341307805174713813922813819626334509217319549057215060921968793663`48.96275317941672 w^4)/((1+0.75813138724331713713992403076082296036964173846314465949255179413871919906254`49.52287874528033 w-0.19640539016558303868617029942907315931833857154043516158809152684464656754805`48.96275317941672 w^2+0.11390703096506039218035509132409156208120356528421988665586062645119532113574`48.96275317941672 w^3) (1+0.12819572890741131948981809305164071252941682437351240341367487729975145284048`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 4.67980005836001637450595581569156779018455642942746667834112805113805121329645`48.88056585533233 w+1.58088944720336368055878946480594513321203756271898384759758194740133963891116`48.88056585533233 w^2-0.24710343912737232976949568474954635649937157986558900562484477607381286889422`48.88056585533233 w^3-0.15894170995181097373986720180915554708828042664844976393416963627884594513773`48.88056585533233 w^4)/((1+0.75473866823744454286453378957656998555928751061583996808352464447686103123181`49.52287874528033 w-0.15760616584226738784136507271158810488642598129993784392286602330323024730189`48.88056585533233 w^2+0.1576052610396640569766372685453158407999262928471002107692747689357238506537`48.88056585533233 w^3) (1+0.24158925323049533958097289991135146965437702427969009052720199893071988369851`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 3.53411567362559769925198898276404706720000145164610636054794717936219569358456`48.98238695917618 w+0.87637125746787074690446503011159895868299336880666547156633759556769634720524`48.98238695917618 w^2+0.31790690561506353069803844654410998889261209807520793922399689343677911676169`48.98238695917618 w^3-0.25308852677613613795547042135913894609559981886423567526312135682764530479627`48.98238695917618 w^4)/((1+0.75706241625381294798373771926512698719988326003563734598583280675911332840571`49.52287874528033 w-0.20769916295384695026814117997630749296659908550075535245772995017490148166879`48.98238695917618 w^2+0.10388480600441480740500342476198755920351044133266166728792056911625283886889`48.98238695917618 w^3) (1+0.10219015259843005341350104338499506801136522815772902068022192797369204937735`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 8.129269804280235158325347538590447993088162381866441390367`48.766502649351246 w+4.773930703516170013996070202722465457023524062536846798676`48.766502649351246 w^2-3.06985498942887677346282690216050814301269147336348839709477482642279615228882`48.766502649351246 w^3+0.38965300541647100128164494430684875805404660837129181459715673124004647606464`48.766502649351246 w^4)/((1+0.64612197591987742750784687618442738309897785032446709420429426419439245524538`49.52287874528033 w-0.10423937709961474197920559835381743033914705282330734831287856910840351507568`48.766502649351246 w^2+0.33575827259008422269459259676302788097733091355513998326614820249075967825555`48.766502649351246 w^3) (1+0.686702387782420510174836617457661261713096165621570000564397742895240632738`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 7.4307140112227079834941068031951705356171414516547347422499`48.7577275857559 w+3.96609727351894656401129079379017737084605534004446311105077415562213449377078`48.7577275857559 w^2-2.32930022136993888733526324151373434751245102842519015969741742183971795274138`48.7577275857559 w^3+0.23860334294715901777437306091338680477671766081994525284798752820601112173229`48.7577275857559 w^4)/((1+0.67842600344449662976963522272928775642377894227948487682094427850747265097077`49.52287874528033 w-0.10636737185287069880226322735155667591175121732219230195782613883204758337281`48.7577275857559 w^2+0.29720562098594592414423375033249938906076611912602760976802165041403814733036`48.7577275857559 w^3) (1+0.59398506635074267497163077244535236236165028643387487009545933362109925306314`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 3.88247951184597811436945268803349854603957005410947996334268310940255949590595`48.950662328060744 w+1.07710665234916968409478999394248731991749746226232507756475565106966131324158`48.950662328060744 w^2+0.16011648489848068012518669673878445087581902245843269938126716764675924047076`48.950662328060744 w^3-0.2277633020789808622127729021155007471141524210372954369226633990136294748987`48.950662328060744 w^4)/((1+0.75844711506052917499009354327409674151061533928307301114441578669547944771518`49.52287874528033 w-0.19001201071456546724234572445790462740968176085605552860528974566464970917738`48.950662328060744 w^2+0.12001589742635009846383434188511854050019976942349648698411250251157895173821`48.950662328060744 w^3) (1+0.14405388224781336161653949015798543551919699637854734633526038335923929031941`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 82.6011124573248362782031589893562767690435945850932055555507`48.954028958775865 w+24.4912408241058528363299695175443752376059458613066826705794`48.954028958775865 w^2-13.274051422397664570410500552773901217931961879618563551903`48.954028958775865 w^3)/((1+1.12990571240922902119769653547532921852306432231065366652404202898661084766204`49.52287874528033 w+0.2500401220746688389444201180693486337842431918421519715938263768396236329922`48.954028958775865 w^2+0.2474809531697413674376934005371889644792824888751363985571902615571891111814`48.954028958775865 w^3+0.08492028870563678963338614103752603701482305481111167150751999275198361944737`48.954028958775865 w^4) (1+9.5892227562783924827258292865886785747226788978249945926445697721737933148674`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 46.6342767134068035519261821258235551312991776394060480196567`48.940257485621196 w+13.8350998243225544998275324380493001347174756786564051967763`48.940257485621196 w^2-7.87116747914966135948969379451823660941708777807565866106298534709357376424575`48.940257485621196 w^3)/((1+1.10923937516043277682900402672598652569248113974836361388244145556636350985079`49.52287874528033 w+0.2340725379052759616032417466664116104612219388894024173836060595106036642433`48.940257485621196 w^2+0.25272963067441483785670929066009828987875607666450711903205333875376372472279`48.940257485621196 w^3+0.08356109376450017357735537879417731041047131615970209437963908217575895156483`48.940257485621196 w^4) (1+5.2364264007037555293384621868079932509087967944663765993420969063868372329727`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 66.3290659834280990673243809478301765485114640404711196640116`48.949839869486965 w+19.6679978790840630616686838465773455078174111569264448674597`48.949839869486965 w^2-10.8315429658839605994991466181334312405176221989161740031281`48.949839869486965 w^3)/((1+1.12336430224362186538516703600595308656589667386049444458766624816030577952548`49.52287874528033 w+0.24496822436227018160852415301458687247261175258659466104050596364888249108043`48.949839869486965 w^2+0.24916511504725057140378843737160992097573447179380722343735693221807549500508`48.949839869486965 w^3+0.0845358602031159348552239103727656413902168694839465136016305208954397172946`48.949839869486965 w^4) (1+7.61923691883647515042360433662649887467847268402724906829037627936189160460363`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 3.6778767030554406607675922464519417040349904360776115884815567666819783161306`49.49699331710453 w+2.71969722064752331669000943412052039623697228829792600103922460902271448708853`49.49699331710453 w^2-0.16207244754054935261505389873886404101374413062676962476333065716091730903314`49.49699331710453 w^3)/((1+0.4551705793331167403529043567540450501316894586422093958320344930523741049496`49.52287874528033 w-0.44179908855460772080886625857667866516860123780954530673064986563741922396807`49.49699331710453 w^2+0.10684020934374792186743795248198811502483510238621437363873416358595160164576`49.49699331710453 w^3-0.07745355926822365133782128031783276084311244496668303553851796835634735035015`49.49699331710453 w^4) (1+0.19508208198533183446783625019672852566662756202619590407690586869215501676479`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 52.7995022210980793654091490366414721788337824227114847643556`48.944132800683946 w+15.6600279499122672618095201865700709447244735587856075220901`48.944132800683946 w^2-8.7987108133143584045547964711974059160685722292616739854747`48.944132800683946 w^3)/((1+1.11481162710683297126523017379215902411445670692113157388880467947576603184798`49.52287874528033 w+0.23836394070832226702634681758469747881381623186000089323902268859142688124836`48.944132800683946 w^2+0.251338077069054034826441771762164219512301378646771173270949678414271633251`48.944132800683946 w^3+0.0839696918571302650401017474486876821514388661093457267450050390387396367212`48.944132800683946 w^4) (1+5.98204996352936399944824309706003231793273200821505263744212834971737219287348`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 3.7308409543350083140217257248574139915511429857408689415858866419502328566064`49.48438407495516 w+2.70871827629822098428645326857972547734213937892408466585750068762048307310771`49.48438407495516 w^2-0.1879934070614342072247732556839912311987530098475534845575790253092732817616`49.48438407495516 w^3)/((1+0.463938428491236053463782750409973493391895115621748153352308970132802594625`49.52287874528033 w-0.43139959915789885558094589598637427792825394134064828916023382866218634491853`49.48438407495516 w^2+0.11091163556646854693509441608569973256478026514212405398138602147708675067099`49.48438407495516 w^3-0.0750691476023691058758516255655661273965410405100154893143717749376305132641`49.48438407495516 w^4) (1+0.19930759400070358861641477126599885198521399246880524159422324887951836776037`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 61.9653195066693821591279610929459076293648327480734803127369`48.94830209003451 w+18.3749585787213012409838639090268093601151912131429578744902`48.94830209003451 w^2-10.1761634563421896108129913920980946477599309073342800400449`48.94830209003451 w^3)/((1+1.12101895183730188620995012823135870832508043534880184407522987713590718787349`49.52287874528033 w+0.24315452165572839635004612748283805622684599225992263216380297665642521351536`48.94830209003451 w^2+0.24976478716970316081158789475044290462128721993780592828500413164336830097656`48.94830209003451 w^3+0.08438785310297190172646110293510629097081208783590963764850026243031590123891`48.94830209003451 w^4) (1+7.09108490535883878650877327964182813155745054489427459474213357416900246628989`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 83.5085231973354057478242800868686838506854799810167542864029`48.9542108832514 w+24.7602607955392208096644634205659395073693945683250491184062`48.9542108832514 w^2-13.4102144963599843422616582243389703716627259140253209505515`48.9542108832514 w^3)/((1+1.13019482008583737167278031009237723590499771142261434705269543134933587832333`49.52287874528033 w+0.25026479049051709096784489924930171913757819279150973982467637971435469160282`48.9542108832514 w^2+0.2474061978979864407198282915448497150724435686948149301052833984377011612535`48.9542108832514 w^3+0.08493632794791678947645273293937445464077199750192322656134005534701515879836`48.9542108832514 w^4) (1+9.69909794330566352794024407272571704337479371018292362236977816326051983219729`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 64.8216410862733139593372520745235497727934754529083645721911`48.94933451386671 w+19.2212991040651368125551709109388869314547203916115818443994`48.94933451386671 w^2-10.6051699746178647485280260921056437094580574516326440417236`48.94933451386671 w^3)/((1+1.12259023433584429670376976424027426638015140760038483468460604492707939699183`49.52287874528033 w+0.24436937264754499920545912613280217363402039120500717527598686495291479369594`48.94933451386671 w^2+0.24936331204413886271893199429995486375257503302489340063407715955756617469922`48.94933451386671 w^3+0.08448761119874655578585447691478961542301944409826871057970188377136397946582`48.94933451386671 w^4) (1+7.43678156774961876264395231091323546613226429902049346902152877059799399088124`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 36.5559189380165566555443119087870027071717470846332400402269`48.93046309387376 w+10.8560319632953738103245527064982516227938457798758083621708`48.93046309387376 w^2-6.35141700738677736860059960594056902706282407485743911197669500167651260860556`48.93046309387376 w^3)/((1+1.09598196486258301622473357522421860601600707019585697121870105501082448715131`49.52287874528033 w+0.22387760205136518288635010276266080935007938817422460182875147246689740453993`48.93046309387376 w^2+0.25593739151995740183640362128681304501172613411215829641633088320404206096144`48.93046309387376 w^3+0.0824597161414388443600064226562138557786502558696697200186206111485571826416`48.93046309387376 w^4) (1+4.01858496429563941660063976050396152496610132557848727681665479912263804849966`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 75.162204344279119679607166256682660651479145676822085918755`48.95235814051104 w+22.2860053144719920863877535970043372214854078233025388286053`48.95235814051104 w^2-12.1576451091100627665655282064009527435727295338461445305224`48.95235814051104 w^3)/((1+1.12727002047889360568898137915358448884490990426826071832531533119784029269152`49.52287874528033 w+0.2479939765159861635353728742398893585054757758001847139006956509137932698314`48.95235814051104 w^2+0.24816133924438152091318216955227383964208942931875970783083552905510623487898`48.95235814051104 w^3+0.08477037355423369858372764635051687618445985287012081520207162978053616498244`48.95235814051104 w^4) (1+8.68853783848791943196871581044405103490200077500908611547675602505162182508981`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 29.5294218661946353810369794588092767423723509718522343563017`48.91841980167931 w+8.7855854920134541005096595319221299684117554513513740655358`48.91841980167931 w^2-5.28640770566090405557028328553270800181677448161028613288103249694977135855635`48.91841980167931 w^3)/((1+1.08120096830230362944086718466417107117177774710898528497219829305879738501329`49.52287874528033 w+0.21249412532999651191733660638866347211220652039509555817418634559048549193113`48.91841980167931 w^2+0.25929246154994016713220454348115782325386576228572014219973680982082470025659`48.91841980167931 w^3+0.08101291111403186963028079685881984946525939267678170885388788282945840198878`48.91841980167931 w^4) (1+3.17090662988655506632603847898987828560978659144198054506945759691721324847517`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 52.8118186038649144021622617402681956633490016781470179528167`48.94413950813353 w+15.6636748408032656594675376854803358833241178074191060174928`48.94413950813353 w^2-8.8005627788857293378151759387132749747687376084091075939824`48.94413950813353 w^3)/((1+1.11482143591506242851704266542208247900207025934370602327195416312957194344181`49.52287874528033 w+0.23837150133919544728803069222192720566122125001800156374462455771260789893897`48.94413950813353 w^2+0.25133560886370927977035947421084492537431919902411378185044510727432266601582`48.94413950813353 w^3+0.08397038321704496363816280812560106201826208829793979715935390081763748852279`48.94413950813353 w^4) (1+5.98353983998344659802737716157312319362831108116327027466026162338992108132286`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 2.60941281913884605788907190926053608953056517665378224332475389100075430303642`48.930427388552815 w+3.10221290662976801368120369936332161541893647858238305463468871329110970705561`48.930427388552815 w^2+0.38961253528325161083039326298651199364238927428555062773314902341124240009625`48.930427388552815 w^3)/((1+0.23518216627301419973914803583677391251348095460664232974139110469146946925953`49.52287874528033 w-0.69791154695370854198453008202237512296400961945488235137230247094455347730207`48.930427388552815 w^2+0.00847400231919759413130940993470904760514718287980721390395370009943732422948`48.930427388552815 w^3-0.13273491060314556761979026811227562173888816700378041800636098630345839924029`48.930427388552815 w^4) (1+0.12061753224677204201996542868283014646366933112661198225441424634228004209469`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 80.8585755582437550475978748226636049158032142354479992563864`48.95366727752002 w+23.9746431190510440150816564932229775173197048183494299228843`48.95366727752002 w^2-13.0125619743891271267705986616493741756190180315891623553143`48.95366727752002 w^3)/((1+1.12933217882311243437586451765132570791248763336530438304539825507067441792704`49.52287874528033 w+0.24959455990629028975845583461730070551461264304869750318856580491025073834093`48.95366727752002 w^2+0.24762918469963034016879435211779216080300917418995055665280380420450889842762`48.95366727752002 w^3+0.08488823383240534820526165222245739043141266118890923291502769305403048015738`48.95366727752002 w^4) (1+9.37822965600844271707271473654331373970915099837918687557761290748990894635951`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 7.6116407028103316223208779044195146748578884913456422178136`47.953342532409174 w+2.7986308173957215833730118444450234890578589621245370616182`47.953342532409174 w^2-1.5751051744540251300443047294572935085922696628076177213371`47.953342532409174 w^3)/((1+0.82769903437939017225542109638903510517944825852642952222312687445551182383669`49.52287874528033 w-0.0153658808077709693411010983805298657419357500667559274035503203034435425762`47.953342532409174 w^2+0.25376276577496198651981243416991841592651932537575643075388061641875794664933`47.953342532409174 w^3+0.0279103295864569347202283191929300119372478500370893725960721730647755167045`47.953342532409174 w^4) (1+0.57858899889222383633316570726414356922071977307644144409049486977315606045301`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 37.1144575615694794483109999704687472044119298872241689838145`48.931177480787284 w+11.0209188950668775808981270033398579783011002947137096373111`48.931177480787284 w^2-6.43581840588026640220011142664061817768890388920061186957741410036195483745101`48.931177480787284 w^3)/((1+1.09691003566183082031625303853385508549277589944723307764839533755764633038308`49.52287874528033 w+0.22459122124852206635186525733730228534323515511784111500900647648206183150878`48.931177480787284 w^2+0.25571831780081844655271401800382676149381618778402681191267668616234664580119`48.931177480787284 w^3+0.08254281705485865421806496125916182033993363439419031118874948107685990174811`48.931177480787284 w^4) (1+4.08602892007510817374426849997514767831292954775647436551960680698730715870133`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 82.7458153984108638645637831754509485748845365627834975477024`48.95405825720453 w+24.5341406108244501298678669813015941415823416803306969565608`48.95405825720453 w^2-13.2957653047270096079784854189997863978118782682577825756458`48.95405825720453 w^3)/((1+1.1299522442768892019990963592824268079597820536676487315189961743356226801228`49.52287874528033 w+0.2500762793123915608070605857038200996431944012366241684345888560688842182298`48.95405825720453 w^2+0.24746892284488803601164641799248854078979664569132956369991391245350188314174`48.95405825720453 w^3+0.08492287560270576515330220978764517458335747685283302855328389666332785539247`48.95405825720453 w^4) (1+9.60674422127526403889950074126643139471374870255562926028086355088973978751899`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 7.0795367787920958160732187674775340692969611412414918272531`48.42884827477481 w+2.7176091406768181102323131846730682122145334660135002624672`48.42884827477481 w^2-1.43307867346349672822844925525873913683294938476383517710191765831621985582407`48.42884827477481 w^3)/((1+0.79940793645420471485517114767139014407332690148241219357536303179708988156113`49.52287874528033 w-0.04520219923703855293288601288304024836191674439965925256583610102887347180718`48.42884827477481 w^2+0.24628773087390213086074153610555460366936537046401546109810638799806596821723`48.42884827477481 w^3+0.02009788118800940420935338305163243115151540742631185395162886441422358047495`48.42884827477481 w^4) (1+0.52118879060822494953583823444703181856000802642147852509033045648773793635967`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 65.2995451716108488446037134339299710322339746939729625132991`48.94949751542828 w+19.3629145900123613728398324082879942621093084360956123047681`48.94949751542828 w^2-10.676940260138321780130738454336328879365653347499014699652`48.94949751542828 w^3)/((1+1.12283955327746764785064450938291772427875699483067782308084763694219892546996`49.52287874528033 w+0.24456222862792268943595762045482860664389909964323987663839470840368381295704`48.94949751542828 w^2+0.24929950398158126016165402330794346984555856822836537709993216706516521536366`48.94949751542828 w^3+0.08450321604495719696206491253225572191749717273082814873391281118115094226396`48.94949751542828 w^4) (1+7.49462503510879537093307952145280893149557357964783408771344782474188958055299`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 4.4561969439835075934444785765189914997727458248604829551799698408899006882689`49.28958731984256 w+2.34067436179913741196676191840587681259275786806543995704778023055526133751607`49.28958731984256 w^2)/((1+0.63111884458103530645903249268370990284197218804744550134359383404042328993073`49.52287874528033 w-0.32623052015487703074547766363225379314523636488672327844611634172572984832006`49.28958731984256 w^2+0.07178535664067627193235540208404822529244971278642538045387780231911007001406`49.28958731984256 w^3-0.05239043963026528157678133510955578975341754238848875795974556654517192255405`49.28958731984256 w^4-0.01104177232130003641107822929030158297357184321192401763020449302700587738348`49.28958731984256 w^5) (1+0.24540108111314767124353710059326360667934392775899551202021351451779453006764`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 70.3432337654629226169629035823368730180866453753029620025204`48.64868095563459 w+32.033723822319783821918556165364850929191971871188416578014`48.64868095563459 w^2)/((1+0.97454620527025791425679463106133834710752496663807645487680205191313473922923`49.52287874528033 w-0.12936339262963958411966728549820080062807308220315672860981377336438842561097`48.64868095563459 w^2-0.05779008891979221236749199431040197407992038618275454470737379216565541018033`48.64868095563459 w^3-0.02350833207327139183843176720211168414079787699521603897177700717768215109224`48.64868095563459 w^4-0.03596351273526258977230502177750093282954236343314835845592911736935399929986`48.64868095563459 w^5) (1+8.14282269032516644462790901656998695589175075571520797964785960947701595494938`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 6.17316669225717837691729848427905079773857147517635495715049310973155471801576`48.97802261041773 w+2.39954826293146019626254014784509488798835255066765135430654073389196057538596`48.97802261041773 w^2)/((1+0.80542875985653648016800655092832390648673435215659970038481225827091666268814`49.52287874528033 w-0.19524568463676970483082228442851479821946506250963424035194271562782360466792`48.97802261041773 w^2+0.05318471005115379319626069562287258253385807281655104136084901914894746394115`48.97802261041773 w^3-0.02343074978559635918910651501736616477551608834378227323226665729690308786846`48.97802261041773 w^4-0.01987778000985459474130421736369120304782552649744881424881561300546453440412`48.97802261041773 w^5) (1+0.40986221278418101908655156514876692579063855826327003869123043672042547456134`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 69.08459524402036445208789982975431317523582509976368411403`48.64789544819331 w+31.4291101725572716682603077169009852663817656362696251302495`48.64789544819331 w^2)/((1+0.97457362185242981822441335789750130509208669243017037700499772994885530601547`49.52287874528033 w-0.12907514759277568185786431232621823672196620662374510240701621124039409105049`48.64789544819331 w^2-0.05742854899851834832527963428946076203594744761281893150040396435767412482416`48.64789544819331 w^3-0.02338691126775095765726838493000531978787599124138360690068301440696101544346`48.64789544819331 w^4-0.03591721147519500083284757013322948617518847115901124059365375527894384807191`48.64789544819331 w^5) (1+7.99031145491533174050274873184386215216876878526427171735759325087674682474826`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 76.0911912095788244874000462580829097243573673910491281628123`48.6520291667199 w+34.7963641110361991337335926471669823235103376228055495541843`48.6520291667199 w^2)/((1+0.97441044615265576244198968032859705088377721009723372520757196291818292223947`49.52287874528033 w-0.13059144251568526633856413808328258338672228685710717520588641118571215804623`48.6520291667199 w^2-0.05930521822025607797847938310826142330911693608877979336272557678801166027938`48.6520291667199 w^3-0.02402011497511412592970782833727147135966558065630290357287803592699748217993`48.6520291667199 w^4-0.03615800498429255708199720632402773077637811414047954833009792134763858156363`48.6520291667199 w^5) (1+8.83931449200418081132005184934282065676638112889473396429205313981551382833767`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 34.5404752854047528257198210277550849766668037899492023106179`48.61351960673449 w+14.9228581711605066500635547001570748891977219678865663439774`48.61351960673449 w^2)/((1+0.97326340419992467259624493255551345141094947022296162091236235391798754451884`49.52287874528033 w-0.11712625125129112119972817193406655682957546896013319726908856162658315472879`48.61351960673449 w^2-0.03923554846480342222724465178353947220485517317394212492542589347614800589131`48.61351960673449 w^3-0.01769301096007046056273440258048269981553871824661948768230233945779764101812`48.61351960673449 w^4-0.03364373539650698245871970392084519380931061604085588593210487765668416468152`48.61351960673449 w^5) (1+3.80506106072872425724305727377453364047278195224895002043310811390039993863052`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 41.6567416669526110013474037985895966785508779969733693834772`48.6246259893839 w+18.3017097829460854021873528209859434676755159457034610065578`48.6246259893839 w^2)/((1+0.974285232117806646509131501616114951728874581163446463248875496446457501528`49.52287874528033 w-0.12037824635980542292876311865120531465937906167366604159612989662533709245771`48.6246259893839 w^2-0.04505197119924825611402845607471689608340241441268846726225808731359743143929`48.6246259893839 w^3-0.01941490402139109306548269632999050426198630803484162153305604793458935184493`48.6246259893839 w^4-0.03435836581473287097081755000378418771615578034381246007659215451057806177922`48.6246259893839 w^5) (1+4.66705618875914973549425081298034165883146514774745705321321636265389191563736`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 2.99735826301956263274944295441197483514072460729213394506485356404718455104404`49.607687282485685 w+3.05992351319999073814667861213333119963230251177164884080987150071228801896188`49.607687282485685 w^2)/((1+0.29528618145209786112335890860131143215375443857686323446844020474920048801005`49.52287874528033 w-0.59120368990997117256907493851388838539167053371344486549672117916406816082151`49.607687282485685 w^2+0.08148035458027097103928616115909935345217039349236502579109293974003192833309`49.607687282485685 w^3-0.1103532355470933247065018283338127509812731043403147381733997734423709318778`49.607687282485685 w^4+0.00461900164843817223930730255490048213866061805295959138555914975958497552795`49.607687282485685 w^5) (1+0.15259738348933226674512688304785840042249965200119950361546657539206825492494`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 17.8971351923577722345168768790854573439027367039284124692032`48.20044343961485 w+7.1504820300478572453323502643959344592729753145770587447035`48.20044343961485 w^2)/((1+0.95989592684701650869293611757904248677264323103579749395243556237556058257168`49.52287874528033 w-0.11006002518724743013213217580355062177862029749420732321119136716375346102542`48.20044343961485 w^2-0.01249244165900488169898339452781737962741995747354358783174487390786554702717`48.20044343961485 w^3-0.01147066522520730927765538867374430667482410880008188691801107962970388162291`48.20044343961485 w^4-0.03047787311718710853905962270385087088247262333709015986248243812472564520092`48.20044343961485 w^5) (1+1.79179352250469670598009764193976726165943403662708129289686489508231103159756`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 38.4091083489917137621767469294787287806108283491156052806921`48.62100657536558 w+16.7574401497095530110513961878021807886264058635473427424937`48.62100657536558 w^2)/((1+0.97393102385385970187197232824223858803490661919845723296227589437402350840547`49.52287874528033 w-0.11895094509530268386936400892805399587824792151578659109007473733336737884362`48.62100657536558 w^2-0.04262077608796866672351876555590563637016758625558270986674074055820360372832`48.62100657536558 w^3-0.01868252984483679137765876024375523360133895466934286311686246578991620751513`48.62100657536558 w^4-0.03405826586134848862899705136058231031586605746734752919683165936793889046376`48.62100657536558 w^5) (1+4.27364152183794533105760119509476882920289035372453911563528605975610755574588`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 3.41155011051188704007358198395604417345847539468569661877758447236313682586669`48.988969102669344 w+2.76289747313834395015851474574108920833566028761589708380559694224139867348442`48.988969102669344 w^2)/((1+0.4131229711422752436356731664506989252368225004056745423737112465505736206231`49.52287874528033 w-0.4974228902352173439914764006081309224000203650903846163160512049449816272935`48.988969102669344 w^2+0.08003679585375358084858089839978916306015741171092393082327665659295590069012`48.988969102669344 w^3-0.09010556661027190281956307024289403974961410391554078949373831562132114039063`48.988969102669344 w^4-0.00069247121892210903943274518562671610038011705947977648663929592270814228442`48.988969102669344 w^5) (1+0.17332421672643636954676014561790825057455835798225347128836207303726223650964`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 50.5302406927595921405197003088623070947134340533219174855399`48.63360251379801 w+22.535358656144053045132862106015469654832539951544128705977`48.63360251379801 w^2)/((1+0.97470815198573554066868920990304103094788887231648978137425029054639780599733`49.52287874528033 w-0.12379310134887688260448537364883142349668070222691034097674714463802542762702`48.63360251379801 w^2-0.05031737971302658835778809171628563087370907475960542886245525492143414276914`48.63360251379801 w^3-0.02105806173402608064006329710226861423545931572456997396928865404162011997786`48.63360251379801 w^4-0.03501523605559477376139437031520160600144283468600208242659643743972811784883`48.63360251379801 w^5) (1+5.74211815430254895050996063434786888430233751066378768018771806210223885899383`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 3.71922799658075724957267769643151331814281280924979882596545330361236595631646`49.482419684500684 w+2.5914058961987946679774085868220146975100017755145886627689461344453764227446`49.482419684500684 w^2)/((1+0.48887988577767212689192940807044290257396695154706505367263559097200346015778`49.52287874528033 w-0.43754229876286366481302691148664747229391637563476515644148613572225865972883`49.482419684500684 w^2+0.07816833281091123037792686134421652317052237842329402077145186012500076937876`49.482419684500684 w^3-0.07700112206654549189440409464823194297375264317839366036484438578952722460377`49.482419684500684 w^4-0.00421748060872472526344220890445407373769080679459156514768247799535385960066`49.482419684500684 w^5) (1+0.19166513232207851644047453961488546613431166180041586644081418873305852015959`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 23.312137497433353140798768996311656794379458671774544783235`48.45161295071335 w+9.6467792395001750116640435816447249293057564013636161657321`48.45161295071335 w^2)/((1+0.9678079372686529431233338169803424546376250015568920775791677558946215562246`49.52287874528033 w-0.11153221070302739717759575829961338534420073952770282262453558731954492595794`48.45161295071335 w^2-0.02451240711635187118071512736183837521093762341231517458296405489314155713448`48.45161295071335 w^3-0.01386995715305975000799124407129137194346693480696590352030492139276870244502`48.45161295071335 w^4-0.03188213406815342621687568638269634705509366172816041784696292042532901173263`48.45161295071335 w^5) (1+2.44593049017191276215645144965702354829162696863428672394913460053920894769013`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 82.8025950418604802431048860577144384070988900858751513903768`48.65549741810105 w+38.0247027154301964219755735540173616834633174527793111083694`48.65549741810105 w^2)/((1+0.97423975049287182943375077356078966115435230440834847390556361082772457145223`49.52287874528033 w-0.1318634033571829955892569177314139078703543727026741571280998589308288034108`48.65549741810105 w^2-0.06083445537116826220940891547594524571554529473689682807479891098953904127256`48.65549741810105 w^3-0.02454132963662354138818249992697898843685305761810231350066909105637136258182`48.65549741810105 w^4-0.03635504315721928166827963400253574733631812841715140152525533549065995742447`48.65549741810105 w^5) (1+9.65255211539821093360399020875489445716510791752323508611173971048330844978334`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 4.53571544999992495657160997140135297361513683042916709701176828357891483349594`49.270901288300216 w+2.32597624445702762474382143032836209915424918884391389820387663610501966963039`49.270901288300216 w^2)/((1+0.64343333556488048216481085388276029894947058309720202768311678137345566128288`49.52287874528033 w-0.31670116097772157446458366136090136929412473811646617163773024613848183868838`49.270901288300216 w^2+0.07098446798595381270462166440300577691452814509438354014697262149493690755432`49.270901288300216 w^3-0.05027310246145346766941379496964184520504359864263044676979366390323211425728`49.270901288300216 w^4-0.01164581931707384450316489454317908834200029857887964455557393195259360431886`49.270901288300216 w^5) (1+0.25195740942938302123679883441535035689823249784398606768644152255050220740311`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 5.78845743028599210837420573889640810971266645748604403946922650038331297666072`49.03223983036704 w+2.33232124618820436528255899761929065181186134405001111020454475688710898942626`49.03223983036704 w^2)/((1+0.77945522612439349269182018917874047449575205827255862880002721221478961976236`49.52287874528033 w-0.21395772126714805028734159606101298063539344956460052898795077347115034723704`49.03223983036704 w^2+0.05735892734699165374918206214859334635014462079199922458295375676438556126516`49.03223983036704 w^3-0.02750207121074881420454233836866507014777527768294624078778587868967383874707`49.03223983036704 w^4-0.01850901204733910812801302945467296184297361258355054750072712314284118158341`49.03223983036704 w^5) (1+0.36974185687582504761472098498019690606444968446276398908077983051137672107893`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 4.23320947768606941799692861290713955221599698983818754823900194654978139305735`49.34425858303236 w+2.39404412547155646062516747006264569048705609292590249376084665168221451629192`49.34425858303236 w^2)/((1+0.5936063078659483133789514697388837903512640274012969073348710007631388920059`49.52287874528033 w-0.35539124186031357252986016298278684091657769886308074617428476181487897643678`49.34425858303236 w^2+0.07393682997664446288390638294205532650760820594546761487903127248683056676714`49.34425858303236 w^3-0.05886218966287395358942248426292007488399477335746192734437453473636350107777`49.34425858303236 w^4-0.00921543867788160186032260720362626810501980322815633411734100114665476883703`49.34425858303236 w^5) (1+0.22776068296668348978569893913498613021821520883131529673195532007438177007714`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 40.2123570296941153462859419962590284282643046850435773488823`48.623034029733766 w+17.6144794109486611271115193128370181380798237093176507530618`48.623034029733766 w^2)/((1+0.97414621112951359652888242968217047334171908895393014891416975232355578121257`49.52287874528033 w-0.11975554199324991268990911314960525741229043914352534853928258693647042533244`48.623034029733766 w^2-0.04401136046659396817704430496073605535879171428142485553607998736668811037045`48.623034029733766 w^3-0.01909928995319942375808355627762468358480233977932117513806074085146450908336`48.623034029733766 w^4-0.03422966903259635075039559508974767111614191893292760437898175492968501007155`48.623034029733766 w^5) (1+4.49208042139779967529560703503800552172847233374328528567457555115434715111767`50. z)),(-2.06328256114380758351358059359278165992506878500761098400356203936028535765677`50.- 66.0912077254578784922601805669434100082705684488317482598242`48.645944957708245 w+29.9917041001891095905568723550207199574403709263788751501742`48.645944957708245 w^2)/((1+0.97463395570161192034793870654687139847295566716958964299402064350037168118716`49.52287874528033 w-0.12835899634961252308913357847661756418800741031698291973797603261111945481863`48.645944957708245 w^2-0.05651996908400447344103236442706181416375111467247493835204144953860644025943`48.645944957708245 w^3-0.02308299194913579760883633895309731798635277566389582147418333369538040821142`48.645944957708245 w^4-0.03580103877310897061088694765504722627765626986333004398279571365395682319435`48.645944957708245 w^5) (1+7.62759913660326089277055402965507014075759544796137124249059407327502056118344`50. z))} /. {w->w[z+10^(-10)*I],pi1->pi1full[z]} /. {z->zin};
(* and 20 each of [5/2], [4/3] and [3/4] for the Ls part *)
Ftri3LoopLsNl1Pade61[z_] = {(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 1.16205558804539110933242375916817984843108013754918596186967984308425732416267`49.51508600783567 w-6.01773555260459126983932804887430897113699184269201932344918898811985709139892`49.51508600783567 w^2+5.01182817889587594641852629396019891715203306919046833420820261330469269353307`49.51508600783567 w^3-1.0404828902225978738956609783249996383497265508987597402233250991199937382048`49.51508600783567 w^4+0.0837319394392686873266622416650526849334142518449052554398240025521098440389`49.51508600783567 w^5)/((1+0.36329811188456645184626805973532251502207957109060948851860975205433547168449`49.52287874528033 w-0.61915701503587425537790728247682164204998354855630578879715766825627520609306`49.51508600783567 w^2) (1+0.91491507363772421937125468293160386932029601793209601935674967235031819757492`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 14.9898405696287700742921793548294000872133066862770220781170520075522511383982`49.55014625199273 w-46.3892362392175981546140621404105185083692513516698656730496`49.55014625199273 w^2+38.0619124351723624078380535793110949059009641822027946774335`49.55014625199273 w^3-11.72576075722076476777073742911788600837657090202295751606561523070961253499806`49.55014625199273 w^4+2.37095361404049882703439819103723404383070637715979454538714552370610991016065`49.55014625199273 w^5)/((1+0.46803786766248885958728097609271563734229567126926228349577936124314293114812`49.52287874528033 w-0.51881249135134206720725409112145726626605053485387569276479718539934350329386`49.55014625199273 w^2) (1+8.66685918683389428522586397640169197305524442654694268398357634300413866846609`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.- 0.18756042513212242608545020202665521904021553751600755295775599078876625305206`49.652024037394284 w-2.06130311042910494641108718335839375798858338192107602609219824774072063404316`49.652024037394284 w^2+1.71399786833727505632397754278639435231015830446874449333375404460524780893068`49.652024037394284 w^3+0.09990007625474019476691590485065156284981611945505879223893624569319642562253`49.652024037394284 w^4-0.17594308430768254779256238146906422902467089251560981540619013770638094556149`49.652024037394284 w^5)/((1+0.2546055363771502941288065075714899147863937884030776213667700816978512496553`49.52287874528033 w-0.70641815366050108159561089052565739685864502050791254480916612147484579421955`49.652024037394284 w^2) (1+0.18292921010222689512806596780046729392661364637980966925932937600109232373874`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.- 0.19987732420651825588260712817764747281954654535518425348871025767309377839837`49.673029172696914 w-2.02519313842252547045030753133449921803130253629188005013802757708131123632453`49.673029172696914 w^2+1.6837656649454449217396593168738068780266205671333062109942385988532493208828`49.673029172696914 w^3+0.1106173020409013631792063873488282863139276576713768092969905594615677168894`49.673029172696914 w^4-0.17844739510434870433274798580657800419781908201743437176237352802750397517287`49.673029172696914 w^5)/((1+0.25254291506726294265138274480240004242377210328528919570554370983350829244019`49.52287874528033 w-0.7075136118602598403671749259006906356202840524754766108015089805782808087221`49.673029172696914 w^2) (1+0.17651660970035107873652113753280661926639537574972069245602318525633345534705`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.- 0.05261650853147852301267089709910496491375162161431033588132337521320202996644`48.89962069729389 w-2.45719000305570581535664811792937652674866319271322622880806086623185697664468`48.89962069729389 w^2+2.04597421118959232463424713828483222952171978540163372785254070189716508204182`48.89962069729389 w^3-0.0180851180356144215511583461679415729204374519147793378741683534568874126212`48.89962069729389 w^4-0.14836007812068579813891397399250370820383097046015717651946186959680425602493`48.89962069729389 w^5)/((1+0.27435815276602528605709888390363697278618372297338831799241322045359527176582`49.52287874528033 w-0.6941534334185660239901373835808794042885805655485964035077639736917162127485`48.89962069729389 w^2) (1+0.25389700909287034262443123273917754737280211543193986345252920549298988573926`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 0.84413054139100998166237731123814470141617107556595231779749557854528566666485`49.08030899383343 w-5.08681306970414295027699580160392904427587104305690040210532827008950922821594`49.08030899383343 w^2+4.24042680779559613035257376868096225314342644660630409261573868760753604461105`49.08030899383343 w^3-0.77985671412013825376828420290769030842158006432451738844193192331729517406648`49.08030899383343 w^4+0.02564786685522453920426094614373899322144301957848323517097808624463382544278`49.08030899383343 w^5)/((1+0.34813210669686458868772150842351377411698751952987687948684913840641513689999`49.52287874528033 w-0.63308465439618238745222109407342987817563973519601510662220067711164044991343`49.08030899383343 w^2) (1+0.73987373619156030084649019379891128435068268345671976435037111083466002910509`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 0.76465147785547500647384036416024261001082146843489941943547522895183791772168`48.732734441394435 w-4.8539890466190366635774611500973239479400686484717913644174`48.732734441394435 w^2+4.0471316417752316477668407769930412538211000230552682396791`48.732734441394435 w^3-0.71408988880128928069425690985772471484944505276549984688532952719950478866995`48.732734441394435 w^4+0.01089796561507440456209082194478329850479286313053110117219884352576544152507`48.732734441394435 w^5)/((1+0.34375391268235923962919749725222887432365889588322716279917288343459599511795`49.52287874528033 w-0.63705427328364325179833479652891464545901045908992348989327745508503639592821`48.732734441394435 w^2) (1+0.69626131145644821456756916386041258288350568535715328182619804550893138615984`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.- 0.31350552068224676704814215512746991386041369879067801064854607638133792262383`49.69897000433602 w-1.69257673929406810219242049903984233540353564612701679164628955263124765217045`49.69897000433602 w^2+1.40662030788639389287127330897478523268033091477589025611125083899414134983416`49.69897000433602 w^3+0.20765773962159643530913635484734406793386610533599374487650191544372338623569`49.69897000433602 w^4-0.20094719074290746006535292240875374838928324054062745291429625555737904693536`49.69897000433602 w^5)/((1+0.23022355948698478477634170402205759621290327798835674570065502436290139605926`49.52287874528033 w-0.71639398029601602551022145446316627094360484598644278113680817764208912302478`49.69897000433602 w^2) (1+0.11818058807782333067466794506861710773362480826648794408382320137152267517178`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.- 0.33319432278816282954789212349066689925047698702328030384958384970520645846029`49.69897000433602 w-1.63510724388319329329151270688691775608170089096605856558233174629583955437371`49.69897000433602 w^2+1.35919344031155567712561624471578652765838091913898865904050963760892101558629`49.69897000433602 w^3+0.22381107684530350498036329362134663836066111029092600680741635489558230585943`49.69897000433602 w^4-0.20461979558082678842191871503252920417667026012110471261448450264149800015373`49.69897000433602 w^5)/((1+0.2254980001902403737490756427755281634171983280461682557878284772897182530685`49.52287874528033 w-0.71746720746494813511050299775989479469787078419960192174951143234691324729282`49.69897000433602 w^2) (1+0.1082870267174316482753751031759511616506404461211949801962403958989888431898`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 3.58101331701195495594586993875758885481901097743959228631790022216100022236937`49.60237197471613 w-13.08907959456504726872647824345269451217933479955480224243033512598968732801479`49.60237197471613 w^2+10.83068287638664719498462001512047709461389598748591176924232243753059356317745`49.60237197471613 w^3-2.95709690966356759627968187972520604233492114587929347873633118072468295843068`49.60237197471613 w^4+0.50112036855192837217687372011103878813233736556202720903588114139267605776749`49.60237197471613 w^5)/((1+0.4202708457828461722018043870346500184617209721457566318940688058822581140936`49.52287874528033 w-0.56519054028657414244759167367934831290153964282174267598907080389843150307569`49.60237197471613 w^2) (1+2.26133561270684645300243407712581455955359676510668092311510753311023397857822`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 12.95527991057073735313563644079220936700272492476203040355107079306239757532895`49.55364257793413 w-40.4521132299811879239991936458137818133845243335703933965956`49.55364257793413 w^2+33.211243498135630926335905829500965561950152862805743549764`49.55364257793413 w^3-10.16891850671515262092689273330198623787658184402663064018553092792107072678138`49.55364257793413 w^4+2.03999140804490406048194912422620791167030160693699730137591268686998204536159`49.55364257793413 w^5)/((1+0.46492625652802264309773230972077324314009776202645928358829757200255420827957`49.52287874528033 w-0.52185313046804577296207853105261760229913577762138217165556450809005148379012`49.55364257793413 w^2) (1+7.52319671889736743369769575384875779148734166300536031047450524061702039489684`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 0.59258708379644664381785880188372374660847033595420314424955712335233863324363`48.992029556162635 w-4.34979239223322912662186982224669229988471168416460654949028448392988824763256`48.992029556162635 w^2+3.62794921499967261313701749502490075272624475966755644028172331433725857936618`48.992029556162635 w^3-0.57071901219045974038925674907835718159051237745150600877266114944486308798509`48.992029556162635 w^4-0.02140823839684228489855863591353682491046231069109588905063704919391396388136`48.992029556162635 w^5)/((1+0.33327268812526154154987839715204548174209170036357460047715800931300541750929`49.52287874528033 w-0.64644577793929811709247850481560920094022132240697002296448767686763517600761`48.992029556162635 w^2) (1+0.60209539593751918509340931010491657036507497221668592736454620716475794882179`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.- 0.20274165085120427866347763405925161021900513380839041725016351082745853179612`49.67672780873929 w-2.01679664552612905217584726742069566371420935977899946973507397484395375831724`49.67672780873929 w^2+1.67673819912808436110037821184587384796062759733589649091201648783225603924992`49.67672780873929 w^3+0.11310669550195815400549888404183176094456876409901259537384968808886900393256`49.67672780873929 w^4-0.17902887440183555944706891010528521883585475591350706627629399512889817600813`49.67672780873929 w^5)/((1+0.25205542615941165841307749267058658209338733687993085221730370840448643312047`49.52287874528033 w-0.70776657423695225774219066739006955064235373188146478042954068706097087813025`49.67672780873929 w^2) (1+0.17502729818967801198185779100735765706179611134613085822934792809849528472005`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 16.49085028477370584478553468830183619907252372257580007944534068962013383402639`49.548058686912555 w-50.7692700093331483599894785412415591863507927151579286658504`49.548058686912555 w^2+41.6400596392902562639561473956457507249001656508097572553373`49.548058686912555 w^3-12.87375794565623586333781240989143510041586172403081343551884255139050676427425`49.548058686912555 w^4+2.61491692311658652136988232628374486056127174770767411369896238612821198187694`49.548058686912555 w^5)/((1+0.46988981281075433558892758347736398683786914305272240226706266433869475385755`49.52287874528033 w-0.5170017341904084402346027401909131265299382016672788193792206646707658463062`49.548058686912555 w^2) (1+9.51071416531585428712796469963377519860216064151909087432565558549396181676585`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.- 0.33959932242551231209294405897213295150940120813204362430550528571742168399506`49.69897000433602 w-1.61642910359230544032324082854662210086422665213195910045805672317248567820323`49.69897000433602 w^2+1.34382984554153034166640128119654754830088648209822656515483316728404500994659`49.69897000433602 w^3+0.22899128416586749694206554997501859561579414095871230696053411604574805203556`49.69897000433602 w^4-0.20578856172861124428615927420506288661589735401534605995795297503639891817701`49.69897000433602 w^5)/((1+0.22388170448547122370788814076441295768803538694729103978491361586298279066376`49.52287874528033 w-0.7177624899514229343272119451471875841262929283803376298061038154774620610337`49.69897000433602 w^2) (1+0.105088288347614851854080264970405308687286307022235866935336718715023531664`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 4.36676620240713754701025886259292235562500349291418000491981750643850822176571`49.59282494808891 w-15.38393217332210315370817196997436472401969501844764258060969427406404145512626`49.59282494808891 w^2+12.71184596558817512502854107659152803183336569213446228411203456105059959174202`49.59282494808891 w^3-3.56814031050282752119540281993735420497121224224485383476554031535797255423243`49.59282494808891 w^4+0.63248073979010566489969695221489214019812556072124733631587348969703153243829`49.59282494808891 w^5)/((1+0.4292087063925236191553331346945263831959113833191543484819671658838098090173`49.52287874528033 w-0.55656888007757844963810455543103753484202185640368452905633289023852291172716`49.59282494808891 w^2) (1+2.70108714558921729873777065986822056257341995226777269008417417066561704213165`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 12.8871150170858114366083321706551446727680347884603840151021727346700805379984`49.55377620638863 w-40.2531949845762523834411622304554687841622336040785166442679`49.55377620638863 w^2+33.0487135652545078655847394192468965653060689244294220057782`49.55377620638863 w^3-10.11673960695382615712251972306806684547141714194826178063261649599058123601378`49.55377620638863 w^4+2.02889609110981127444944020647422956079716395876303577414792981976002208835383`49.55377620638863 w^5)/((1+0.46480708563478751695555846167247776584199459029761187555303275031983237097919`49.52287874528033 w-0.52196953827917321938617414473328031328740699706100718141601180802698559891207`49.55377620638863 w^2) (1+7.48488375903540538718663056390873277030485425426781465237252507381889178928637`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 17.1505122195280614493527447424312477616686175124340143406859944596496616083113`49.54724448929161 w-52.6941777319813524483108075239376938347681577219659757012114`49.54724448929161 w^2+43.2124822365093737322679089870794168944119596773067409905081`49.54724448929161 w^3-13.37815841222015136337144885459414382382758106425898847567099384120219472477836`49.54724448929161 w^4+2.7220904805262473078050913385159394339705642717034575093309189936545911879551`49.54724448929161 w^5)/((1+0.47061091358452367766870020308231005658362739494529465398602705149539813063759`49.52287874528033 w-0.51629646301612882261879551955026550373685317385617382809272171813795357579386`49.54724448929161 w^2) (1+9.88159372842173697917707720018033268512602383534115686637864775504340375485155`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 3.59661621582203263300273180804232007509891454491842083368952290351977611659311`49.60215656973515 w-13.13465506282670317948992198901818813448233482815720318269275140349625876289073`49.60215656973515 w^2+10.86806232515635179044008561821737737675394097687719893148372878728060884740209`49.60215656973515 w^3-2.9692618251818377530074240677775906669305614435357885786706498798637333640417`49.60215656973515 w^4+0.50374019825084638503220192985650684017495127460462776098274574617985100034322`49.60215656973515 w^5)/((1+0.42047352183458304077561381735684926829516446849822629371302195363712469473965`49.52287874528033 w-0.56499538319064621667445932416787977254262812311515551016224040839858034737366`49.60215656973515 w^2) (1+2.27006157427458092920346652101792605850268164772538493394707797523213243322011`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.- 0.19948043671330967211856994154624210925089301765171678257633275613015799851905`49.672511040644295 w-2.02635660551807375721338187560007600601223028910071407517552826154195905218267`49.672511040644295 w^2+1.68473950382159501975699472530718201161927211042055227005872552700147339000509`49.672511040644295 w^3+0.11027227331997350211718310112305948681038133322398291350045237819893467250505`49.672511040644295 w^4-0.17836679509714919540398957499624864102819771693538980760585909226930344352079`49.672511040644295 w^5)/((1+0.25261022476348574036064632313499716344281820124754823420015175423256433390582`49.52287874528033 w-0.70747850339160976922076023969094145233984916256329309474528428074991043946281`49.672511040644295 w^2) (1+0.17672303149122520767647616042982285601900146059235542477031823510572944999772`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 2.96573235824476278474388436383614772212555092431421708021625388355791815747693`49.29331735115526 w-10.78278300063345750527230652598734083362231015469627176555387276634109778639386`49.29331735115526 w^2+7.73137236524763017040303713466396660357487053929358728935976263877719310282182`49.29331735115526 w^3-0.98578048428355394734059349720602673854854826784393251353842049872584847816602`49.29331735115526 w^4)/((1+0.53470494501915911375902362837668351182614772069445355344578895420594380443357`49.52287874528033 w-0.55699840659784275314519086423007772652952565339970516519460412958683077000929`49.29331735115526 w^2-0.10797729011014799062402515570686352604909214260320834151117671726240462298235`49.29331735115526 w^3) (1+1.88663154859122262131201238089699554907241879808646570487089332543285649157997`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 2.40360291114542615394579675561225948726453736699476673640954640539577924815174`49.29677619297767 w-9.22262424430813468759166875651954666089194585626168560143550147817133852953094`49.29677619297767 w^2+6.66975082631558137405333802450303914727571749720600928343864055633615457904765`49.29677619297767 w^3-0.8467339659324411647673552067648046428513490759657729955872609517825913656506`49.29677619297767 w^4)/((1+0.51948965236578881024403108952602468262117059186888281998230095906958890469921`49.52287874528033 w-0.56307642964875322058789039282241259697891025163180058481290132248309803492279`49.29677619297767 w^2-0.09875418707033790677569483794665290756114011384873195134612485898828931062567`49.29677619297767 w^3) (1+1.57423755776118834236683623598372312426434295430067839838860502428010860397932`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 0.09708199166277317797242919464884370328814677515022700181345678997341598913838`49.69897000433602 w-3.43185743877126882012977491513547051203418269322528512473951556242963271417349`49.69897000433602 w^2+3.88517552765482965415606580733328506931260064819825425005150226104454152225948`49.69897000433602 w^3-1.12502799176376872627860174105755359163173677323261730972677417383554750442336`49.69897000433602 w^4)/((1-0.02983192687148622923538573090338772825890887945486652262281244584577770475702`49.52287874528033 w-0.80272021116659565836622787592355484531698649301560832021820325310197504309132`49.69897000433602 w^2+0.18963000281798661804500375780316957575718126937478481312838494796616664417267`49.69897000433602 w^3) (1+0.41414993536151480325167118804915484849764311421904959590784533136805188961847`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 0.71733479895186820812154564149600782961320892471711427249779363417411774411486`49.168135713112235 w-2.25098016645683732672560932960626257330101114321848982746548927342956481498037`49.168135713112235 w^2-2.42247768528064316984254175738566111310717675827378902285773284506233262540563`49.168135713112235 w^3+2.77818389505496545881340526011075162162614446287841690562401678070166338244931`49.168135713112235 w^4)/((1+2.477076844969278680872560207853347007970970882331247475098504390018778474625`49.52287874528033 w+0.19692987100768368292583014039417207680083705727481524802404787529348349672381`49.168135713112235 w^2-1.02988878052416511327457322542167041958224201899054498770680005778024339143613`49.168135713112235 w^3) (1+0.13631494650143953018356270471150098549802063290389827414957505849483068275619`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 11.85105878692192228094976623470006739721709719632685985153196890735867092912113`49.32457587226936 w-35.7201575744828492134853659813955011437557084476972835044176`49.32457587226936 w^2+25.2246113409780441724473852713001903834201706255989818067129`49.32457587226936 w^3-3.56987208496519166766348537174676148511632419714033046962100964935669788788054`49.32457587226936 w^4)/((1+0.58044676465960885906867607904751145131718376345101665837182355746211261241881`49.52287874528033 w-0.54115163755442434406870926451974070971278953445083898333991934395967359630151`49.32457587226936 w^2-0.13883346330807196993652060754566407964681085123560013219963752496448269161879`49.32457587226936 w^3) (1+6.8731922098120124016004078205902433814386545654044507484659127744273765098541`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 12.74057694654276296520339332088904129852124666319843909502732196990226497665748`49.32618939456471 w-38.2222898532810874082903907017160523997076343607376402888101`49.32618939456471 w^2+26.9903764253719051140769706955826421312753064800807276000349`49.32618939456471 w^3-3.83642768916779437898929571787127156827592574192239437500797761213528422608262`49.32618939456471 w^4)/((1+0.58140851632516777841378211927433409402180755751313781769761618329165312911917`49.52287874528033 w-0.54090265241853860748812958818781861736749852463254027149485514824062272273815`49.32618939456471 w^2-0.1395832633708959661283749959113066533345275603854138959004761887059096271625`49.32618939456471 w^3) (1+7.37330573668234555665679654651483554024608269200419900413370218949346958981588`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 0.67374787810634903286018785477130668964881448744206659306258435258674261779162`49.124905552613555 w-2.22826839407043238027444737020120407663528098023660958660184279402703804333894`49.124905552613555 w^2-2.25139537892841137922117109097818608474072039323368131517665081192168740836859`49.124905552613555 w^3+2.65126692457661113270694391425651722048666869578187460713330419172569208005517`49.124905552613555 w^4)/((1+2.39578254514297223139727761889244807562396239698509840040877659125807652674247`49.52287874528033 w+0.16088157163493018138653674383401742192623615342002509308408675838385740835186`49.124905552613555 w^2-0.98794277679394598992975134637644040738705787408668111104447018302103153954645`49.124905552613555 w^3) (1+0.13212087848241160646786959691908132735480088327322099270992361700959181378945`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 7.14424747505258097330007360495915841813686799108770167057256750192400234856652`49.3114371744376 w-22.4876016943703919309665350664587451268152205210331347250623`49.3114371744376 w^2+15.89993817852007750773107435571008367324187925707376280480116401105134597495343`49.3114371744376 w^3-2.16956530705164517768293722951721507101994476234108155213824956313691669413432`49.3114371744376 w^4)/((1+0.57104943680594511510148281529806618565552028829367797841809588016094453512311`49.52287874528033 w-0.54387389109460244106635805959968398943419672830028411851211302376937011719968`49.3114371744376 w^2-0.13184497563909286304598931368072851117885122530025276111340909157109700770292`49.3114371744376 w^3) (1+4.22796017884892385203925403229834339712144150624676894798713691230247293347898`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 0.55636733580640337651425121948748925342685733946387620601418522171588825608981`48.886887991288845 w-2.15928685903746022584586064919203562505968946986488286391394136210467630158643`48.886887991288845 w^2-1.81084187047617830788112422278311800999590268359018448296033978341798879271603`48.886887991288845 w^3+2.3204572434638894557764758883578967268041294643032668580350196832724511068185`48.886887991288845 w^4)/((1+2.1862212003856014784615388072515717318153195880740478406893810817147042053101`49.52287874528033 w+0.06504756008249334789494704226039262794502240818590547421962456773750094414134`48.886887991288845 w^2-0.87828146240068498268583564233988221201548925159595985265448845650812741413158`48.886887991288845 w^3) (1+0.11848465962803486300721494248215310543211068976325181543822554057712044799017`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 10.10207279866037177986260576476723895267828436478323664541634694468180893208198`49.32075858376993 w-30.801328701310307918348710126371623495401685310867146023284`49.32075858376993 w^2+21.7550697871918987905026080607521165083231881716929003595345`49.32075858376993 w^3-3.04703218702392940289597265289195031256357886108369656281216002683330192539532`49.32075858376993 w^4)/((1+0.57803143644965215363636068999916749862620166657961278293963170659228283942676`49.52287874528033 w-0.54180440243294096789750707344736288263903893312894603361545753624612498360275`49.32075858376993 w^2-0.13698229294104927712598854345385585090929006480555700191667881305577323601839`49.32075858376993 w^3) (1+5.88999142346737942109695890351511336955831787187893828831390845318732664798749`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 0.50177136496274677155752756364095769700492169310721071987893498251349976358114`48.49567726441883 w-2.12260648137192744446488708790463812959001936157394130092803655059028236595037`48.49567726441883 w^2-1.61779027279201198727263040915775034053723375230978416250336430668876351392751`48.49567726441883 w^3+2.17304420744348862609350906878353409397874710502395621036062057092176270498632`48.49567726441883 w^4)/((1+2.09487141564270775644405611408340734030096923887060642222030088670152548635347`49.52287874528033 w+0.02085922977654716932308984302276933940189836186894196713016842948918631404642`48.49567726441883 w^2-0.82921448381661914000960517203951643975445290102414179595856077176380193099757`48.49567726441883 w^3) (1+0.11061187221420145322342855936052020282335947598848836119317950200115196237314`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 0.90787507884504311483149725886435049462994899856499305728902211408045131450961`49.27621454317301 w-2.33624292521333054600073257857339754905078548399398183610462055531553636230865`49.27621454317301 w^2-3.20655149721060108930857459159882273344346982407874745117434299339821403396327`49.27621454317301 w^3+3.35270257521853397545193543376997494740783884638656866927924000225303735927343`49.27621454317301 w^4)/((1+2.84780730383951452259695765144275786228807383147630590927999811313057165449914`49.52287874528033 w+0.35755851365324837254177878807775996932994278162872052683408712816325043221778`49.27621454317301 w^2-1.21918079776482562240491829895407967934954443033459031990354774557665740331832`49.27621454317301 w^3) (1+0.15081123922379145477681112858384102099066118715706430673380002775202835302263`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 11.894056552897743902301544662790182026149985093740365197164797096003179356653`49.32465837034091 w-35.8411002195813615139015633408361541632280963154443738894606`49.32465837034091 w^2+25.3099496700211678459674991118739633496725724524808769005339`49.32465837034091 w^3-3.58274841400820078480955513600602164187865271549338748672127360679390308404596`49.32465837034091 w^4)/((1+0.58049674085136181834901437571634207597423400197742641268243592399969362620724`49.52287874528033 w-0.54113853823231972756379033217640430656365534192972151275808107357150026002452`49.32465837034091 w^2-0.1388722392086773459136745241488568385386830623198611676342258398649401903991`49.32465837034091 w^3) (1+6.89736595912547382379069861222372520404914144806801061109995805599215963901552`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 0.71430975207403910276317506708179554620310358952317341748356412498032000286368`49.16549611879934 w-2.24944856893314181411906332071065625398393825787933172531619839771151887986087`49.16549611879934 w^2-2.41048887417239222530404848825857557365453614678890508966140032818160811226888`49.16549611879934 w^3+2.76931278885009851377212365217811828758184382697328398704390237450263349930845`49.16549611879934 w^4)/((1+2.47138417040081862151576858515695214416605014384798741636039860536018389569006`49.52287874528033 w+0.19441930620915156241607714771162376006930016386026523789097620924910015289093`49.16549611879934 w^2-1.02695875658348875425556985430471257420637988618233689577462066812314108995148`49.16549611879934 w^3) (1+0.13603652627477567325867716227760529203106656647812000921067087397880516095052`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 7.96308322079077764351397495718063365782375595439793885949301548866009144108291`49.314479272468205 w-24.7882515747866071133827492093932377445896023207304304535848`49.314479272468205 w^2+17.5185421236841657557655015914377901509416243048320422381737`49.314479272468205 w^3-2.41122661006397641735606069074146949507712789941890973767618294740781023457139`49.314479272468205 w^4)/((1+0.57353351586416288894477588742168105427395571719732624781248942999940420533539`49.52287874528033 w-0.54311022615789515446418642941990282757983116312445662599193226341152361980191`49.314479272468205 w^2-0.13364043381979348272968230281170008555356961625963899344460065359514809553268`49.314479272468205 w^3) (1+4.68793426606210503557375027489201950229070712838286696382719263060746630424046`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 0.65527248797688211211125165071270676789249901486554532134767516449272673611439`49.10238605146765 w-2.21820393898097145862663405366182718803567828534080310606439113639427857744753`49.10238605146765 w^2-2.18000696531252876724742992089846656917828663552182696713452349361506350717415`49.10238605146765 w^3+2.59808459004562258919626893381015405214043876440413186388476414677531991943815`49.10238605146765 w^4)/((1+2.3618281836054024357847741172768395437166388529709906034176674820239575602663`49.52287874528033 w+0.14568244136834039230175071034145083835702924918963667567547154519245856581993`49.10238605146765 w^2-0.9703476710259626661414221459635086550758330488370443243540204804212796676827`49.10238605146765 w^3) (1+0.13021706191897891244971885754002100434370431595245473737133641143043855800628`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 0.62364819789268953131606639312655535233417045137617205912694795761330889823851`49.055382968101256 w-2.20032548184217866463018005669265209486862928349501120189595520583683698060093`49.055382968101256 w^2-2.05949184882591246332163907797595824738168445804023358848530353876928613020652`49.055382968101256 w^3+2.50796702675412948152545154135876451463847565609485109556583858212712892106774`49.055382968101256 w^4)/((1+2.30448139351319640418166263099709358902007260170111135606161386193401193876017`49.52287874528033 w+0.11977386003654735945259732518983354242214224479990202761287263713108063230082`49.055382968101256 w^2-0.94050503349071292573575061228226285432395717802929686347143796865750383306092`49.055382968101256 w^3) (1+0.12676509626967209365320502171774732176628606180715248165193173412845102786277`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 13.38624755695418569277736751164647915383797889852517658070044948850305220032647`49.32724882538984 w-40.0386492166030886818485575262822064554817370886192356264734`49.32724882538984 w^2+28.2724649572905148266692078816282771721375969273903484469343`49.32724882538984 w^3-4.03011743697169007937458478115613706929288233008123764007706474992812756604422`49.32724882538984 w^4)/((1+0.58202265886721168552852098426598885389020432370444501471524617666782325183696`49.52287874528033 w-0.54074719162702107027509326152368759202766897170737699572055553000669849750389`49.32724882538984 w^2-0.1400661437232915799423248522124472877502456854578885801359417319897271431766`49.32724882538984 w^3) (1+7.73634191940325986413847231256798064389464538282758503746621743947288743143898`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 12.10781800887711290117556979613903611694896284609951385346090523869526018360094`49.32506144099133 w-36.4423707886398721409710688791412231471092838524799592033824`49.32506144099133 w^2+25.7342302102779470325454856015849406050746052157033236577414`49.32506144099133 w^3-3.64677599089253188346609589009262093652571579951245700283555646247175813986919`49.32506144099133 w^4)/((1+0.58073965117719262249067477688492137230860267378214567333619291381962957553968`49.52287874528033 w-0.54107511682229780961133938245620058052862811379338197325021531309788080600322`49.32506144099133 w^2-0.13906099765653715193689449038013295052421589994959872855714094002366707443148`49.32506144099133 w^3) (1+7.01754605053241118462192264944031080603997426581876034824866977893765491869732`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 10.72501010060021429985337546473877178499175010218096858658063161448343417637609`49.32222971733335 w-32.5531073715203330001517180241370716496271212354131464414536`49.32222971733335 w^2+22.9903975795004151201776024036345718111867687163503612815642`49.32222971733335 w^3-3.23302431092779676310757108979673479277596182747705984785739457236600467155764`49.32222971733335 w^4)/((1+0.57898705405107418384556044222810961856818889150673106410495987855516684847013`49.52287874528033 w-0.54154166398780466882305980588458759788014521301737673014556003745842747892353`49.32222971733335 w^2-0.13770950028007926765502473164775510463088447678140891944671622389818826077288`49.32222971733335 w^3) (1+6.24015475140818533103946692169186505774914554293339461842288502232617512990596`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.- 0.05125479739649237771319421967107677091483653550098390125453511790568628768557`48.787059560612974 w-2.25221028012471263881954166420990249692512735316973409565835510983018297909812`48.787059560612974 w^2+1.61642903683215496657430259832550192155697732484378465586722433042238908431596`48.787059560612974 w^3)/((1+0.3955007129106344022592637861377208129120021656441579678112867819551645830383`49.52287874528033 w-0.5411222756043870302935576397951490629069265429979311498861661165790509112229`48.787059560612974 w^2-0.01940764219349582602854872756109596170950724173406034031666766274100050167076`48.787059560612974 w^3-0.05097759222454438728350969217024971346517610728782123824854853302092908131221`48.787059560612974 w^4) (1+0.22437733157014777030484563823392244646573724070298997654153876757567828443796`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 16.1730576508816913181344302609521799147971446285645797253696`48.84965462451736 w-44.4066236637252646965139437217787130663174548905090486846786`48.84965462451736 w^2+24.8514495680547887036828839130403009075097820208853035286367`48.84965462451736 w^3)/((1+0.78324605185672035909982236552171021884485973773190619334692725848347315859507`49.52287874528033 w-0.38031653664344105512634673746008042678545539013028983696931152591685180110604`48.84965462451736 w^2-0.21054560629701644580685261899074084152093028429762115235026181776391956427165`48.84965462451736 w^3-0.03609993871954692492390178836122588360101301885831059480364062600565757453405`48.84965462451736 w^4) (1+9.25361674899010461000899476373850698069551225246793317935267243831878605795096`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 14.3982016500887401829066012830204331360694622745031821323002`48.84789161203851 w-39.7944856430383718856555711208880587494488608060723275408393`48.84789161203851 w^2+22.3085130994995950949352090130365388724685788032540109435752`48.84789161203851 w^3)/((1+0.78022591665993430442657760943813385667208571146849879775033219200157124841461`49.52287874528033 w-0.38268590611723050702151350602175172007460306938787498828991104329391608263609`48.84789161203851 w^2-0.20949603964541902068568053389482863635449971057600074569032781072946475456239`48.84789161203851 w^3-0.03566338371538781616826952323524410468031735734361458024097824424044983390828`48.84789161203851 w^4) (1+8.2560152823432661101116521526727935082043844348743252729368452028710329902898`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 10.1211333001569399650324561019160308581887148209334177118619`48.84121508369118 w-28.6799712549182247826537201196962972254132978547936476356507`48.84121508369118 w^2+16.1802927020882548427131806465943398941170835905019724816322`48.84121508369118 w^3)/((1+0.76905781618792501011579987939797250470163501469961790167141395992671285267953`49.52287874528033 w-0.39127922172438474072254193198268086590418492793479701418146138171377854610098`48.84121508369118 w^2-0.20547314280238432891437286878563332382218984851878643192357286858988583870894`48.84121508369118 w^3-0.03408690901561787970168786474185920593620060205493272036768180682953728804275`48.84121508369118 w^4) (1+5.85295636062463081113513992081160756488907666643353064444886302580193260767911`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.- 0.31180931317493658288580328540810691914640558781279111454840665418391613969156`49.19820307684425 w-1.5839662778941032048024360419668816236374679052397577247271991303760910100683`49.19820307684425 w^2+1.25833221259979975781914282353486608059757843967310696149005855568936417303039`49.19820307684425 w^3)/((1+0.26469713035192288810905708507565061736051590542668624955314594966925254760014`49.52287874528033 w-0.53614137261944645954069317153431526715202852758695498265547534336587508760818`49.19820307684425 w^2+0.02959827827445260670083888062634276059826093298954621703483344177338563030392`49.19820307684425 w^3-0.07975891312370140453685135389675262587202439672617489125438189140510481025658`49.19820307684425 w^4) (1+0.11051631208445078343280471402236053697335121383196677378379573179370768090605`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 8.1341597915876517627839913014178248228897408131666687997981`48.83592143262764 w-23.5164521099860314725626724483782973419268521099823944057732`48.83592143262764 w^2+13.3331498523165939894016026540006462004604213252041788398079`48.83592143262764 w^3)/((1+0.7603873567437845925539871422234362901033258042770084981999849530081212026733`49.52287874528033 w-0.3977684935783232126744761270242830408994482508523565379146390854350823729895`48.83592143262764 w^2-0.20220129976053107573804329078966044036030615745310082363297071667900248113082`48.83592143262764 w^3-0.03290870875518896287122713396143764803738807419225536209362384851945472780686`48.83592143262764 w^4) (1+4.73745137691544130176083165482500072368298108967033892144176862074800029727324`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 12.157395325276256544463622980064939038017389512114469599651`48.84495390468134 w-33.9714906967038117214618003821905908587203960871317329518573`48.84495390468134 w^2+19.0979168104379314324051616952565726777226895627853282988318`48.84495390468134 w^3)/((1+0.77526675197711900491752637620462889404331397982964854291434271760054197775373`49.52287874528033 w-0.38653442595871039082721195861148065733576092898496613054650523478854120606883`48.84495390468134 w^2-0.20773690038431441811086272950124504167003845174745924785908636836602960801109`48.84495390468134 w^3-0.03495570763626749178207534142870068718254244111679114615211431720450633903218`48.84495390468134 w^4) (1+6.99680151580694788836473966556870431870728643894028428547867858072295874365942`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 12.7279375425193618736304930572157423606153799146076819474368`48.845796539762354 w-35.4541158831784640470959994998246603055633238839633926657982`48.845796539762354 w^2+19.9153904779290092987414020469872147936474257237034215608202`48.845796539762354 w^3)/((1+0.77668083742972294929823901055375413950490291674515821481714030614930458385406`49.52287874528033 w-0.38544236175245414554238729829200657567943635811326903528579108749503618242717`48.845796539762354 w^2-0.20824299332734850553466254960054651782265003523528526743103743791900908024459`48.845796539762354 w^3-0.03515629872258009538005797674097906884708866096803588296910307242393615186104`48.845796539762354 w^4) (1+7.31737799164304364992592592537874987630325880611385756851241710463959638358602`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.- 0.24141102471686564097977098856049851526103999437010214614167880450570104874589`48.87955471259997 w-1.76406708437135040445131599838270771984225333123244898434030712287563494312028`48.87955471259997 w^2+1.35430417282376872721477254851721823294109396453175253632297770965088493209616`48.87955471259997 w^3)/((1+0.30739633319817696751829207800766859643874992378647761755944612065910869498206`49.52287874528033 w-0.54134036900229789653134883812870662965478232608520372484207693152186560248598`48.87955471259997 w^2+0.01614432252693966611100545976537839247841855291375450871052449310076458120933`48.87955471259997 w^3-0.07070554084572751031567310134011407625928199499216467055306435759452599741744`48.87955471259997 w^4) (1+0.13944054863055216840263913276613576938931085555353147193782981623557781974802`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.- 0.15536629674172340955551191537749091512203497995389424113566048091150078893366`47.27167015534883 w-1.9846226506205539206426307084147068506916130410479346136304`47.27167015534883 w^2+1.4723488097438268594338553145261008414181214783484602240659`47.27167015534883 w^3)/((1+0.35145075795818769830698001466087634618652592811609368537430641832065702916004`49.52287874528033 w-0.5429737575295267532684217157837474690840409031368506907968`47.27167015534883 w^2-0.00045597426883024383975802413068345105845080191344998216115650058094191058326`47.27167015534883 w^3-0.0607919295802017601959996703985925148264109375845611135062592979611147635224`47.27167015534883 w^4) (1+0.17682710192656699088161287726827560703055717508024453981443111892898893935452`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.- 0.01558663118958959958072705884480897200010892007997030996992430929006337321264`48.61424359972688 w-2.34405427093800428125408598854091893055201862086627413591517944186198343402604`48.61424359972688 w^2+1.6660830523223084167189476740619347371113250976025539405970515883328670487367`48.61424359972688 w^3)/((1+0.4087118893667221953863553535049859860653436147743149862032930046836863356167`49.52287874528033 w-0.53992145553914208709200323999459276252728427672393234111536248932777665172268`48.61424359972688 w^2-0.02548732504524535170264006628814783047056752781181712932788436152956955225052`48.61424359972688 w^3-0.04815064822415737614257327459929453977246116316828361924541413605999643533978`48.61424359972688 w^4) (1+0.24113788094750863472258552435688179006693616209477058625905935643650714432829`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 8.5855267553915900485214717692050653512929156542228115060297`48.837317802017644 w-24.689422388295763465812638009414757465122688995633223355544`48.837317802017644 w^2+13.9799316746398064205324344436530802998819228023846241246356`48.837317802017644 w^3)/((1+0.76266613368678748114743827357138820101405452945149273310059387514325392747409`49.52287874528033 w-0.39607837246052938074768391755771527722749151691279750986377376156254793962053`48.837317802017644 w^2-0.20307344957884557830429733146647619735924546899413760918422504880340239973267`48.837317802017644 w^3-0.03321419683004617641271136551116162701875170764811943353052851281596995404988`48.837317802017644 w^4) (1+4.99077559981940586533980163511833554318208475647075095055699464795185151735939`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 12.8624632205201452100033837848150524555270601492088965318721`48.84598474318903 w-35.8036970931372858800535986359562668635077669481304106133977`48.84598474318903 w^2+20.1081381011170251939947893262643644975450447044072030428377`48.84598474318903 w^3)/((1+0.77699754244612619540396350576892315521399816797379539863604627729033127024584`49.52287874528033 w-0.38519719597780711705913466119585968642843000645108846833930931472182659482044`48.84598474318903 w^2-0.20835585248989924212702671386983737387883730510411474932016464772714578647302`48.84598474318903 w^3-0.03520135730992643363537951153057227454068274357725332248510459001477895371757`48.84598474318903 w^4) (1+7.39296950926438346510924583584956955076380512526979485316567314168178464295374`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.- 0.10018823158291610507727096681700093165205976429825061650360965433716975868085`48.577689671722965 w-2.1263454945938099206350508197325336723819069866056966438095862553764141517037`48.577689671722965 w^2+1.54854414775173965778841394159527111327084113492160206692192018768142902459056`48.577689671722965 w^3)/((1+0.37589513953697708992912681531169393201813496875112392283188553938473742264126`49.52287874528033 w-0.54236094945779496545930692672632476797226835291629706661019978984712654124415`48.577689671722965 w^2-0.01070892297269365373666189275420358293734930258192916682819495018581233636498`48.577689671722965 w^3-0.0552912143650893598733383384685380727703406331246927950213301337399048763324`48.577689671722965 w^4) (1+0.20175366818369875174508671067084682627451597372778503844450067557868268234533`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 11.6060893571024165207243333307113372229579708665285978196965`48.84406449419125 w-32.5388493174630756941034401432360534533766595303942749300702`48.84406449419125 w^2+18.3079980948397748084358218925273479421781373807483109833249`48.84406449419125 w^3)/((1+0.77378064819418105664266842418933240240433702155422706226861865288281580059917`49.52287874528033 w-0.38767753291286536842028395118524488356282445891969958642527993114902501593207`48.84406449419125 w^2-0.2072012159667668248438556183163672588859282315123661244289118718115509219626`48.84406449419125 w^3-0.03474596503951160224657358629373491759973241973743578076497775096286956062884`48.84406449419125 w^4) (1+6.68706343465489736208010372581112742064610769036714048974531371101144075069515`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 13.4783133515075004925785067901671281977390725440687088961036`48.846799984555275 w-37.40405548423764325624825355734126971980271822806083146978`48.846799984555275 w^2+20.9905204062340889767642726300868649465183198815560468658113`48.846799984555275 w^3)/((1+0.77837328563045206669013952434813232796940773955425840924882180094074848508809`49.52287874528033 w-0.38412974053089955967717059485811514977385228208561530303663444854225553046572`48.846799984555275 w^2-0.20884402317138998392930367967512730298508799290810869779511511216360893720087`48.846799984555275 w^3-0.03539764611009564921564788581051175432598577818064647493603664819876496363847`48.846799984555275 w^4) (1+7.73904127214868934373620852171530986256920970448339607386774411811218259340604`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 4.26745760689957102601371981187679756334241862798796856805302829100362128199803`48.81519259428702 w-13.4676164575541420078880337577559078039507873288498815090182`48.81519259428702 w^2+7.79169829168757085892731179530937891338208583971499296969484314904507716288958`48.81519259428702 w^3)/((1+0.72542665080708334240395979731331043073236762454655980999589793746170502629259`49.52287874528033 w-0.42233225757626643701852635768161021762891167631287130833523181524882784613851`48.81519259428702 w^2-0.18780546073649353978132113871724242767269584670609654662478480898344852269325`48.81519259428702 w^3-0.02865767807572064742980335173243422159361287586606279400762026957383747618956`48.81519259428702 w^4) (1+2.57117157451257119986506077818570435503035190543992586745350894988070865097153`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.+ 3.71010708653129121194941065583784246274172749817267040244098381449656092577179`48.8102091320327 w-12.0190690096717905807291750753136496093191799515886162879612`48.8102091320327 w^2+6.99278169041604160925183169761301803200526498741663638633635454306315146921899`48.8102091320327 w^3)/((1+0.71583447804825757422248407327390330909017657783357222759263042574451211791923`49.52287874528033 w-0.42862776025156344696553308391446687289971119545217440291909260616404019516781`48.8102091320327 w^2-0.18355078405238108003593256736579603525123677482644589934269243320963718966424`48.8102091320327 w^3-0.02765549817661290555895848686984931741731268712195842543667410755678049545817`48.8102091320327 w^4) (1+2.26005994999512024649925580892364389135301090659705554229007612136234926515403`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.- 0.31857728174731040059953516060462321568685173971995347540636847206337805352565`49.22199121439545 w-1.56666200555766816222357509708631373822323225242303782549909862058899043841864`49.22199121439545 w^2+1.24912381513008001454627805625406942495043308231574870349142019416735170290624`49.22199121439545 w^3)/((1+0.26021921709989471132722796659758067145479364276617730685573830093755218976035`49.52287874528033 w-0.53537590175735944921833678747677494042096960280133729598886100419792033039254`49.22199121439545 w^2+0.03084372848778832111392760579475164965848123381761916498558286115552429458556`49.22199121439545 w^3-0.08065014905952018773322924274094354187430347103182759694798585441563834335317`49.22199121439545 w^4) (1+0.10782880807549755516428781384383760664578081904931437486344007950826835325635`50. z)),(0.44444444444444444444444444444444444444444444444444444444444444444444444444444`50.- 0.30156623964183304048246025809612001769228707486110298274460647070356576829456`49.16056742574154 w-1.61015780897274278496407074062907474314768112594147257715891354528963392855547`49.16056742574154 w^2+1.27227264017602233423216684721662267715880825335643522785272081565054789347579`49.16056742574154 w^3)/((1+0.27134179903795051048423366796739513810326312644885129756849676025325407227299`49.52287874528033 w-0.53719807701932456900299534940716410270081481794297576845010007017813987204667`49.16056742574154 w^2+0.02769023556478697172955756730726594624908412398482905255711742202068899538697`49.16056742574154 w^3-0.07841238315003705457305877082110095417092744651196084626842111629892256664077`49.16056742574154 w^4) (1+0.11461687377531462044089102116241703885560607211174965759911637357668887870757`50. z))} /. {w->w[z+10^(-10)*I],pi1->pi1full[z]};


(* Pade approximants for the spacelike region at three loops *)
(* In the construction Pade approximants with poles w0 in the region *)
(* Re[z[w0]]<=2 && Abs[w0]\[LessEqual]1.2 were excluded. *)

(* Sample Pades for the 3-loop triangle form factor with LME to z^4 and THR to (1-z) *)
(* Mean and weighted standard deviation *)
Ftri3Loop41Spacelike[z_] := Module[{const,ls},
const = Ftri3LoopConstPade41Spacelike[z];
ls = Ftri3LoopLsPade41Spacelike[z];
{Mean[const] + Mean[ls]*(Log[4*z]-I*Pi),
  Sqrt[(StandardDeviation[Re[const]]*80/Length[const])^2 + (StandardDeviation[Re[ls*(Log[4*z]-I*Pi)]]*80/Length[ls])^2] + 
I*Sqrt[(StandardDeviation[Im[const]]*80/Length[const])^2 + (StandardDeviation[Im[ls*(Log[4*z]-I*Pi)]]*80/Length[ls])^2]}
];
(* from 20 each of [4/1], [3/2], [2/3] and [1/4] Pades for the non-logarithmic part *)
Ftri3LoopConstPade41Spacelike[z_] = {((28.48822446346302073552655109094618449848858622909804012522519754875166194714027`49.99200588679519+ 36.46842512340772094317150937595082171665835656140184410050464915629563097572671`49.99200588679519 w+27.02651079360238440334816266259145018787060881379459367203730777972126527385614`49.9920058867952 w^2+9.4431331940805284974532183304553785671290256236365307020335862916499719201608`49.99200588679519 w^3-9.36481321047656829885619096439870825843595022123976035197506138097214275651917`49.99200588679518 w^4)/(1+0.24205939508759154190227856752213133271960540239432454862801643269807962078967`49.69897000433602 w)+50.80866771837126955675729867337343755651740732639771250683719013854430020435656`50.80345639260733 THRSub[2,1]-10.89768572776407920519535721232108829897361819007971161238242584423988531476217`50.80345639260733 THRSub[2,2])/(1-0.13586976068752969320047016311761773808951862770873074546650979566361096161735`50. z),((26.86390926254352397749244439529521141471916820497769260201492297501123195067387`49.95803979966548+ 39.65744070874645684442164899288137177219326454622193864494119497333442736589184`49.958039799665485 w+20.67703537248908957488447872659868339765795475237456513127356616199582139722104`49.958039799665485 w^2+20.26288171501494489102065465574094340822373393239708504670963971683667018582505`49.95803979966549 w^3-12.40491325043749239030193527731032591583111121232840335222209324276335186931482`49.958039799665485 w^4)/(1+0.39036583096236797903923160724295637406181378937927703937450431171104925582717`49.69897000433602 w)+46.84970666679851256886376328098979087909019226021109598880188246777122313066686`50.59342043735682 THRSub[2,1]-10.04854885238605030807984434685115212970939822169672403433019818779515688678317`50.59342043735682 THRSub[2,2])/(1-0.20320193282569693965313468675766726605969772622775364071745881344416445230181`50. z),((-76.59918678949847387041233814909084622329704314828417522798067854598919691291573`48.765008645401444- 45.15458497800722490112592678254191982473871619485526889896840483517517423441446`48.765008645401444 w-662.24438202695416321692144951374625572964797976869683370500458585585617220703245`48.765008645401444 w^2+358.45008890468573178780740086341768226673549841926583841838752642804330224436114`48.765008645401444 w^3-57.85163409507801803017201623117228680878244836149960168182029872282976097679111`48.765008645401444 w^4)/(1+0.63611690243393844140641853859471517301241645337002840494415255479861449088826`49.69897000433602 w)-205.3220191862220497944448040198118893856679035321666079106260125836186486481943`49.89063508570978 THRSub[2,1]+44.03844734689534646576928733982320237957504022294783626343036672667411429213416`49.89063508570978 THRSub[2,2])/(1-4.49202160857598731042086658063155491827249989938039417679281771349253862444531`50. z),((28.85602618240893064449795898910374474443592799361224222947328155952177113467742`49.86793216026849+ 34.88545430160346739286594829760944614444045101654090802383925359247487136635988`49.86793216026849 w+27.63151424035240673411797592433012476610725574689149985547167472292586437896583`49.86793216026849 w^2+5.94490828234032590006266348929504372119867482366265156600464467685289221360638`49.86793216026849 w^3-8.23481010409162551128830259500721632353005357546775704581797006175584923815732`49.86793216026849 w^4)/(1+0.18096284686429430656110893124397905035359114137987298905935882721098913150476`49.69897000433602 w)+51.70511483601449969560985254210637439071925263901824441108706530423979607067812`50.86274332217572 THRSub[2,1]-11.08995998722283595024095699590553868732788950796766167666538820144967617066507`50.8627433221757 THRSub[2,2])/(1-0.12062340416832649911385393240035297819745055710551533143947680811086830491389`50. z),((-3.34506752412056756341205192888871390107497334624288797310148756165880601011954`48.9800263536682+ 19.64293789054099086783948639070765015816286955528933890198915211640021853479917`48.9800263536682 w-174.12893838608458912716847926662524073030854395521370558757363729654222823630779`48.9800263536682 w^2+124.79870368919222054980273887011174261807774710082569973923097946744549170742672`48.9800263536682 w^3-28.12349876582799571388429765882159875367681483795950457346305517165575822051906`48.9800263536682 w^4)/(1+0.61383803360674542677549293512365240118933874028195322480089550881969697262439`49.69897000433602 w)-26.77896000982149127945888528798944900939102320963551863668416214230278272801395`49.49543956573135 THRSub[2,1]+5.74367924624557734927473092512352073231917849561011100342128024084674830097796`49.49543956573135 THRSub[2,2])/(1-1.45544412323685139062741644942468064164092944775780555850633946132330293422885`50. z),((-0.07229139475862451882058162454974250382043020827341764619376068683418143801499`49.00696366781388+ 22.46190264013374399861804663665642862481154498496688437609923086420976818380964`49.00696366781387 w-152.39487938593406347639728590379321744572460219410704795186288651398767282649937`49.00696366781388 w^2+114.26712625141847865579271980330684410898601092160065238115555023290771584693686`49.00696366781388 w^3-26.75610155991360089952556716049863347190333552307835296754210101911525873970335`49.00696366781388 w^4)/(1+0.61041487047271349124410088225392275302242578082129206283472646517486117583155`49.69897000433602 w)-18.80218726317332920290909038431115572764096479424775643120982935416752404731824`49.38434859726626 THRSub[2,1]+4.03278292838495744379349882276695165493881449480498428449836272437286715381082`49.38434859726626 THRSub[2,2])/(1-1.31977887452949501729650097553983251484531747200772102739240682785007640518109`50. z),((-124.94837884217066352656210362601482595602396750710858646561683012024850354242546`48.725018083556655- 88.28047511257773299714078284306407408553602267229821093993498640036257901510798`48.725018083556655 w-984.75678576329634030227535999754039021403768509526561202116176940277137004798783`48.725018083556655 w^2+512.22759120029075406177766395185662301247263451611176441080683629050435478517918`48.725018083556655 w^3-77.28784989367266934918483618441401575241478144717389302915561415954838282332572`48.725018083556655 w^4)/(1+0.6393775236838561929309965238466909400837628970794830110079050291451292933245`49.69897000433602 w)-323.16402922416599733408764474715679105240187308155036175733282992148199074599332`49.92740343038974 THRSub[2,1]+69.31376450419198328090838886329479444910637586135319333615631095869240598724383`49.92740343038974 THRSub[2,2])/(1-6.49622382264686113428849834515869874146273179890203503980988570856695168352201`50. z),((-66.30636901928623547649034081890993100023805254328673888983990519643711416193761`48.777972418554846- 35.98678389796036273153065393952890791489089314325985294429735625281840993792291`48.77797241855483 w-593.59895179199284915319024263047629302403513227109089649781563965280784711475516`48.77797241855483 w^2+325.69723595059822304604082400190409280307215109673700279657698757098758435798278`48.777972418554846 w^3-53.7072148747915733025051948874820478241480501544321352381970668776741609149362`48.77797241855483 w^4)/(1+0.63500573801229268240611303040887733091763973426974367870644110650613034744179`49.69897000433602 w)-180.2352228303552973381564686963060038682667231820953911544598470265019200097129`49.877382372372324 THRSub[2,1]+38.65771144336756963567946367936269009495118359120441701323706258979204331695673`49.877382372372324 THRSub[2,2])/(1-4.06535701940117659937189869391309420543627015907322511072985130387370837088419`50. z),((28.36569233329431579719464653173474635443823819856452861820635496899887182867965`50.+ 36.88882088282510121782219548963039533814310818388568889366480227519547037521297`50. w+26.72147703650538295272529928729170063740567648889963209388530159711785982536159`50. w^2+10.47835638259582336170980635666835601547454337639490556267544034959644649434936`50. w^3-9.68646222255279728499976840323713280175243583309964854846855020220424782638068`50. w^4)/(1+0.25899440152510086621002042160947420912592618607632397791966144494502420771842`49.69897000433602 w)+50.5100188289010858398871660133809868049282759978771789369632009824052255410152`50.78495679667209 THRSub[2,1]-10.83363008752506089974113580490160004490006315210833774160389865504518231387459`50.78495679667209 THRSub[2,2])/(1-0.14094904239117020207015457763236740019205097920563141689185214239087462440381`50. z),((-152.14002730936634673943102413129435686936808319019823155259199135782970360188223`48.711085379071555- 112.55816974833324650005402712942174104999854478979863534006295763883395932676815`48.711085379071555 w-1166.16103823300602339126463547561441260148585216287323227966990952485617532317511`48.711085379071555 w^2+598.68341382168362153518985479748445263420158505602355308389712170458499035220444`48.711085379071555 w^3-88.20659730983262276198633111374206049684926133677741046288182010958949962886738`48.711085379071555 w^4)/(1+0.64045616048974482366819955657064253582170883010949917582845392069174130548631`49.69897000433602 w)-389.43852887099967847024726907939258751847682256401460462503902792518529415088352`49.938932187783834 THRSub[2,1]+83.52863573284377655788724251566106831276886192951842496540397610602554004362`49.938932187783834 THRSub[2,2])/(1-7.62338975342022696615108267695741814339864989986681640661722118090767284440755`50. z),((-119.48654638326208201373331013953803559221215238656924632708829978718029130334166`48.72836667103633- 83.40542071378151726502777576017024470727662674780605541990092895439049422391608`48.72836667103633 w-948.32056089571877910205170725804289502873482767496642130300382345862485262370346`48.72836667103633 w^2+494.85990749918673247031859311838120284302006136293662120331961350285000210475426`48.72836667103633 w^3-75.09390456823519060183769126821155861730531934051663987476562136294126260948528`48.72836667103633 w^4)/(1+0.63911394627810846973615800029972190546912251889645535034028395574149335637968`49.69897000433602 w)-309.85184574968122655847247210667729247101389215840108657122782831622834754047553`49.924540660981776 THRSub[2,1]+66.45850381010346747707885419653105915538501156628076438433232244152497880516561`49.924540660981776 THRSub[2,2])/(1-6.26981638454317227586998227854148623631831704554228216357889558555696002580239`50. z),((28.17255988657612058192990716317442644464099375816374106016789162093575273928931`50.+ 37.46679301509275859619833710420607978240564032333486106777084365636974017080788`50. w+26.15880782735878254526761978482264461202826785397940986480278104504540450676372`50. w^2+12.0069872106843794799847673960407922117377006296155296893865979277570917063114`50. w^3-10.15002399647099461362669569150632730079123189632398292885522541343774788153528`50. w^4)/(1+0.28298149847512915991927852621930942478301465613839044641673953177201395694004`49.69897000433602 w)+50.03929502238898980416876628794730931299766318038824147138243473423595135429603`50.75689780038757 THRSub[2,1]-10.73266699720394175837708329360817947968692513442306765044606287945402333465597`50.75689780038757 THRSub[2,2])/(1-0.14895489442071076115686269758801167027300053767364544791244350394857642813156`50. z),((-121.69665748419126588365590949108344361092771537064262529015503183856278396185086`48.72698548765123- 85.37802320115491849644065221666321288198219574974666206986957770573778961696026`48.72698548765123 w-963.06428123319026518851322744109642197735531139224434398180133720220272811895869`48.72698548765123 w^2+501.88776559433173995574069537029164949612971693548473097940347266288993738939555`48.72698548765123 w^3-75.98171338891972623615970289304187923942035817714673240478067335902904558782736`48.72698548765123 w^4)/(1+0.63922286870940817485361389556264295666197246480929104070728947408822447305182`49.69897000433602 w)-315.23857350010438748462327884497902647260960474110307069112994272550186557455629`49.92572590466344 THRSub[2,1]+67.61387490643929113506493497805425865564336504828167623987964810240687802610131`49.92572590466344 THRSub[2,2])/(1-6.3614313500424783647098132839834240334859957963979834864374461392081951092012`50. z),((22.38983992391869815291131146650620606540676017490722342591064011877076452394397`49.25828511068685+ 39.68561430172522166628075892139256948453471475076374517337840062076708359060432`49.25828511068685 w-5.28064266250410731207607679887666081446836823735721329228744228752227018603059`49.25828511068685 w^2+39.39450390947467580347836652093980376561951326092695186857605915162286566846848`49.25828511068685 w^3-16.27535336275367817641555454851612853337412567863210812336482188815327481610717`49.25828511068685 w^4)/(1+0.51907102900155253072408463159056797347224513251963322482428706657873866723506`49.69897000433602 w)+35.9450089556493860776201453858759378334263533304265496929460876164339847289075`50.19670570911039 THRSub[2,1]-7.70965720360142672803067132656575269318795677696513245277271118128704619466826`50.19670570911039 THRSub[2,2])/(1-0.38866397042520417478562513273527871786081952029664591984776948725111276810292`50. z),((-157.81827820459526415967714730005499156683771215674191440088626308343439868436888`48.708643247581875- 117.62914451674183479304488750305327318332007820692945456349924221177626985060628`48.70864324758188 w-1204.04366538375298759329185629262652346049155305017358559115994261545342879565425`48.70864324758187 w^2+616.73591221595923713089341769997028547544997871605826342456476640624784061655026`48.708643247581875 w^3-90.48605385110594930356659039843450569613153699927362587581266414835878833682061`48.708643247581875 w^4)/(1+0.64064225673984557619731781596565591996113211388114364674700693931322633905221`49.69897000433602 w)-403.27819134694270904460192096942725373578884692593232348622077348764871071091552`49.94089164736996 THRSub[2,1]+86.49703264254316676017209815789298108863927812109239288619828944471480223629376`49.94089164736996 THRSub[2,2])/(1-7.85876830956796597560341684870415868204277374584787781626087090792703105015763`50. z),((26.59079977824190225931585782853059065458401732213717331961227956678668128772288`49.91298728160733+ 39.87868784855946303116053520373517673693157625208754000149721460378992765911555`49.91298728160733 w+19.30481877182170123500552018566801788438496261414474442452633327922237774989887`49.91298728160733 w^2+21.69836128536932984156282295988217104488913772364155622502983407850756291693038`49.912987281607336 w^3-12.75420671203471173754161599272178689715752057152810890937904695844631633066269`49.91298728160732 w^4)/(1+0.40523689726520285837866444190334722990772916046729253047480940436988035459088`49.69897000433602 w)+46.18405395939715587555794104643224544313209163785542997912430872102231397737329`50.56365949468628 THRSub[2,1]-9.90577648037062795215908114035516890711855022361975425947282117347475737307524`50.563659494686284 THRSub[2,2])/(1-0.21452304513145702413105947974021412691146723346220657518854139397106711151377`50. z),((-201.37297124283714698472072588197794434497283072055661466643425201402056372622578`48.693623296941006- 156.53521601735259076086313957862298346237056545716383418226884227826447605744602`48.69362329694101 w-1494.62929471438548954528446840037808331063575798353752216968836190904665309987968`48.69362329694102 w^2+755.19501327419693323988309783959525060681247167770963070177439678396269830246239`48.69362329694101 w^3-107.96561049546493132729520170700733541168116106937537510512915773191467294812264`48.69362329694101 w^4)/(1+0.64176765842844657891374126818261571539151732540600753247755668451607889005122`49.69897000433602 w)-509.43451695049325463894627596267475791962608696170980661065596945935805619134108`49.952562693652695 THRSub[2,1]+109.26594838845624830820302129650776119613654709112239756589171644516692390206021`49.95256269365268 THRSub[2,2])/(1-9.66422582632076414294316184184156235034885307967891212317576766594809166419214`50. z),((23.96566003840452566003954249208117832832485891724669352441224302469656350111035`49.19705099129264+ 40.23654232212644743965320551072388672376768652901483685009954317298564960519442`49.197050991292635 w+4.40435917122909604940531648404054172516800879423194895602143551150111259803447`49.197050991292635 w^2+33.33998149527677690036763007598226294113828540558124888645178643303873609938696`49.197050991292635 w^3-15.20105436129152165097749355109556059615456319356979789191204794543279541467471`49.19705099129264 w^4)/(1+0.49165972454671954726220632450894022057087996465960802738010937349063472421073`49.69897000433602 w)+39.78577240722746921835422641424957109201484272562220213393253959094039013515305`50.32070700479666 THRSub[2,1]-8.53344249318984862916826039935790039148636507785972334403980452501623771014911`50.32070700479666 THRSub[2,2])/(1-0.32334204821005599437696197035697590400886142223072022305254683185929720446736`50. z),((-128.94171815144798757291902789388769047014644737410361625556163071470043825336536`48.72270170220812- 91.84515612162244202244649294537995055710915999496327020630723153654909388936443`48.72270170220812 w-1011.39694545551601669567794517111748266603391654147984126291951558285073378298367`48.72270170220812 w^2+524.92528602377281289205291457399166686838682283635198515013159868154281576150765`48.72270170220812 w^3-78.89173729450542345640680279173570633576466526737739170678684551601280930917212`48.72270170220812 w^4)/(1+0.63955886363073161200733207317968521619817611378051802969234352934049082853894`49.69897000433602 w)-332.89703842225385087870348715235941205519265018252312137850137148439549538852454`49.929362454032656 THRSub[2,1]+71.40134680440346806342237447652420650055452027947273823948150175590461834049486`49.929362454032656 THRSub[2,2])/(1-6.66175832581851293924233560594274754128943317540769260752718985155731516515965`50. z),((29.31634454691955051338306903248139018200170614215078827850520150097102701981328`48.96875503979368+ 31.89553114103789992717919136144268956561403795647286075798855531246815586024897`48.96875503979368 w+27.41271025487036316303664139061462991787127375748035496347525154323019634238705`48.96875503979368 w^2+0.33967861836231465389097681507832642859438384351150645295388832416276936288098`48.96875503979368 w^3-6.30475485129010610525600962306377170813834351041649020897639322167267975950523`48.96875503979368 w^4)/(1+0.07224815318243617277489252897727846196299946211389881061076102289916885904953`49.69897000433602 w)+52.82705377704613941536452025924723349124079007433993022637339407143071117517987`50.946852127034504 THRSub[2,1]-11.33059880997005009073706938381621500826592617355180922721730774676672954084002`50.946852127034504 THRSub[2,2])/(1-0.10154198737185536292590026659111363182977105505883690436463764503284232414391`50. z),((12.165353915312243798852910274684560037748112812856568187134675584456043121021`49.194081154487336+ 38.96287347946708311105502494791279547027368700795945244832638414840044649351178`49.194081154487336 w-52.1641273419245389613735639641973925988809978942033038592635214149872347851428`49.194081154487336 w^2+42.60738915351048978814955887278974967547593540396333813167822210157367238577309`49.194081154487336 w^3)/(1+1.10386907423925334296166199737204765676034252687505212060516922803402734248793`49.69897000433602 w+0.50016566617117366073959032474524876419007153552552057179602429279725026800123`49.194081154487336 w^2)+11.02475834326241848876280763679213057625906837070869744807697349718673078036374`49.36318922867252 THRSub[2,1]-2.36464282660136200343501746565601569842680720122981130818016391835774514216289`49.36318922867252 THRSub[2,2])/(1-0.81249602689186787479196111566442031851672022178747155557593259393665355909593`50. z),((1.9950320313172904025630931240597583479842488451217199534448461936384836259148`49.11837010766102+ 25.01173752020155536091584347792314254429566225150479633165843756114338387548687`49.11837010766102 w-128.97386888136853120084780930610584683671054742566215392138204520066222081916928`49.11837010766102 w^2+55.72787409326471392987441663956046495430590589773758570735142056600164551589454`49.11837010766102 w^3)/(1+0.99958397476934632156191673569364279269609161419532638109617617157353714270263`49.69897000433602 w+0.34464121000347407558956244160445208623877211948732776398421717384358928087659`49.11837010766102 w^2)-13.76347746090993749567590264417576847054718835728908549951184304274505733293826`49.278025259554504 THRSub[2,1]+2.95205638379547176405676341199030360304655744217228092264120789888025653356676`49.278025259554504 THRSub[2,2])/(1-1.23408283677092947228614807259830895407153890523125211712968430854958671814233`50. z),((-206.51829741302077577769920836701292910844946789342481464803838554411438579535907`48.8764960850217- 199.97856046491407082527061307696473201534573733143487111908151461403643268992711`48.8764960850217 w-1564.06605170955598968383964893250025986669835923579847432193251133390584085140809`48.8764960850217 w^2+483.28806112743638701192715203062603539003023353524904589104845856423736074429709`48.8764960850217 w^3)/(1+0.82997453730338296189571275376150630084696530078323477783804418784130475195432`49.69897000433602 w+0.14397231031473988999343450466127757819450536039395198443506121516323401386083`48.8764960850217 w^2)-521.97527621560621913047510776128851474188483132659238493348562913525244210303445`49.95364370819205 THRSub[2,1]+111.95575033359427480609925715375357220223019924726424031952170185106471556540012`49.95364370819205 THRSub[2,2])/(1-9.87751323950368814042647412868000213030096720538865187863453551465956891708714`50. z),((-185.92116969085998941426889514855847363271757968722672230025486665022270728603995`48.88144800436679- 178.18870314187116459716280533792336539977831291525506806366001093427422722561657`48.88144800436679 w-1423.20096134135617726604916518829142553851020089740411810309771238384283130713032`48.88144800436679 w^2+440.12982181933297313067753521956237914449592129200983714020897821376429283188227`48.88144800436679 w^3)/(1+0.83213381027589920146381190661426447907639586264771239571236010897763704620023`49.69897000433602 w+0.14622424134336049422191952808058801410398780855717723419886890159049798935374`48.88144800436679 w^2)-471.77367348471763257622284444965609370374994394156603654217166634774374825344168`49.94899008002497 THRSub[2,1]+101.18827080384713869794701622331902873450911330634174186953012773944914181967835`49.94899008002497 THRSub[2,2])/(1-9.0237076797482445805214038093127003575255671699199717579608351203869773493379`50. z),((-205.77502444505412745850496750786461705054027109387164586657914075136696557869789`48.8766610066162- 199.1924388734046990109221269607442220973976556318493392818473217718329475834668`48.8766610066162 w-1558.98313400835712531787025691710054144361221974705594157875414340485910557984081`48.8766610066162 w^2+481.73027793725661067265967428845497743565348113673640443822947911044697390204629`48.8766610066162 w^3)/(1+0.83004587489313654986908305371849805696968262018814606978911607916258820493015`49.69897000433602 w+0.14404660026164793927530781491757635586408152916665032725017829988553443127562`48.8766610066162 w^2)-520.16368895150803330251159300885886592358024738699691527455691474096002001723238`49.95349060672066 THRSub[2,1]+111.56719244457441228245946952224798808164592629823179204099383940380331606919859`49.95349060672066 THRSub[2,2])/(1-9.84670260410703202658973070637360716049538654616789523751483496452521874932971`50. z),((24.4898833226846175264271831796251611261790718170438528254461772016193003478596`49.03710657678572+ 57.16024599252274133550446301272691083848592317468815229999545852390554323571498`49.03710657678572 w+61.66085035392435140730770580692994523499023848318880062495619415523134473032741`49.03710657678572 w^2+67.21937882626604435781499428015380980656944449652955271138183336146915910682689`49.03710657678572 w^3)/(1+1.16688788474755410799366285281084432390827391767951562759633004204169069425663`49.69897000433602 w+1.40786523075073562441377341294509035068858212516042861155897550866578792059227`49.03710657678572 w^2)+41.06346750213121716425685108538328342496307411474270352872160630453085055354902`50.36464897049618 THRSub[2,1]-8.80748863975180953356694554792632160659865195896423538838671238755313103448476`50.36464897049618 THRSub[2,2])/(1-0.30161160303783729227267007640582230816153039951772598363875946506267216818575`50. z),((26.94304088308849607044285494125344806093321669558469669776760607315280851214662`49.95594996374595+ 40.24607631702706966884098556103232299028644649223743636629379329240111888378091`49.95594996374595 w+54.48991250812959095566527635467439406953455969049099489955374955425415322915446`49.95594996374595 w^2+55.50997480468142142782304265576781348245807363336415836676470494170844415864673`49.95594996374595 w^3)/(1+0.41034005290672331226873309183870151807385909088346905322760414621317894489052`49.69897000433602 w+1.21392513626502940557807862459264513139563879388041658315562558372994468836597`49.95594996374595 w^2)+47.04257502357313197137964903015768741123572443521401369661166313822254725926975`50.60227250835495 THRSub[2,1]-10.08991617873694594504951180363206316949632723159786080635883422829796934738855`50.60227250835496 THRSub[2,2])/(1-0.19992171732744263205355373529533712746541654152311877876612420096344348507151`50. z),((25.61671360235827975218860880867245355586568046666948008446797269340977616709836`48.55558954569548+ 52.3045775169125348074255521294080729556748059324307345060589491875221511648524`48.55558954569548 w+64.89654688729635451171913746628090566626948187608945069352322749975643848965408`48.555589545695476 w^2+68.96513344297317519890006825236578638303581605924238479096646663969319926473351`48.55558954569548 w^3)/(1+0.91512421801379050859912734706511182701802020787463075539575137095322021599526`49.69897000433602 w+1.45673393252468976654999559997350823523785570012369992662996803045743259881956`48.555589545695476 w^2)+43.80990316094640708228676094739112260100703443402627024511826842941813005014391`50.46584129790279 THRSub[2,1]-9.39655727755178657455834584599634849228688030863257220990338169679616557557942`50.46584129790279 THRSub[2,2])/(1-0.25490150002424954924814267265273982893449959629873131705912493981861190319075`50. z),((23.73156773445744029560118736337970402318587092118731254136008684507890448745955`49.16736309693407+ 58.07364512665333986520349393726262688291681727284489938919933294505882898931057`49.16736309693406 w+55.64875933533412195158349735617604932763595692687182727849521725459733550563592`49.16736309693406 w^2+63.27793461651605433182008114667640721095055586184476921276729519831095155238906`49.16736309693406 w^3)/(1+1.25056940886628688360521728393297759244219679949134908739707460795085953807993`49.69897000433602 w+1.31671277155408490428157080349125425109503673679241385007474262867134850095783`49.16736309693406 w^2)+39.21521669656563560413330598459585476554708551333453499501986282635836589493447`50.30159206048937 THRSub[2,1]-8.41106697924332642777213831070503830316820862293577810664378600190650406443484`50.30159206048938 THRSub[2,2])/(1-0.33304579493154376722916633801777629009560139986554265249371564622630182000315`50. z),((-100.2024894004029501662914427932695833928133459133874648984453801725214936177238`48.916488505171166- 87.29011909698411210622672579317509941524171526992347013267988437018349037336739`48.916488505171166 w-836.54276017040926982356263868046048264114350372742492392386789849544119648218418`48.916488505171166 w^2+260.93303555172443733136721238976656810762139542939451018279470072591368427746589`48.91648850517116 w^3)/(1+0.84849740170229546750594889316563303866173866259434200737066128436233347507597`49.69897000433602 w+0.16351426358213953083238710031110302518022802253300856992408913270610502856764`48.916488505171166 w^2)-262.85060456925548954229168037266401656546254825892457325860859029009754515223519`49.912328030670096 THRSub[2,1]+56.37745311146605452895269085712078786800296046012476660034117148296613785178703`49.912328030670096 THRSub[2,2])/(1-5.47044108869106538301323236443134534718097995579302240397017981911873187309252`50. z),((-203.14140110592529790892268984679906166506174423064853155665606781809037934051574`48.87725310995139- 196.40688351111674295360876334333098971489223260734801526216416880554450972331644`48.87725310995139 w-1540.97273085709550511917820773818793976871697110500046774074060596985157273475477`48.87725310995139 w^2+476.21082090825444453959187435048135024062765582825064843429063579550040450377`48.87725310995139 w^3)/(1+0.83030231701830312482556154801090659574045435186925019068763140339190175862589`49.69897000433602 w+0.14431371678772837040410312302149985111334300126455093486797815658946136483395`48.87725310995139 w^2)-513.74473023079802892938743095542026675941223131475732704292514064030079287755994`49.95293988107496 THRSub[2,1]+110.19042351952552355119355306472159207528497403252531091716266898224371565163`49.95293988107496 THRSub[2,2])/(1-9.7375319333425553483491320947868415416299644732360360182805280700287203629731`50. z),((28.2644039933675810235987534563033785955053784667174086632250397267321909872138`50.+ 27.41396060108004304963322341892058969973895183472240633167109949051652138251051`50. w+34.81121763080567697511235558227649552450242666803375443184221450292730144914025`50. w^2+24.33918706259311335720082911949671306496472240500621228229397454502728160609532`50. w^3)/(1-0.07441316020805836466314689780520342632936011156824175192323485853138588457855`49.69897000433602 w+0.65797011922264453203374903527756146381505144237366765558540756907717774530144`50. w^2)+50.26314765973305273457822039246543918521706704146265037730625266890883358381511`50.77008088177964 THRSub[2,1]-10.78067998004042505943838315603522880646940727462317891875142597494825183003755`50.77008088177964 THRSub[2,2])/(1-0.14514771265890853296820845572813747384325757907799612769632605229265916599812`50. z),((28.30380911511533617575183231679816556180347294576358243821536573822823921064077`50.+ 27.12028487730346836376889258116092993116353517958967397215558093933394606426229`50. w+34.277776373559555534378917785573604878856197083704415793763914759591480287165`50. w^2+23.31366821286037386223798856037880752695945432577801331478995588933246292462915`50. w^3)/(1-0.08502986657623822512051262695235211385468393655173200290375739767197070860373`49.69897000433602 w+0.64024137494486991195985361134375165794017105376231673583381522817430246562398`50. w^2)+50.35919019023669787529164028590002223011803808951614012294695232851066313231287`50.775825059853254 THRSub[2,1]-10.80127964070717145304459042569871608923181577715601438214305127506956263980649`50.775825059853254 THRSub[2,2])/(1-0.14351426587521572589194035330702784611316659241338903598961739469885524380102`50. z),((-13.8518703924769898277207368803274682214250576570264159561674012303502091592076`49.04537564038603+ 6.21096123066145570829621897804313818421786484031242779560869399339496327287744`49.04537564038603 w-241.65817260618920367711613158885771903663607697352871544122235750785163682867288`49.04537564038603 w^2+84.3681562345956323286539059027280368611464239962170701098388664411763525087022`49.04537564038603 w^3)/(1+0.93024786602199763455630655677579872688732161148236931302298218462429362431246`49.69897000433602 w+0.25628472641478373785172252950507976750128220672641775068378903844971576292807`49.04537564038603 w^2)-52.38730456562519926402765485659026414134874817882284551034870452834987476736219`49.67318075238339 THRSub[2,1]+11.2362792987468750941813098250569753047562016838141715218087315861601352234847`49.67318075238339 THRSub[2,2])/(1-1.89097896213603249178815310739184704197122230025704923006517055049178411009539`50. z),((-192.81772996708939028497749899188133873771981512151989555959157769336741479422867`48.8796970726494- 185.48593113514101739366314424476017248670935386646969638067372008633274924939609`48.8796970726494 w-1470.36952118401713934415532705955494321928357820511405979929348296919629134690549`48.8796970726494 w^2+454.57807329937527257404409929193442215088062890045040378403730201403680255822466`48.8796970726494 w^3)/(1+0.83136621292722015809087625217154595371531499582492421920682543076008974659349`49.69897000433602 w+0.14542292369266137601904191970414879160039937790611713489981632367211646685771`48.8796970726494 w^2)-488.58273462504321412265776829537350875650103918251649429809402287504111453896119`49.95064903212364 THRSub[2,1]+104.7935585217104074435907073756402768270176953877838218336451329548976024553634`49.95064903212364 THRSub[2,2])/(1-9.30958839022700996286544232307887033663768957038497748107899641894830323376285`50. z),((28.78082866865429040923432962521439745949103447660699617388574995402623981800924`50.+ 24.12867955206397676153810704310407825316808398615151147467005459011037006717521`50. w+28.57602888699902829664108316525748634527941714652541588879180422314309392849891`50. w^2+11.15742752774486992164260059986126432498979577747929037846279118732056803071997`50. w^3)/(1-0.19166579630698652876593066593404389594344665797611322923557696802267464240783`49.69897000433602 w+0.43376707852645791943339281297270856364515510008414394367978982340174321393341`50. w^2)+51.52183512037728700495748053436804987150207908637011058701705621828960168817149`50.85012071062267 THRSub[2,1]-11.0506492784209571707945983483481382366508264578427334212702228339950696660553`50.85012071062267 THRSub[2,2])/(1-0.12374054050838133500742030614152526773007098446552689132014134312745632869528`50. z),((-62.58808914660129967170141966695006896370967572081700855180426801902998451823938`48.948513600523704- 47.11966140133180245362908271508326495277150773099494329666238524220291477691391`48.948513600523704 w-578.55049563524022211057395051952843087411837599813363351334109774711684447424251`48.948513600523704 w^2+182.8539267706544659101569700933672567492117302958752991416235932065214173901775`48.948513600523704 w^3)/(1+0.86530510998392451112738891762018599316829210291797864804674621535064856885399`49.69897000433602 w+0.18169611829284178487759408227881016670696632724030681094341466773914719960993`48.948513600523704 w^2)-171.17261897953032471865633301243402364145835823056536307362624017319941635595491`49.87176295123683 THRSub[2,1]+36.71392088406886186595625626602034657413467891314945122021221992795401523321361`49.87176295123683 THRSub[2,2])/(1-3.91122445922826169863110926283394263231354988349890037934904131351121365355195`50. z),((-94.05408166537475458784550943070335561031033412175925271071020947151024810292528`48.9205890407407- 80.7445183756466398272492574154532803813508091562934511782722646603766160683102`48.9205890407407 w-794.41262091645511403908498584728695450068957300812858734309890553007665244197295`48.9205890407407 w^2+248.12943823959508695663796309983553578166885568196124906804368299237210938801059`48.9205890407407 w^3)/(1+0.85054483955205538920033595222670996162283463258982515995218595129622039002204`49.69897000433602 w+0.16570589449938631070928746232466986974196587322920622486385609321701144099116`48.9205890407407 w^2)-247.86502372978165763000044936324052276409659051124916024091975547939998470700672`49.907554591492314 THRSub[2,1]+53.16327415794981661037632344019606204914292288397857241138554544170398084988059`49.907554591492314 THRSub[2,2])/(1-5.21557328485828259737953626426034157812249125627626070986509621462168077206398`50. z),((2.58431543144017944550270000030631969338665754237403476411131619502821164591094`49.1219832872995+ 25.75710977014980657295565459887323719756982775807695508950476232426025816020955`49.1219832872995 w-124.67866467265271949515094619612093065755965186306105852278651239641117814643703`49.1219832872995 w^2+54.78111207395404465957855219115477890152845817901544788354970584064984342337657`49.1219832872995 w^3)/(1+1.00365903765159550299122727825988687199615294137929816015712044851835365043135`49.69897000433602 w+0.35015741206770510770436809448874110926754021579344040970128971917733467190866`49.1219832872995 w^2)-12.32721064021883035430014598735033631513957704870464691690379705327466000220671`49.23884451664994 THRSub[2,1]+2.64399901610647087257224320972876648979678275214915662750684960053608657515176`49.23884451664994 THRSub[2,2])/(1-1.20965547728258757097628883316597687313564856403508039408768782935263601608183`50. z),((-167.70787236653042083146728988228291202709713305126094910274480198716862495213647`48.88660121528686- 158.90971051956447287875299440694724468424603830244963721352786986312500763547875`48.88660121528686 w-1298.61761274859945989708311941024489475836171334105762059481891663354672484579585`48.88660121528686 w^2+401.98744448325559702495901311722564434857044032715590022885099417481575582125114`48.88660121528686 w^3)/(1+0.8344194021357017520776077406246198805403207000603503005276731335483973591037`49.69897000433602 w+0.14861535782909075554625402565865710748754699331053551947832676944315681411438`48.88660121528686 w^2)-427.38220643022152247330058763787742906204697069360636025737973731692116290314666`49.944019640839585 THRSub[2,1]+91.66697692470506997711595695756592267066823146338346847347186606115660840008202`49.944019640839585 THRSub[2,2])/(1-8.26871821098555057399354322783698197842144573788295282590979979486693863519417`50. z),((28.92664270816349471982112512474521311791742285772822714403167838087699567901572`48.62919866035213+ 11.33837641633630173907531196505105478475460884380393530487939109281083686465712`48.62919866035213 w+19.81940561756009544251193030454518688904309657445141552266410655693021721843309`48.62919866035213 w^2)/(1-0.63411027801509377846631935599385426594076939746829426209628631809201749124489`49.69897000433602 w+0.55025639806277079734389444265475896455139445450368307012981152314904088179595`48.62919866035213 w^2-0.11467913329543799038744157896905187101824553903202790283995906682801638717842`48.62919866035213 w^3)+51.87722925992769401496107529185048336438078555402182202392936842392398989993587`50.87485586770633 THRSub[2,1]-11.12687591092738453236968307294943957727264298772476789629654414695108451463694`50.87485586770633 THRSub[2,2])/(1-0.11769616192789555364699786000782095351916117369407355676895731047507970854719`50. z),((28.96811897630066951914530019551705858858301255679967833090131534721624450846543`48.55433384558066+ 13.18574906821558239696321758275447340196515697192041127112223674694627043263215`48.55433384558066 w+20.45562675664049223857608241160776233900275127829199103544452037087880921723798`48.55433384558066 w^2)/(1-0.56978401078304752158921901574434506922853873955980199488769501759813013847182`49.69897000433602 w+0.49639922129627998683476809228644549189235470566366158720629661543460156608544`48.55433384558066 w^2-0.09407447170014233236563179801940910402483577047939149329059653169994227014006`48.55433384558066 w^3)+51.97831981798361243381856517338330436934303788584440670691965461750173862373663`50.88209228414998 THRSub[2,1]-11.148558296654246550865201057490500026029111062020171859956565425812653953307`50.88209228414998 THRSub[2,2])/(1-0.11597686063447655284073559677078254231133026621121460694348827883514601582754`50. z),((29.22016789552350119184849656383682223420860614042340049792366931070283443523388`47.572118148687046+ 21.33518912092219209622389287009856257289453962649851765705338434311373179301421`47.572118148687046 w+24.02888894166466334223727223611944602643422913456949859435862077364192904653477`47.572118148687046 w^2)/(1-0.28810559551627090129524326380196400692468370164446600612763621943380478212576`49.69897000433602 w+0.27262341709177804451112076476956294121999869378067615332111475118372133490244`47.572118148687046 w^2-0.00819116950168853133027833532553077271319360805956258865882731365093102706553`47.572118148687046 w^3)+52.5926413817597390597680319005433647559052690253185260262589289818563817002773`50.928195525023554 THRSub[2,1]-11.28032091981391973827229409842642667967218796478473622995780555348158878580357`50.92819552502356 THRSub[2,2])/(1-0.10552876459576206982742569259434005387040670350608388858622197998813554091199`50. z),((28.75171237751768452856229103616249661694301650705573429292636901574401009896346`48.00773044757924+ 0.59136140125078397335427476996045474471112310983211171759589988667864149031434`48.00773044757924 w+16.88187149243696838475099091944152451257102057345042306535046335693177054603093`48.00773044757924 w^2)/(1-1.01024989921183421495062243444721416050415255083722941947426715864996839376496`49.69897000433602 w+0.87783538870436054054157985367245656987242456654593139317659321569059532493268`48.00773044757924 w^2-0.23993501285967007478853327844514630391075670077045699939703544717540738168895`48.00773044757924 w^3)+51.45086966828349187332568962793359634257731019336454457330469862626236543272914`50.84530658663946 THRSub[2,1]-11.03542826930626142300379227670222650069606498237731021407676138366030438344063`50.84530658663946 THRSub[2,2])/(1-0.12494748798121490581836402434456121617907894149296485592470607928893845434318`50. z),((29.25239393706118236422757883330799098470952938546021083813564616457965408277763`46.388203888205155+ 22.11559078352450443193721274376307516112361675604443344254035846200805012160901`46.388203888205155 w+24.45906195140391323718380725665751832826768178959384344425695220410305966091872`46.388203888205155 w^2)/(1-0.26138256298799635641556333509631381489517668460055729286963702726475814294305`49.69897000433602 w+0.25274436085419193029339208221488022865501648996566820264656319174327499209968`46.388203888205155 w^2-0.00052039854114685385174700038569126681613689119625797169022894065861131801633`46.388203888205155 w^3)+52.671186262224949160516778701736607814725560660344034216992705166436091844012`50.93437632910582 THRSub[2,1]-11.29716760092705510247625904954761823422367226852702986570901798539159140709355`50.93437632910582 THRSub[2,2])/(1-0.10419290972294024166355892571225875752777528621653406977978440859773294105629`50. z),((29.08070639404742949194018346717847454990447444859318133236548672964123549199685`48.30137705654564+ 17.3629025842425800969730503990060301614529062162776541756960301320311602639105`48.30137705654564 w+22.10473086004835232285113106191553194376226915602127650327046241440302072389083`48.30137705654564 w^2)/(1-0.42489594793058128792232384776564969008223290273666460626631910073921846740959`49.69897000433602 w+0.37844836493561216284553673367186300643981921592475474069463297044269813847584`48.30137705654564 w^2-0.04888395318148662756650286099582145574913467338994006221958751267834021658728`48.30137705654564 w^3)+52.25273035203775078551958961167092775778955319922864241439070964329362111879283`50.90221692876861 THRSub[2,1]-11.20741517865488650661174519090251738786930417847737532015491843454248333066051`50.90221692876861 THRSub[2,2])/(1-0.11130981363028349115155250492218392290957535141280669371297909867811198489422`50. z),((28.74163149266689009049869070480674584209821198211811641222949953220418862331417`47.59851502726637- 0.23703579773169675897889823900364192126790732690901182877551971606473086135973`47.59851502726637 w+16.69566506164070006803013632942797154364391251455725948639937752279126784144023`47.59851502726637 w^2)/(1-1.03933965916200903424116985837370057643345075272870889131156659771510834846383`49.69897000433602 w+0.90385542721339752450944564604070972864197005930931720738169165040767685057025`47.59851502726637 w^2-0.24989228061033512160931413535653275811716752237667550050317724217126624730503`47.59851502726637 w^3)+51.42629941833010058648220185069969344396384354604048685762905122358359267572957`50.84364909223176 THRSub[2,1]-11.03015832474229772972233011990560188842742600454817096033783595505811676929642`50.843649092231765 THRSub[2,2])/(1-0.1253653673889151445290235992794432334885226269367910447966572013509371161166`50. z),((29.17862418156226936472318348441757126834368072474755002372283962550264080387921`47.92081644184235+ 20.26068668067891859339019268195025660733913396328340040213533219799858254224588`47.92081644184235 w+23.46697156565240077367214814728781007048921794052718869367138494706067535156749`47.92081644184235 w^2)/(1-0.32498850353049068101494821793045384188731701275908933415200567611439659389828`49.69897000433602 w+0.30052139907295230131006464095051498359988469724439420428133190875256687411847`47.92081644184235 w^2-0.01893932898722212799498933771049180331575902624773122887943354101616110808131`47.92081644184235 w^3)+52.49138643726553461789142991664260967976511981302855448257038997204004273634739`50.92032864950537 THRSub[2,1]-11.25860327569862137385975886997571323425715608605057893087117605604318024207108`50.92032864950537 THRSub[2,2])/(1-0.1072508616974286555857280261474846768266594132767037016336515460988184973351`50. z),((29.0332537127748657189106247343867880011215309620531407692398630819373528105291`48.41997629606531+ 15.73212400526266130725485042783008745819780077471855815585282731191264085635753`48.41997629606531 w+21.4220370683022442720025592483033141602847474065224381323432573470505936198517`48.41997629606531 w^2)/(1-0.48135534868570240541100812896611104130465731139308558574362112378754901736269`49.69897000433602 w+0.42379556451385365588325798806082601389402721035612346387625501353416356147891`48.41997629606531 w^2-0.06627187783339070127333986152169679292149947549592820784686169637387541295717`48.41997629606531 w^3)+52.13707341744498838895483103054589971014561577395521938553806540241557992882923`50.89364686984889 THRSub[2,1]-11.18260852691556603827950049173039411789646624066076106734375959145880111512782`50.89364686984889 THRSub[2,2])/(1-0.11327685309531660956588376954496663718384428558982214832100693237350450499843`50. z),((13.7327155028251822465848152802243087054536390048803596742022281943602031114375`48.76091217992174+ 44.09136009394412328976716802807409764421175339185434238138617255240360473284403`48.76091217992175 w-37.61840982878764793305691136927292604427754534146551325651236094448566652913152`48.76091217992173 w^2)/(1+1.32309170465094038060350094730748722985072208359817617314972624864639631875972`49.69897000433602 w+0.31401052452247045642045277599827808222454882156233937174215089763913447427522`48.76091217992174 w^2-1.5256324074180094204373827262477031117704479905192779761127140043382966548115`48.76091217992174 w^3)+14.84490573533407763023523467447570904462932288399346464273344668068563155831004`49.52859327350808 THRSub[2,1]-3.18400628527913679983988365478356660472751959931065918436752946094713588143614`49.52859327350808 THRSub[2,2])/(1-0.74752473304851076991712577281919591964070118063957564634684230053606599132063`50. z),((28.7576109100376382308005781885381861646903857904501035929588298087345179536459`48.26914071312053+ 1.06215657321819938798076269775869653292862108306519874131721346782455708279589`48.26914071312053 w+16.98975303795875874915746759707403297505223439969927631689677300131108832977117`48.26914071312053 w^2)/(1-0.99372228404234978762158067975509136500433489035747217968128931143509151779499`49.69897000433602 w+0.86308791129355728948975638160492344546991541420846404108738704243717299051741`48.269140713120535 w^2-0.23429258322965989070645827353045932565983407842138046662588519039657956575434`48.26914071312053 w^3)+51.46524622555187969325360560845178015916144228214681237311387884025328238985922`50.84627862533631 THRSub[2,1]-11.03851182197539476665773469927555809260917116664056620564447508009569135446625`50.84627862533631 THRSub[2,2])/(1-0.12470297816762006035571573361993681850140969237676753974049655679805777004574`50. z),((29.22606515258622036446218483282769611359992533532510386253855569034480041593934`47.490127735631674+ 21.48130666058533174791385909243953158563780426093841391739209897220162103700791`47.490127735631674 w+24.10796880871606506880145677242629739613505355034145044244322738119342474640255`47.490127735631674 w^2)/(1-0.28309782421010352041680742612824109756879167978032895040949752013469358182863`49.69897000433602 w+0.2688760612735563455771639681123488374301084295796364825321435404096213219344`47.490127735631674 w^2-0.00674599689585739273696925682874911092462744805320050509676347221501391225591`47.490127735631674 w^3)+52.60701483034237943913966302415717188966622178722078262939107965741597149326554`50.92932140889759 THRSub[2,1]-11.28340380571728607211295805598628560071008325720927512403446336191608582606063`50.92932140889761 THRSub[2,2])/(1-0.10528430765325161833255284135007625782551205723415228333749753638209031895959`50. z),((17.81590484415824381976940744065551336361509952347664568593178880001188101132404`49.10498286480411+ 62.87167847984305738140052880605820671860390018998249778219292702033728239795846`49.104982864804114 w+29.89826641082882271908765845000717737938523831346473133603407509628671190451635`49.10498286480411 w^2)/(1+2.01728075553660795367818978949822422323274182494856380854201710878518855897937`49.69897000433602 w+1.41471519089433025201371586975555147021104618168633612434709593563705279258228`49.10498286480411 w^2-1.20495993153169750983144552415925233385179860670719829575813581467178022499579`49.10498286480411 w^3)+24.79690739079096011020022740261066195033867887773300958212836562336062123114006`49.86291147732763 THRSub[2,1]-5.3185591337125648548550051304126222832056823114798543357942632807258283664925`49.86291147732763 THRSub[2,2])/(1-0.57826570780037277663513364769577789336726386091964906670486778528618553104982`50. z),((28.8097621453841213714920245043802204471811809794065193939130647853709260732355`48.81490435993123+ 4.82984401642513763832020377498818521992355900565993987380925756736402407558635`48.81490435993122 w+17.91237688804580259708935027696281102264305249693487068456496377750871779446555`48.81490435993123 w^2)/(1-0.86159318800685411086802004809932079604722760514836895997574556639522753939705`49.69897000433602 w+0.74621393913274435699236138526024342354281989887548670763342656667321675903344`48.81490435993124 w^2-0.18959714156549419776670839918790819703963584622722652851342869104487275766635`48.81490435993123 w^3)+51.59235499693520180037475094993207761609063383331080388230473052451898608693257`50.854944721367694 THRSub[2,1]-11.06577471836653163803706583926882174627830222674434206713752783500161096257729`50.854944721367694 THRSub[2,2])/(1-0.12254117117746217690297240900464234841029064034987669325100607856105509547795`50. z),((28.94309908005232818605853829297877368408760494100648730862555932099485906582951`48.600260510402386+ 12.09499581754148975962510729609277589317501091839813563290309252592934540048032`48.600260510402386 w+20.07397797789135282442884937148491559679970201034315760245300839785414923234617`48.600260510402386 w^2)/(1-0.60774880044811729744234673483714406697997610813213475134791445637146602415786`49.69897000433602 w+0.52808816471321015700172617919036148172986468014785204967039541885823313380276`48.600260510402386 w^2-0.10619949964156241931326056036853521275492025085263097575768163993743939345054`48.600260510402386 w^3)+51.91733855356799740631310436592146568427073049023623048892459473672907766190842`50.877715985218884 THRSub[2,1]-11.13547874379986679695463357171184163484263003156471752269021620624321915523946`50.877715985218884 THRSub[2,2])/(1-0.11701400167712563702029130783809334957132818425764883961844248650128514242743`50. z),((13.54386952686548040735593664523225625654527504139753271790040128817846528459266`48.659638006813694+ 43.31146249026670001554504927519033538817231529969624244938252655026500579149365`48.659638006813694 w-40.84407624410680053853681311536389334395530936769505136526958529504609227115174`48.659638006813694 w^2)/(1+1.28740677259413815018897497896400661300419701650802730571869834214006866299147`49.69897000433602 w+0.24376961200857863667386434346832322476409467994504626366467058673098369490886`48.659638006813694 w^2-1.59859797699495656027846352110602575974699878248000566286837774467629547318765`48.659638006813694 w^3)+14.38462939047965394907208533595652045662830557668605626232154856526957052986422`49.51039017233931 THRSub[2,1]-3.08528401643417322653674910567526733993995475237098397142607271585860837134133`49.51039017233931 THRSub[2,2])/(1-0.75535289949903765296118178992317286900096380215258354301479750206257939950515`50. z),((17.69096237981164110351579253799472369227091425002382442070358157141920075578845`49.06990852104648+ 61.98845816820900452681876382115809981733681425556440277632575161298908083754964`49.06990852104648 w+27.07362487481415922200662296892733362051638497219735578174012094141701858598279`49.06990852104648 w^2)/(1+1.98335029284037121407706606615726602273777354505607931229848060452335199259921`49.69897000433602 w+1.36615566877466004620818514501996629557345729231010785656400518037060799608097`49.06990852104648 w^2-1.19331998348111810649263299586652447844451859981196032576383267661443646517647`49.06990852104648 w^3)+24.49238376769384847621722503595361023440556781504919137682248844452051625198405`49.85367260049124 THRSub[2,1]-5.25324345254597388023106698259539737066495136448206624185666895319008464409814`49.85367260049124 THRSub[2,2])/(1-0.58344490424696763927532205478600309961068318680657806546448334522032495796437`50. z),((28.78020025045816844925911286807589780648375593568849260346870021598093529337198`48.713269494278876+ 2.77674567378401675389965681242039355589945951736500808674848474460560039065764`48.713269494278876 w+17.39598707110708447383642624397695525345043077598485702296980500319772688001589`48.713269494278876 w^2)/(1-0.93356121930961207419271546361053052735555859975653040985607648933065882992677`49.69897000433602 w+0.80963844446965491871138226195416968524510981833047391506587342853721507776644`48.713269494278876 w^2-0.2138482729900845350278471517707642928615551843347661666005080020844762473483`48.713269494278876 w^3)+51.52030346989397064982704673161501877461504703197116386870526890994002606685284`50.850016382498865 THRSub[2,1]-11.05032076270973090798649181720456026428821649192308369954884657266779060412754`50.850016382498865 THRSub[2,2])/(1-0.12376659010893428669472262874037855429541177977619042056544841958406465154616`50. z),((28.8084554500511426464630467091111170104012572596406772202059493286022959223657`48.81684054474229+ 4.74326289464617423207031224885789596436716321075012767406085946456709329143643`48.81684054474229 w+17.88989031645685299992490740557995350722886306090775622971953929937976464266792`48.81684054474229 w^2)/(1-0.8646264521177275330038828724088321358003817515741291169899596347868116626405`49.69897000433602 w+0.7488750195775103184450952887363566437227861754171547596708454664241130355007`48.81684054474229 w^2-0.19061450439791638521494260006663398725906361900945512599236913465095656305138`48.81684054474229 w^3)+51.58917017423169805126645703240951915896503127806526742866124111364447408111613`50.85472598568776 THRSub[2,1]-11.06509162238153531277670246341486353120270253117053949126513222465118395934137`50.85472598568776 THRSub[2,2])/(1-0.12259533716386829920805574934144525144641674872212763645321622121536133502826`50. z),((29.09024429179962669720666663216468188655551942226800465431009629487296548948477`48.2743696733106+ 17.67104373635763253911750714185904270129047017043062200314213914697984388321094`48.2743696733106 w+22.24003035129769660596100083724984347865680803669060818335503976683607434978983`48.2743696733106 w^2)/(1-0.41424516549385858865273945846479381661443808752486693626407430671059766293055`49.69897000433602 w+0.36999258099522038966902771520663732711084027167063744265227613946519372455183`48.2743696733106 w^2-0.04563909997250103476635271626208734932002416865858124087144160353236363192332`48.2743696733106 w^3)+52.27597717364814801987600421069947230158487448448542908684507652430210336739964`50.90395545501735 THRSub[2,1]-11.21240126798680383845461181192836631708092703025414285190944164478080385649893`50.90395545501734 THRSub[2,2])/(1-0.11091444247761334549312987256414926855833736868330637897040527409783264045598`50. z),((23.11766449129574550679033838042675484471028762604446799169317164435431042328122`48.78698872187793+ 49.08611024156235338072725707820505054711991869525901048154651781021545359936706`48.78698872187793 w)/(1+0.90157602428149714162991764895979546908809635757897081163684232600841828283188`49.69897000433602 w-0.44797753937074482743303917602039474762967259417831818046410484402672461675732`48.78698872187793 w^2-0.78058885444821277768622323029736422983653011775232105815953593504005113403722`48.786988721877925 w^3+0.58933843599290088861636518485507567496081269053724445453225781368970172750818`48.78698872187793 w^4)+37.71894366548427224851734739633666462361166509392955703032189345688141785612415`50.252719374764744 THRSub[2,1]-8.0901391929444185929148563567714695269845308442222792060024948993123418270751`50.252719374764744 THRSub[2,2])/(1-0.3584937121962120413450183780722874304370789113781683959230356752317375427924`50. z),((19.55437401547264343149939324278684307623666911599527182135493893637672220756716`48.33600381137154+ 52.11692631841503437093579262264970365895543001252773417466912487907768443260573`48.33600381137153 w)/(1+1.2659464882059943003664640304659763648952072467392116595473439149860172989098`49.69897000433602 w+0.18792416875281631239056982043502840453605195980709694807298382453670371892696`48.33600381137155 w^2-1.39549049520236190419598767853434863347580064838476847935171059149946539424176`48.33600381137154 w^3+0.64961815004971871298558592966983502710044061858432209564037790625126515312611`48.33600381137154 w^4)+29.03409715217322917696142994304687357190197524185631912700579156947247567981411`49.989226250175484 THRSub[2,1]-6.22737183166385545589135202977291595771388902762015569214463768097268551433983`49.98922625017548 THRSub[2,2])/(1-0.50620155089685099678979127217545030882367823905750616629925560381224974132266`50. z),((28.95163602402495647413468382876027353706236473838023467840104412613038590756275`48.611859359251355+ 5.37913184948278207985482075592736796711947793651613963709406389078225022052068`48.611859359251355 w)/(1-0.83961092694229351890286732225055597470830267499272943656628903803135864711303`49.69897000433602 w+0.07044727141589939942549233627615651238596587243576618242039770890783043837379`48.611859359251355 w^2+0.54969414975586429858567070229949604491447227433574816463508821365960617369899`48.611859359251355 w^3-0.30496609734154769782121487610481655944946209916882330877778935360495912246441`48.611859359251355 w^4)+51.9381457396781575875006853027196929518156775680500798740228510196231049100868`50.87920540764611 THRSub[2,1]-11.13994156845735404375504114225609585399764784000886226861723991350638279470106`50.87920540764611 THRSub[2,2])/(1-0.11666012271276360515224011527949461650277221893412825244701114020845184152562`50. z),((28.95773220385519583477510491175275018341398357341053599963586675250431678814901`48.554325015774246+ 5.60093336267226998794773206020791734422290681910536262253367349222196481277319`48.554325015774246 w)/(1-0.83182676792704583811533783718072579599536016475405528228157479762729530222299`49.69897000433602 w+0.06112449308525105099708439460574586071373570193100197538818981492645740853579`48.554325015774246 w^2+0.55567687939194359347352674498490863478979824453182342571921235309631380115503`48.554325015774246 w^3-0.30648948520281278238632556114400444676373443751612790848416502527094081092282`48.554325015774246 w^4)+51.95300402487898493019112359720802178940653879329362988631523240218521177048588`50.880271396819445 THRSub[2,1]-11.14312844443429601364179308496513215769012642683598039475611407956700844030445`50.880271396819445 THRSub[2,2])/(1-0.11640741989407266364636557476229921328068789951967434411322955573534324536129`50. z),((23.96631830207995836459306831603347372642268986291955908154439569422577989359915`48.85301720016995+ 48.49587950014630948129505888964084291064949136484578554377572696458839923471263`48.85301720016995 w)/(1+0.83626211870931459211947047104411271107611974291959495314030431860513787618102`49.69897000433602 w-0.59308059979121137022461526510601030888735751641241183244551890774467215420049`48.85301720016995 w^2-0.54911540631327570524288491482379148728688157288927433688785891335426475407209`48.85301720016995 w^3+0.50199118316418370786323446724293339589754271577879538711691585230328689628403`48.85301720016995 w^4)+39.78737680042112274919528684210785262935412503287700105193685759167737777286373`50.320761169293384 THRSub[2,1]-8.53378661110502627966443682635669975279069665056847242618391894456965346144411`50.320761169293384 THRSub[2,2])/(1-0.32331476143524686409490628977263749845402098139429400556181555208111408935715`50. z),((18.69455464907733229034896076022650833273758139878979889938698442222418573172619`48.16782929941077+ 52.73106757315146724037426290659002934349128122055787770392466693846341892660824`48.16782929941077 w)/(1+1.3684023317935453438214047733816446222607133789389607033271033551163905698677`49.69897000433602 w+0.36171163491684809806658431620414858942218334800932808213107433089158321605754`48.16782929941077 w^2-1.42992000088346296062330430116725957816776139164501975987475374640723559594524`48.16782929941077 w^3+0.56408407938605808028901413529138489772056659220398818575707772846692786003929`48.16782929941077 w^4)+26.93845008747786589691642781841952117326261151618986541855081311542065900955642`49.92714025821296 THRSub[2,1]-5.77788743986777324056595776075693826267724323673654695830378207465481312883257`49.92714025821296 THRSub[2,2])/(1-0.54184334354466126862667773660946222350991969983164222722620697568664868858845`50. z),((28.96708720804315471895602908463748115250193796790293035566880140111421356865162`48.44738366072142+ 5.93366684907812561116962714880952067925065167307580527684705806550024469824041`48.44738366072142 w)/(1-0.82015142839901973609232054275273192949381457965711953727454568919926180431801`49.69897000433602 w+0.04710083951735160134923373831783691194551741453366403645869075933086148822662`48.44738366072142 w^2+0.56473767307945002917760744961684757563665650602098405137644898481730158000967`48.44738366072142 w^3-0.30882149212663813985634640402729255977847293671707322048807054689666077077111`48.44738366072142 w^4)+51.97580507802215797643068017017236675422846128699179146817417758347743053368296`50.88191114419827 THRSub[2,1]-11.14801892321625594486223308581552047814861503864597855040275396731222248436377`50.88191114419826 THRSub[2,2])/(1-0.11601963016460368392570800824470162665940904491404070054855653999554476145053`50. z),((15.67443183661360228591509142094172224242611353271160544742475749512116099315373`47.38819411172913+ 54.07728832903195664571243661741332434361189007985762508303843185585897588882793`47.38819411172913 w)/(1+1.76562337864019111168682465866691645479885709920103710964811277508422313478392`49.69897000433602 w+1.08238155098645993892634824963117136029090611437124790879965775861412016498486`47.38819411172913 w^2-0.99746370793094219267669081310569421923296717870252977730207050824328290889436`47.38819411172913 w^3-0.21391277354588773787950211924634104601478231122349113040004852823110608170635`47.38819411172913 w^4)+19.57747200961349240320498372450832569791658076887361216309487491294780770224369`49.69824909722619 THRSub[2,1]-4.19906970376480587752930674583464057814379004754727962726446496939083792087767`49.69824909722619 THRSub[2,2])/(1-0.66703544232702810014141121867081315960786890174564718537685278027731533646417`50. z),((23.82529807010987643085366573015047142160565337871902067195501750442312911821195`48.84348515765971+ 48.57948410571271857573158931814532183074422641925124188561756910623926948113346`48.84348515765971 w)/(1+0.84618544682174322486759064686461584820438697534929655896670170725830517124874`49.69897000433602 w-0.56865570368428678048143386162378006383138172409751485012025157193738095859263`48.84348515765971 w^2-0.58949664562879640191523297513500103534777335250914191683228738339426656292196`48.84348515765971 w^3+0.51802599761537709206256737421099037969734160792365988811747811787325716540688`48.84348515765971 w^4)+39.443666659964843489852461536109633893636494120138661852471947802696235587893`50.309211062732956 THRSub[2,1]-8.46006601853015266917362339635331982646304521772141908647811401613585796988566`50.309211062732956 THRSub[2,2])/(1-0.32916042398189961043493172889466658947009763801005546785643551032031679882488`50. z),((20.90934426344884831551038827545291100445632607904371512185233162150245936345165`48.35071764538671+ 51.00491227953463299639690235700902067019888854625306378268316022080786877660213`48.35071764538671 w)/(1+1.11469421740293590140050918397905368053637171166828388117516450138065661694253`49.69897000433602 w-0.06622192140236091864361767861788096099428284438569182667822735415349659446684`48.35071764538671 w^2-1.2401557203706137323988427520149073500613574779186611795949768289810151699857`48.35071764538671 w^3+0.69558427771780848076375177349826929504659282474194167764627882405662257977507`48.35071764538671 w^4)+32.33658082944291941553192078597630392663573125851689311406361787635263511516913`50.08708974119745 THRSub[2,1]-6.93570430429318145483703918850798057354409470669098154820978620048933022074178`50.08708974119745 THRSub[2,2])/(1-0.45003444125754976256866170146961396046427654279269480921887528028933605348508`50. z),((28.89082323188317369322530386413158896803324405005168414993232245300730332952794`48.738029859912736+ 2.92628875194912128371957534271413733825388862474702109724086278050590319291005`48.738029859912736 w)/(1-0.92575785422420183930510684853043049494098150354779832584711094995189303874162`49.69897000433602 w+0.17234343884985750803742682095930253370224816534171484238792339347633551620668`48.738029859912736 w^2+0.48623354021617866442902620858083962088381128323088789068907706315404860586478`48.738029859912736 w^3-0.28959265192673794293768434265741703200841852570679778794977380610189948785718`48.738029859912736 w^4)+51.78992606200080756462702063128423308427056561919776253975780434771489884459862`50.86867975580285 THRSub[2,1]-11.10815070405304668795414046898806109458459180063217783343740175078015014467339`50.86867975580285 THRSub[2,2])/(1-0.11918097419920859308369912328701014934668867054543032621886115160157151293355`50. z),((18.95945987380560982056989767430833311517917711249519194506861293111166335096086`48.22407067766755+ 52.55093810653354124077253891468827521504964354149656774432430689671921383955805`48.22407067766755 w)/(1+1.3363249274542962946002636599279923363947798259880029955458758603472405042486`49.69897000433602 w+0.30697763529970906620715602378257966581415954062862307617844245063216056326399`48.22407067766755 w^2-1.42527401202242877643516444742600444291294844827979725803401202855750389723949`48.22407067766755 w^3+0.59565434320110242548788856785979753962497125477058160826037510806346666532447`48.22407067766755 w^4)+27.58410646406271850063642791867690601693585650099283793278664181956716071337235`49.946318415897075 THRSub[2,1]-5.91637090334194933667270645177980848730079265110275139880348718696150337170242`49.946318415897075 THRSub[2,2])/(1-0.53086231955276163889979020265219824970735274396713721781790415497012357099644`50. z),((29.00410240143558065257209016589333398206358068908273116498353949493188002910387`47.51922466683579+ 7.1657568485327051279597897213906784261801348771993872430929332635203599291488`47.51922466683579 w)/(1-0.77694065756587874352765665297954008767737743110889456714125588133403432187495`49.69897000433602 w-0.00525947984566580723564411454308719615246483234571146728626773543185397738887`47.51922466683579 w^2+0.59926070960531682918734642478207524380845137339304500421633161343747831776979`47.51922466683579 w^3-0.31798464919475747839802979233289035336866933008571270677521126732808293687433`47.51922466683578 w^4)+52.06602261023148090333410996622629928849626105551871647029248662174870043300824`50.888446253148466 THRSub[2,1]-11.16736921042711593824094501966936048300204295536056510722596586263106170317149`50.888446253148466 THRSub[2,2])/(1-0.11448525224841135974632238793607519774227160606924124001127347872475139349704`50. z),((14.94775553417697138503160486687660393402019184124355492972163065753104781249616`47.711746045538874+ 54.1753195874651178382821392190518547470182164181889827204126700630562623537033`47.711746045538874 w)/(1+1.87004473879857380084947097335761984583048148292724779791975349523282530186605`49.69897000433602 w+1.28965812073564015307482126244263708165454327713087839858290298377649088110599`47.711746045538874 w^2-0.71955314604475642727996710180320492095833969924795249584634033139859917727505`47.711746045538874 w^3-0.5476624812467854513541281303603131800987009422984258828657673165081334766588`47.711746045538874 w^4)+17.80633597836846482256621111234003379395577792795406678658283028597059658922801`49.63788468064553 THRSub[2,1]-3.81918798837299012395172083748023272227607234866869139290032518392170982703967`49.63788468064553 THRSub[2,2])/(1-0.69715810192948236938733908919521118700914907596053684824863277043822164923147`50. z),((28.95618128133212103704825508493877666412937529465275647564930058522069295713113`48.569718931992135+ 5.5448831630517794208411417283794342454475324486018771258507311428854661843906`48.569718931992135 w)/(1-0.83379375945602220057643462754408894839032311396480769062846959097667111702389`49.69897000433602 w+0.06348228968188059455134941360759855809056231461115767922391299586075426969273`48.569718931992135 w^2+0.55416076695191605249884760465078341663530145521526569138966565605054590960917`48.569718931992135 w^3-0.30610220513428906322074601765635646477792986249610789143030254746133984334602`48.569718931992135 w^4)+51.94922394459691633715659209636821929242515472268038536998518151980905572146806`50.88000000927815 THRSub[2,1]-11.14231767476074272633795001239989058760458046858564351852551283018970144690413`50.88000000927815 THRSub[2,2])/(1-0.11647170974510497476078808320087282625995212344841232987333711192185339753979`50. z),((16.96223358953055667156183568962371146780606828966056719667221517987593898741404`47.558164381627535+ 53.67612154538318129701889938576368990595962260919500231702147620827752227080206`47.558164381627535 w)/(1+1.58913880789421475746834056563069674511933701024989594337404094680385064733397`49.69897000433602 w+0.75061421518101640289100394451040093495659304814346289871695421130147111155693`47.558164381627535 w^2-1.30569878372064480439066146965729498572860243193635046330932854023698791159478`47.558164381627535 w^3+0.22356484736758972034112237648034742900950436017965462381158522870302819370972`47.558164381627535 w^4)+22.71624518557050723864266960865278165885681245465577916525863139686866432341687`49.79905533301791 THRSub[2,1]-4.87228876614828188797104522727942471724390923466513435367448187756792242485233`49.79905533301791 THRSub[2,2])/(1-0.61365264491298396176791938789154757862777860555039454337027884308884558804499`50. z),((23.3088980327592433828810730769867607309956555438846919360546924667236036289959`48.803530428315085+ 48.93776767115331792912404269739323417848928121500917786751718445408283808468539`48.803530428315085 w)/(1+0.88578506401805113782461357622723569136267459104696208626757876676084350320743`49.69897000433602 w-0.48039692498514005454080783334582899550062784512522381574082037024521765857508`48.803530428315085 w^2-0.73086508957850749037360472855261968889441821021059956353776232720585875810491`48.803530428315085 w^3+0.57162350092999812823265023269942337563654111718071563719566284200006389948298`48.803530428315085 w^4)+38.18503924962935603416552186049234957698356411664699016257155194225884712951616`50.267764131802174 THRSub[2,1]-8.19010960002665660474426959343261962389793701539304114724734022367447285767177`50.267764131802174 THRSub[2,2])/(1-0.35056657482464610053849690071647973266211517088898529942299145060015627076462`50. z),((21.6169522381091070742371952848800271002835911456864306804372498623211785620201`48.63086922455435+ 50.38104563752190901264938589424042206229243817145393186852165174327489800596269`48.63086922455435 w)/(1+1.04124666472495306731261913504918536470618767022967904342744423710038773334638`49.69897000433602 w-0.19156109541234062713583885084346511448831811418427627550706599137544790722374`48.63086922455435 w^2-1.11770171747533021642473104317045973417847861702469460624385470378980846420151`48.63086922455435 w^3+0.6831671997795673028172546874203126154187038721555491339704071701933113339122`48.63086922455435 w^4)+34.06124141864163341825718027219191804716580513622267244499358284990826470935669`50.13892707041302 THRSub[2,1]-7.305617744895998790992045707190398907260251118011852850652077403679267099841`50.13892707041302 THRSub[2,2])/(1-0.42070221440330771506737740078406720631025735927267896948509513480694232504635`50. z),((21.89516043185753711249096286571046196189010093242609471930550671800190066450472`48.66311406004718+ 50.13334013848908426304877934079233423881869334829854976616379230171187541205994`48.66311406004718 w)/(1+1.01355907627566559560575413148862458126510659412920863187517266924179224737632`49.69897000433602 w-0.23981794043233176558142282995383873163468931949831399740277164680006121654363`48.66311406004718 w^2-1.06275947083927506133147357437003496754179850399214995736052188699979778584249`48.66311406004718 w^3+0.67231520910191063385182479885990049995462324268864607678377585317255765737542`48.66311406004718 w^4)+34.73932126586275754471716278814589816062261610947477084668698843755559696436607`50.159559209223616 THRSub[2,1]-7.45105554921524518228543921378133901072627529507664748751791108176099554437718`50.159559209223616 THRSub[2,2])/(1-0.40916974707115825921520439586196309082441858081745612710071305858499633359582`50. z),((19.23009350847349108024974187361072892042383155457141591114737885353269120918852`48.27716694070906+ 52.3583585840756228725136891400269724126587644715216613147382706316733546465062`48.27716694070906 w)/(1+1.30402164166221331487479223188043350555456678958891610499516909401261561154036`49.69897000433602 w+0.25217947247478703625620796790447394943050498736098624470512547942029963952014`48.27716694070906 w^2-1.41493562570737982106981943614450970609200092165215463040584880833397037935635`48.27716694070906 w^3+0.62301730032763977887854296653731606893999376197256068853381544113293647541629`48.27716694070906 w^4)+28.24372475630624097208929753558328642578446664583449691700127217295431490047117`49.965857584843086 THRSub[2,1]-6.05784898517236935156606762028223679718924483256206931307551489646203582478009`49.965857584843086 THRSub[2,2])/(1-0.51964383777932241335345820105538869060748289056053422324481462175653748481518`50. z)} /. {w->w[z+10^(-10)*I],pi1->pi1full[z]};
(* and 20 each of [4/1], [3/2], [2/3] and [1/4] Pades for the Ls part *)
Ftri3LoopLsPade41Spacelike[z_] = {(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`49.82381122594542+ 7.10513306516795718363226960287865753536029414062738414135830446849192536400917`49.82381122594542 w+3.82015282041660854736843106151487893295165784231483116755099198266427618359701`49.82381122594542 w^2+1.4817823420212833811521155670217439332848131285956344871840918933718093595605`49.82381122594542 w^3-3.63130154313722956095805197616610636648067679693658756183750645109093642086568`49.82381122594542 w^4)/((1+0.5894051572703027444968774105893712209576647385257307042000143815267953652179`49.69897000433602 w) (1-0.14498650563663121582883100079562239942904811862103694425781405684121713194826`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`49.82508183053322+ 7.11274879748358960196140432820824628493442609043465265029624188628432952401764`49.82508183053322 w+3.70631219467500860186464885039277409530214062552822589126133019705116550815522`49.82508183053322 w^2+1.35862204090501384025388281012047304345327211472222707172913629446400177281179`49.82508183053322 w^3-3.54155390470756544099414479590979409448012401520963644217396336608770928242228`49.82508183053322 w^4)/((1+0.55391675687140725755350588730248969261370777603679446845402154231241287518768`49.69897000433602 w) (1-0.13561410195412857208596467086465896080169254552971069023259705283246945381914`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`49.82692223860134+ 7.1162313510391801382116335074679302630028962182465790715247890604044485050858`49.82692223860134 w+3.58609816924199693107301188306855256224382959030738778376266348693656433035596`49.82692223860134 w^2+1.24416205161148592926521734997083141035990230492685191771147646519501189907946`49.82692223860134 w^3-3.45357152188874148572327404196675232778999189849552564403419889563818048165227`49.82692223860134 w^4)/((1+0.51985996714569341809410576597481561374427231044193415533571642940444916026744`49.69897000433602 w) (1-0.12687112363218686531416527839159331843749987511415534189223083640703140630257`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`49.83644636771164+ 7.10641887429554028169698906555061809848825361996410432134857842282894221820512`49.83644636771164 w+3.1802853362725378552950011466271322924698755259176182559131211024670520054361`49.83644636771164 w^2+0.93134270708513863147146518863959190406637640177546041436765224581033377065395`49.83644636771164 w^3-3.1886544718155589043495260033202935066812086154442701485119780767394462035156`49.83644636771164 w^4)/((1+0.4210097231805756669660179642092012994237614449597395379979006786420129771733`49.69897000433602 w) (1-0.1028031779014385129966090212148306849714727673899006099164514446655515513659`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`49.82669299072655+ 6.99172726985017732174682688850635524201516838453452089074683263752693828117882`49.82669299072655 w+4.20424800030496508910153258616221147265546005241686704546350044538911367360771`49.82669299072655 w^2+2.19825525669720241603428397147039924150082686726769587235563137848391343604881`49.82669299072655 w^3-4.06485305286691543542031179677901701820102993286395535392861229295707499421731`49.82669299072655 w^4)/((1+0.77514538747707054840642766823982036560910321488910881767838317830987893046563`49.69897000433602 w) (1-0.19887157893912622342643013038597717201604008665228853257232703214681929817002`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`49.82364492173728+ 7.053314282294447911721717262859420325408108263718143799041853441482810096202`49.82364492173728 w+4.09452707092567709554881948256908365744605636059218008639252522037461904194297`49.82364492173728 w^2+1.8933367958932295695743180591411652228890650231410274655893856549862326476953`49.82364492173728 w^3-3.89747676371953968633045228273264632742995660333373350274138464640869551993831`49.82364492173728 w^4)/((1+0.7000948074717167981341669392408010950651564285727066438477918350532926499697`49.69897000433602 w) (1-0.17606307180641234564103638339769983065350989436039447089672860616388311660823`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`49.823212496066674+ 7.09534018998396980421072616289938358668896765548834137857300927981518628910882`49.823212496066674 w+3.90732736790893044174197653660282689446520436483736329587764369472318231808394`49.823212496066674 w^2+1.58965958458113760219342781839024694056609163415842009517209905609967414984872`49.823212496066674 w^3-3.70592773597848557696421406067979841746470810648097412839442806002204559593899`49.823212496066674 w^4)/((1+0.61955511271232203116734479779258278432680582325590750121239456806607189129436`49.69897000433602 w) (1-0.15316732206396732519567332905491773945412126109008854466134338945377404006827`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`49.82434211945114+ 7.10930549301046285691924889944725046523759750995722016881412176599984885597649`49.82434211945114 w+3.76701428485735818554365795406197591739703014044991545424280545253753597683498`49.82434211945114 w^2+1.42217979301908696119580065259521429896019522778259001687389017159580242970735`49.82434211945114 w^3-3.58848929548688804893489168205992517633270030070450542586142403656256452152917`49.82434211945114 w^4)/((1+0.57237648707108002588275951598367648518621591693018768539564752554062333346291`49.69897000433602 w) (1-0.14045523698768282771119339817253932593220248020048320312636671173113879834804`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`49.828601151590085+ 6.96165579832264445674352317837825333707016957100673036215835121754213351829434`49.828601151590085 w+4.22855403754841261585742669173097148677417621370990235870667213107972781396988`49.828601151590085 w^2+2.32226820794314582994015920941720389764248626857332807712664162931479409973287`49.828601151590085 w^3-4.12643438444420672083434456499401534376404706968678001125952193884407718067749`49.828601151590085 w^4)/((1+0.80415991782652809708724401178944267828967552747412286696077577995933373648752`49.69897000433602 w) (1-0.20810070965603656523188774467595878773731447371642728212145111532731830474417`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`49.825529873235574+ 7.11408638311642975283478288177852347589362698735968896925994399423355807033097`49.82552987323558 w+3.67395516523202373595642848910093497292617701397573756573842437809735633431914`49.825529873235574 w^2+1.32644582920120290738843340368215037908894192977449345214459757702813968097418`49.825529873235574 w^3-3.51727656249996814852855264674961504880530716615107910795862323538678168473242`49.825529873235574 w^4)/((1+0.54445016296920143723418529811291311947295779113550675026428575860727537208017`49.69897000433602 w) (1-0.13315958288955842096335783026702762978925827505384053673944104379990608010725`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`49.82308290121183+ 7.09003366891184169850812321489931828631276380053453700729866506972620627272241`49.82308290121183 w+3.94281734896286315460943464502009742516749106099209788233316246215287963802026`49.82308290121183 w^2+1.6381015851411000838476446043552445737802829896175633425897990465479563338142`49.82308290121183 w^3-3.73827571750481832464779360927262248553951446162599219319670803481759535509984`49.82308290121183 w^4)/((1+0.63282156791969092149156095268945975355755856793109462108406349432094372623597`49.69897000433602 w) (1-0.15683253943989095618054799939957922777192502897117835540828786811008501705327`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`49.828542806070516+ 7.11653689069383446194026095908395874057074198900880937314693277446676352201942`49.828542806070516 w+3.49902128841513516869644627896750207863354359332932483758697894943514036431766`49.828542806070516 w^2+1.16882520473088605771257133187582827216392684586750015312487690920466946935829`49.828542806070516 w^3-3.39314150225075936185967413997867760916875576736584239103213419010313866262551`49.828542806070516 w^4)/((1+0.49685025303978783681544448235369010419684634002247417771236210822346899798695`49.69897000433602 w) (1-0.12109862315759449252327625628525897537100387932053050836018667906032458818166`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`49.82304006367324+ 7.08052824721502377335382224696733735158344819038742867700108698634172074545733`49.82304006367324 w+3.99448432881384950117684197076082303469430481289384989735022573841693434992079`49.82304006367324 w^2+1.71472976884924243791743308552569966205512332643682688317786038806535331097865`49.82304006367324 w^3-3.78802170807707172128833465051980438698237863429706689214973593262093371556468`49.82304006367325 w^4)/((1+0.65347412512844100710187911949305963316337828375019637890415841739564462640344`49.69897000433602 w) (1-0.16262012250318330478304512293542685031983134837357458130354412361814250864575`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`49.83090664390411+ 6.92857666073966747525402917251718458027325945568164182559776700234400931425853`49.83090664390411 w+4.24199571409928951231088403150911587316584188819093761862625121822740720114964`49.83090664390411 w^2+2.44740045244005734870433178479604884035714401817499974014459442097822525944764`49.83090664390411 w^3-4.1850260126817768886982941226190635918540592780398255642027529914256937297256`49.83090664390411 w^4)/((1+0.83261366731583394313613349314718084431194428699277515086921573204136790773256`49.69897000433602 w) (1-0.21738722905936151457918636357560952494486845949335823073676695768205336719875`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`49.8289717374321+ 7.11637437874560797904155893131963901640399129262556496397227124998947810715669`49.8289717374321 w+3.47785682177564694389080309039027148161837971996029703792805207702404450716355`49.8289717374321 w^2+1.15132197285707331503179685475437164523102640147919342725081072560849182814571`49.8289717374321 w^3-3.37880597831188745376329245730291787031826275727489332741169882887057534972926`49.8289717374321 w^4)/((1+0.49143459320973730411083533147957119647048295216606656424006508728579177882887`49.69897000433602 w) (1-0.11975538416748359909959344484321740550146234817722545609557246770440427498225`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`49.824793547990936+ 7.0263255078029160028804755100547978524079649048910634621308744802635578207868`49.824793547990936 w+4.15584993243286391393160182633776800400834794490153777223030109867586434295916`49.824793547990936 w^2+2.03821666592123255872310408077607419298379578804910994824048792308413665936759`49.82479354799092 w^3-3.97993888843222164821228223339644768009362741041493648425746543981104551698955`49.82479354799092 w^4)/((1+0.73643741591266345329666335809440466208216900216549483882004576674152511690891`49.69897000433602 w) (1-0.18692170910222409833363987333184234472164106863044565005223313580636333403982`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`49.824460553508594+ 7.10999690672575013278623505288791287434062685547357032682547603254745201108297`49.82446055350858 w+3.75649064205238654965036304324634017857366340342144449285463537677184846732186`49.824460553508594 w^2+1.41083783410286161222859269491321128836174928244565619533758145066580697582832`49.824460553508594 w^3-3.58021163256745886756224262924666037296967166928105636346443976956106348970137`49.824460553508594 w^4)/((1+0.56910534926693352523678537851881210738179619670006700414145205244454255371781`49.69897000433602 w) (1-0.1395920311976857245730365398576665768684897829192509029284262009103432468618`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`49.828743234743435+ 7.11647109668622474587352733536014404452852272514675335836853688925564420795377`49.828743234743435 w+3.48904820963366184388502653078805984898586809462657630436903794385743701684567`49.828743234743435 w^2+1.16054059266947787248566878181512587408138189049060511959639786626346043813667`49.828743234743435 w^3-3.38637030112725743713881925214066674530485200634562902446792675815262061726224`49.828743234743435 w^4)/((1+0.49429024086049523751056990375466883027570249544375419949899040309083061388812`49.69897000433602 w) (1-0.12046294234684789338757295917940389239714108149525627481431977264346654612661`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`49.82985594909571+ 7.11580977316917828204114538647182817768409264425411943412397308736503227826728`49.82985594909571 w+3.43618106931024179623191955048190175184362363934028370830574959177773549432444`49.82985594909571 w^2+1.11768950079435303685261355005703560046959888302118926894451791896908164430812`49.82985594909571 w^3-3.35094119371842418023102024744694622531300407792670129366777073249586870265012`49.82985594909571 w^4)/((1+0.4809530548613080884196568792706624664537312453095319575719874285206274584177`49.69897000433602 w) (1-0.11717209045765999789945373619705078904456703339990217959906668974013553050284`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`49.83133664450553+ 7.11433443953991450219808860869611368405283890036052661355558692590104947410404`49.83133664450553 w+3.37130510386337292047993809245889351539244506054904387215551882925862235875468`49.83133664450553 w^2+1.06736616370101960229807253301310488538736117520552963706812195096384133032271`49.83133664450553 w^3-3.30845152177152456196617669711946115250584893912974991582969516150621531318803`49.83133664450553 w^4)/((1+0.46508161228054943948430878350224885441487964888968996045777624425898757193465`49.69897000433602 w) (1-0.11330114953994021901297080714532279072595839484269620724172334019106266542506`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.50076653301473+ 2.68419768013722541287660180016216371461139809477438096861510326613252438607081`48.50076653301473 w+4.15068400279526122748191580506733199632292393671107816504398214473259359653056`48.50076653301473 w^2+1.2511590586276429599899610773401750649985452413478120753920161702076248096598`48.50076653301473 w^3)/((1+1.6809261480660035312032067365448493022986688146450503147463010918487620001812`49.69897000433602 w+2.15889727883056728804193662139845528786284694585025361592009144350316165871111`48.50076653301473 w^2) (1-0.70829316549085995948936231202499151382809522825435313447394801468114399057434`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.78989039484072+ 1.24744564569771668418362359963273849405987664244686709646732375125315868754308`48.78989039484072 w-6.4098042110540315514727418295470109770391747636252884095263490291931166876376`48.789890394840725 w^2+5.15780137286989082122741893552735234859128142702066766093696531432167165161413`48.78989039484072 w^3)/((1+2.03369691750126827688569366098996540617179651408299690192193303998917559668352`49.69897000433602 w+1.10926142205276907802966936058102071619288984958967634206494141184398653083517`48.78989039484072 w^2) (1-0.89087102799533730326937677163820358348224352589446964319592897363551187419106`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.75685973618515+ 1.714710625933505534605270935822817559008666183337532872203279331915504721459`48.75685973618515 w-4.10945147319104239784584468656643107618737004720383923931566307349456005159119`48.75685973618515 w^2+4.14710962204653045232752631670707102347004038151195423101770356019134338212107`48.75685973618515 w^3)/((1+1.9780571172581230028549009536197626446927195068582651426632451019159315433523`49.69897000433602 w+1.29129401648749004464992255422467679383234937120744874044546184813469010034416`48.75685973618515 w^2) (1-0.84626483835701741064638789387805645818883116556263467221584822151751858801775`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.28816963808797+ 2.45992861407287338375706264986520273931910701868245049071785898800312711549554`48.28816963808797 w+1.01963385450584615755515978897416517953568597035778859061748685832165475859444`48.28816963808797 w^2+2.20448397392141684109705136323122367746830037729605324735722208324126177211925`48.28816963808797 w^3)/((1+1.81399795946467300835943974124984908792103064321615679358646012179298484597957`49.69897000433602 w+1.78691301112208366198607500238357405230444340966552188270655779102715395975349`48.28816963808797 w^2) (1-0.75629412268052125769868225920615130532587998966593688187250141150539445645209`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.5031042844033+ 2.68252844128311556256204159618543751236092723071869849199336320490565094095551`48.5031042844033 w+4.11064028668845329752610407888710415707898913748546753299355428141754081409222`48.5031042844033 w^2+1.26218296163341247105980283945097433992049462756149839961893907067885952559737`48.5031042844033 w^3)/((1+1.68280611500568775807243089613407799781734350682452391699989241542857745853144`49.69897000433602 w+2.15378046358437194488898439314248316876960766715340289375673541252914781761834`48.5031042844033 w^2) (1-0.70887281525269334213974164999376245281910870258755299060277122405629152464865`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.44929377696274+ 2.50178480761825484343970990674092475319550354982307165346082363077741676935044`48.44929377696274 w+1.45031332844837596180184314103540159242670831305618869279517260918014572470711`48.44929377696274 w^2+2.06249468123527213875329869339030609555510595947206639014132900039900669629992`48.44929377696274 w^3)/((1+1.79730788843917287069768723498230890224323701563818672999621169852479060364842`49.69897000433602 w+1.83477513224543346562366694533505386578915198896353903021087497339235446017144`48.44929377696274 w^2) (1-0.74937192797590948505591694058173707551309166466731732193249293089010577142571`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.67889680704019+ 1.92356307082575498238176724270084702893757937689508178606897075970933533153977`48.678896807040175 w-2.93365717550080229452642095194001437791398186567144892150641984173072557598431`48.67889680704019 w^2+3.66237153297025220171720200827137622587403301555508242188903470593708574666401`48.678896807040196 w^3)/((1+1.94566996011202361595320712600752506929289636269113681882811426863911059647313`49.69897000433602 w+1.39342479282692796439955369131658428756851767066082088799036311237974619667038`48.67889680704019 w^2) (1-0.82444781546443238122031869418738928894208546169590325953229611690038039242644`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.38061748863778+ 2.72509509358401338379175414397691826858695613524018898255556663670287758582838`48.38061748863778 w+5.81323240939418167344209648409238336487267183233226854891476574612099128257396`48.38061748863778 w^2+0.82050920649805538097742504585495120498339006402433866990890510808501315486834`48.38061748863778 w^3)/((1+1.59856023393760415956188624856361662188016517957222753017543063646834329797319`49.69897000433602 w+2.3798305784090833225708643073794007201215567533848691548453866178377651094765`48.38061748863778 w^2) (1-0.68501499556444557834373021123893304455719178398108920009842135968600466579034`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.682776583347845+ 1.91857663907259838042515102896121483137960057278510202731464904038412384571719`48.682776583347845 w-2.9632041627504768827173663604627619035954129785138894721873577634722416139336`48.682776583347845 w^2+3.67427732282583765591421466645893605596517698857039832695654302321041152448606`48.682776583347845 w^3)/((1+1.94651898559669653023999427039687816194417215597017610403490938438339292144988`49.69897000433602 w+1.39077904391319076105932153311850647815960607930731242175708082772041767040564`48.682776583347845 w^2) (1-0.82498764764420213838770559651579829041163294459222723705403032271612654877888`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`47.893676904075384+ 2.66278793337371912783832846192021756403871543072634926359243337497886157969895`47.893676904075384 w+8.67022845239823354665093689199937628988364111334066599525165961526046270851344`47.89367690407538 w^2+0.20357986930466808507279884406357457652381614857741786935837646323936284490917`47.893676904075384 w^3)/((1+1.43649131115469429073218365800639366286385257912296272728996812675297856473551`49.69897000433602 w+2.79901021312648574300135458226910558413394122277267474802476840387491825952019`47.893676904075384 w^2) (1-0.64859093597742357320623763760335216860555280423829016262130512928073542237502`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.4198354032914+ 2.71923500596075756244546427899443974738998927916206907128564349166255863565876`48.4198354032914 w+5.34522384034056624386533729010557816083778071730969801852551040742594968864011`48.4198354032914 w^2+0.93639035049859993196783450698693376781318451067752831924503402998833706839101`48.4198354032914 w^3)/((1+1.62260918277249295981562998777749942545274775105169126876812459612725702158114`49.69897000433602 w+2.31594924851841415902783851366784687747302287673973431608592444119596277015108`48.4198354032914 w^2) (1-0.69141220203308969367809029775658116655086809622834602604742625590217543091754`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.637899546067224+ 1.9722775871748613607557244047778867970719736067410558712198005860514133369472`48.637899546067224 w-2.64057351316338399534314787941521991897388094407649624955503117342225023361219`48.637899546067224 w^2+3.5450569183182968327088456064191378848345648811264087181053022903375192486956`48.637899546067224 w^3)/((1+1.93714715729832899718442845040723952942554616715081266813911614430521204724486`49.69897000433602 w+1.41989458193766041472548295504770165792761723878531733358984278564024430430298`48.637899546067224 w^2) (1-0.81911689105924261408019983215816930606860887581364180566279312172089012643628`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.42712802879528+ 2.13993451864652908658068869653398072999987656733289454971220625963768130383429`48.42712802879528 w-1.55990344098149122797617809781641474453917836772864370468123781798387816235811`48.42712802879528 w^2+3.12495005325286112387843213622636483843511356653808501067867166595332005756616`48.42712802879528 w^3)/((1+1.90408927963313934219049245290544177302584700590870418085894085396927596038181`49.69897000433602 w+1.52111186988294869733566451996257877024489772264688431366893226627514894195051`48.42712802879528 w^2) (1-0.7998384626411568095840904413534874188201357158291827399139724552799120440839`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.110380467210476+ 2.69785100308453677472818311644370420354397454123910637122044628152396178202248`48.110380467210476 w+7.85644530152152126008882248065139138720629859241640424872623033185537915918557`48.110380467210476 w^2+0.36356584508374623493769624715961440365444816120809682664810797631752817624859`48.110380467210476 w^3)/((1+1.4853760384510803874733610520061156678193715257414993803545456274882061193504`49.69897000433602 w+2.67446333701414819312718425091800833960156454400565410154526283505438400681625`48.11038046721047 w^2) (1-0.65850870446285324467614007449225070082583887669867104708094605273887926612754`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.59685591852441+ 2.01458895025324292294200319225276751024086946076419618231842321352281989664502`48.59685591852441 w-2.37906140365510043355781457289978806305889659956222236203825582250611491180274`48.59685591852441 w^2+3.44158644479209900338101748619680921300330221672562810463772580831823221373897`48.59685591852441 w^3)/((1+1.92938554052629906807862175978858637727399268872068726181623366854249704990475`49.69897000433602 w+1.44386240975632968399495507288230073471920229014257971516479522854203061433846`48.59685591852441 w^2) (1-0.81439690826984510217107291069128757701962515813159247430525695631406215768604`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.750442637082706+ 1.78518007026114838173883536691152033331255092076425572211822402942943312268889`48.750442637082706 w-3.72580444197916479439463706917989401278841321854412321305022729325908827876003`48.750442637082706 w^2+3.98649648425635490054153714120169765273169226255013583346709891519762353173664`48.750442637082706 w^3)/((1+1.96780013199982171664152404278601382239365682540081588833674627969483064675397`49.69897000433602 w+1.32391457692029246900451799621002959235978981652755747415213055510962486973087`48.750442637082706 w^2) (1-0.8390712124880713911061671706966387783897227022286329545149317821384497031799`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.43298009024905+ 2.7159746173231650172022948155630092275612566227649644888311827526220620704758`48.43298009024905 w+5.17384243487098077584197678497769724938313749552785705042662770738426689360744`48.43298009024905 w^2+0.97987378037426224630902353866598226208638234258471483969308177656326209561438`48.43298009024905 w^3)/((1+1.63124485215227646369857600403705156832531942821482324157480694944918900075444`49.69897000433602 w+2.29288904492808554112655331196188494349436747267925350130967833679733677731986`48.43298009024905 w^2) (1-0.69378530549291391203706421182791354298768688345763110609324660491883307898804`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.118524142778654+ 2.69924632071106851836396641842272336521197838295730670525662306212924315677606`48.118524142778654 w+7.81557417952412071527653085038280024526016694672560131709519741856251309251805`48.118524142778654 w^2+0.37192927264726139282026934074330215269357061811995067514934030004482506506923`48.118524142778654 w^3)/((1+1.48777329328497299505389782358379544301831503392547075047147809802354130912516`49.69897000433602 w+2.66831671618074693006484940944865933472372585070251444826144480074547292081349`48.118524142778654 w^2) (1-0.65901635496958343531052937893549420334811464735440792835313989387726852047085`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.29841594962362+ 2.72466676113933540471893301040724789412555727619354373749686751445850813064955`48.29841594962362 w+6.61943750062518439843419198239417409604494170730985885863744837468647941467084`48.29841594962362 w^2+0.63071189621634943068995153646604531573359902458045308671082162110124676113675`48.29841594962362 w^3)/((1+1.55550931724976304372680387320533316621885281987569521831579578751007128347335`49.69897000433602 w+2.49301277869850061109608446059734393226213451450981934960506393337430225262464`48.29841594962362 w^2) (1-0.67428040502023786735324713712291716874516726873885294922420223541702398436628`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.14582833830672+ 2.70388502676851512031012379102981401249883142066089798285930465087732030372556`48.14582833830672 w+7.6715495630595300648179925429373922419888482627581887228146944925978544398972`48.14582833830672 w^2+0.40165231310200953805867519729397450094615089454942871685264398539458864982875`48.14582833830672 w^3)/((1+1.4961770183941247546471432069178186811563014562870712178312227565579262913487`49.69897000433602 w+2.6467394719415152377630142279840687799660467088155342053337092320467794847721`48.14582833830672 w^2) (1-0.6608125537321486057379252769334977075863946300299763111346257228466679128511`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`49.21507505884601- 1.51014301748397835764280511624631241329668286186385217806468669267047065602141`49.21507505884601 w-0.66439633332702944472279838123879172638753704071697752134536176401310822391864`49.21507505884601 w^2)/((1+1.02053998699580333432221699705188098000127646613613808168608944267433910132574`49.69897000433602 w+0.63728890151035160084083468743158856826523747672904628067471435579432413838521`49.21507505884601 w^2-1.46001067068964952492166125944989200170227401190837781620441329482625255973752`49.21507505884601 w^3) (1-0.81873725499404592439082774027347414238639479521284951391191564690449853107706`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.55629243479163- 0.70415250204849983463138732906025384176700345657239573989986854547144445511372`48.55629243479163 w-0.24542389608402694149918514114958384046542394746623141111409043977476833029719`48.55629243479163 w^2)/((1+1.16164458963226631179120566272735650765247144295189435827688532168651321192481`49.69897000433602 w+0.87533299443988385673121727395685267218697519235076818683184481518178106243975`48.556292434791615 w^2-1.22367751433170444502142566860677993489457838103322855681588976505241228516838`48.55629243479163 w^3) (1-0.80106512361725432053104746081880632981914160768230989505810671554381817425967`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.59932652315526+ 1.76059820530454196348783062414415613657898832955730036840294607893965842975258`48.59932652315526 w+3.50879040005670714036785900159091298478500979977260893341377147670326376300935`48.59932652315526 w^2)/((1+1.47554307763647793225473114409946074085391165724320977102254455484157318936525`49.69897000433602 w+1.83960000746703585334760541073450473958589538131664418195033619278146800391272`48.59932652315526 w^2-0.48246731066182576227505360576230011314302629055348292242316839182099112570637`48.59932652315526 w^3) (1-0.71762181593818039219384152036738209757122482858968100606806293294167079631018`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.64781681281953+ 1.67632440338720952755961449732225707798968336126772589964712233141521885600393`48.64781681281953 w+3.25872968580459366730813234347317501449336970986594957846537668845087801711116`48.64781681281953 w^2)/((1+1.46990942840125690394786935906586220473258444718043126832047602512274337272204`49.69897000433602 w+1.79010289259680204243386038802673568375527473389526685631930626397755231614818`48.64781681281953 w^2-0.51228326889438509159608767013037007879363050068677947426042604479699284483722`48.64781681281953 w^3) (1-0.72174963879182763090803078317027510242632181961125517046502769074310957352126`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.25415233535736- 0.17032527624429759491647829774903699133566986805399494354943933529922390990173`48.25415233535736 w+0.18035265866366428586831923032180143480163445151614376036564792407850591170532`48.25415233535736 w^2)/((1+1.24646102862879251704748934108812847895947986893266878707449262900556799776687`49.69897000433602 w+1.04020671566300449163913204627381987156612626362408858922731614512756825842582`48.25415233535736 w^2-1.07212634283274547373238868842583994858312152697416534490139057231358882439217`48.25415233535736 w^3) (1-0.78720029152523389989304406448344493101171851493176560198539188452020141526073`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.12009417486248+ 2.27785512238302506503673756989503549954614393846198826983251815110230877347764`48.12009417486248 w+5.63102760402506020821768357900703772294151095025907181431347400160994146354729`48.12009417486248 w^2)/((1+1.48514193582569448471518044260545213603318338629672819801269616666801662928936`49.69897000433602 w+2.23737428892461887969474273752239896574705728422404963890927054092505135573646`48.12009417486248 w^2-0.27191655687266525269669874386606844493103913769452876860022876301281017515458`48.12009417486248 w^3) (1-0.68604114907156958203201835220732582763097414420968857702036935406505534840903`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`49.21428774257103- 1.52065019528205754293368502047491434594819691478671916800248898362195871003868`49.21428774257103 w-0.6683872884285797679446479900620632312782597637411291119612355876916550267492`49.21428774257103 w^2)/((1+1.01858873534908295857528922695539220650337322639534931498345647649191998861961`49.69897000433602 w+0.63418403353965717587436287706683942412738116378469277670910861568528000892154`49.21428774257103 w^2-1.46321997807038158586777183407462748874435674247268954124701656027694797410765`49.21428774257103 w^3) (1-0.81893969463844402510824119291765426575544910554264173735546879063205331747173`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.599538113392+ 1.76024664086007157568442195116243520723836204518554825678748462156926139867658`48.599538113392 w+3.5077098931939619016266794714792736144622678450762348238158844982701613186927`48.599538113392 w^2)/((1+1.47552114433842417933841740121825065283299653856043754857935890420424543886977`49.69897000433602 w+1.83938777765764077884018006394915724335049913740568658702230504246727700628847`48.599538113392 w^2-0.4825933785817448382161358431013735940420733072040874042294713494996397829222`48.599538113392 w^3) (1-0.71763942808812121301754175659478387019421237416969138364778816211655904950897`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.77980370105087+ 0.62289858160034141155496138657014632742322159806716624929832920902845479910304`48.77980370105087 w+1.11086751333633970920297635659375181001799225154629459761207139944862991615788`48.77980370105087 w^2)/((1+1.35883141505198415190256813880205089805084287198816620814945405379183161668973`49.69897000433602 w+1.31295772553609139117432174479496674069510427246219683731727011383167195188339`48.77980370105087 w^2-0.84423292417063689454310526171817781782740039371572793841514823811407020731833`48.77980370105087 w^3) (1-0.7631832916302891001524856094675996243332452277752660273509007764825770617375`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`49.062467016168604- 1.22273999367045214939090917233264542200896120522989986051380291447938491678359`49.062467016168604 w-0.54166537022393885207041791157146734490585007593251274950207837250277172298453`49.062467016168604 w^2)/((1+1.07273737155327465753571281763389443284676818503474619170006112658606513429554`49.69897000433602 w+0.72182283292626809086024460733771766719269468219522830317484729860348149071121`49.062467016168604 w^2-1.3738347406360289987297479342916064526537001700573115186456120189571140453853`49.062467016168604 w^3) (1-0.81290611051792663202436911516187529449127506136300300710202438602134350861871`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`45.93488211358334+ 2.58179073449533588562352858855804114700616497630582453980310148674924788613078`45.93488211358334 w+8.80304124835891460741963581369155826913628171565382501479253580803317234224865`45.93488211358334 w^2)/((1+1.40691198257610959143167839264943626234481380401949405233469319334612537669855`49.69897000433602 w+2.80162696603619832917908793870850188428970567450364711906729429688313179235927`45.93488211358334 w^2-0.05270447487718790199702394285129045014631108031898512499967574467832600790594`45.93488211358334 w^3) (1-0.64651708770070038509595218885724849550712854177473205886624939295255987578954`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.459956595006126+ 1.96408399766931189367158770927947197595751272699508598510109294943148291086656`48.459956595006126 w+4.19663426885336095145217305422879036306167680992372682373660750611252384611736`48.459956595006126 w^2)/((1+1.485600505771408538543156241637091941836274192663824378117828164404847046515`49.69897000433602 w+1.9722224898774687595032548446933602412943194474479962632061958650594424357528`48.459956595006126 w^2-0.40662633382211409565935265139859589185148566205290169117613209812951266470431`48.459956595006126 w^3) (1-0.70676849318152669798745280375749907625180291078834486009432807746402285783597`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`47.193275567081606+ 2.53733531365291143345185303473596460078387858906080207935001673911318454566861`47.1932755670816 w+7.84316789555615102639159208971478369502968693208000145804891394759275205348034`47.19327556708162 w^2)/((1+1.44013919821630786392668335344264913225985019902041556018983576718921702944597`49.69897000433602 w+2.63188233127641355981517603732806461446583324630171503108884733538027349578774`47.19327556708162 w^2-0.1097668480059823215430483679993814568274296648065287250666924422201027807445`47.193275567081606 w^3) (1-0.65774432071718659606309817346722097514647579735127568070390964009194606254378`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.51852925192524- 0.67976979454722093335192985758448403172925303169444111840563274909593353194671`48.51852925192524 w-0.22884429890400135809346362104007231689067315307172063885821877589724430990639`48.51852925192524 w^2)/((1+1.1656663030903759794037624765582115251836503293783427854414143902883713237965`49.69897000433602 w+0.88266474633323441063459716507342179112796727912934659218360682638358575782938`48.518529251925244 w^2-1.2167204841501090012275756303906167685109580436624330006162195046944786989708`48.51852925192524 w^3) (1-0.80046876827731815997787193987300235945493082692468174592150038025246148658672`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`47.832080493266034+ 2.41592722359716003805441700919031162875172040593373241724668219447599594539572`47.83208049326603 w+6.55938072550622884608281800707736732702912317677829404474412090444597575185075`47.832080493266034 w^2)/((1+1.47207661246107170813882818380288664536522617391179296210909591445599630570996`49.69897000433602 w+2.40412284399488558721541295671580804281109670694748270177412707455008031597911`47.83208049326604 w^2-0.19807616008703805824705838551208786399326570083302552812933623211547534694998`47.832080493266034 w^3) (1-0.67370438822364589695976156521721376034464040164451060005185447755662985516451`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.53210339440683+ 0.3423814622707568172377977027232960073677443987442390296899716527337741391937`48.53210339440683 w+0.73367545323431536236486982475483332498264677740716133063251309162012689026757`48.53210339440683 w^2)/((1+1.32117025072173888854216302639588216610243209982259991895090199218628907671834`49.69897000433602 w+1.21132648833521088307841756398587781441185237955663612211859810358912505804532`48.53210339440683 w^2-0.92582183192116396043783827238576211220026172487985171005537054932454079794071`48.53210339440683 w^3) (1-0.77219613247448881605584763906402571054686731425144092939260398949386654364026`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.908321010311084+ 1.07805079085978872730593021081904810138093870771247224384788103765209401774725`48.908321010311084 w+1.86744364087653427997671745532696908829071935111713604871358052725352476400957`48.908321010311084 w^2)/((1+1.41391551843154635022624071876036845723075255619242451936341173028000512564797`49.69897000433602 w+1.49556534941052536463232137397834520021969818712139158135724495147673544317133`48.908321010311084 w^2-0.70741243542196892065444583532952206581401439504762995916714468668074110988042`48.908321010311084 w^3) (1-0.74705380737784369468407003607586429905070838614890925870907309813617296161806`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`49.1588958414033- 1.36714055571342938137103764628643808026685159820700667615805338911402371344688`49.1588958414033 w-0.6066814908534465630650077503969173455553269563204960412120309556502792502017`49.1588958414033 w^2)/((1+1.04678925172101871002468510752269477145734937216543271529904921357156039476799`49.69897000433602 w+0.67941490545834397114768860605503816746703205583866501897568046756830685143307`49.1588958414033 w^2-1.41677213862790861487705605082919506718250554169365162623092773659690391410803`49.1588958414033 w^3) (1-0.81590524886925531002121916767483548078130001899819421257856984735636976653196`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.01692860529138+ 2.33715131910122262884749769684706880218806893107954484533378862475921684173211`48.01692860529138 w+5.99297429754380541522474585920605315690271015511440160650198549399771542144017`48.01692860529138 w^2)/((1+1.48113032688039879644809183632035111579834231128147415428151669143133253261272`49.69897000433602 w+2.30269821584550920707140043126275443560612630655287333646150173731753120265508`48.01692860529138 w^2-0.24202624741781447196649223535467391825521803701943717183728587694035222899185`48.01692860529138 w^3) (1-0.68114287624791881270760502441292429721622500732771242963573233037531249208915`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`48.01877671236095+ 2.33619805104475861832420803468519743539358638571703196414077897997970863292675`48.01877671236095 w+5.98678676267321335563387325721816629524633441435075422022799859384837787495291`48.01877671236095 w^2)/((1+1.48121084224412083992582702761495826622401297011289808641614021864938044280354`49.69897000433602 w+2.30158525322577917978389683397427409224585309142172126821699152740187159803439`48.01877671236095 w^2-0.24252499001037875697690312864001820606336607436248777901958636238308373711255`48.01877671236095 w^3) (1-0.681225628537814112589517705152319459283594080125078135493389671330019919219`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`46.87370112101208- 53.08958619663000497493197328275943505442996601961991496015822404964521318558217`46.87370112101208 w)/((1+0.21364922675646716066107713169775083072541674301627305386572448248365796950538`49.69897000433602 w+0.57620221803985466149015559573153143818574432774863489822968352053352340544404`46.87370112101208 w^2-1.04977599083268872458193631117167707078034465373654181182924053571680208138598`46.87370112101208 w^3+0.8828899918802603032449785325343790969749745357429732767157055984756424972448`46.87370112101208 w^4) (1-4.00544513874672457846169250750149710703968934194970437414266527634073011691273`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`46.24754882034012- 89.37523856639801909759320877633451252186532104616972823525296970489851204695801`46.24754882034012 w)/((1+0.18489679593604310016619718220213714846968545635590358428291652842163430198789`49.69897000433602 w+0.57276823922237932221146342414146248804333072003767785581757943084331220132363`46.24754882034012 w^2-1.03305563065848131697782875752491174568363540034166668755367054800233329209184`46.24754882034012 w^3+0.85452403370027051387181678412947585875737984474395905047195978487772998927332`46.24754882034012 w^4) (1-6.38198601883659759329382010729675935951895502567843598968336365690933613097333`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`46.30223798507895- 85.45223220123818052517019691887099986987999546204890710719472222715550169608044`46.30223798507895 w)/((1+0.18683762170673564221512434958088185654450213782700693130093344371279187559807`49.69897000433602 w+0.57300278932732296733517827338808563976202717668483512259825346946239983197543`46.30223798507895 w^2-1.03429307390263867251932509774777537244595408061196256686670314884074813686313`46.30223798507895 w^3+0.85643995426763391024567226919943917381904271221227292212106459656813200655195`46.30223798507895 w^4) (1-6.12475547866293096857388323697230966888898817227183417727085709600784263777055`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`46.484346874359844- 73.53101666803994165070107561157286410767118638547756358804019363626180933835387`46.484346874359844 w)/((1+0.19399546655966152449846799563203759330475936818567808879457783596402343591624`49.69897000433602 w+0.57386169252926908409143011829475312232239633299798970045836329951080451673474`46.484346874359844 w^2-1.03872095289992460734603137669255399806507601351315845657872771990905107035098`46.484346874359844 w^3+0.86350167186809150028122485864448897225321853966711325865637798335291690229236`46.484346874359844 w^4) (1-5.34339939389963579775623672683777581578066356242248206048820659312757558413437`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`47.108099266599574- 43.49197428650269936953772670101981294162114079127344563228201181527621851718437`47.108099266599574 w)/((1+0.2291256413296669460213120118752428731671658349680943141092170182143567558105`49.69897000433602 w+0.57807560942675125864833513410786993728514157380786456599825440075982324978817`47.108099266599574 w^2-1.05733209249105796580620098939858733002151103566103853978124846923401037291438`47.108099266599574 w^3+0.89820790591875364203873386700382947225458211131967266264464839835148689140029`47.108099266599574 w^4) (1-3.37881418989990955802402699954837669418093371672510826463274516270268830143373`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`49.25890441586835+ 3.13705881339992162156124194432856377150829153091079889234264164057679830151982`49.25890441586835 w)/((1+1.13301938505946807166247158952564228320941987145468082910586409230207182790671`49.69897000433602 w-0.12696503309560971507346094428649259568279930912939451863487914138959671603278`49.25890441586835 w^2-1.68853874514598802657987522340479526720885112616461863863140289125177740067999`49.25890441586835 w^3+1.22035564282951905702984660479757371023851606174556812430374425956072716523091`49.25890441586835 w^4) (1-0.54156647328401247505555253039794449984357831417041699364188735016932095165512`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`46.35885374912959- 81.56318612021015965629435483569490703136161581110940251151221781210278017598575`46.35885374912959 w)/((1+0.18894456251607138236969627966109292506904111752058222989215510924667732198147`49.69897000433602 w+0.57325652222255725637284843611091484927487220934345852922670741572379110151335`46.35885374912959 w^2-1.03561864259150957495875504684636694297196336908979855069107488956380513444209`46.35885374912959 w^3+0.85851920577641422849715618354435285021638337583073103510817225778557464463254`46.35885374912959 w^4) (1-5.86979743481962849616812783446619575319774761165897549103106738047413900213166`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`46.13764765627966- 97.78152212138787405522482314676036695993497791350515060066470092889960307851418`46.13764765627966 w)/((1+0.18125926452794621226953500474258880381607741578307954400099590459854981685821`49.69897000433602 w+0.57232619251557183142297398043370177442654090424798968468624473611880542031759`46.13764765627966 w^2-1.0306940743170067662852615173654221697951588807558050285381195163295564460475`46.13764765627966 w^3+0.85093129506088011355338008041031981094464227278719044897219762590341715462897`46.13764765627966 w^4) (1-6.93331424178682661671151244128101599556450857616306745968573614425999677040834`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`47.18367818360689- 40.76011144343884643193610902334664163021476555159361198612441938738105176206607`47.18367818360689 w)/((1+0.23483192747636759715704159703758988345335986560373182066039935101812343186779`49.69897000433602 w+0.5787837406705501058700135306309688719734956119064933116342254690440844078168`47.18367818360689 w^2-1.05985880493702789498591035100903132428872833212778310637147347246897643872798`47.18367818360689 w^3+0.90387869157938127941953299359895719428664469090719151637127707779945270766589`47.18367818360689 w^4) (1-3.20077531919151408987062684767065292264549406995248817132943534525637975111881`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`46.04567370066394- 105.38931143227064191562831898042206175864649851048152531859626392806107537649517`46.04567370066394 w)/((1+0.1784649049025040381231472299832141543607490144273864483892432018102983380476`49.69897000433602 w+0.57198412837277847062220860212976074691741717399501357836174655459334784666907`46.04567370066394 w^2-1.02884243302038905493197609155619143211742406063779743947238951148177977313651`46.04567370066394 w^3+0.84816935640903084043362192121601033796258106277053907967451392136642735480347`46.04567370066394 w^4) (1-7.43239743142750921728901376403610118859048439825329615140011146055414485080001`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`45.7572968966256- 133.08024869587238434081856432094917985928824762472609469873510737063179670292396`45.7572968966256 w)/((1+0.17098187736380535731165377310832151855611274821071262650273903317687957476266`49.69897000433602 w+0.57105525381984559145377393413597475665848923632430563682304015655400330087209`45.757296896625604 w^2-1.02372335869355212188129014069683726793016986084561315458593021833488586723809`45.757296896625604 w^3+0.84076238371422959780963582767009983143197596858200642287378638185267949536003`45.7572968966256 w^4) (1-9.24963934149477383049279885284470695595885629540866428380773040706254907126581`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`45.848417144811044- 123.65438305888256981235741691631237139268263200093092538033404742154633467750416`45.848417144811044 w)/((1+0.17315419501232502798785622496221482074670691094145996490169352852162082242264`49.69897000433602 w+0.57132703001595366277112228851243538675500815284775872732425416164541309331315`45.848417144811044 w^2-1.02523352629358405852732890197837201063683614817959066596211940871718900626184`45.848417144811044 w^3+0.8429144337274622948208225869173214256043405834764257862299240819767364306815`45.848417144811044 w^4) (1-8.63096497030173345067170109616050673260540599949154010012543858336540470122247`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`47.86730707612681- 22.35986560068628112736871420958798448861738559345565000879288326599845911292444`47.86730707612681 w)/((1+0.3078061575653687780292002865187274417165216214304827454794080556635875677705`49.69897000433602 w+0.58991972769700714418455342634475621111002571720223409425034056104144572587312`47.86730707612681 w^2-1.07907660003493033630415191721383743344096890992080042783099672765483577642345`47.86730707612681 w^3+0.97897774157423290038198043704644117197817671765137019416334427109584557232565`47.86730707612681 w^4) (1-2.01024360237235498551854569285971166057350042406800637616072164558634583650431`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`45.67191795386898- 142.53522547496908658955789322401706651826032968947608108609209497772185802916551`45.67191795386898 w)/((1+0.16909065842720097241087336981387587591664514215235780465346298366031426043766`49.69897000433602 w+0.57081707938617051593208379776385573872983015385997449385975145836930870760968`45.67191795386898 w^2-1.02239253060507250631379883572820966283586620728369252018999750252558851694798`45.67191795386898 w^3+0.83888745284769557931850245936626540806072495747588091562897622030108552197851`45.67191795386898 w^4) (1-9.87029639816113602068113630769708809953803128135934881405344264031662181202533`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`47.973598915796174- 20.32230335637323049175428039093615847458039280402310925101415983418271302892619`47.973598915796174 w)/((1+0.32355416437355824223858767936238484231519146940076173069977329883056974592028`49.69897000433602 w+0.59316423214684446170472830661940173599745167504287139155571072274650812052416`47.973598915796174 w^2-1.07975679493962231756592218139472433113196941638033063337136781593098028017296`47.973598915796174 w^3+0.99624352308767068153721083842117475265237332456843478417822503446583157626767`47.973598915796174 w^4) (1-1.88032615006843552149403192524678342585942383420003946009010192289439582511077`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`46.08191437302838- 102.32664582834966372791671264512276068867708542690058225797334198729970218009307`46.08191437302838 w)/((1+0.17954011725785275222671388449861765631127398349171304189427914609050497166079`49.69897000433602 w+0.57211602367369831294026739509069064389190079759176481859513178674126687501695`46.08191437302838 w^2-1.0295587630348550599617843045216066669545595629509554697953330018278877123317`46.08191437302838 w^3+0.84923231932714422331058676542805153764940874353076677365149727367466522368202`46.08191437302838 w^4) (1-7.23146922403978578494334004797375710327720529196294203999729591909202872507273`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`45.98293098035426- 110.89936267113920078276825268479937249427836830944660787718409399149001706243919`45.98293098035426 w)/((1+0.176679343151705210743093676810271070785742102153164418643523025528216631338`49.69897000433602 w+0.57176428353437185860752793105099502098701247047231214142885679935301739244064`45.98293098035426 w^2-1.02764219272681984510578831423857067899748778387050828736961526029067658915939`45.98293098035426 w^3+0.84640346438429975325815189723841195890606899582411625115962987125494947107765`45.98293098035426 w^4) (1-7.79392520996657615135100331982604641492802338690508366945360208490039105933485`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`46.196321513039564- 93.20437749803514511163758138545072363767196096684472422482582977231190979956767`46.196321513039564 w)/((1+0.18315898720824830576787775738282516202456407286894306940174479531281265218527`49.69897000433602 w+0.57255747779154330619058484671845097729396129057649706082037884611368490623771`46.196321513039564 w^2-1.03193429640747682807948185372766706314409154107419811008488102419365819081804`46.196321513039564 w^3+0.85280795696089745893462902654217884597796739578743327126649756479345882327593`46.196321513039564 w^4) (1-6.63310083953591994671175378015795983036942474758817824249327525668737396404203`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`46.06783195262678- 103.5065248648321477043895909378570750645633264436972521337575986935316711787864`46.06783195262678 w)/((1+0.17911839883427359189270319721274775574049025130292790969391526904434902811861`49.69897000433602 w+0.5720643342516038768997308252521199489767660746110646885183684172350023320881`46.06783195262678 w^2-1.02927838001297696472479444181703875347878643082724778703969843528846925264526`46.06783195262678 w^3+0.84881544022548969063832554783323086563087364090740346968217093412085380117789`46.06783195262678 w^4) (1-7.30887409610062351886170529319322998859418942571256818490988716461302004116319`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555556`45.67283779993647- 142.43000268587791430428509523986088087689812578854743722116750754480688135553848`45.67283779993647 w)/((1+0.16911032768180138670607326832265218120078377434421081073457009779662526166875`49.69897000433602 w+0.57081956428751165186669640254621717348062213051409402216592033981918804370063`45.67283779993647 w^2-1.02240644868235963168089009222705894253302850627708429567331797627790422358873`45.67283779993647 w^3+0.83890695951138436728649351971739540050806102089743625457771875031196796767143`45.67283779993647 w^4) (1-9.86338886947609597412752619577387581985716933277684139983139776964750382057046`50. z))} /. {w->w[z+10^(-10)*I],pi1->pi1full[z]};

(* Sample Pades for the 3-loop triangle form factor with LME to z^6 and THR to (1-z) *)
(* Mean and weighted standard deviation *)
Ftri3Loop61Spacelike[z_] := Module[{const,ls},
const = Ftri3LoopConstPade61Spacelike[z];
ls = Ftri3LoopLsPade61Spacelike[z];
{Mean[const] + Mean[ls]*(Log[4*z]-I*Pi),
  Sqrt[(StandardDeviation[Re[const]]*80/Length[const])^2 + (StandardDeviation[Re[ls*(Log[4*z]-I*Pi)]]*80/Length[ls])^2] + 
I*Sqrt[(StandardDeviation[Im[const]]*80/Length[const])^2 + (StandardDeviation[Im[ls*(Log[4*z]-I*Pi)]]*80/Length[ls])^2]}
];
(* from 20 each of [5/2], [3/4] and [2/5] Pades for the non-logarithmic part *)
Ftri3LoopConstPade61Spacelike[z_] = {((27.75349106640862591309119436644004845808883656311623481092629161053289343623017`50.+ 72.17210390454858684756604231354555602365842545105309287878`49.35974500512269 w+88.0250642461739485495931243577291246500928859014040500570652`49.35974500512269 w^2+62.580532832726567775258610899304646227383905940255144941256`49.35974500512269 w^3+16.2398121938587883359670697096652137759811931197457529350953`49.35974500512269 w^4-15.03013977755887833215469526619272545815653686430298521158786323010916297287713`49.35974500512269 w^5)/(1+1.54147496667147582506659902787747944413914518854874821911837065552380236409192`49.52287874528033 w+0.99579092092217842230170010824231733388833251697432250560107575130230879635738`49.35974500512269 w^2)+49.0178940430516762112230634968322279554157767701456110374554509937221331626853`50.70003483544608 THRSub[2,1]-10.51359203667661011264172951082343763179517551883874338392496393941736148800801`50.70003483544608 THRSub[2,2])/(1-0.16632640822621067532483880017811889857671426555547322684407492977791561858823`50. z),((26.19457510254967455559151694066646338575896255886644823512713055426507392396695`50.+ 74.6513168150137635877299700321698408388876031033607614794176`49.234336636094106 w+83.0586737751106234537161551442698546965774716924173022975969`49.234336636094106 w^2+60.7183798193620130835719429319290639234972028913792935179444`49.234336636094106 w^3+20.4355710656052436051863264205816568650503095970783206791316`49.234336636094106 w^4-15.89019864875917728057122567714796109971071587781013262253822395195913731204216`49.234336636094106 w^5)/(1+1.74258362330470629099595978112621093177088347574607372017538239392948833476484`49.52287874528033 w+1.05304850289982845673796766959237859500060933073563757777995318407873749232028`49.234336636094106 w^2)+45.21833126108737123278010470235089874399707998699756314591131815271693970146336`50.52244245741293 THRSub[2,1]-9.69864366349215934108619756634462637168965344570895359887637806226701421994537`50.52244245741293 THRSub[2,2])/(1-0.2309476085745598371745309187273919302528188734478297452988761976226573116859`50. z),((25.53931393949409849925807813406490661917457907021735528159025002013907929540444`50.+ 75.0552832904541858599419727783455393282723056058793442119256`49.19902480701846 w+80.4595321570872041228956494744292592216123057163535044271048`49.19902480701846 w^2+58.8016735170616763901878565867805693132413612183572745101232`49.19902480701846 w^3+22.7711363528423709822306254388557902315931266380990103304876`49.19902480701846 w^4-16.2718450097266872657031399303990753258366941033799704143695`49.19902480701846 w^5)/(1+1.80945860205451092404643591252796808565004009191472924348046158844276509854102`49.52287874528033 w+1.08092448960392584478397663320328950725052006325505772747917039615981731272009`49.19902480701846 w^2)+43.6212561234067130982053910934733795183553325990398482074694052963614922073151`50.458534864938095 THRSub[2,1]-9.35609535991252596452186327225134851936082081677513779850326869232347344670393`50.458534864938095 THRSub[2,2])/(1-0.25810992128414850858123127242372453606428428864774236996256593533919503607935`50. z),((27.76016448809743609300213948104628391893595696319699135384266249423887515455101`50.+ 72.1564297367159147603947551344004078616176365419021657752692`49.36051413480746 w+88.0442814268607834076660260829675490679754609720633955552219`49.36051413480746 w^2+62.5803673441881365739951887432218158775097040596615885357102`49.36051413480746 w^3+16.2293918762381465548083998336683159260163989608248856850865`49.36051413480746 w^4-15.02775608278028883817775558675297845150187560746129953405958555876436493366412`49.36051413480746 w^5)/(1+1.54048029519155871295357516736180574292043937179121261648245354146182695927494`49.52287874528033 w+0.99563968326103927125359017701554037619327675205039778817230142045014058725019`49.36051413480746 w^2)+49.03415924609340394500252054051072548929184504501256578716258747401375444959097`50.70090183182597 THRSub[2,1]-10.5170806751118771428016357627032793641375296901487216952593566600746581881346`50.70090183182597 THRSub[2,2])/(1-0.16604977720185826855168824299775352259623940176245193098933709256429062919287`50. z),((27.78730243955476399058560611103094229803006516584622865974492216663517887292947`50.+ 72.0922534631391598521741780056242776740656393303119533923092`49.36367455585756 w+88.1224949125045535054434125172093171190091592374409976201373`49.36367455585756 w^2+62.579095817746237877859387662076251273105951774421219999068`49.36367455585756 w^3+16.1880269076974342504078391422300711394748033076982498865887`49.36367455585756 w^4-15.01831094144209893555225583084006023646685256413175284877611795532101232131236`49.36367455585756 w^5)/(1+1.53642461798739363054527056936065140491799393204264746266765269708016746128799`49.52287874528033 w+0.99504038396752573488321110622616097070456099859176064052694681270642325301246`49.36367455585756 w^2)+49.10030286943585277462312050313788337135408336726607578287318637693773720547305`50.70443950297489 THRSub[2,1]-10.53126747536566490506815743693000730886105225003097770549100379047604186038154`50.70443950297489 THRSub[2,2])/(1-0.16492483715452776892870232219999981918008252065512408925527787257027894577158`50. z),((28.54448472395543325611686431490981043122234033127369015408454534523876152128965`50.+ 70.0572592546711495608193612950231162792357828026384067618718`49.48180425604581 w+90.5287636216799369440571631462195367681434108928608933869664`49.48180425604581 w^2+62.2878023081052761450178019541203500722484782022548626775654`49.48180425604581 w^3+15.87932899577285308493480356389156681389091761743260226807462992832121307514111`49.48180425604581 w^4-14.99982424163346291908459815912956562196875167786446801110982186593763504908111`49.48180425604581 w^5)/(1+1.41781352068483377059585888587325240707777328950645096879993149367848518360503`49.52287874528033 w+0.9930476733454463146925088513309307938783091089868491473581775598724773363449`49.48180425604581 w^2)+50.94579146129672754071882569563302806327930305012888767968699910397904937741119`50.81214606570062 THRSub[2,1]-10.92709668308570511567220857080294934857521767575559062105617972259783136053153`50.81214606570061 THRSub[2,2])/(1-0.1335376237095165234550216140533910621367151347703368684718150001818914327865`50. z),((23.56582178429538661222666053220167941157229542034597100514057954597849653673106`50.+ 74.6326881232414000500311985954827736560664282313758899317077`49.11592942533723 w+70.7604526563408364856005537310714040174442078246492058002601`49.11592942533723 w^2+49.8788123156136542165527219475958094867210024536317409309311`49.11592942533723 w^3+30.4444266077408856951815567080448496389290367383531077377111`49.11592942533723 w^4-17.1585246080169179473989652103712987176615809223379530803755`49.11592942533723 w^5)/(1+1.96377726828037773335090020229021059244625745251228881767340588898780045767778`49.52287874528033 w+1.15706947661628520111853409614653774471994229759055003214442254274545476846823`49.11592942533723 w^2)+38.81124229506028943159962932199441037367082318406800531912216002802957802296877`50.28822681627062 THRSub[2,1]-8.32442062012072650337611006025141726938484190371856364502980991411473021633478`50.28822681627062 THRSub[2,2])/(1-0.33991640406036185943633827718090696610802975106131316826537077720252306645566`50. z),((22.33715360650722950342518190794725580694841040863060156370664246972648010575305`50.+ 73.4868708106564367021336816672374817105393971971184635410871`49.07323429487095 w+63.5903634864230866634139108384209152267748210140955152033306`49.07323429487095 w^2+42.5742907358306252410227703649416101192807695720528092127712`49.07323429487095 w^3+35.3810365022284620542760771031778634121219077439139739459605`49.07323429487095 w^4-17.4990684435956746747143204720154448942635194415985798858822`49.07323429487095 w^5)/(1+2.0341091979993212349782122342613350747614140585285481717603528163946410730383`49.52287874528033 w+1.19635078595158228289230371903927122492497452743926106762951797832098227011036`49.07323429487095 w^2)+35.81659602294720567250071610487857695286992122890261401793813269466386173058003`50.192717857105364 THRSub[2,1]-7.68211458446160449424105766967443342293609918296648076211543676167915579969952`50.192717857105364 THRSub[2,2])/(1-0.3908479579857878323175733627659901425290780686633662438986375864453141482633`50. z),((27.88277743245819271213902248578588246719256075571145036299253629682451322556726`50.+ 71.8609792341803743232280923395749479003871029102924662336351`49.37523145774862 w+88.3989426317587193826470812285245924810728051165782602955187`49.37523145774862 w^2+62.5672778479128376837022733561581302024752068859048392850878`49.37523145774862 w^3+16.05590396669636976263554770937295377704791919422291100512660011061968556273085`49.37523145774862 w^4-14.98846826097134841568462299414079524351037464033413515722186754361639935912883`49.37523145774862 w^5)/(1+1.52202192269238193257779256375146296221312460780508016092371745309945589560276`49.52287874528033 w+0.99314443376574983624369327805063431639349198842546391707598553608617883086924`49.37523145774862 w^2)+49.3330051048701396244107158914408619634916196803992156457424380821509099582286`50.717041724379705 THRSub[2,1]-10.58117856226854180056070336314068815072663426511698995645511023356199706967565`50.717041724379705 THRSub[2,2])/(1-0.16096714553566901889601790538815837023628560527662282867817566130332830039934`50. z),((13.56937496745356864155067954657208467036389983152010552560924316804332482485418`50.+ 56.9126043606149961161014755173046027414120165296789764031253`47.3397442969114 w+0.302327991280803128790560524384022394145203761233169135391`47.3397442969114 w^2-26.7727551741127488242370660667764788043274489927812223123293`47.3397442969114 w^3+70.1030422253531349701381975483238352350171621217960558380577`47.3397442969114 w^4-17.1517206175957866430627833075774787404861159860251719946177`47.3397442969114 w^5)/(1+2.28686292823910980261369637798714022412434503423508397724181204766406179946411`49.52287874528033 w+1.3564759249640591540180935766148102802417637790413698249072`47.3397442969114 w^2)+14.44679407737926804182088432062679121623340931937456567097305784956946500640907`49.512871285914834 THRSub[2,1]-3.09861739539525738080434157553481609928718510038420273930759445818832413999285`49.512871285914834 THRSub[2,2])/(1-0.7542956313560289561259088987146770018389639500562132620465005620299669555695`50. z),((29.30976420765122784436297975025498451306682527022778877340206423126416918104862`50.+ 67.9099260363787968220573819182784571588019833099147327175535`49.312235666632056 w+94.6966396378629697384473849007180144531746304747085034382715`49.312235666632056 w^2+62.6007111662637330657498534434999181645167240566450164124759`49.312235666632056 w^3+18.3461977604111834983353398892012474627625646169445443539448`49.312235666632056 w^4-16.0061832490197082693656800830222143705386891643071662126411`49.312235666632056 w^5)/(1+1.30107067765962083388843520540102785774843718663838061681876652410828726994795`49.52287874528033 w+1.04871757792345177689712046554246459743213375093210838987592068070883001635207`49.312235666632056 w^2)+52.81101544479715410417471917235636351070507385812401071228694451963357788131556`50.94555517265051 THRSub[2,1]-11.32715883186600488612084097804323293276476881651874043871789570762481036955625`50.94555517265051 THRSub[2,2])/(1-0.10181475988305973386305271473862997614401861073256501774507256025797481792148`50. z),((27.11827807081689769978125052986461593623383196027339463311072673635642388013232`50.+ 73.4640376695092390995730462586707304539979766839794283413289`49.29814639451214 w+86.1637538814565110501587700623298953626920986243659165127893`49.29814639451214 w^2+62.295377737072535263400854286723486861985527792095489147302`49.29814639451214 w^3+17.6022225889066111357439159720133253027262659935656416983081`49.29814639451214 w^4-15.335811210173604920016639978048077178990390880445023781322328020389041297698`49.29814639451214 w^5)/(1+1.6310184666374994702207800812887276324376133160453729952697294697933004947572`49.52287874528033 w+1.01543292521647728273566397653656205880090565599480391564107965176884936215813`49.29814639451214 w^2)+47.46968252131197082565065411116809492953706019169645404499315838257623723436671`50.622271416625175 THRSub[2,1]-10.1815242348294424743592468513096276020460503058602293966967988969871508812973`50.622271416625175 THRSub[2,2])/(1-0.19265767123438273785108852807273292733251038507498511313915901657803286548385`50. z),((22.04262429176204364324907151612334052423641669900196694659860795137919084063445`50.+ 73.1390125932311272300488449813519990534132575921119383942286`49.063604707972644 w+61.7710935924356056695081002241763012937812811423484973260657`49.063604707972644 w^2+40.6754017563332528374993569694933414967691744159217829819879`49.063604707972644 w^3+36.5676806330994025351958210744380559900797155121792756069321`49.063604707972644 w^4-17.5594010257181440548407362319319430575757380320825271956254`49.063604707972644 w^5)/(1+2.04881344278573150216069134228321441793233314207713727501189785485067787730623`49.52287874528033 w+1.20488246909403640864376629357284522805268236640544301539223426289440883736879`49.063604707972644 w^2)+35.09873653055155792053044262699566790128648123135611630850082400238829496803098`50.170566433579594 THRSub[2,1]-7.52814465184730384572661885676147874467517953036446162607665938097212021822414`50.170566433579594 THRSub[2,2])/(1-0.4030569790605971671253871670197415657965544957260731160555010878430324707732`50. z),((22.12557431402294680974567980529030115999804420951227326718969335109537354257247`50.+ 73.2395098902932817681441896230306650518924728747396250482814`49.06629693099769 w+62.287003659696174908135531648695722373604038163641524320008`49.06629693099769 w^2+41.215333891158943462211241876173684715240892153372261053662`49.06629693099769 w^3+36.2334663647700072193525805805683185600508029799892626420226`49.06629693099769 w^4-17.5431828575401739500754760997030471652967094136797257827364`49.06629693099769 w^5)/(1+2.04474685292186622199792041012934545301338429982462999129450073069331633029119`49.52287874528033 w+1.20251232049157062788657037061103614855179104997694877715003733882832544165083`49.06629693099769 w^2)+35.30091151923116244217255886617573992294100039965610646185757559142550909866549`50.176781751185665 THRSub[2,1]-7.57150810906009647155639475614645322514645278001857942711288919288876774493002`50.17678175118568 THRSub[2,2])/(1-0.39961848068628271821597426428960415556555696600679618464477776201705314727848`50. z),((23.02365705787789489583155777912077444050913558378124711861307465950851325686946`50.+ 74.1929930301042461766590967353912730977278396671510734230475`49.0965247542497 w+67.6859030864776852135972351976798472557072002551353048916847`49.0965247542497 w^2+46.7882890837640499095262062945933936968110667950050111375889`49.0965247542497 w^3+32.6180893640563560775551889680361806397245031133819605971768`49.0965247542497 w^4-17.3273197361867115419664577195566467059107417444125051040654`49.0965247542497 w^5)/(1+1.99674944755278794804557371229719616520325431770621752799365683098437868571796`49.52287874528033 w+1.17516269704077407968623976425630807752587747320986260330094881453250597203232`49.0965247542497 w^2)+37.48981832869686190662872891196269336973508787182260085061214598999661658677364`50.245377844175394 THRSub[2,1]-8.04099529634753018739849627438089665951579976281368533634332401626422319640652`50.245377844175394 THRSub[2,2])/(1-0.36239056958298947573407365789884125911743720352810538027498340450296088807227`50. z),((24.71658369445459103756341639127931467265339907701549038463298663892768285165004`50.+ 75.1395975205417936870516779208841036744932415356756442892046`49.16128450583224 w+76.7328018153604925973498699120104518264714708739994297222955`49.16128450583224 w^2+55.5906819620185031275370704819438766469416213975867386748183`49.16128450583224 w^3+25.8974027750460924943046034763718683752297725957177778686407`49.16128450583224 w^4-16.6941947385439089572673269061400376669173084880366282865186`49.16128450583224 w^5)/(1+1.88133640051633488131740838424272284523894105705283046744637445806147601299268`49.52287874528033 w+1.1145227111662795264046299824713068852410057472608476370094150226101160684368`49.16128450583224 w^2)+41.61600677634741067931542377723813516274054497161292567192671927133766591432372`50.3842003787482 THRSub[2,1]-8.92599990235824336847641018483289509886731989295469729040848931962786172957205`50.3842003787482 THRSub[2,2])/(1-0.29221427150565588367259733094361698990457819527973079071894320678612214555073`50. z),((29.08287147091460902637942236597520507984273502279427345352154997742151120376171`50.+ 68.4943803671751723074940729734785050879106143358390617114045`49.40928977804762 w+93.1014684688658667176044075038654824490250528754501793504819`49.40928977804762 w^2+62.280279024440072695069168033883688371094585696166384896858`49.40928977804762 w^3+17.18779569155781956514917160860904506821391187750671584841178233519936195525446`49.40928977804762 w^4-15.5299304805483444290529048718276146874417263869296079024564781059585909489935`49.40928977804762 w^5)/(1+1.33324757221100415471851719482473175313133038117236082675879655690033350856669`49.52287874528033 w+1.02248812730812862574240136656237738982162913168108407163621853251452053240178`49.40928977804762 w^2)+52.25800731736195189344888949818965981031334840241407423017546072977354352233017`50.90261109491267 THRSub[2,1]-11.2085470073817920780876021192613243975602294287909517924972718355457526846838`50.90261109491267 THRSub[2,2])/(1-0.1112200654531865994159095386948977490250654518011904300422447458063887771262`50. z),((25.00290226985129335596603891724602224544651426570088590122009640419894264716985`50.+ 75.1581788404030000132303429247531400601856019442325358220772`49.17377717504909 w+78.0855021372558680434385467976551498395834048163463771750893`49.17377717504909 w^2+56.8006872985191073632198223684063694454592753203867654419182`49.17377717504909 w^3+24.7923236332877913979313316047462439330266634989460784392027`49.17377717504909 w^4-16.5554920867886298824724380118972600472376036566366662648459`49.17377717504909 w^5)/(1+1.85770225309918268394786901216796394802752094243271736876527819388331043821785`49.52287874528033 w+1.10309199421752982213355909188209758109529218085487938660472712855462437428953`49.17377717504909 w^2)+42.31385414470034730418749796126526904281454488401933338077830374385359602141133`50.40943022494098 THRSub[2,1]-9.07567753902470827970148315998984321554024285905656972222943262155402909477156`50.40943022494098 THRSub[2,2])/(1-0.28034560734856840478201095765366738448109061967044150767757920803130129081368`50. z),((23.97155226080884370048867757969516579566619837843979732946191393890600767073399`50.+ 74.8832507520956698197892643600450512739282780289181558266543`49.13117834739787 w+72.9576844095600506389987391485267641280914075373583932105091`49.13117834739787 w^2+52.0347986851299182614189202746051477081948626451437743665427`49.13117834739787 w^3+28.8274496063265373311117574633009055468003968650547376905738`49.13117834739787 w^4-17.0117067450144022922412501161753831332246954866136578093114`49.13117834739787 w^5)/(1+1.9368040860113088750560171544626712524390077731994642684749706162760057894336`49.52287874528033 w+1.14271196515673860587412440447339923822174979662111182416021395592886188515535`49.13117834739787 w^2)+39.80013358478259795919687278522928967859960257068014600329788658293559736087825`50.321191924784536 THRSub[2,1]-8.53652274714462461980408500397986480221311725980092747763994246798244021568653`50.321191924784536 THRSub[2,2])/(1-0.3230977999674862502040840490526980929646869381220694248717642116680807738273`50. z),((19.8174782578613437316966856224127156934933040397866796234843652574178677187974`50.+ 69.8332379569560146635697607631687817225018848077685229375445`48.99593765029551 w+47.0586339235648207214709435393774373555590277191808125342445`48.99593765029551 w^2+24.9439700426138875170588326276754697872172208042051380177923`48.99593765029551 w^3+45.5072174144058281380468470555050254757111672084606882836469`48.99593765029551 w^4-17.7968627477777785542407881528437921205771446123923737504548`48.99593765029551 w^5)/(1+2.13982848574816978313758549638257933820824798146022582096183725707930924876105`49.52287874528033 w+1.25996474140975714879469059105665001865145049587063084632937168601283192701788`48.99593765029551 w^2)+29.67536397497386523563134446284223703702881179655376812493583950812468448593154`50.00817334652263 THRSub[2,1]-6.36491380267673221673046898158738727003095119423252882141784525751443132896189`50.00817334652264 THRSub[2,2])/(1-0.49529518239844029565617944920565159399426922934617526554587084340039262074661`50. z),((-4.53423409576175831898442605629018116797859721916486209737269358522613231382091`50.+ 14.7649937167890937570446915879120634783695286544831307942575`48.539170191259764 w-168.1748624699209145495031579837315689114080644276068334872978`48.539170191259764 w^2-17.8169216836000308591203439201536377664266998494399159076038`48.539170191259764 w^3)/(1+1.46376335041054155053892512003970515376241611030340605882929983744145223507643`49.52287874528033 w+0.95076107906406501435003473156764422313308774834273946678421784460901937021338`48.539170191259764 w^2+0.24238440368097701832812196375627972107690748323143270071494179321560393941782`48.539170191259764 w^3+0.4522649626962293326178833474443185683259101097738542149045221082673645146714`48.539170191259764 w^4)-29.67732858895855673334660915213897042570119190434404603694170623892199669743538`49.52560524591896 THRSub[2,1]+6.36533518246768070031207148140432784932920229904432876915074555260915117907543`49.52560524591895 THRSub[2,2])/(1-1.50473823084439768267769363006829100641915196475000558281618153028279555718549`50. z),((-153.6366335176590530554356584959810364036369452303441396582849`50.- 287.4590396162928343350879911962084684442212693158069552401502`49.08535344217646 w-1375.5939010846811317897883809744035233743656124165775821245596`49.08535344217646 w^2-771.3428314667102584777288531553082288079169571741310330783525`49.08535344217646 w^3)/(1+1.77021316687911342267131409937750741114983539440300861840058123201827120305931`49.52287874528033 w+1.1842859475127250582052107340571026086050786686305293173236807062412618131107`49.08535344217646 w^2+0.2535107129233756946368389259068765703518632951791106686549577202089859418631`49.08535344217646 w^3+0.33648469322142070543451288805054561399007414218820782626534384420915402406422`49.08535344217646 w^4)-393.0862234101006890828220000086070093938782679024870688640664`49.93946115807994 THRSub[2,1]+84.3110106799363340204926202565896924806302879191631322584031`49.93946115807995 THRSub[2,2])/(1-7.68542804917881512380330044902060426543752161467140095901352429763580239248403`50. z),((26.45798426865103542533192656617529500376680326072309437222535463868953228217538`50.+ 54.4632584612705239222954099386457717706853801657006672166523`48.65382869777153 w+56.4759702858699170771529587316367338779793047633625678687073`48.65382869777153 w^2+41.9731373127744063156634834871247899996779324787296924626253`48.65382869777153 w^3)/(1+0.9597483041612280463924614435710333629850182217118309021328684843629565447077`49.52287874528033 w+0.82884794248640908221645328248686906135205571101248655344918742324456047692639`48.65382869777153 w^2-0.30751923986094944407344629057292390310900840708918689686229861915004459980543`48.65382869777153 w^3+0.21116440074253906267087556132053445266420545372400863104563104392056183985643`48.65382869777153 w^4)+45.86034127775914806094892809652510146890562461590994543515230360695214851953201`50.54959954237734 THRSub[2,1]-9.83634503827620729621171525788867444653702600119590489759532937223198009293202`50.549599542377344 THRSub[2,2])/(1-0.22002860017971878300841532450779118727097115540641941984617745917226944807973`50. z),((-143.3173738575131209868687755021682643455051270147716872630403`50.- 266.2879018106911376104310656020221684015112490909036461063018`49.08496609054109 w-1291.4735105778229337704877881348025173639009783836130939439877`49.08496609054109 w^2-720.3867613067195913801911938794246415031629143164619903382287`49.08496609054109 w^3)/(1+1.76776672458840728943555624657912250448908606295329072986154947409595854591148`49.52287874528033 w+1.18328407730965529641368461385062785394164035422209229182125653715417202546996`49.08496609054109 w^2+0.25420204725279253829491777570732305490869242328870617718981257605991068465048`49.08496609054109 w^3+0.33750824205237112907578073297764100114274425028715849428136910315005892887361`49.08496609054109 w^4)-367.9349799491904031401976439332871131928623717912750001870092`49.93561541433827 THRSub[2,1]+78.9164518535025373059703488347947496598736217388901127340462`49.93561541433827 THRSub[2,2])/(1-7.25766737355251637257532296954521117924881457499779291781209836239511540033044`50. z),((26.95493438298021931223504114169855541005606023757482691928856192315123857180838`50.+ 52.5212109470761100870870299542101609650142778924130803079841`48.84935774463964 w+59.2374605551829979609434329143473889486201356966190497450444`48.84935774463964 w^2+41.2531578339426403603593373153018216512535399333938934805498`48.84935774463964 w^3)/(1+0.86544453734080506031594796767148332682297056589998473364910415313825566565392`49.52287874528033 w+0.8937049204795222624058769304765377742260189382261599661195627984833211267552`48.84935774463964 w^2-0.34701055271236054545183283521650175576773588158325883002206254949651024174966`48.84935774463964 w^3+0.21926144505264248556257114963488423619850616707439047790620048554143454752865`48.84935774463964 w^4)+47.07156317981987681561305155846793808944629815194019633414105163570398596568696`50.60361235799162 THRSub[2,1]-10.09613369694378770255629926088993250273327011753450236814914987440146919416208`50.60361235799162 THRSub[2,2])/(1-0.19942870021993698586402922727034570876350472691545907807041833250526891190816`50. z),((-84.14797421379814101443829539273309976391620737752130562245957337076197596789263`50.- 145.0251781946752087575106077127729856212179259420701179191117`49.08067411247323 w-809.361333996834394958057949405215802496617324521456313194146`49.08067411247323 w^2-427.398230467748529307279774349660293389578627309820603953869`49.08067411247323 w^3)/(1+1.74370069016814256896124128851261466280899573649692255876182925061180749695939`49.52287874528033 w+1.17238910633907003894965767945863774198055012733505661647528127968904957499862`49.08067411247323 w^2+0.26020350216909562135969463218075063817935979758888627949263299568481295657898`49.08067411247323 w^3+0.34761621778993669282723284690499533971751507275783225076972802433610722251891`49.08067411247323 w^4)-223.7207606266069152543703125633154564998259684574057032727741`49.89865981685343 THRSub[2,1]+47.98469728824553156489416999795507455219443239202651723829829690328237724952278`49.89865981685344 THRSub[2,2])/(1-4.80493886379815782169021525671225295109371459899246492444811801480217886727672`50. z),((25.09361167989825641064044700058269320974816976258574238425353672623426502715086`50.+ 56.0942468767343988585315609251331133142130723118875456948754`47.432572414998596 w+47.0754899896182865178526735176653105224238368067737495826352`47.432572414998596 w^2+40.9496835419839187884396238022975794740483349468563351762193`47.432572414998596 w^3)/(1+1.09037999774566776801151121537731046920198755342272993256215141426980752055044`49.52287874528033 w+0.716726994732573991839065820647016295671050057109317133875`47.432572414998596 w^2-0.2757628572188654675667535573830463712830348897717523926915`47.432572414998596 w^3+0.20693466444550239127488835372851390774598214979707655604523780030697513259309`47.432572414998596 w^4)+42.53494117336558448023743214012798116473623685213687655530411556566327715582092`50.41755788393306 THRSub[2,1]-9.12309734090248436382080835847905276124434771212969889995497748116192601375552`50.41755788393306 THRSub[2,2])/(1-0.27658546177560555112870428764725509962975833504786799713136273065736603743088`50. z),((-193.817925984416278658708462498781864192837982290770374382127`50.- 369.9261845850297227878050079376887258961362647397008505874781`49.08644133748104 w-1703.1929457133356588975766935933806127883296920015112173459519`49.08644133748104 w^2-969.5670014967472715188111787830851167132990607033196497829458`49.08644133748104 w^3)/(1+1.77741519683426134932652423170970295311639343194398501752406177067184738620598`49.52287874528033 w+1.18711818822947809547335844417264834939512633131595957071578016277101049557987`49.08644133748104 w^2+0.25138868089229061060983029413821239873015372180257707165641040881895900163481`49.08644133748104 w^3+0.33347980855538731279336830475586298706206368334655499312606697110475702854821`49.08644133748104 w^4)-491.0205232231513908805184942310950928755526494430702845343924`49.95088070012778 THRSub[2,1]+105.3164270637506019299743696089292064181319863437797025973474`49.95088070012778 THRSub[2,2])/(1-9.35104916728089723040145195639933467844698094103950370017346984761869609362147`50. z),((26.93823329782470374955129497527096335232134610814994540440971374989431129462481`50.+ 52.6077286102679972452837281031870312479816918577264755235673`48.84311177246334 w+59.152763859818750386949354303155312002076714922951926902886`48.84311177246334 w^2+41.2939527649776996365302556316702852555471935713246858282293`48.84311177246334 w^3)/(1+0.86934619531077778069681458932750298557368862608521232460245256473297362725364`49.52287874528033 w+0.89105759835350867702949083634913003920463161335566925912159694411289303643868`48.84311177246334 w^2-0.34520819110724975136550185699676884981729581752779088203168850403458341371122`48.84311177246334 w^3+0.21887633504286387989107417030435796374143435249216365355350820550732805050705`48.84311177246334 w^4)+47.03085744388127495958868522696077447364530922308259059426316766431667119677233`50.601731618440276 THRSub[2,1]-10.08740293627840147666484647514851047927162015898079311308465409091954985115521`50.601731618440276 THRSub[2,2])/(1-0.20012100448449647040075719835875791040583785281834206023813907545928949791779`50. z),((25.0429876333654668384174333419171850718828063150934931872732073537845575844624`50.+ 56.0961089877269608673478185214918592426335941949574046985423`47.61728395815724 w+46.6888212116113695527609574402202415586324879545691171498007`47.61728395815724 w^2+40.8646367848377432582109368032973366540119857586470341151255`47.61728395815724 w^3)/(1+1.09315870592084924086530173473472244716745903985665708989004785536030613046307`49.52287874528033 w+0.713259276556270338604129756636987114736421000269638981588`47.61728395815724 w^2-0.2756785213711141282522748960792454550925747578907382399320339112499865926755`47.61728395815724 w^3+0.2070416803325799251674006764385421119695300170776099924293638202034414866361`47.61728395815724 w^4)+42.41155463583711262577563692949572692034659792981195092342196731759900299466053`50.41301361076509 THRSub[2,1]-9.09663280700690127640743003818786397749112681687063393820897182875367192506107`50.4130136107651 THRSub[2,2])/(1-0.27868396273991765717624791937532268302366973736408533763684243750777625975687`50. z),((-82.02831823453556643405236026071736897649720334993292413681397324587987922239164`50.- 140.6882632689206396531003313688886177188614023854134067957857`49.08039376605312 w-792.1032475594004126470684364109691574824477320639681665527195`49.08039376605312 w^2-416.857701460738193979944575409729767778306137325822011832882`49.08039376605312 w^3)/(1+1.74228147393577123879368959745435266294210741628954715713892655412194739485807`49.52287874528033 w+1.17168954350590799553708848637274490196402292815002840534683521460187197634057`49.08039376605312 w^2+0.26051228420012568033788054811696900643972562426792457831697522113630652608578`49.08039376605312 w^3+0.34821297126526318987581873844872238104058395905283110562622074396127667190196`49.08039376605312 w^4)-218.5545001250223185840831383154303507045248070416447479549581`49.89652850548521 THRSub[2,1]+46.87661306045002811786517542110377342458631120645863583899529213647528804012843`49.89652850548521 THRSub[2,2])/(1-4.71707350294417380403017334937690378222419437185807405158905142232617473557154`50. z),((11.84652808478183388032604207828095319579977107909238212635865796077389925372792`50.+ 35.7422972027995926163314447076036648212112503181128373298526`48.41528357744678 w-64.3613158785339053473077136621950087818008409463878946722776`48.41528357744678 w^2+52.8216637545194479580770192940264619708255654768144756674029`48.41528357744678 w^3)/(1+0.86837820529788673246197963249925220051675560890718691185974539345109544022556`49.52287874528033 w+0.17265574928915644345030558627254955762149081398538077771295607351145534728061`48.41528357744678 w^2-0.1955825029461652964239279396368458918599477304286865071650082908376442611622`48.41528357744678 w^3+0.5173855839704566601882979088309266021485751281438448594445280595369672915671`48.41528357744678 w^4)+10.24768068949749104272794567453290528121298718174962481702784325391870403787436`49.32443827756009 THRSub[2,1]-2.19797149989510234200316695391202769255672932029165676811690393147041738268777`49.32443827756009 THRSub[2,2])/(1-0.82571220297100292684882488478451607380415677715289851823078484086385772384592`50. z),((25.19438668903620128284596640193236362186388635774163607963136490084819087056484`50.+ 56.0815398288921381039217361332902357680993382685432011651208`46.3434043224143 w+47.838388258429864496930499343725721755908797218024456337208`46.3434043224143 w^2+41.1122350730624214467248085761636089839745245598889186959767`46.3434043224143 w^3)/(1+1.08452455688409727893672217086063425038781401505410851977634387042905774898951`49.52287874528033 w+0.7236956535827441221366353624512868306311186376276659661555`46.3434043224143 w^2-0.2760865942438957162553901653531002681667300761648935302413`46.3434043224143 w^3+0.2067619945365118920341971236531058016323037163298897848648`46.3434043224143 w^4)+42.78056119583607888401185507515767448198883641656512839853311981749293829995591`50.426667903286145 THRSub[2,1]-9.17577909646762720975268046552404144997042426757936941825622934176025620360624`50.42666790328615 THRSub[2,2])/(1-0.27240807043021865603188501576746383780852595996345274436457351463595709882001`50. z),((-131.0366238569121597985262048768251552134261741069703944233711`50.- 241.0985146954051865663579458720887577343860007073759686358688`49.08441803353923 w-1191.3734052003604087953866867004816526476357052493452940582235`49.08441803353923 w^2-659.7077801240806988650994090335029807667699687881225203529626`49.08441803353923 w^3)/(1+1.76439869176113643933070588576678055693966460288172506578679658525108714125173`49.52287874528033 w+1.18187218419926394516537859268528838351007773919860231081866488641038617330658`49.08441803353923 w^2+0.25512927295994280382110204785759623912418211675203613078640541883337638726571`49.08441803353923 w^3+0.33891924170568100500970226351561263781096721191921737713017341390640522543689`49.08441803353923 w^4)-338.0029748131435720613692490881938099307536891778484747566153`49.93034837745443 THRSub[2,1]+72.496492428813354562232064617912112143138432139393156162435`49.93034837745443 THRSub[2,2])/(1-6.74859772219533302539066552734025320871443481797097663721053086702774194528701`50. z),((-41.33492143661198909129452388156324211559280442601535539548336541414028459235025`50.- 57.7021315313971905570061505940981056541223827455824869916531`49.06892092037024 w-461.3246486576776621183055126250256847323643433865159925095108`49.06892092037024 w^2-212.8459772507391574961223940286388755115478187036329508949416`49.06892092037024 w^3)/(1+1.69345437993685636328454846763861211944529560763450981474059144572297798940586`49.52287874528033 w+1.14410963326021500357531825299610249687620398050460191978625092035270996200845`49.06892092037024 w^2+0.26817781152136230460433044827140206909964530178073076892847666487916487553658`49.06892092037024 w^3+0.36857580828458104878701087649128013365817173301802432393157154490151179052341`49.06892092037024 w^4)-119.372042872897213891032128769147271756631471626895113346765`49.82606924519313 THRSub[2,1]+25.60348590757567133370290922421882340517918453523800568915478212247441283809664`49.82606924519313 THRSub[2,2])/(1-3.03022430241124659526539753666971507526059175910532110668951267139134777490297`50. z),((27.7303861477895224852424011778726060367062009974934493339566873382535351218155`50.+ 45.2059228595116052212736864898013183688748273933324031517712`49.17424602110571 w+62.2271750525876437448549679992572228212043019581348375692975`49.17424602110571 w^2+36.9667181287343725890404125886279098476692465008224560773754`49.17424602110571 w^3)/(1+0.57052387568007646432755241465566894921056246499109083065472934127158249941727`49.52287874528033 w+1.10094175027039752427274944555711506369968466687656809769500619078351676374926`49.17424602110571 w^2-0.50983066771344181729891048481033182659599208842952111177348089596042176004567`49.17424602110571 w^3+0.25655003529903223434362604270784814229841060177478988566547705858462829988225`49.17424602110571 w^4)+48.96158017437581314024524504952774047910744153398759043117422604406863555494712`50.69704197991729 THRSub[2,1]-10.50151356915319900671903740625941992147598834267090373388447037640926989214869`50.697041979917294 THRSub[2,2])/(1-0.16728416836834267047525929662978036958290477473634397611087043376650523845636`50. z),((19.97182826491875324816582567700860647111602741195097903893919658644598549892427`50.+ 48.6587625512516299876855539589543211287765658837876363475413`47.566747315252165 w+0.44990771759446596700228644417650497866590279080233889005733848127786497305625`47.566747315252165 w^2+31.832178761479117926375589674803517564282284097605368664095`47.566747315252165 w^3)/(1+1.06116169908827611155581247075369565398085242541364208453900703851697389976748`49.52287874528033 w+0.3454721016957257517702424552545640905197386426040805392600971729047360850626`47.566747315252165 w^2-0.37295618053289487505951254366981358242306455836736958968153195077943202930486`47.566747315252165 w^3+0.27232506393378859685105102740810219127065899743440154092443405636087777659612`47.566747315252165 w^4)+30.05156292078459872549390210924483580073889888068979049310655648848897509170277`50.01929111805506 THRSub[2,1]-6.4456027493990877056325971739285374746979740600898719797296364369212268114606`50.01929111805505 THRSub[2,2])/(1-0.48889696532897392173451956053498346808151251799910536848453793348832710411893`50. z),((-26.40793888205433623212165897452995818996225411623642484220317527147752958457784`50.- 27.5886826377204144552072867940097901797769962681177038402803`49.04059793411703 w-340.6944792817547179492196093637428031216425474134064146636647`49.04059793411703 w^2-136.2233460470334241484350553459605126903970666693915392647723`49.04059793411703 w^3)/(1+1.6502100493023275326829899713576782806932251182126946749474663419937544568259`49.52287874528033 w+1.1146954806420277817412390406775022816351033996439130265934450147686204009364`49.04059793411703 w^2+0.27048955751593431307252160472337552177667357037120662239957176068757673619709`49.04059793411703 w^3+0.38606049369189149141539975372230421931100876128593772715073158002488608773947`49.04059793411703 w^4)-82.9903464401193196448835649401979974746335490489213305122676`49.76738867773941 THRSub[2,1]+17.80016588814575671567412823857637479600328753079041015345769870697758773220678`49.76738867773941 THRSub[2,2])/(1-2.41146129490017684461450911152992811412511454898295206965263580722023745439937`50. z),((-117.37344146296302699065213488838939099750867048852949983779924801524934508659681`50.- 213.0832811244592637849145609434883957757991126046919400188191`49.08366027834467 w-1080.0215545331820307315633053829647863055624466691680879791301`49.08366027834467 w^2-592.1376634411781839194076507144986723787857441997553977509576`49.08366027834467 w^3)/(1+1.75990589135890389496125620032364986741745475984853803801068509817289375035395`49.52287874528033 w+1.17993058156415782379944123065266260985672046039013074762906206246439055783054`49.08366027834467 w^2+0.25632185469512252340196147191323861291697830984991096508262827745461002967181`49.08366027834467 w^3+0.3408041929187554653296715257162903201334147830397963473047913792671573711379`49.08366027834467 w^4)-304.7015522151412336372683666767760069590033041659724979141656`49.92337142531416 THRSub[2,1]+65.353844253662114536847180457332241421550983316753822717238`49.923371425314166 THRSub[2,2])/(1-6.18222258245411841765939788088153344187582924453130395154282174959248051767025`50. z),((-136.0144094406210800599990008850348784612754744003042646353861`50.- 251.3077161761851232543404906877815557845554164939393323314247`49.08465315609704 w-1231.9457558265704120412695146679221534002458465665954028551349`49.08465315609704 w^2-684.3083747742367672303855675428143698148892846690096601389531`49.08465315609704 w^3)/(1+1.7658307481985512416132665999427851175428499956770729512556381527917346884628`49.52287874528033 w+1.18247710499511357550943292954715073832918478869330333005395323599394961184784`49.08465315609704 w^2+0.25473850109935253480448329313899037706632775517772973056171217300348323364848`49.08465315609704 w^3+0.338319054105559015982796197203874516964413242211347453380664136372583321156`49.08465315609704 w^4)-350.1353855902072014216636401909217715836950880990964815149517`49.93258400373449 THRSub[2,1]+75.0987098398550414106869937933804824345550301419028212615613`49.93258400373449 THRSub[2,2])/(1-6.95494013381559316085134077856805625217823926387013507038728991747284019030161`50. z),((25.43157018067395793130846897848983243024124684950461257672360379843662441846427`50.+ 43.7608876770978681374550778562238546467643719693077770194151`49.18642430916387 w+8.93728813142675961803025534498492362220884170752062744680266445542360213685966`49.18642430916387 w^2)/(1+0.58763945571798621334095834194180467469871582448306020909038765943660035007834`49.52287874528033 w-0.31291633302798629496638346855280318564987446142769008317421674345899818765338`49.18642430916387 w^2-0.71489388968879994697766126311987481198550471932502099687166527209901130082757`49.18642430916387 w^3+1.21543496855932719493521543443763163888124562709248904153755989292245136312344`49.18642430916387 w^4-0.51426428280297908239538038166494940491689795089229049126586742479443530064394`49.18642430916387 w^5)+43.35865109177398520253961422370506562814119542383038515080863295956704615481819`50.44846182310038 THRSub[2,1]-9.29977057845740712471641635003043926204541325112070487380561293945823938696525`50.44846182310039 THRSub[2,2])/(1-0.26257618578231005046510776118495459001637450716439155292287498730237426391827`50. z),((-50.0233335476656037150700732994257359866831450763044439448305029315874353050889`50.- 50.0271181701840782284005001031294870214447853847853216366472`46.64291338582263 w-506.4832434456893336419037604579008538532910413303388132578539`46.64291338582263 w^2)/(1+1.20292003508679794224719875973150496497253977538393857285768444628343842892367`49.52287874528033 w+0.5447236059446011820327323355742316232724066719850322196491`46.64291338582263 w^2-0.01707102433223887790201296476174572429665471858721291464774547519828401494`46.64291338582263 w^3+0.3689503210137394307030907515304413881605951575750128004719`46.64291338582263 w^4-0.112117674116491095415758183891322652294155451368838657794`46.64291338582263 w^5)-140.548403919203189658271216261804420607259797918777017420014`49.84821867740789 THRSub[2,1]+30.14549296864382446032115787944460907017611043601861048225161735251320026996174`49.84821867740789 THRSub[2,2])/(1-3.39038202274633623936339108620224211879790811123817792003563619800111244380919`50. z),((-118.23732235178295228775723649454737412208593124476136114553440565419258132676989`50.- 144.5778282736627033715574225581099237263001404422517819903497`46.788342182328826 w-1001.2194849990212038325340418144430261466966519859272193642541`46.788342182328826 w^2)/(1+1.16585026457561980841400148546537515016838182225344504987405033918719787598763`49.52287874528033 w+0.4878891361715372430851544170318390063229527468037263883512`46.788342182328826 w^2-0.04495164143312549041534366119543117921244886322111627461630493068492460635724`46.788342182328826 w^3+0.36197448889964137585208831659504205162877299131919090831`46.788342182328826 w^4-0.1191041494251924149118779977842296037997168812108492898492`46.788342182328826 w^5)-306.8070984724810014743440939764001832247863362277715149402757`49.92385379523678 THRSub[2,1]+65.8054518715777099850583049343686074582346934617830790187354`49.92385379523678 THRSub[2,2])/(1-6.21803273597602648743247097933662298537259232641212272091367398987508471448576`50. z),((23.60808201692019461257217832004676880239156157348074545643220285034433312817649`50.+ 28.37470257131247478239539614755252714232294861040634004060897468033515171290766`49.69897000433602 w-35.20053246956158866700428039825581064344472841856208826989004723646082410001592`49.69897000433602 w^2)/(1+0.00040593672923202499868414231241177448279227137525627627032607021059816058995`49.52287874528033 w-0.98687325269406662650354032290530211226782714197560340297204292887214692526077`49.69897000433602 w^2-0.5378349957616148763883683628196687113485410863365509953094764993246911221083`49.69897000433602 w^3+1.66230088040528339100815020645815318996439162599871443957477228495880130368551`49.69897000433602 w^4-0.81938251147851881788746433610663977583684888768026585526672875679933246672692`49.69897000433602 w^5)+38.91424361826240551751041539064764744076404841392019999079474460113104003324917`50.291621839921014 THRSub[2,1]-8.34651283588246066756338634843348944491531374049384713502906860294312227919505`50.291621839921014 THRSub[2,2])/(1-0.33816460536015774234324378652643528327880381627980039759921450575361654038599`50. z),((-165.2802639495890296143101347101424395453108048364105194883845`50.- 209.4900787051948976831680579545961806958360214078450554440638`46.81710924939749 w-1341.5842851664097665730522986204848027580591087743353030540754`46.81710924939749 w^2)/(1+1.15633720806249026697218839365198750655314266312666427053038192614718057942388`49.52287874528033 w+0.4736678416834757846821941471196005931131587775705198799805`46.81710924939749 w^2-0.05130850313336218118087043686516827587363355853164262339052521975972616880861`46.81710924939749 w^3+0.3605070362728175272628999538547191774076242683927978707135`46.81710924939749 w^4-0.120575061663391303177856725706460108591530978331728816401`46.81710924939749 w^5)-421.4653701131688628344554786883938392910472885536930821149597`49.94328291591397 THRSub[2,1]+90.3979056110609514155436024327043401273454458224530165315882`49.94328291591397 THRSub[2,2])/(1-8.16808740501819169072896922930069019657406960335077863678123344192325604581682`50. z),((-139.4831262034004781379074272259248738746753037408674779294459`50.- 173.9069039739473397697436470249792105561502664895281092313058`46.80386222880872 w-1154.9728912167386433832459795065759151667805257722467858687952`46.80386222880872 w^2)/(1+1.16085275251399267451905067454929707790639225655775346061044764611052468519605`49.52287874528033 w+0.480399585436497951925386796834317315091030974121446021086`46.80386222880872 w^2-0.0483314450225886397922960782659498312710697300580726641636448081695011155594`46.80386222880872 w^3+0.3611893534378471162810203555042731393835832009336685563685`46.80386222880872 w^4-0.1198913537700593124596391238133287396847256479046128536327`46.80386222880872 w^5)-358.5897265672585989218873679349589632666470562279431175309857`49.93405872513934 THRSub[2,1]+76.9120372727637163246950138509301669326884671770463962391133`49.93405872513933 THRSub[2,2])/(1-7.09872764133740698507924727063783867131559411178156003925226291658443631023864`50. z),((-43.6488317869482340352872924067950505413789922087316073461842204942067469764609`50.- 41.1163399912576872634092659408514113201913005382138464677062`46.60545858287205 w-460.0346684928291142753566658423446275812672215420222207363323`46.60545858287205 w^2)/(1+1.21058212729438017919308869601890720746952761020853249989636296129217975980965`49.52287874528033 w+0.5567503326892887512826262912844790453348117912933187645613`46.60545858287205 w^2-0.01068467198448330454144172401945859159500245864482586918567073480287961844889`46.60545858287205 w^3+0.3706857643872168203002613501115790391631880387873960318072`46.60545858287205 w^4-0.1103823052931611110701396335887385945299374928008110324093`46.60545858287205 w^5)-125.0117616593904780487354533128326300392685545513675850990619`49.83258356683443 THRSub[2,1]+26.81311972967937684043312241964801130933731848154154607530845684247097259561608`49.83258356683444 THRSub[2,2])/(1-3.12614202203421810462268484138719082883834996081404109594592154073434622050976`50. z),((24.10804244666035168711354401527194387335692600682264511541916931396610889109536`50.+ 34.4213678019400075904001279604867462654394839401712532653364`49.66378083718943 w-19.05566464694468795721367922911394723480461273736439176749586073912607792600305`49.66378083718943 w^2)/(1+0.24608163456364481529059061270780098401719700172715117493111561009962889280592`49.52287874528033 w-0.72209857615896410293799885504488540240048881563154927703977065169875873269527`49.66378083718943 w^2-0.59308894832760319988279871273881149265919139698728026368886144875770922103404`49.66378083718943 w^3+1.43985100629410708897495894713085574990838101267588249882679906357335108086614`49.66378083718943 w^4-0.66992037213094651094685091878180087123447044065213439684545527373101826109466`49.66378083718943 w^5)+40.13280259471500456368924582309774254999899851631509997551256666441017325719354`50.33247934395821 THRSub[2,1]-8.60787518530940175459564281475388677473216395755196236509661341652279141000787`50.33247934395821 THRSub[2,2])/(1-0.31743991984439082332438567696311655923811784046351502303668072070583481548663`50. z),((-172.9723195467976356262278232828084538910806537416211183065817`50.- 220.0956923352190009348882706769554716106091296619024015897882`46.82025716180666 w-1397.2150571890936910003380932601607704073036242436029208501487`46.82025716180666 w^2)/(1+1.15522608023528721841219118416957198668829932142569516881808950496096076603855`49.52287874528033 w+0.4720165563497405260114976893639648967099664100371464760518`46.82025716180666 w^2-0.05202990250613775922681419068980651096665716046540680063959121876914097296753`46.82025716180666 w^3+0.3603429331176947290652733150933814503286912461739881568434`46.82025716180666 w^4-0.1207394042388935929622785804419702729416012137198706986786`46.82025716180666 w^5)-440.2133006248345991351611704870351626043126127479440813328198`49.94555324482591 THRSub[2,1]+94.4190512922380796654083803916745321813138779137869976165318`49.94555324482591 THRSub[2,2])/(1-8.4869435058996065603687644344616715165309157020888480890332296323192062563833`50. z),((26.8861810198906928697045757400952058122661145083728094153376186965634057567789`50.+ 50.2565656402839136127554463530881816799256469707699121929423`49.145761633334956 w+34.7747835661731668845575559109115330224340339671349289202134`49.145761633334956 w^2)/(1+0.78405953655150150848291585587531198996123571263599813875794669772974445366752`49.52287874528033 w+0.09164803911249513528921379896433507500394157721904327797861490481743658880973`49.145761633334956 w^2-0.98724723232240605306616056950389386262135756657717792584051406666753768538735`49.145761633334956 w^3+1.25746248148118533284583348189177630105518521203428287724552653540684106840736`49.145761633334956 w^4-0.48404108073756521844499629756458162034729146584827120304020586352704843287338`49.145761633334956 w^5)+46.90398986247236196188924862532581719664243988979003295802658369015874714032888`50.59590100909735 THRSub[2,1]-10.06019177146496247041747588732135517890993864911891163455635701824118920050084`50.59590100909735 THRSub[2,2])/(1-0.20227870942751032782544071849052325515361637310629414406319114593686591965994`50. z),((-203.3510991885169309816083834718072129393662238820165091011347`50.- 261.9671025377520965871333299899361651914005918000423991915277`46.83025217727816 w-1616.8831434018701528346932742004841590647145899192804776771447`46.83025217727816 w^2)/(1+1.1515900906263155900747597170707110234758568081840542227658598636813978258356`49.52287874528033 w+0.4666273023174260718733423612999799202063431565654469775656`46.83025217727816 w^2-0.05435980949327748531120953718147582260414628791560949022763355432777739736503`46.83025217727816 w^3+0.3598160404681890456779969354366022499475972397125612442975`46.83025217727816 w^4-0.12126670787079189977649861625250126051178654812114104903`46.83025217727816 w^5)-514.2558296412448487735034944539602092023688787556933204242435`49.95298420964653 THRSub[2,1]+110.3000465622230400867835232942476476210080220187752741453756`49.95298420964653 THRSub[2,2])/(1-9.74622447490475379769168136642194609451259721178977418705990163736144218113844`50. z),((-167.4416612587370803001190568634456807313999443416497281506111`50.- 212.4703326467800040171512292902433516284021747894678300388493`46.81802458291853 w-1357.2164980010432093970366583501439091861826460851506547348079`46.81802458291853 w^2)/(1+1.15601571460058322525745505158623267762101243596773461029287888053826255161049`49.52287874528033 w+0.473189848797620980142983901954529635632951061686784155546`46.81802458291853 w^2-0.05151768535258089272887519682389877771979019149645203842046680017327486671004`46.81802458291853 w^3+0.3604594034838315805875219926040454461067850907778965987737`46.81802458291853 w^4-0.1206227685601844925455074222118975067674593297918090120747`46.81802458291853 w^5)-426.7333672106825644963147402167711109471202530811302671621966`49.94393978867682 THRSub[2,1]+91.527810789872004321957554008954475307416755778132634659314`49.94393978867682 THRSub[2,2])/(1-8.2576830546779037512580611838703738768714518068615832486380745650231073556734`50. z),((-68.74290759283885092416443865765661608573521982277586085694154668403716996391695`50.- 76.0789139446111097581437378575022114525606028626927232563357`46.71244770505902 w-642.5491592163540287555977199547462941765955437379031207770036`46.71244770505902 w^2)/(1+1.1869471336040063112863505312649395885883306088861297913114078847219209979203`49.52287874528033 w+0.5199588491080243084193541163991532727231432912830293851744`46.71244770505902 w^2-0.02969464856865541634967183629797701090888340216461497270912527542474037036434`46.71244770505902 w^3+0.3656749773022431688487163773408341123481861971947547314083`46.71244770505902 w^4-0.115395041837856960808644795194592842475810287738740898556`46.71244770505902 w^5)-186.173824714945752793268216225067303475091343988182326669057`49.880803431794256 THRSub[2,1]+39.93145113989525588617915436876979154459675078118209295616374231500544684509531`49.88080343179426 THRSub[2,2])/(1-4.16635800403941621076198068385534335149217994613649794452893556252894417732745`50. z),((-207.1668037340837365724842954277673592173228172399727754866122`50.- 267.2250333493978459858047516356158977490236090574606943732096`46.831290050239744 w-1644.4708613816043926336580377766149586467156160013072581420669`46.831290050239744 w^2)/(1+1.1512025141332580986424765965349540410546444299332359222419119642668753954662`49.52287874528033 w+0.4660541320410658217506690873770187303156999237854172876123`46.831290050239744 w^2-0.05460538807840849236869304724863831998241011490139949008310096407430289122685`46.831290050239744 w^3+0.3597607718318606472123188095685422420675264631986072107174`46.831290050239744 w^4-0.1213219819212604791798406263981417042889984540453853585411`46.831290050239744 w^5)-523.5558877036558489642678366547369818954748798946148759739335`49.95377646755357 THRSub[2,1]+112.2947674349663349895079117302040268574700804998581252449042`49.95377646755357 THRSub[2,2])/(1-9.90439554610143631023183872580170164042555476064572780203769631923195725649057`50. z),((-141.678327799941364532647987738663736735916080273759995001014`50.- 176.9358998794394647912460792356701513123362604102781977283676`46.80518771672217 w-1170.8554408539385148549127848547880808040268446116441541203681`46.80518771672217 w^2)/(1+1.16041192921713085908710635129062095109940275455853598676477570922490403172777`49.52287874528033 w+0.4797409230350082371965545667313513126848659210373701649446`46.80518771672217 w^2-0.04862528411178875269586668188440391862813660903153943044766040785012746393997`46.80518771672217 w^3+0.3611216323815774118829080450785684283668861916518036064976`46.80518771672217 w^4-0.119959235280506612688204188388630864256783620984961306305`46.80518771672217 w^5)-363.940115220973122801695027748217883893029923634299079144199`49.93495907083936 THRSub[2,1]+78.0596141860724112566050570591828229691147817544981685665296`49.93495907083937 THRSub[2,2])/(1-7.18972456834553887252980802739891454083885253320665019835201362874227731679491`50. z),((-176.1793043442699410362350311329660603529014069187251871440226`50.- 224.5169180064141192151949265108476210452372867405702435458834`46.82148415888425 w-1420.4074076981676549688253856857928289702471027681715943871365`46.82148415888425 w^2)/(1+1.15478873441261195226092410325921447057018708433581185130413071837932665728876`49.52287874528033 w+0.4713671630025400467090019695915671812596771894895818208648`46.82148415888425 w^2-0.05231264173103219199570864302037251869275379013482025696322600066620243603472`46.82148415888425 w^3+0.3602787427675168586417064382641711854507240571720143707811`46.82148415888425 w^4-0.1208036754645000518354229977824651749635948693917905660932`46.82148415888425 w^5)-448.0297194448958973103753022878307614560297492627475190511828`49.946446922195534 THRSub[2,1]+96.0955541340319231959555181665008610931013137716553591055023`49.94644692219554 THRSub[2,2])/(1-8.61988152944679408303329384465815840639627834772976559520560219180517798894322`50. z),((-59.12897841695497981137589906030369936638957045304600820454171809381224725148191`50.- 62.7166633062762166396856158585792362480487700365207127245036`46.68232985370354 w-572.7189022476259208848371805689788955527770167917747602517677`46.68232985370354 w^2)/(1+1.19418030887929046591203114059970546875552253496257358683054384253014754224007`49.52287874528033 w+0.5311218392800540908577223622035684562672855337125188789493`46.68232985370354 w^2-0.0240932660806403219157420919135367889212432502030629537529764845792186198937`46.68232985370354 w^3+0.3671033596195192784078251872717206783452813087371840688686`46.68232985370354 w^4-0.1139652045152316657142588257411922173487793903653240261358`46.68232985370354 w^5)-162.7416908911919344047732312191097541386125043648686526617893`49.8660483268944 THRSub[2,1]+34.90561515935745211976338233384726439009460699585267267902074921749386741710335`49.86604832689441 THRSub[2,2])/(1-3.76783514725132439902754817081921166436231456831796633477272588967049272475827`50. z),((-161.2500448125615859516455851151111985703884107293744648442823`50.- 203.9326046051195807539537336966787338555058753060918197523324`46.815333350141515 w-1312.4348439881903605637922698832151074947809613916111644299317`46.815333350141515 w^2)/(1+1.15695730413237560694489461129892420942434639313554483229939450682417224464123`49.52287874528033 w+0.4745902773067851121791049955515491595597814467891209440474`46.815333350141515 w^2-0.0509039913341859277730085384001122635663958203218129211242805369597794952543`46.815333350141515 w^3+0.360599260414022853563888899386523145983671616630751298928`46.815333350141515 w^4-0.1204826840239080051001906930618532304721567594144346156843`46.815333350141515 w^5)-411.6424733110194427046798839398056520621827874700429299686905`49.94201599436635 THRSub[2,1]+88.2910437882035608175151844768013148358051460697429661236289`49.94201599436636 THRSub[2,2])/(1-8.00102413519515885129614284863953650605427568718860383451322975487117544069737`50. z),((-199.8185624041250955729658819906504983366076932124570942891816`50.- 257.0991420830089177740768899535143748985099012120123798582711`46.829254072405014 w-1591.3421250217119127587273203287887584053571336054461557723387`46.829254072405014 w^2)/(1+1.15196096557476003667956749825442721720866031681366442973325055371430628272316`49.52287874528033 w+0.4671760070461807868914309611162292527678872028690746689709`46.829254072405014 w^2-0.0541243128405489095826162897289224180518793800808255087519259448439438060604`46.829254072405014 w^3+0.3598690868614402581464813977803155899841770842952634586092`46.829254072405014 w^4-0.1212136488118563594094182943355809120015873653663649431795`46.829254072405014 w^5)-505.6459394335200302774153318875323412542058874111414140027475`49.95222612117629 THRSub[2,1]+108.4533561873755923338673097159885379425202227660541824195249`49.95222612117629 THRSub[2,2])/(1-9.59979145826091879968795875605585726640540497375669770067844873393716116995103`50. z),((-108.12200877511171580054476922061773293038301071237699572755906563421009682398667`50.- 130.6030981533529782462661621824729576158647891446374283987325`46.778689083353164 w-927.9859424297873141525812972906266253590390765300504583056834`46.778689083353164 w^2)/(1+1.16881895308999658380715307421957664246928379067577458447945089639655878397176`49.52287874528033 w+0.4923576837448304598188838381003183453320381609388633438018`46.778689083353164 w^2-0.04290156197428596385211755045105734072644552754141734413940319418332333258625`46.778689083353164 w^3+0.3624564791198482988966704124180824356274648594724196283893`46.778689083353164 w^4-0.1186207979982909891938319128193656317862240966216615133212`46.778689083353164 w^5)-282.1529350122011736140330019267344507108786099387481859133232`49.91779336762231 THRSub[2,1]+60.51750913786363694788912032710219003867817283936880582567162541623454074672315`49.91779336762231 THRSub[2,2])/(1-5.79872616629643666702027589469803652344864438365315385300740767057677510786827`50. z)} /. {w->w[z+10^(-10)*I],pi1->pi1full[z]};
(* and 20 each of [5/2], [4/3], [3/4] and [2/5] Pades for the Ls part *)
Ftri3LoopLsPade61Spacelike[z_] = {(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 15.9104768424302415826928301971442948544883493815296414292386`47.41612946575273 w-42.2176230107779702208564985114803158435110762600665141684017`47.41612946575273 w^2-0.442784647418282693573325284303788495278604065567671451055`47.41612946575273 w^3+4.1358805946692298499102865839207546257109752288530502668721`47.41612946575273 w^4+8.2155400821576675047827477621018206402825228853069092293934`47.41612946575273 w^5)/((1+2.14801351502598461602203653769579391626097436103413188792192888048648643278143`49.52287874528033 w+1.1667290095488717498194036166155089652605997102730127339993`47.41612946575273 w^2) (1-2.04661296856740415741030982052994027404785210599569573126401866377731615579045`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 14.4824335742223979782335315212201182332027368754389143100443`48.06122306722242 w-40.3832046342118411148791155183788167045569680159347658997602`48.06122306722242 w^2-1.9031360495498143922519812026653478650562489736157537584185`48.06122306722242 w^3+5.080240895703641860075382251816667625138100589484103581068`48.06122306722242 w^4+7.6056644717346130179261732817101105803814649995495031970835`48.06122306722242 w^5)/((1+2.19317597432118144954659190091573207394703935221354495747798248343712545840415`49.52287874528033 w+1.257658597415534355535708588333835273511830806446961430316`48.06122306722242 w^2) (1-1.9640905219760895523598159016026796339688536636093905063275963780171697305186`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 5.70567777031118698903222481840370459940475531170391489055942881079184559595677`48.89396820959129 w-29.6411338706325981136027789764245980717080125758458780569192`48.89396820959129 w^2-11.2321643427592373357310197550005918095900676060236494507677`48.89396820959129 w^3+12.4639304030736902353037919695551496552608116943848200087466`48.89396820959129 w^4+3.29970005738051824850032639634767634170919052970310119414582826394024382379002`48.89396820959129 w^5)/((1+2.64337832463587787866606200797681326133754219391080789770058627413422858535184`49.52287874528033 w+2.1390262385920820932159750482447294693838764488808367525868939823559755721178`48.89396820959129 w^2) (1-1.50006591075767680633448809752599575049398423481024540711808303804460433086791`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 8.5834470801219413552000142991118458631582138073290907077766`48.7343037927925 w-33.0348949070103086978334367632263938813943345745959003205322`48.7343037927925 w^2-8.0868763078634627977472445616860529357803219115775370047889`48.7343037927925 w^3+9.6640377940686206110981008686966278454228135876238556099341`48.7343037927925 w^4+4.8451564491722442678518251060170469668397964193377306736225`48.7343037927925 w^5)/((1+2.45398432461385135336311968684481524307153738369747247643433992515773956908467`49.52287874528033 w+1.7728514672898012577256905351879937477022831811770321996138899263967249716724`48.7343037927925 w^2) (1-1.64176794935287666621685547582966246033464453926878460276863688062705840182417`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 15.899980784093350645015696951304959181910236416484749022461`47.42658172933898 w-42.204080048404711772312702311467269030239251081024706431083`47.42658172933898 w^2-0.4534791756866575214968921236322525809221321219683281491658`47.42658172933898 w^3+4.1426415242097364243846000487751794156945724441099999843869`47.42658172933898 w^4+8.2111212341589365473948340574147752917506884741806663167439`47.42658172933898 w^5)/((1+2.14832608017058452056949337972338075490253075833079260018237308035084215322408`49.52287874528033 w+1.1673604304942799556220841383435104650055778594715255762109`47.42658172933898 w^2) (1-2.0460015877730284515099900951787784358746425433825844011510414878784895361258`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 11.5599958262574305882096702601243879366245636174915505502896`48.4979973720472 w-36.6892621562542628124256124671139369877823434877095478754362`48.4979973720472 w^2-4.931080086766238881444495856259352329019429198149605575561`48.4979973720472 w^3+7.1924053659035927042309019244170373865947950909506422634664`48.4979973720472 w^4+6.2940986472583836568183784366265848753298207048013011803332`48.4979973720472 w^5)/((1+2.30503452454133350310621585109549677117909223106145387866090538555811427799563`49.52287874528033 w+1.4804913369429384781200867191603485656771999786319225547145532866407539206882`48.4979973720472 w^2) (1-1.80007019798598372260946822965958013185932265469708776036602030155695672731956`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 15.7115464389425247527570661132620404908119696201288967101148`47.581536999673254 w-41.9610898387797164646942758572834121216372225465252914087896`47.581536999673254 w^2-0.6455703950578889079024071187665614729013253611374665096034`47.581536999673254 w^3+4.2644541893872785992960466648274134694724440869414103464876`47.581536999673254 w^4+8.1316364470233187246766835605622545846842539205201057004942`47.581536999673254 w^5)/((1+2.15398421006268257194718329903441589251479970526620020011821025646273785269568`49.52287874528033 w+1.1787853536345097121379954830299407602252091333127680989114`47.581536999673254 w^2) (1-2.0350372216595023582936266075438637296216192606478085821585091767007427712887`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 6.60525707357555800378419963129063336859007600043740353319878211489656245411192`48.848890660368085 w-30.6848875467485274057189517938835254732603039922917072192158`48.848890660368085 w^2-10.2372791555991989085464916430238637374102457527656579670592`48.848890660368085 w^3+11.5384770956742715254764389082741163433469397975083432345786`48.848890660368085 w^4+3.80048678043348920681854385882180602791046725714276143340435716839546688798784`48.848890660368085 w^5)/((1+2.57858346256276818941635260459076212588466802922983865007165217654022561073218`49.52287874528033 w+2.01435490350421920266993202336538758289801626933522596685518282644479381534122`48.848890660368085 w^2) (1-1.5429636458188106185678109168691352215407502644327060353309870957769481698303`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 13.8218845582420705915055332209485022656409569908671744954405`48.19919174340043 w-39.5406825949222069458717761584907744677048917332860809375213`48.19919174340043 w^2-2.5825394299824566703810249716638387743808368462067747066663`48.19919174340043 w^3+5.5350102908883179176085008779940176185994607453375471655937`48.19919174340043 w^4+7.3172147587738688246211643058289746923623557706462678929432`48.19919174340043 w^5)/((1+2.21600278885741836997810369973275926798838333580192350121103257137603411134473`49.52287874528033 w+1.30339510780550910684499841928281246493871271829980108683706802890044469932002`48.19919174340043 w^2) (1-1.92640349463333895414249688267595436161746689336671821901569822616189931823342`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 12.4231096816339946958132021393040760358574084931827660709764`48.40370462353013 w-37.7707405154042863778992430994719077065441098857273074424495`48.40370462353013 w^2-4.0305466729272915889315193364460374481397235768327893323588`48.40370462353013 w^3+6.5403319766641844517831337549334890921626227612539893730767`48.40370462353013 w^4+6.6914430680168232171589358665443446232989802365094856069496`48.40370462353013 w^5)/((1+2.26892550107506194723294606955628812192073295388883855608329832817543724342905`49.52287874528033 w+1.40890139717116202848678539665667193423188646052332253624734881919006976380618`48.40370462353013 w^2) (1-1.84774385232663537355671127268804215124616060096030927777388102714181441535686`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 15.6936508385923857491795949467097098432318095571063236688731`47.593794303288156 w-41.9380274433724066529401693926492022790736774824709178067687`47.593794303288156 w^2-0.6638226000153390864212893923189683555465029819573789621562`47.593794303288156 w^3+4.2760658613227149688854214991357835982324027488451955879479`47.593794303288156 w^4+8.124072518721412656221305169482875502905590767615860461159`47.593794303288156 w^5)/((1+2.15452619709638699912764782067331314089948495875087244022317446756414234274322`49.52287874528033 w+1.1798792203923056150358884648638715154355700325691981222106`47.593794303288156 w^2) (1-2.03399709503726239916029572701219405757018881805399682969474866023439282273481`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 7.98768813277619540845434004437572668820198015526868330951767792404453399406634`48.771391461818645 w-32.3197651702041253197895476935849170675599521598905011219524`48.771391461818645 w^2-8.7294781712090606955744375580646457919808677271394837773226`48.771391461818645 w^3+10.2068251315025880406638610943403576133102563905244990752056`48.771391461818645 w^4+4.53819346426478368708158531532363329640582320861153306793151283095918567682288`48.771391461818645 w^5)/((1+2.48909801676742114212905484376800484973812668408664873765670012361704392146198`49.52287874528033 w+1.84116448923854923049030888839477617187429567953918155194216981350249910718485`48.771391461818645 w^2) (1-1.61140892329556317530095920453034984320854658795334141465766939632162641686224`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 6.11943380401420524070226385881922152319940551506719886677793703521984074302835`48.87370461590162 w-30.1191267278991700867857932575699379402030217530315604275172`48.87370461590162 w^2-10.7731509947918345833273558685750824418897878896330219895592`48.87370461590162 w^3+12.0321995762825142149209739526666987902495584188491124953639`48.87370461590162 w^4+3.5321718181548280437543645084280806381186124241018470931788923801614913161846`48.87370461590162 w^5)/((1+2.61289781359252712487287029220347844268584661403450056172301839731512207746112`49.52287874528033 w+2.0804508322574245439591608927846771664440373742688596595178832504332954468851`48.87370461590162 w^2) (1-1.51962683630579652128057229532528724520443152108401540862234197922273700520339`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 10.688929901404982932691895681434791318119440382871646064833`48.57850193532218 w-35.6070344916212774707617925158966364840653615965451653698786`48.57850193532218 w^2-5.8460313369970303503794222843205234595889373536683201413578`48.57850193532218 w^3+7.8778380298212430452503605968282953272964492447947482922281`48.57850193532218 w^4+5.8834370453678425299927016215810078853189416157181193172459`48.57850193532218 w^5)/((1+2.34446421326832433755029870076857777243139486253992352177391126083695445043499`49.52287874528033 w+1.55832553443134168968191641052205513538970003780906861888663988726057867416398`48.57850193532218 w^2) (1-1.75270431123581881151494170698145352402242671321212858365096644588297756787752`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 11.0716009430106152705172523210822496549486261142419484089609`48.54463480125269 w-36.0812768176596167199377892552045221992523586412150163809085`48.54463480125269 w^2-5.4432850602605545698654419765182625721925536487132229684865`48.54463480125269 w^3+7.5731754013927227758780555665817143131340159895482051118077`48.54463480125269 w^4+6.0650966974814526323327497893886521262128595283778767786467`48.54463480125269 w^5)/((1+2.32675450251923935919952137856463610654002303937104708865033056176229646724915`49.52287874528033 w+1.52340886355184654694653697157986949283634365033229246362131638281437841308891`48.54463480125269 w^2) (1-1.77341585708468399787927810458249091799821639670699042566925663088211632021362`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 14.5404686431556258515558394218970795620493863552768040570301`48.04693628461581 w-40.4574178166393820193127104967152058510486116837283329530741`48.04693628461581 w^2-1.8435687563805045566336676937878815610316946988131963391551`48.04693628461581 w^3+5.0408538972431828582604210903958591835755494931014597721331`48.04693628461581 w^4+7.6308063125032867241740694878445168519808849646349715527394`48.04693628461581 w^5)/((1+2.19123187686748944273403327144191640191206754171965806393698940250678212795356`49.52287874528033 w+1.2537566317896983600415085501175670503212219076152815017082`48.04693628461581 w^2) (1-1.96741702038930195839317822311081441639529206367598533257850704472634859564419`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 13.0606189509903004747781452608161307614106350723599627192287`48.32077437913671 w-38.574902578573347877540437685422867851020632851835332020825`48.32077437913671 w^2-3.3689461410631479242146001053981125698761442432456000959812`48.32077437913671 w^3+6.0746594733003561423242469343277994660053859584614854450753`48.32077437913671 w^4+6.9792910497778938234221755892636837209937357696032944687358`48.32077437913671 w^5)/((1+2.24399270412833264565216710384354571576934779489545432742009741610633728311141`49.52287874528033 w+1.35928504970532067999235632626482141574640483579193281061891207767642142338849`48.32077437913671 w^2) (1-1.88339082406956437670665878011831269956217591130386934320122890449546321450246`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 8.2573061396105271819232837561479462913934582350850760935884`48.75491524900251 w-32.6426569410779681985902160265896792852421625694198616497562`48.75491524900251 w^2-8.4381537661566111401740056742319922121086595225764950309434`48.75491524900251 w^3+9.9589759030833758007677280381298233590197742963922915564508`48.75491524900251 w^4+4.6778900592034628372685735730222286079924721262655605501683`48.75491524900251 w^5)/((1+2.47296284768062076505693903794747251032635204240186258429748647586445734376475`49.52287874528033 w+1.80980000976503980932501708050511886139224560258253062488602638939563185251069`48.75491524900251 w^2) (1-1.62508726285969509534840830713324578338278031963688297696391560510969011543196`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 12.5016473301559611397301376608868374790715632476514795941709`48.394195921016525 w-37.8695708573244519907740984649629632640062947243400064722844`48.394195921016525 w^2-3.948884043841111861208251803874291927847223584035957326311`48.394195921016525 w^3+6.4822551144733169474485128413855777422341165096355611329188`48.394195921016525 w^4+6.7271546728503689205859265795177806458800574808726429877569`48.394195921016525 w^5)/((1+2.26577685562421567811225572428240788012172884488541194118987599848060009995554`49.52287874528033 w+1.40264410045121825388961632235025152268779149457740220386177122970314135756202`48.394195921016525 w^2) (1-1.85211609853106028799370963304289218560609857217819890882591156984418546391543`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 11.4425380851932940292473508347418838203430869019579378295834`48.50959775980555 w-36.5427719396269937952115355728026188978402374173914049699289`48.50959775980555 w^2-5.0540836972152719097540576795247361145948184158153371732846`48.50959775980555 w^3+7.2831747838319363374431939113686977287017835762527398470944`48.50959775980555 w^4+6.2393083619051749543266340582067484923913646836734522159409`48.50959775980555 w^5)/((1+2.31017013727438821622232736097339241691543237664081273675375245303026197628656`49.52287874528033 w+1.49064859579406254352795756941950427732127146495206683572435676276709591587031`48.50959775980555 w^2) (1-1.79363789920153040066469410108202822543550046160432062936800117836248402976637`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 32.9767482853434495929599524509272084011207428791215085230114`48.66576195302026 w-73.1884160992250376278360774591129201658053009731759433983993`48.66576195302026 w^2+14.8667784334450963122028936842258629965779791089346904584645`48.66576195302026 w^3+28.0508011558444060742749931747052942972982103432094752847644`48.66576195302026 w^4)/((1+2.03422072052772576278037869101343402130899810845459469324737567310980797959014`49.52287874528033 w+0.57688751433493429639366942207391568984164038603927389955455090539979778808202`48.66576195302026 w^2-0.69375427960727603125920896447922350019618641940318282584347863126589674583389`48.66576195302026 w^3) (1-3.13930668955027646667218806166260739461417586386049798888994151937982247723036`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 15.3756509144284536505831315986617648370841982841642363529653`47.397283334466856 w-44.2151579280543473648133451512353009852066740877416853910225`47.397283334466856 w^2+0.4775395741704416344366627137161045180496192384623653117396`47.397283334466856 w^3+19.4989073182096542050846373445176042343599193390169370762735`47.397283334466856 w^4)/((1+2.23151824637551811089339313209176804159083907390234697516533818410816675673071`49.52287874528033 w+1.051171109432904074850687524977230938274481152834486674658`47.397283334466856 w^2-0.611546880006964521297277326131421178344488335299442923515`47.397283334466856 w^3) (1-2.03235460139007153558809577652789168744865872307194903713115788803570800145939`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 13.6164178423581231892324900034184848887344010591345939476456`47.77990345881785 w-41.4222724839882932796896901167757944176071573210424593266129`47.77990345881785 w^2-1.0921709534720570392731420083327757065398218610237289530422`47.77990345881785 w^3+18.8113347179274657095200430411274656244270206112156696062381`47.77990345881785 w^4)/((1+2.27288719052132300805365991775128194768203127551744415305947683683143165559702`49.52287874528033 w+1.1477882295346127690633746778299095509174278660210269626891`47.77990345881785 w^2-0.589555596245611532651079879657205409014828032928080415432`47.77990345881785 w^3) (1-1.92712678159708499234417871851072987539373286818179995847082325836475061898031`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 19.5866491858144576963837684507611103745956549178700529849597`48.26470938518387 w-51.0264791998339010929897062938732632629489430032965208173494`48.26470938518387 w^2+4.0726750436336945430556153883377288036501305581925765059758`48.26470938518387 w^3+21.3473312168701319759266237515588013464592851311516510442579`48.26470938518387 w^4)/((1+2.15727059589067042358597108607835378351594838348918708414619023646503307786664`49.52287874528033 w+0.87558329558526614142663686550844773042163832997404504758415080912771629278656`48.26470938518387 w^2-0.64757649479539334755520813442492209686445729883089463656976238152469377267511`48.26470938518387 w^3) (1-2.29042761170662630290142808742522505605112663224493931517537757368002490310956`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 13.8814477448506835569241354203306646755350314949656844889952`47.668976230695755 w-41.8403448727947796698879413823760818070009187294507471090504`47.668976230695755 w^2-0.8522314882635326414875474850672546198881658046544039485452`47.668976230695755 w^3+18.9106450581936312967193188501943124602413425791313642434706`47.668976230695755 w^4)/((1+2.26615017922221894768696221401340121162902755745188390272507545241463081746968`49.52287874528033 w+1.1321073691860839637220159120239822598480386586332413114861`47.668976230695755 w^2-0.593217726645451422895942220675023219216381616048108535906`47.668976230695755 w^3) (1-1.94285325229371805250232041485516201314110729576379841598196487630251671227112`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 34.3427065272311371766334690224667537831554956119033726432845`48.68244760491775 w-75.4673294028167344067178882999499073707260409981280964110753`48.68244760491775 w^2+15.9454630156653440512643785958122655631890571438064746314076`48.68244760491775 w^3+28.7652536521015385926316558282714908314766313820445081807286`48.68244760491775 w^4)/((1+2.02655786131545952229002061045780928491417371155999069284733743184615336853806`49.52287874528033 w+0.55791088366279513237654681120583733811560565951060677879636963432011434429493`48.68244760491775 w^2-0.69589520826788057534462228199383064637264803063361442100367063122211630112128`48.68244760491775 w^3) (1-3.22712545779092660912669087104089762247395717044001910911222469406612444076179`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 32.3154672661611001529325367261550594032656861200304343557507`48.65700822665132 w-72.0858206925444421564231033800390074193460184643786548134482`48.65700822665132 w^2+14.3437699135539068896827022054456245374804206857069754598693`48.65700822665132 w^3+27.7060725038506057712598442086879954232136992881287061201974`48.65700822665132 w^4)/((1+2.03814041406995650794248101505347887454903673065366084815687191655736778435371`49.52287874528033 w+0.58657587854600154389641737190529880080876823770052637323217896935001005897023`48.65700822665132 w^2-0.69262020830058749838491035465100917249328436330307171382048305698592991637181`48.65700822665132 w^3) (1-3.0968447941574316350047082300963460460212985790319981399694324097487891059437`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 12.5686168553792114744130486267245935089258749792181601890918`48.06701884865793 w-39.780346218647869665195230765048404473077343387640705054426`48.06701884865793 w^2-2.0549414707377301483669377549786569528581806627289502804647`48.06701884865793 w^3+18.4360852624640907535825195943138663789807527684080477308717`48.06701884865793 w^4)/((1+2.3015381566062213521539891250067023681097274904678710591833995009248775171969`49.52287874528033 w+1.2142581199218837731728788479127518436044619727329275377999`48.06701884865793 w^2-0.57366022388169384211299382350338103123116644061363877684577002141672358935588`48.06701884865793 w^3) (1-1.86545588163794311535192545543228554679060776338475068205869669542931892076168`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 18.3429378830123272454221397883515954059571915072364827154696`48.15413701997573 w-49.0005800659927996894946156832279589094803527078919336314754`48.15413701997573 w^2+3.029014891448189976253777765337720283137729928437101463832`48.15413701997573 w^3+20.7784511346491674567743030352261744910486368801325428095869`48.15413701997573 w^4)/((1+2.17629212304728094469331194204652944626191856405973548708059151453178827935938`49.52287874528033 w+0.9208591951817106677925884667594377627323957201687549112976780449504626789562`48.15413701997573 w^2-0.63882306773616157776191046646341493993389078042481984821063109141241670252234`48.15413701997573 w^3) (1-2.21347933126790175026837528709839572562268362486420935801767701147320042384878`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 35.002167918734759965800046857546370503382795217537358703452`48.689899780614574 w-76.5681460325164115814630245343336155208766631776853137170279`48.689899780614574 w^2+16.465514010310540527441474936774048738716352456946430733878`48.689899780614574 w^3+29.1112200085711381953690778461898695254176399956054083765578`48.689899780614574 w^4)/((1+2.02305295143691500162948455190706719206963986797691519046472096461455615272707`49.52287874528033 w+0.54921504651527705374614073888978427637526803699671371970782370814385410242701`48.689899780614574 w^2-0.69684016947120799630677623603874434166714608145816610238051994315601836204406`48.689899780614574 w^3) (1-3.26957151151495912934476269958362487650403317268805296945063541717939107432491`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 37.6234916677313209998629342820895446204025648701032940458234`48.71626774133935 w-80.9470815024763038680793344103292445855581115127493382928108`48.71626774133935 w^2+18.5287948228885648690243573828821039398316055463472723204853`48.71626774133935 w^3+30.4921377847914541917376941592906135915367719190460826559469`48.71626774133935 w^4)/((1+2.01023204455725313402562815713445732172485530033664406580412109971747379309952`49.52287874528033 w+0.51731830966149962806123704883463426548568630275610948778037468298808295699564`48.71626774133935 w^2-0.70010744415470882704960442687522244042222366369941534564885889284475091676578`48.71626774133935 w^3) (1-3.43857003472912431431654303024002399324760292036264230865384780466921535985668`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 21.0155787630376966037078183876326240950194908994006176106805`48.3556814932827 w-53.3649821898291887136354777253250061071380847926792694964163`48.3556814932827 w^2+5.257893498527967013857064351230391616377461006175962834811`48.3556814932827 w^3+22.0187081529723248165399637110196632250823860331688629187574`48.3556814932827 w^4)/((1+2.13776633874712497865975264954734430629457106003725930884880674829457316678639`49.52287874528033 w+0.82893085657879658134190793292784478560924402419305574164947966618592465240525`48.3556814932827 w^2-0.65616554033389900845890249453067860941739412334523823151293793980481174335631`48.3556814932827 w^3) (1-2.3794228335156972421510154449482655588904138622124578796700110212524989133893`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 14.9081364786876727317131473949256234201366804074490060233975`46.54108668291741 w-43.4691004887452003920252441027778694739006990458631588732013`46.54108668291741 w^2+0.065362804889346570072648462864042896085945347056104387604`46.54108668291741 w^3+19.3100326486782298069431252510607160816937400315993342197214`46.54108668291741 w^4)/((1+2.24178024866756442362502767715152822974235730813841622519714524346613034043643`49.52287874528033 w+1.0752128008251172806671755411613064189112537731031726279`46.54108668291741 w^2-0.6062057845453086626177075815787285662244098547727541793441`46.54108668291741 w^3) (1-2.00420747479763035267735581546709981658487652330661155903265194642025320697462`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 12.2304067889342713470402755862651156666121020842835723201298`48.13320849918299 w-39.2544684930657402339054761514958368343877229935290717365244`48.13320849918299 w^2-2.3710324542638051247846858530146333659327106629476268818851`48.13320849918299 w^3+18.3214718795021454745546127684712834530234455771393832463122`48.13320849918299 w^4)/((1+2.31153366089652769730150033139020289617452860172301904195923746256808133529769`49.52287874528033 w+1.2373682873078032134326409745124314541264960179414967667741`48.13320849918299 w^2-0.56799918143139258142126637301189024688260924265607326493087603145812583531756`48.13320849918299 w^3) (1-1.84573657816304188305227072152352344828984485831961935646707349864187131447863`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 17.8951548163633278178185266376844894761694799027863673429599`48.10271763066692 w-48.2737081294117655223756066990821643279384183642595565738965`48.10271763066692 w^2+2.6500309978505611365709845984436066801987009790990175026799`48.10271763066692 w^3+20.5777391067363847607661292794876057135062305781815589819512`48.10271763066692 w^4)/((1+2.18367135354999924848398705420175530581199915178470052090455879796787620644597`49.52287874528033 w+0.9383670085822310227527458026216907863119736617851435343690287407436683410929`48.10271763066692 w^2-0.63533310331528963155001513374533894457404732643714221294731534681918122222342`48.10271763066692 w^3) (1-2.18590773305532588936617166837804924621758038172208362998542190453930494322024`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 21.0305570336029181758569564749336616473084702862310116238958`48.356495615151196 w-53.3895486302157681389642910836102616681996623374368552375673`48.356495615151196 w^2+5.2702487965047992424366527198777415761642671063539227410919`48.356495615151196 w^3+22.0258338490005200371061610175178945244431645867445760522277`48.356495615151196 w^4)/((1+2.13757379631685712459725081508149302022080985144532982148426670923528683787023`49.52287874528033 w+0.8284691233718575547755532303583761863495304813499853138692715127756776426739`48.356495615151196 w^2-0.65624827414824556583205400929244540566062850884628432858735074065938607498851`48.356495615151196 w^3) (1-2.38035867188686746220723117454865921890920578255695884770313514679662251621468`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 15.3898556898457408365875743084062432649534012863334371331991`47.40825491484232 w-44.2378652376598230997360990874663797840458742652117973356366`47.40825491484232 w^2+0.4900122174296209513286613975983130859570781919525177649261`47.40825491484232 w^3+19.5047091105445079409831735691136893864825299028878277220526`47.40825491484232 w^4)/((1+2.23121404603957562347363768992751586721484838463772221824585296607394031635472`49.52287874528033 w+1.0504576494331798836733698314123733376352415955621502775234`47.40825491484232 w^2-0.6117039965126627108792121477423782519599766366653940796322`47.40825491484232 w^3) (1-2.03321171173495879456556556115252430699935321878151201436026812178052633628461`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 17.8988971366634079830530587132344646404815266245159990715774`48.10318190964443 w-48.2797768726804696272504376788240876482379808004527326017715`48.10318190964443 w^2+2.6532060616003246825414565509831861749474790533891325196295`48.10318190964443 w^3+20.5794067488818903541163298203633310335435349524108306345971`48.10318190964443 w^4)/((1+2.18360843079090798703346250499662913829261333506798997452115991958876887054329`49.52287874528033 w+0.93821784976225995268291791219802733045766562637655049822129272365400824266177`48.10318190964443 w^2-0.63536307695248656770702713123423534240532752419187818000485716408219758691838`48.10318190964443 w^3) (1-2.18613784822468242792405723676983176622684648590471456458817772688714480419025`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 16.5629067968362016483428558197370655523600658094907237059325`47.878818792464 w-46.1203866790940889510258195710505067239103879085987648817951`47.878818792464 w^2+1.5106028430235232002152098556459620329024590830751038241332`47.878818792464 w^3+19.9955783755098077930191302943847055892698616268451836587579`47.878818792464 w^4)/((1+2.20752288694234722178566847791424482779395359200298175749600041284081160987575`49.52287874528033 w+0.9947502034654513346651705199861988221340555195567521070488126766186879173713`47.878818792464 w^2-0.6237161136256944143383984623371582916745464514518824479618264577712324211309`47.878818792464 w^3) (1-2.10435067351476955768954065670378611347011478126818390667349713979284958407683`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 16.9020180772045865666558309212355339526138093569678811584873`47.95032311453703 w-46.6670737284022569340334142416614201153955990179372709682719`47.95032311453703 w^2+1.802454938989588010014775809727067785474732912791315093097`47.95032311453703 w^3+20.141468498875680321763869331454818317420690760700621165944`47.95032311453703 w^4)/((1+2.20116458176419330634902183470612632814126955755209797096399625025194178259894`49.52287874528033 w+0.97974977976557825479767722446116132549125287953390274660299293319789284409808`47.95032311453703 w^2-0.62686155685204734511727588163874146458378856898122115171218872026027874045017`47.95032311453703 w^3) (1-2.12503848060209578149327517045275076302616780132183248983966936001172027015275`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 2.5666576977095613802176856599696248997800237918655995547863`47.82457049448109 w-10.7940176787962519673930394530313802825782003228195230237483`47.82457049448109 w^2+6.4830986066717466774525229381727980586540782502635185998194`47.82457049448109 w^3)/((1+1.80033525566312302159346862603084587590961755970303248253722012146307809153944`49.52287874528033 w+0.8338611437345604715119129078580933586905924589614811012819`47.82457049448109 w^2+0.05957448093304691268850238057004963813186380639251367044839794852529824762749`47.82457049448109 w^3+0.8147072705065271400814725475082647449739146572135327033811`47.82457049448109 w^4) (1-1.08309214604430830754567659564602421584048786692584924470588496918664842170389`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 7.2375974149556375551590152847421284373037452018689047908722`48.580213998374454 w-18.4345010316926898538458355761207478393820117013655515966405`48.580213998374454 w^2+10.3370268859818115747221442861701069835385065363037879432436`48.580213998374454 w^3)/((1+1.72128816377887639872720342691088523560180937554967943586815809382082106362757`49.52287874528033 w+0.44362008336050033540969646951214216083735126091057161422410253710649233112389`48.580213998374454 w^2-0.23160028675835384267040164541410987075394883654705292329012312571974876165937`48.580213998374454 w^3+0.49508110306968263847820813926297807005109153632873981417794023580515242340056`48.580213998374454 w^4) (1-1.37018042749087209397854070917225691589283138796802285925412084544881784306516`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 3.1491534921958767208316339865855770040406535743985556277239247887748695051148`48.9264963004095 w-1.35281519647551170738635670318700642411027823303268294770779929333454273646723`48.9264963004095 w^2+1.67124263002449866107479062349771679798768384966210938501029594884874391651893`48.9264963004095 w^3)/((1+1.20386359813188844895832009465715058265884440394402459679583252796390776228777`49.52287874528033 w-0.3887570242228984108483624583323106941624951805749922830423004615338187009869`48.9264963004095 w^2-1.43888117804982826469426542924524357376435480429610004861743925285753662685477`48.9264963004095 w^3+1.28400325011680137957850954375992041075829163488667069030463771769500021244778`48.9264963004095 w^4) (1-0.55848298560931759935445240572963092439358949553078892716448731814121400955879`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 1.8677688340052207366144412469482910650712097272046101676546`48.14073049665227 w-9.4068721003841132841905931049683970209820456102401199681701`48.14073049665227 w^2+6.2205234100496757485566849135251185456993585078426403448432`48.14073049665227 w^3)/((1+1.80237280537276723816059907420166292025340171917479155248425950652345778039921`49.52287874528033 w+0.90194100148994824748433817267040212799343382467001329391027676732464260599635`48.14073049665227 w^2+0.1396105407238987158286946799942807438770143665027534696238185945745150962663`48.14073049665227 w^3+0.92086636181373729441970008119484986311466161057021711600772442287370494823475`48.14073049665227 w^4) (1-1.03768912636705464787410738493550216661709575656059153024857224969315965136301`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 8.1659726807052918048934538796876587254536563194642966596178`48.617411277718816 w-19.8073923054343954232981410894397570691741525151888457975109`48.617411277718816 w^2+11.2943144000038415971826865310568389861991337685505747143769`48.617411277718816 w^3)/((1+1.70650139482280018587854149468678393059188956393257469419524529898890285049258`49.52287874528033 w+0.38772058805272742535650235799287659777639373467799750847316078647989189212365`48.617411277718816 w^2-0.26074292434355961038756423578720040987857079107828822411498717381297053827855`48.617411277718816 w^3+0.46541735247296781484490472735673674508574618617088157785028872405237859262584`48.617411277718816 w^4) (1-1.42747189139599091118688579074768978375238939169409160568275401308062077558878`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 11.1783893674007544972212900599871867166656194003932913402415`48.44247584983913 w-24.1323907108958120943237344885051724345803546301017757105352`48.44247584983913 w^2+14.5759233238507662268113970431950990861798645880950661551171`48.44247584983913 w^3)/((1+1.66650336429106696048969594235699270584292885000349729538231582209485782903383`49.52287874528033 w+0.24262201110322570241403345199188171254212670601717442500860632547951511925526`48.44247584983913 w^2-0.32525701806349285822135876784635977467291156304387010987254118371778529957952`48.44247584983913 w^3+0.39802598717280492584507378708946431225246341333272986667068098463684343730041`48.44247584983913 w^4) (1-1.61536837048027778170792641450973651713381832071811417657031155989688126192133`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 12.9498567747752266425131559859877469214845857906612939088853`48.31817993849777 w-26.6168771524494965969907506238286003513524330475231079070635`48.31817993849777 w^2+16.5863107564190891032309460545579638861955137868006043381025`48.31817993849777 w^3)/((1+1.64790477470759460197537899198811876936685160925104603929325354603733408057419`49.52287874528033 w+0.17693566189424198032289823238946655310484882673007290891429240672362287613646`48.31817993849777 w^2-0.34939887871113078898817491844782063078872175480458810645077763177743523856079`48.31817993849777 w^3+0.37119286418422008597430280061879684040225236136189611007638452386964219646545`48.31817993849777 w^4) (1-1.72709249437178377461676902607083950632407417485417015277857462265613564698828`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 13.5846807622002814817262594747813042506249328124297930615071`48.267819164009694 w-27.5001604709989703818265412336590354561945462342616096330259`48.267819164009694 w^2+17.3165522783862732682060584920525080588833717167166362261117`48.267819164009694 w^3)/((1+1.64196919689540599815013651400979278210547459269689417008846691348619697963637`49.52287874528033 w+0.15609988334102330150032979726015082990490533679824943483365124691098131852066`48.267819164009694 w^2-0.35641328571974728813428845724565982419851642212142719066420224844090399395718`48.267819164009694 w^3+0.36307788674347842490020153841388797887185831555778821447115285837014570055513`48.267819164009694 w^4) (1-1.76731236551600299995912943868678367346685490754716217264066137561647603384462`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 14.3721441016827345721059413060723279466129913485875724143399`48.199544608778254 w-28.5916249285408563562413758641450936764720655939482776903667`48.199544608778254 w^2+18.22824214141488721795901670534822316692992574719880725818`48.199544608778254 w^3)/((1+1.63507804825366664895330949299381799547937842018291095136770733269775764676045`49.52287874528033 w+0.13195961385138466181103673084962215314284629186143959352358645256892678459748`48.199544608778254 w^2-0.36415567337647607869286510695679266871098088416272533420545986202878155554725`48.199544608778254 w^3+0.35389446281895461638180083562939125580612615356864276193303745080798748908299`48.199544608778254 w^4) (1-1.81732074664273661385274849716723678895553179015164856120619651061250782335835`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 5.4696543808576931474677493608924019430263053023101241282967`48.36716839896612 w-15.7322168799543468626499444447643472293269017657391630304068`48.36716839896612 w^2+8.6309089471780105703513091914972795727424535793881133032067`48.36716839896612 w^3)/((1+1.75247930251927766742501462366403539393778194119593020942202461393453219966948`49.52287874528033 w+0.56895379820209128709293549174524075248752453131922641039931252609484678673793`48.36716839896612 w^2-0.15677771493289172590230824662201455266002819237388122006213206785458573994445`48.36716839896612 w^3+0.5715735255928091598642253321430344824388482721278713508160095557056135187366`48.36716839896612 w^4) (1-1.26183596906004905590320231628282519672867154327718546840342626535096137988865`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 3.36169826586084409766722242195479301655149429718014968690447187382096132451333`48.88594719301215 w-1.11572884194870488590758222775548131241668784679365566722082903870955082052761`48.88594719301215 w^2+1.34303061496820420036458129881526221711164894901553379427363293540787986308558`48.88594719301215 w^3)/((1+1.21992285375511119724039053676617805567623857307833778227474360883804132391755`49.52287874528033 w-0.36328911664009292768514237210571228377474056121884526576816788769494295679389`48.88594719301215 w^2-1.48021786319001352341712141283754833324886671964238780696908024462387524417453`48.88594719301215 w^3+1.27485935303960183072933330678795589225146720234724047105143702943193055743213`48.88594719301215 w^4) (1-0.54853500416486995510000435261949404000124047208419059951549231182535029985517`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 4.4309529902964113205975357934629830814382817419183636821013`47.884592499412044 w+0.22135494513582587718816907988606683010260553073288932746361639979066789018848`47.884592499412044 w^2-0.10816365029469173538659910489301181009192761162395907038074262347630358179481`47.884592499412044 w^3)/((1+1.31060286858218996682865934649986464783291377441181216745296958516016931893497`49.52287874528033 w-0.20371613369432763208895398878125163490856950260269014619495550512931868234211`47.884592499412044 w^2-1.6730680552741602211830575953762069067178159296721740651598`47.884592499412044 w^3+1.2596752122025788809173884540061724158308408007977609792119`47.884592499412044 w^4) (1-0.50096199677733231168413126057427546479967141108439177788941945140144277398553`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 5.1875861294499441536569786799004131617252532005049964421021`48.315281639522496 w-15.2865389849817841572924130108160702687391331069247934390709`48.315281639522496 w^2+8.3778876457070930539743832290597199789671196203812265974552`48.315281639522496 w^3)/((1+1.75771681885706287950955285734671434577105780232125720790078361909890125879641`49.52287874528033 w+0.59150658836336991250569244525112215917754855418895375453534268019121260708629`48.315281639522496 w^2-0.14179733673460517148327998740556535122559493307669726455556723738303516731191`48.315281639522496 w^3+0.58713232270404524764396581755413041759430714795214512719900929812043771119619`48.315281639522496 w^4) (1-1.24461531703011768779808186646314530671830825369540483770314758177617830702256`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 2.53953259783437094256444636016730538881106268913064349460206632851025908973009`49.01608186282566 w-1.97392661366871527552126939778489354170046745203423018488739061247961997832891`49.01608186282566 w^2+2.69318334037970842213317322368188277990920350483049524491320933992794015828646`49.01608186282566 w^3)/((1+1.16227821383501477315716976558363554992652591539638665677149359385095715272592`49.52287874528033 w-0.44665673211896040834177620871821932491019249495248482235466251897089886735568`49.01608186282566 w^2-1.30939152791372726782020312721209458400209165575380512442462378495073040525108`49.01608186282566 w^3+1.32306934280783219679135923021563511280542546405025171541972624767685925604158`49.01608186282566 w^4) (1-0.58813472748585503445091437556172256429128591695162558226958365791008799030003`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 16.9406593297821653576046982792852751977369434870094447257604`47.90006070697531 w-32.1260197446049856441636255912145319914230864961645037488243`47.90006070697531 w^2+21.2381046180297319150988360696992330907437805389701511874309`47.90006070697531 w^3)/((1+1.61571003111044470099251111618288905117380315524319718932278961413572721902539`49.52287874528033 w+0.06424686190466726016972438911092021973137427789718282932376040427957407734829`47.90006070697531 w^2-0.3836841271384215907053064985943643013186108611475561074067576499497993401018`47.90006070697531 w^3+0.32927919449525017319117787347962270113191631168982119061660140551629510961664`47.90006070697531 w^4) (1-1.98121331938536088649385410558433320441282826038239223276002643893617329560336`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 4.6611818524428373061990110048613524774830687612586724520875`48.369609533566624 w+0.5386976408758644580480749317202661955708180971663068901066922697392044355891`48.369609533566624 w^2-0.37983711113157555150303949637503856867446348721646174408784366894128055266942`48.369609533566624 w^3)/((1+1.3321103634805805234015593490941208651964479509860517373688660070665654305797`49.52287874528033 w-0.16356788499393023655404863568574577641408188936084224065368205893555014496109`48.369609533566624 w^2-1.71323832199508997109736550285138376275639551737555938446043803097118513050541`48.369609533566624 w^3+1.26268836677479086866873783232637956338955989533047331061841762315638486367883`48.369609533566624 w^4) (1-0.49121434671128882768565351010907802596972953059975903467788249773699891014628`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 16.3217827345863323341837334268257911159551366410849106260033`47.98801148609727 w-31.2774930943664598904414265753847479560428770060497929380397`47.98801148609727 w^2+20.5085390160348999888299705082568834655018833576357133167577`47.98801148609727 w^3)/((1+1.6199865046214672297161522843035760728003307982595047400333485708625748431195`49.52287874528033 w+0.07919364287247339342154063933040934800587482541900344395607016005695731806056`47.98801148609727 w^2-0.37964993486596868920947639787744901237129739660634942238503872690888672373709`47.98801148609727 w^3+0.33457659852402794708958220308589423655511328776770404070142726229224231175999`47.98801148609727 w^4) (1-1.9416263110714194587420002832193563705053268746888649738524388655862484196284`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 1.73349128601943753610403679750764029629492176718871861545988816090917716488112`48.17856414448063 w-9.1238556118541814241735410702158298828265718235025195149262`48.17856414448063 w^2+6.1910513205764092783892472179142693217278395608416505213158`48.17856414448063 w^3)/((1+1.80146535559101250439600763531302805194442626858768458556473763785016591799271`49.52287874528033 w+0.91418497416807945761412264171645041340149023595170337352550794289971395703234`48.17856414448063 w^2+0.15662781094161048457583898884643457226852133072759823354732795709928351554214`48.17856414448063 w^3+0.94528119872431368669212369439185422580270400979181224719044286905110170657478`48.17856414448063 w^4) (1-1.02864111113422874688118113072454157421878188194196610182698038757880403685927`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 4.4400243060834119791093143918244475178418456758519816569029`47.92403048772063 w+0.23366933102531805476437627461164910034405668606801237218670329402142937424493`47.92403048772063 w^2-0.11912939721654686791733903824449075655731762880261078497960876812453443369145`47.92403048772063 w^3)/((1+1.31143735358216006178289277368260764352172662465118796973697538752471101301275`49.52287874528033 w-0.20216924890914648858162132993527815754083088401656873182983868099957830986854`47.92403048772063 w^2-1.6746518843493721912750541575485141955930100151172959372455`47.92403048772063 w^3+1.2597533201683474270756245527514602128477264352768629156674`47.92403048772063 w^4) (1-0.50057469217270435420658737368198179819171348929822541226653332169724280810898`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.- 14.9635766571958640759366114147113218537862047833008137423654`48.142954584639405 w-29.4086750305205444029285169076414916237906899189606587157225`48.142954584639405 w^2+18.9167708349592451146265066092479654563511738157921045686981`48.142954584639405 w^3)/((1+1.63021947564493636726417690696780958735473825331352170786894998742484157208157`49.52287874528033 w+0.11496235198916460518935355875071144916608943981615418110820869329366811380865`48.142954584639405 w^2-0.36936041411664454607548386272697332076814368731149393459186092690082890395468`48.142954584639405 w^3+0.34756229489148748051643104670518918582270989218059445809194833066469094092931`48.142954584639405 w^4) (1-1.85495933706440926630985243808957370272407190107967294835592988520642434826296`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 6.9179324407696809198296110673603296756495575609429751945859`48.58616539113831 w+3.26312360483421774970731091293688701138245405909629456820659800136375232490623`48.58616539113831 w^2)/((1+1.94115087058879131161111613898004150809855827964453657780649526420280965413517`49.52287874528033 w+0.64650010357934331177266145342115218823186923061226673778028870496530924422401`48.58616539113831 w^2-1.80222813442491810372372635190242111199852540632565757255492750477615874068685`48.58616539113831 w^3+0.25297040403901436276716038479897571146290456469097336325311484569752301693314`48.58616539113831 w^4+0.77250798566625571975469121629715005404259789041683241024776585803154812150971`48.58616539113831 w^5) (1-0.49522078520409632384260182756237720287410091424496583308087524072774331271713`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 7.525870949925671287556932578840413554679719384121235834624`48.35909528149776 w+4.3180677295764021103255266601198368004057189801358487329436`48.35909528149776 w^2)/((1+2.04967026238797773923329962185842260561784061346535167892846255439317188694689`49.52287874528033 w+0.83938188344280686574611659285273111682097254844580386061913755249097641982979`48.35909528149776 w^2-1.82733865504746403073167428037463828689595695423158381740132217046995307872758`48.35909528149776 w^3+0.15136147526114495306986643597109581862218250950955177050069647366375163070585`48.35909528149776 w^4+0.86550821911976986708737018819227284903815484970382709682493500331745906717476`48.35909528149776 w^5) (1-0.4824130668589738554959878909584633173176334947176577551106099442974894099507`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 6.9288977627832690013601211965732343281233569690181339334638`48.5808572311143 w+3.27958457950288590646176452941397514502658315616642744951481825864337233800523`48.5808572311143 w^2)/((1+1.9434606026171951316609850798470295778998631635242674369389299705331539548976`49.52287874528033 w+0.65008080886415535551812731868368134536686255302945534199791901328694648467872`48.5808572311143 w^2-1.80272743979828437325220670638785042630965484521249827355965693153865973944758`48.5808572311143 w^3+0.24999625245999059430537373365915088488890122503598956794962234779093758085118`48.5808572311143 w^4+0.77492646658368795345286393213490745247520751938248274137851476356457660697307`48.5808572311143 w^5) (1-0.4950778685898666749589041637797363234465862981880667220062034441232763469842`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 6.8442045699932256210378872925714268628125292634636567396585`48.62169207277041 w+3.15425067411894718125462198379476860310485624272363839982765329882568475202346`48.62169207277041 w^2)/((1+1.92537373932102736013184163937771629619532103749903153368568783556588136939355`49.52287874528033 w+0.62235844867969642767425717094395376477135254613041204902130280019239833069779`48.62169207277041 w^2-1.79881531976945647896625847980925408492259083998789629766056246479699491993265`48.62169207277041 w^3+0.27376147899291184876296444300241613653080988998083023557791990495620319349868`48.62169207277041 w^4+0.75572408904971644237490194125922489026472521820877013112601472463530377822161`48.62169207277041 w^5) (1-0.49611993915349181545545118786690630366130806120723336234814718823196009390048`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 7.3309380539499118490970272771395764237595070514480752197328`48.40425131621487 w+3.9442281170757215606967476305071176189387033021956536773837`48.40425131621487 w^2)/((1+2.01976571584262809843019422271056392698894031307852795895710675580207987731205`49.52287874528033 w+0.7790140916472874873266754981872167806957360267594398865130942505499706760062`48.40425131621487 w^2-1.81962670038314999513899764298487896287205492261501557632276109169312029067898`48.40425131621487 w^3+0.16799700132694970602499052345230232403591687008476567428821877119864505438791`48.40425131621487 w^4+0.84594271263421780155679546659959347952023325279362643217009042478221668189998`48.40425131621487 w^5) (1-0.48774274090717538650790605004235656137049536118342225984217018570050131661867`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 7.5285367310629527078306888645182836947850271450626314098834`48.35877958121803 w+4.3234283976999785916046232625035056288189839950544895962924`48.35877958121803 w^2)/((1+2.05004503060991601381474372561394539745411036765300214180376485337791543936516`49.52287874528033 w+0.84019616554897780976134444579551538302879833554738988165468223330902312025153`48.35877958121803 w^2-1.82744640876028343822214094553597010877778659323057653428884468886941501883769`48.35877958121803 w^3+0.15124717252693267430320123734636190648406259671492053625294744869773172956392`48.35877958121803 w^4+0.86570445374574046068060256077963695870688977599965628224323860051445733804932`48.35877958121803 w^5) (1-0.48233163460616986368540872294770291118219166429761953619779315717137875396323`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 6.01034208840661547126865470598096688925624676451743079277173295949068736836677`48.85573913347869 w+2.05837908121609385688640361247882426562561848712060111846128007091830774282314`48.85573913347869 w^2)/((1+1.7284466259111753152645506511970936493591302709461600316169205609805367265791`49.52287874528033 w+0.34459686028849061326680513829112497757297505034085960287557427933807037018529`48.85573913347869 w^2-1.75523678530235488264007153586938923010874237195085483654000440896414739068543`48.85573913347869 w^3+0.56810729345831007604462301160730546123838948204906694105924012170211967891793`48.85573913347869 w^4+0.5266430311075396667246802251243276324866741322975064397398194381011286345471`48.85573913347869 w^5) (1-0.50166744791255793816507437716710932634646870891584980364636342305147587639066`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 7.523001912192244910414075054443213863986737656370852862739`48.359444739411146 w+4.3123056455563261638272826105845994036185777591426525020543`48.359444739411146 w^2)/((1+2.04926591214892853646030471534359641319036505977504575827108969954698062721834`49.52287874528033 w+0.83850517136059334357161402875806153519336229370257784446264446171548053388374`48.359444739411146 w^2-1.82722281763292414872038878431744175435014913853100129718679359152100588331627`48.359444739411146 w^3+0.15148785568163142789392328732630254124070479992013514583155886810731765199858`48.359444739411146 w^4+0.86529492320947206031807865418332715360243820061294855786066402425128447045312`48.359444739411146 w^5) (1-0.48250045623060452848365681191789397516869771249766351231692491908180107566926`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 7.1844731877037814948164340108412396001668666557088643921397`48.46097179969584 w+3.6867721477148540815986217709018015340693512091023989653903`48.46097179969584 w^2)/((1+1.99407159755471692476789883852720709841132764057037738991908809850996816852938`49.52287874528033 w+0.73265012879526554338019969781028861412145125105021851615040072647745753550464`48.46097179969584 w^2-1.81375342421476364925257099842886553953486507985890275625490194051313284311537`48.46097179969584 w^3+0.19105821788114031038721151162902150568709935891138472641576985073972939163826`48.46097179969584 w^4+0.82449518252426317380080254352163053846880756685160052091032237315827799077074`48.46097179969584 w^5) (1-0.4909409908696149156363127835343642988416671095648037331306529808475018149387`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 7.3520164620309336613489668167334008990728698493305911649786`48.397450785531014 w+3.9829099306839195879646392124094242634194964205769465620824`48.397450785531014 w^2)/((1+2.02323921545563604585100647969547400171543571030520100714140933731260283634402`49.52287874528033 w+0.78561847794137788257903004348905682266859445823156780249261142929663859504441`48.397450785531014 w^2-1.82045704956410921686912542016642321553770402474194845156168121409344495768499`48.397450785531014 w^3+0.16540906822829967490157980567400037011452747401328209146993296711626588700019`48.397450785531014 w^4+0.84855948131027966727815243748980648512863188467122243122216442057835241495996`48.397450785531014 w^5) (1-0.48722640287079820321517148030066860357167931865839143071381361606582997847218`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 7.5775640323498994297275252338867290747433493764128463269929`48.35452605077722 w+4.4231723550420260211336176977706587563677693066949645323886`48.35452605077722 w^2)/((1+2.05677868958465115811779521646297179975586685321115118509575658774857616340761`49.52287874528033 w+0.85511712295956643033849424495775091678407646992157291096760088852985730504952`48.35452605077722 w^2-1.82945233504882465707829275764817524045894655242527040802615366033764287192758`48.35452605077722 w^3+0.14967674937931802142632711191747455339795102756061585150941473990011278325366`48.35452605077722 w^4+0.86898253280006397364220967892028719866982207473848543602206831816951889548531`48.35452605077722 w^5) (1-0.48079427773246298919860570278174047219832494567144747422251418669620905535941`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 5.6114205770915563381609881346713187570949437469331088201745`48.67821459731165 w+1.57709647861166115917753910768557194301287881478693519460960693101457386947159`48.67821459731165 w^2)/((1+1.6283883248647879723721109692736916531640947853052703912189870461862232948438`49.52287874528033 w+0.21029588027990030284040850490648129427916049349020529175156490692513313536688`48.67821459731165 w^2-1.73254575308443692616317065456070581909652972344351828558457400554361399017063`48.67821459731165 w^3+0.72759711803775148292580032745111088176394460978003683414685962859255339104512`48.67821459731165 w^4+0.40457660591685812338761146865510770217413819028366813584172536113025987502439`48.67821459731165 w^5) (1-0.50285939529209637395998634823214812065137207953671389847153685334743814235968`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 7.3890269291054815218131459322975584840392670587725800362009`48.38653338494861 w+4.0518502810199139246587755109133543231181332214375616646104`48.38653338494861 w^2)/((1+2.02919759746606104605563048837192826757009599001897274771967586928121986281698`49.52287874528033 w+0.79717082883503635061992428787132781381873050833859989586325211269211274345846`48.38653338494861 w^2-1.82191189788967297156036211745333598881737797529922385070103747819436789408939`48.38653338494861 w^3+0.161325387217370847479477870160955900801911989609822201421500857400351231255`48.38653338494861 w^4+0.85286017801173873414072459930670507080815569214939223586918934516632139581417`48.38653338494861 w^5) (1-0.48628465382106189308984856246921707321273435293006343020160773295415408963103`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 7.6728983403177792400419003537083330269201928827313601339454`48.35459920257878 w+4.6231481707249337560253378530632987257224911074204234971946`48.35459920257878 w^2)/((1+2.06904449491558314086900238777731873510677326908494337071851420843149679333863`49.52287874528033 w+0.88383708998517559418051756817519606531732758665345812547329991979694786324761`48.35459920257878 w^2-1.83353059841361682192005833442068290733586433341531893206075786658780950527171`48.35459920257878 w^3+0.14941913333481743391205627310237036499556009394485072472302779888084263324359`48.35459920257878 w^4+0.87363219373416862481868800253968650925464153438494913115204354767681077814413`48.35459920257878 w^5) (1-0.47759789131548125282195949503810504859377715871386611227506435912880843743483`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 7.2642823486065455380647579931023581193531827172522665562566`48.42822569129272 w+3.8246449507152458662068552945634543064716293184179301447056`48.42822569129272 w^2)/((1+2.00840460546673993579762591091425800393379702088796331594871621351896660560865`49.52287874528033 w+0.75801355730912492840683332618400551050103259550338204947830602726964113493327`48.42822569129272 w^2-1.81698179918662650568985600193262824996554087523464251811281706306050114908509`48.42822569129272 w^3+0.1774114084417683174733218522065693048733130488587792412592162566587345692333`48.42822569129272 w^4+0.83687856298971008047328713453821152978206140712716353092351767290739191688484`48.42822569129272 w^5) (1-0.48928130527006682613655538491324332688157756009025103695612427005118938249888`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 6.8076875778200050979461220997865285367082350411534417632963`48.63910534461799 w+3.1014147210398354535699017033535602968684551424870144277489137708372301306775`48.63910534461799 w^2)/((1+1.91741061493929700223443390387233892697879614082210620519249353708714967263322`49.52287874528033 w+0.61036187709645399158729172976753127943127870640610563716115766941469827271347`48.63910534461799 w^2-1.79709003513667525071860944628746411019159927016157158794094090764733459591394`48.63910534461799 w^3+0.28453675224230931392349670364668523446102776666087258846776758421290010304611`48.63910534461799 w^4+0.74709614087521326521431180768238001830861090353095345632270636941309457954178`48.63910534461799 w^5) (1-0.49652808455119050122070426665526331124723996113137281950716020392392288122324`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 6.42182551276022162941088780552525914647990960268208548455139271214098191243749`48.80897940077134 w+2.57641127391840704980706267302592572928921600482134049173256852775348847873691`48.80897940077134 w^2)/((1+1.82872198491939420469015770977902477146969723275195025750250304220032468102636`49.52287874528033 w+0.48243151145758954094684500614128885536147855554065464382989985699728403136534`48.80897940077134 w^2-1.77765879057786126865391283121489414458706336352741556935772522310608341444541`48.80897940077134 w^3+0.4129530388068362031652894427110012695386670386379742753752543902510388680631`48.80897940077134 w^4+0.64628222066364086006028833191263576674062133501277617946752334992257280545345`48.80897940077134 w^5) (1-0.49970452986036116108147542724398896588861435050976784162894038183976850285358`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 7.3805103580091335715887585809261341953059666118491894791752`48.38892526619281 w+4.0358706263439502627903031191810765205073454144376720321233`48.38892526619281 w^2)/((1+2.02784241784489868093715809118934365331589591495251006476895498343050096910914`49.52287874528033 w+0.79451750425508864460121921209446300838656331694990487295679940593982695832193`48.38892526619281 w^2-1.8215772781245471696870439873402451862952785720122779075872312537758292874193`48.38892526619281 w^3+0.16221288431599652331179314164647454850298071467040695604189354457369805931`48.38892526619281 w^4+0.85190381158868957759980559458752569555374145450729351247492983898353605601029`48.38892526619281 w^5) (1-0.48650534168852408686146758844614623788713837812192443806202008841917674982826`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 5.9313746239715979855567463363367425926760488436474817318873964807549850812007`48.827950079326534 w+1.96187588980391646487527993283714431537707070600981935690320062821532385252886`48.827950079326534 w^2)/((1+1.70880709357267133907644764713587674744307396746972866800589341614587791105027`49.52287874528033 w+0.31805069086510172901289319951770900860560200865365009851113221455572379425178`48.827950079326534 w^2-1.75080324785628503890414063468377775976427591593103759683099569681133099494012`48.827950079326534 w^3+0.59914555499040310840928993070618223944537218289497807505175782302474194631647`48.827950079326534 w^4+0.50283774540454860322982560898466997956810524150775791413397258579157071101898`48.827950079326534 w^5) (1-0.50194520847694769135459735116492932473038734317688406495161258871439305670311`50. z)),(3.80555555555555555555555555555555555555555555555555555555555555555555555555555`50.+ 2.98786445721995082140818322665347276419677109532052754416594043332546409469803`49.17658874150004 w-1.43848106920744232844602707855049727641453458603607219770568030728216012381789`49.17658874150004 w^2)/((1+0.95004245190289940366110876641957603069824383207731930463604472291971596248432`49.52287874528033 w-0.67755629486530783850165985097067941946085722895768175798231581698216864288551`49.17658874150004 w^2-1.57576400419399338072939865598843008083756299585056257429487871253876876111664`49.17658874150004 w^3+1.84111374569921893550932396316591968110483568480452340526529196000862480329491`49.17658874150004 w^4-0.4418790504514084066687850835867517138744468502048142977462575334414036099592`49.17658874150004 w^5) (1-0.50562332908698517813825947760738282040778199717507820934630386345208668844175`50. z))} /. {w->w[z+10^(-10)*I],pi1->pi1full[z]};
